@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {ARGUMENT_GROUP}.make */
-void F31_247 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
+void F27_238 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
@@ -38,57 +37,44 @@ void F31_247 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
 	RTLI(6);
 	RTLR(0,loc1);
 	RTLR(1,Current);
-	RTLR(2,tr1);
-	RTLR(3,loc3);
-	RTLR(4,arg1);
-	RTLR(5,loc4);
+	RTLR(2,loc3);
+	RTLR(3,arg1);
+	RTLR(4,loc4);
+	RTLR(5,tr1);
 	RTLIU(6);
 	
-	RTEAA("make", 30, Current, 4, 2, 282);
 	RTGC;
-	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,931,0xFF01,998,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {928,1019,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
-		tr1 = RTLNSMART(typres0.id);
+		loc1 = RTLNSMART(typres0.id);
 	}
-	F920_6832(RTCW(tr1), ((EIF_INTEGER_32) 5L));
-	loc1 = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
-	loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5183[Dtype(arg1)-497])(RTCW(arg1));
+	F917_6991(RTCW(loc1), ((EIF_INTEGER_32) 5L));
+	loc3 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5307[Dtype(RTCW(arg1))-476])(arg1);
 	for (;;) {
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5151[Dtype(loc3)-469])(loc3);
+		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5040[Dtype(loc3)-436])(loc3);
 		if (tb1) break;
-		RTHOOK(3);
-		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5150[Dtype(loc3)-469])(loc3);
+		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5039[Dtype(loc3)-436])(loc3);
 		loc4 = tr1;
-		if ((EIF_TRUE)) {
-			RTHOOK(4);
-			F932_6899(RTCW(loc1), loc4);
+		if (EIF_TEST(loc4)) {
+			F929_7059(RTCW(loc1), loc4);
 		}
-		RTHOOK(5);
-		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5152[Dtype(loc3)-469])(loc3);
+		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5041[Dtype(loc3)-436])(loc3);
 	}
-	RTHOOK(6);
 	RTAR(Current, loc1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
-	RTHOOK(7);
 	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_1_) = (EIF_BOOLEAN) arg2;
-	RTHOOK(8);
 	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
-	RTHOOK(11);
 	RTLE;
-	RTEE;
 }
 
 /* {ARGUMENT_GROUP}.make_hidden */
-void F31_248 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
+void F27_239 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	RTLD;
 	
@@ -97,24 +83,12 @@ void F31_248 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_BOOLEAN arg2)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("make_hidden", 30, Current, 1, 2, 277);
 	RTGC;
-	RTHOOK(1);
-	F31_247(Current, arg1, arg2);
-	RTHOOK(2);
+	F27_238(Current, arg1, arg2);
 	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-	RTHOOK(5);
 	RTLE;
-	RTEE;
 }
 
-/* {ARGUMENT_GROUP}.switches */
-EIF_REFERENCE F31_249 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 void EIF_Minit27 (void)
 {
 	GTCX
