@@ -6,8 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F51_1765(EIF_REFERENCE, EIF_INTEGER_32);
+extern EIF_REFERENCE F53_999(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit39(void);
+extern void F386_5694(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
