@@ -1,5 +1,5 @@
 /*
- * Code for class reference BYTE_CODE_CONSTANTS
+ * Code for class BYTE_CODE_CONSTANTS
  */
 
 #include "eif_eiffel.h"
@@ -23,25 +23,15 @@ extern "C" {
 #endif
 
 /* {BYTE_CODE_CONSTANTS}.extract_max */
-EIF_NATURAL_32 F33_464 (EIF_REFERENCE Current)
+EIF_NATURAL_32 F40_705 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_NATURAL_32 Result = ((EIF_NATURAL_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("extract_max", 32, Current, 0, 0, 555);
 	RTGC;
-	RTHOOK(1);
 	Result = (EIF_NATURAL_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (((EIF_INTEGER_32) 2147483647L) - ((EIF_INTEGER_32) 1L)) - ((EIF_INTEGER_32) 70L));
-	RTHOOK(2);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
