@@ -15,8 +15,8 @@
 extern "C" {
 #endif
 
-#ifndef INLINE_F48_1215
-static void inline_F48_1215 (EIF_POINTER arg1)
+#ifndef INLINE_F49_1137
+static void inline_F49_1137 (EIF_POINTER arg1)
 {
 	#ifdef EIF_WINDOWS
     			static const uint64_t EPOCH = ((uint64_t) 116444736000000000ULL);
@@ -38,31 +38,31 @@ static void inline_F48_1215 (EIF_POINTER arg1)
 			#endif
 	;
 }
-#define INLINE_F48_1215
+#define INLINE_F49_1137
 #endif
-#ifndef INLINE_F48_1219
-static void inline_F48_1219 (EIF_POINTER arg1, EIF_POINTER arg2)
+#ifndef INLINE_F49_1141
+static void inline_F49_1141 (EIF_POINTER arg1, EIF_POINTER arg2)
 {
 	*(time_t *) arg2 = (((struct timeval *)arg1)->tv_sec);
 	;
 }
-#define INLINE_F48_1219
+#define INLINE_F49_1141
 #endif
-#ifndef INLINE_F48_1223
-static EIF_POINTER inline_F48_1223 (EIF_POINTER arg1)
+#ifndef INLINE_F49_1145
+static EIF_POINTER inline_F49_1145 (EIF_POINTER arg1)
 {
 	return (EIF_POINTER) (gmtime ((time_t *) arg1))
 	;
 }
-#define INLINE_F48_1223
+#define INLINE_F49_1145
 #endif
-#ifndef INLINE_F48_1222
-static EIF_POINTER inline_F48_1222 (EIF_POINTER arg1)
+#ifndef INLINE_F49_1144
+static EIF_POINTER inline_F49_1144 (EIF_POINTER arg1)
 {
 	return (EIF_POINTER) (localtime ((time_t *) arg1))
 	;
 }
-#define INLINE_F48_1222
+#define INLINE_F49_1144
 #endif
 
 #ifdef __cplusplus
@@ -75,32 +75,25 @@ extern "C" {
 #endif
 
 /* {C_DATE}.default_create */
-void F48_1203 (EIF_REFERENCE Current)
+void F49_1125 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	RTLD;
 	
 	RTLI(1);
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("default_create", 47, Current, 0, 0, 1328);
 	RTGC;
-	RTHOOK(1);
 	*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
-	RTHOOK(2);
-	F48_1206(Current);
-	RTHOOK(3);
+	F49_1128(Current);
 	RTLE;
-	RTEE;
 }
 
 /* {C_DATE}.update */
-void F48_1206 (EIF_REFERENCE Current)
+void F49_1128 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER loc1 = (EIF_POINTER) 0;
 	EIF_POINTER loc2 = (EIF_POINTER) 0;
 	EIF_POINTER loc3 = (EIF_POINTER) 0;
@@ -115,58 +108,40 @@ void F48_1206 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("update", 47, Current, 4, 0, 1331);
 	RTGC;
-	RTHOOK(1);
 	ti4_1 = (EIF_INTEGER_32) sizeof(struct timeval);
 	tp1 = malloc((size_t)ti4_1);
 	loc1 = (EIF_POINTER) tp1;
-	RTHOOK(2);
 	ti4_1 = (EIF_INTEGER_32) sizeof(time_t);
 	tp1 = malloc((size_t)ti4_1);
 	loc3 = (EIF_POINTER) tp1;
-	RTHOOK(3);
-	inline_F48_1215(loc1);
-	RTHOOK(4);
-	inline_F48_1219(loc1, loc3);
-	RTHOOK(5);
+	inline_F49_1137(loc1);
+	inline_F49_1141(loc1, loc3);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
-		RTHOOK(6);
-		loc2 = inline_F48_1223(loc3);
+		loc2 = inline_F49_1145(loc3);
 	} else {
-		RTHOOK(7);
-		loc2 = inline_F48_1222(loc3);
+		loc2 = inline_F49_1144(loc3);
 	}
-	RTHOOK(8);
-	tr1 = RTLNSMART(eif_new_type(1081, 0).id);
+	tr1 = RTLNSMART(eif_new_type(560, 1).id);
 	ti4_1 = (EIF_INTEGER_32) sizeof(struct tm);
-	F1082_9124(RTCW(tr1), loc2, ti4_1);
+	F561_6802(RTCW(tr1), loc2, ti4_1);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(9);
 	loc4 = (EIF_INTEGER_32) (((struct timeval *)loc1)->tv_usec);
-	RTHOOK(10);
 	if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc4 < ((EIF_INTEGER_32) 0L)) || (EIF_BOOLEAN) (loc4 > ((EIF_INTEGER_32) 999999L)))) {
-		RTHOOK(11);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(12);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc4;
 	}
-	RTHOOK(13);
 	free(loc3);
-	RTHOOK(14);
 	free(loc1);
-	RTHOOK(15);
 	RTLE;
-	RTEE;
 }
 
 /* {C_DATE}.year_now */
-EIF_INTEGER_32 F48_1207 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1129 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -178,24 +153,19 @@ EIF_INTEGER_32 F48_1207 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("year_now", 47, Current, 0, 0, 1305);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tp1 = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_0_1_0_1_0_0_);
 	Result = (EIF_INTEGER_32) (((struct tm *)tp1)->tm_year);
 	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (((EIF_INTEGER_32) 1900L) + Result);
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.month_now */
-EIF_INTEGER_32 F48_1208 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1130 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -207,24 +177,19 @@ EIF_INTEGER_32 F48_1208 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("month_now", 47, Current, 0, 0, 1306);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tp1 = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_0_1_0_1_0_0_);
 	Result = (EIF_INTEGER_32) (((struct tm *)tp1)->tm_mon);
 	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result + ((EIF_INTEGER_32) 1L));
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.day_now */
-EIF_INTEGER_32 F48_1209 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1131 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -236,23 +201,18 @@ EIF_INTEGER_32 F48_1209 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("day_now", 47, Current, 0, 0, 1307);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tp1 = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_0_1_0_1_0_0_);
 	Result = (EIF_INTEGER_32) (((struct tm *)tp1)->tm_mday);
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.hour_now */
-EIF_INTEGER_32 F48_1210 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1132 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -264,23 +224,18 @@ EIF_INTEGER_32 F48_1210 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("hour_now", 47, Current, 0, 0, 1308);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tp1 = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_0_1_0_1_0_0_);
 	Result = (EIF_INTEGER_32) (((struct tm *)tp1)->tm_hour);
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.minute_now */
-EIF_INTEGER_32 F48_1211 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1133 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -292,23 +247,18 @@ EIF_INTEGER_32 F48_1211 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("minute_now", 47, Current, 0, 0, 1309);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tp1 = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_0_1_0_1_0_0_);
 	Result = (EIF_INTEGER_32) (((struct tm *)tp1)->tm_min);
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.second_now */
-EIF_INTEGER_32 F48_1212 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1134 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -320,325 +270,186 @@ EIF_INTEGER_32 F48_1212 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("second_now", 47, Current, 0, 0, 1310);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tp1 = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_0_1_0_1_0_0_);
 	Result = (EIF_INTEGER_32) (((struct tm *)tp1)->tm_sec);
-	RTHOOK(2);
 	if ((EIF_BOOLEAN) (Result > ((EIF_INTEGER_32) 59L))) {
-		RTHOOK(3);
-		RTHOOK(4);
 		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 59L);
 	}
-	RTHOOK(6);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.millisecond_now */
-EIF_INTEGER_32 F48_1213 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1135 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("millisecond_now", 47, Current, 0, 0, 1311);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
 	return (EIF_INTEGER_32) (EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) / ((EIF_INTEGER_32) 1000L));
 }
 
 /* {C_DATE}.gettimeofday */
-void F48_1215 (EIF_REFERENCE Current, EIF_POINTER arg1)
+void F49_1137 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("gettimeofday", 47, Current, 0, 1, 1313);
-	inline_F48_1215 ((EIF_POINTER) arg1);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
+	inline_F49_1137 ((EIF_POINTER) arg1);
 }
 
 /* {C_DATE}.timeval_structure_size */
-EIF_INTEGER_32 F48_1216 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1138 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("timeval_structure_size", 47, Current, 0, 0, 1314);
 	Result = (EIF_INTEGER_32) sizeof(struct timeval);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.time_t_structure_size */
-EIF_INTEGER_32 F48_1217 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1139 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("time_t_structure_size", 47, Current, 0, 0, 1315);
 	Result = (EIF_INTEGER_32) sizeof(time_t);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.tm_structure_size */
-EIF_INTEGER_32 F48_1218 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F49_1140 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("tm_structure_size", 47, Current, 0, 0, 1316);
 	Result = (EIF_INTEGER_32) sizeof(struct tm);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.get_time */
-void F48_1219 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2)
+void F49_1141 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("get_time", 47, Current, 0, 2, 1317);
-	inline_F48_1219 ((EIF_POINTER) arg1, (EIF_POINTER) arg2);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
+	inline_F49_1141 ((EIF_POINTER) arg1, (EIF_POINTER) arg2);
 }
 
 /* {C_DATE}.get_micro */
-EIF_INTEGER_32 F48_1220 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1142 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct timeval *)arg1)->tv_usec);
 	
-	RTEAA("get_micro", 47, Current, 0, 1, 1318);Result = (EIF_INTEGER_32) (((struct timeval *)arg1)->tv_usec);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.localtime */
-EIF_POINTER F48_1222 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_POINTER F49_1144 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER Result = ((EIF_POINTER) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("localtime", 47, Current, 0, 1, 1320);
-	Result = inline_F48_1222 ((EIF_POINTER) arg1);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
+	Result = inline_F49_1144 ((EIF_POINTER) arg1);
 	return Result;
 }
 
 /* {C_DATE}.gmtime */
-EIF_POINTER F48_1223 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_POINTER F49_1145 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER Result = ((EIF_POINTER) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("gmtime", 47, Current, 0, 1, 1321);
-	Result = inline_F48_1223 ((EIF_POINTER) arg1);
-	RTHOOK(1);
-	RTLE;
-	RTEE;
+	Result = inline_F49_1145 ((EIF_POINTER) arg1);
 	return Result;
 }
 
 /* {C_DATE}.get_tm_year */
-EIF_INTEGER_32 F48_1224 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1146 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_year);
 	
-	RTEAA("get_tm_year", 47, Current, 0, 1, 1322);Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_year);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.get_tm_mon */
-EIF_INTEGER_32 F48_1225 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1147 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_mon);
 	
-	RTEAA("get_tm_mon", 47, Current, 0, 1, 1323);Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_mon);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.get_tm_mday */
-EIF_INTEGER_32 F48_1226 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1148 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_mday);
 	
-	RTEAA("get_tm_mday", 47, Current, 0, 1, 1324);Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_mday);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.get_tm_hour */
-EIF_INTEGER_32 F48_1227 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1149 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_hour);
 	
-	RTEAA("get_tm_hour", 47, Current, 0, 1, 1325);Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_hour);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.get_tm_min */
-EIF_INTEGER_32 F48_1228 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1150 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_min);
 	
-	RTEAA("get_tm_min", 47, Current, 0, 1, 1326);Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_min);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {C_DATE}.get_tm_sec */
-EIF_INTEGER_32 F48_1229 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_INTEGER_32 F49_1151 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_sec);
 	
-	RTEAA("get_tm_sec", 47, Current, 0, 1, 1327);Result = (EIF_INTEGER_32) (((struct tm *)arg1)->tm_sec);
-	
-	RTHOOK(1);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
