@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {CLICK_AST}.initialize */
-void F37_475 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+void F43_591 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	RTEX;
@@ -36,37 +36,30 @@ void F37_475 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	RTLR(2,arg1);
 	RTLIU(3);
 	
-	RTEAA("initialize", 36, Current, 0, 2, 567);
+	RTEAA("initialize", 42, Current, 0, 2, 570);
 	RTGC;
 	RTHOOK(1);
 	RTAR(Current, arg2);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
 	RTHOOK(2);
-	ti4_1 = F1342_15728(RTCW(arg1));
+	ti4_1 = F2317_29410(RTCW(arg1));
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_INTEGER_32) ti4_1;
 	RTHOOK(3);
-	ti4_1 = F1342_15729(RTCW(arg1));
+	ti4_1 = F2317_29411(RTCW(arg1));
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ti4_1;
 	RTHOOK(4);
-	ti4_1 = F1342_15730(RTCW(arg1));
+	ti4_1 = F2317_29412(RTCW(arg1));
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ti4_1;
 	RTHOOK(5);
-	ti4_1 = F1342_15731(RTCW(arg1));
+	ti4_1 = F2317_29413(RTCW(arg1));
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_3_) = (EIF_INTEGER_32) ti4_1;
-	RTHOOK(6);
+	RTHOOK(11);
 	RTLE;
 	RTEE;
 }
 
-/* {CLICK_AST}.node */
-EIF_REFERENCE F37_480 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {CLICK_AST}.is_equal */
-EIF_BOOLEAN F37_481 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F43_597 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -85,7 +78,7 @@ EIF_BOOLEAN F37_481 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr2);
 	RTLIU(4);
 	
-	RTEAA("is_equal", 36, Current, 0, 1, 573);
+	RTEAA("is_equal", 42, Current, 0, 1, 576);
 	RTGC;
 	RTHOOK(1);
 	Result = '\0';
@@ -98,7 +91,7 @@ EIF_BOOLEAN F37_481 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	if (tb1) {
 		tr1 = *(EIF_REFERENCE *)(Current);
 		tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R12589[Dtype(tr1)-1342])(RTCW(tr1), tr2);
+		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R23042[Dtype(RTCW(tr1))-2317])(tr1, tr2);
 		Result = tb1;
 	}
 	RTHOOK(2);
