@@ -24,66 +24,66 @@ extern "C" {
 
 /* {CODE_PAGE_CONSTANTS}.utf7 */
 
-EIF_REFERENCE F45_988 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_752 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (584,RTMS_EX_H("UTF-7",5,1414538039));
+	RTOSC (752,RTMS_EX_H("UTF-7",5,1414538039));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf8 */
 
-EIF_REFERENCE F45_989 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_753 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (443,RTMS_EX_H("UTF-8",5,1414538040));
+	RTOSC (753,RTMS_EX_H("UTF-8",5,1414538040));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf16 */
 
-EIF_REFERENCE F45_990 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_754 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (583,RTMS_EX_H("UTF-16",6,1345128758));
+	RTOSC (754,RTMS_EX_H("UTF-16",6,1345128758));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf32 */
 
-EIF_REFERENCE F45_991 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_755 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (444,RTMS_EX_H("UTF-32",6,1345129266));
+	RTOSC (755,RTMS_EX_H("UTF-32",6,1345129266));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf16_le */
 
-EIF_REFERENCE F45_992 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_756 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (585,RTMS_EX_H("UTF-16LE",8,312185413));
+	RTOSC (756,RTMS_EX_H("UTF-16LE",8,312185413));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf32_le */
 
-EIF_REFERENCE F45_993 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_757 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (586,RTMS_EX_H("UTF-32LE",8,345477701));
+	RTOSC (757,RTMS_EX_H("UTF-32LE",8,345477701));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf16_be */
 
-EIF_REFERENCE F45_994 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_758 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (587,RTMS_EX_H("UTF-16BE",8,312182853));
+	RTOSC (758,RTMS_EX_H("UTF-16BE",8,312182853));
 }
 
 /* {CODE_PAGE_CONSTANTS}.utf32_be */
 
-EIF_REFERENCE F45_995 (EIF_REFERENCE Current)
+EIF_REFERENCE F46_759 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (588,RTMS_EX_H("UTF-32BE",8,345475141));
+	RTOSC (759,RTMS_EX_H("UTF-32BE",8,345475141));
 }
 
 void EIF_Minit41 (void)
