@@ -24,7 +24,7 @@ extern "C" {
 #endif
 
 /* {COMPILER_PROFILE}.initialize_from_arguments */
-void F5_59 (EIF_REFERENCE Current)
+void F5_68 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -43,53 +43,53 @@ void F5_59 (EIF_REFERENCE Current)
 	RTLIU(4);
 	
 	RTGC;
-	F5_99(Current);
-	loc1 = RTLNS(eif_new_type(117, 0x00).id, 117, _OBJSIZ_1_0_0_0_0_0_0_0_);
-	tr1 = RTOUCR(277,F5_60, (Current));
-	ti4_1 = F117_2491(RTCW(loc1), tr1);
+	F5_108(Current);
+	loc1 = RTLNS(eif_new_type(181, 0x00).id, 181, _OBJSIZ_1_0_0_0_0_0_0_0_);
+	tr1 = RTOUCR(325,F5_69, (Current));
+	ti4_1 = F181_3259(RTCW(loc1), tr1);
 	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
-		F5_86(Current);
+		F5_95(Current);
 	} else {
-		tr1 = RTOUCR(278,F5_61, (Current));
-		ti4_1 = F117_2491(RTCW(loc1), tr1);
+		tr1 = RTOUCR(326,F5_70, (Current));
+		ti4_1 = F181_3259(RTCW(loc1), tr1);
 		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
-			F5_87(Current);
+			F5_96(Current);
 		}
 	}
-	tr1 = RTOUCR(279,F5_62, (Current));
-	ti4_1 = F117_2491(RTCW(loc1), tr1);
+	tr1 = RTOUCR(327,F5_71, (Current));
+	ti4_1 = F181_3259(RTCW(loc1), tr1);
 	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
-		F5_88(Current);
+		F5_97(Current);
 	}
-	tr1 = RTOUCR(280,F5_63, (Current));
-	ti4_1 = F117_2491(RTCW(loc1), tr1);
+	tr1 = RTOUCR(328,F5_72, (Current));
+	ti4_1 = F181_3259(RTCW(loc1), tr1);
 	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
-		F5_89(Current);
+		F5_98(Current);
 	}
-	tr1 = RTOUCR(281,F5_64, (Current));
-	loc3 = F117_2491(RTCW(loc1), tr1);
+	tr1 = RTOUCR(329,F5_73, (Current));
+	loc3 = F181_3259(RTCW(loc1), tr1);
 	tb1 = '\0';
 	if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
-		ti4_1 = F117_2494(RTCW(loc1));
+		ti4_1 = F181_3262(RTCW(loc1));
 		tb1 = (EIF_BOOLEAN) ((EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)) <= ti4_1);
 	}
 	if (tb1) {
-		loc2 = F117_2489(RTCW(loc1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
-		if (F5_77(Current, loc2)) {
-			F5_90(Current, loc2);
+		loc2 = F181_3257(RTCW(loc1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
+		if (F5_86(Current, loc2)) {
+			F5_99(Current, loc2);
 		}
 	}
-	tr1 = RTOUCR(282,F5_65, (Current));
-	loc3 = F117_2491(RTCW(loc1), tr1);
+	tr1 = RTOUCR(330,F5_74, (Current));
+	loc3 = F181_3259(RTCW(loc1), tr1);
 	tb1 = '\0';
 	if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
-		ti4_1 = F117_2494(RTCW(loc1));
+		ti4_1 = F181_3262(RTCW(loc1));
 		tb1 = (EIF_BOOLEAN) ((EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)) <= ti4_1);
 	}
 	if (tb1) {
-		loc2 = F117_2489(RTCW(loc1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
-		if (F5_82(Current, loc2)) {
-			F5_91(Current, loc2);
+		loc2 = F181_3257(RTCW(loc1), (EIF_INTEGER_32) (loc3 + ((EIF_INTEGER_32) 1L)));
+		if (F5_91(Current, loc2)) {
+			F5_100(Current, loc2);
 		}
 	}
 	RTLE;
@@ -97,54 +97,54 @@ void F5_59 (EIF_REFERENCE Current)
 
 /* {COMPILER_PROFILE}.compat_option_name */
 
-EIF_REFERENCE F5_60 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_69 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (277,RTMS_EX_H("compat",6,2031575924));
+	RTOUC (325,RTMS_EX_H("compat",6,2031575924));
 }
 
 /* {COMPILER_PROFILE}.experiment_option_name */
 
-EIF_REFERENCE F5_61 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_70 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (278,RTMS_EX_H("experiment",10,207796852));
+	RTOUC (326,RTMS_EX_H("experiment",10,207796852));
 }
 
 /* {COMPILER_PROFILE}.full_option_name */
 
-EIF_REFERENCE F5_62 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_71 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (279,RTMS_EX_H("full",4,1718971500));
+	RTOUC (327,RTMS_EX_H("full",4,1718971500));
 }
 
 /* {COMPILER_PROFILE}.safe_option_name */
 
-EIF_REFERENCE F5_63 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_72 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (280,RTMS_EX_H("safe",4,1935763045));
+	RTOUC (328,RTMS_EX_H("safe",4,1935763045));
 }
 
 /* {COMPILER_PROFILE}.platform_option_name */
 
-EIF_REFERENCE F5_64 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_73 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (281,RTMS_EX_H("platform",8,459690093));
+	RTOUC (329,RTMS_EX_H("platform",8,459690093));
 }
 
 /* {COMPILER_PROFILE}.capabilty_option_name */
 
-EIF_REFERENCE F5_65 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_74 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (282,RTMS_EX_H("capability",10,950653049));
+	RTOUC (330,RTMS_EX_H("capability",10,950653049));
 }
 
 /* {COMPILER_PROFILE}.is_compatible_mode */
-EIF_BOOLEAN F5_70 (EIF_REFERENCE Current)
+EIF_BOOLEAN F5_79 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -165,7 +165,7 @@ EIF_BOOLEAN F5_70 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.is_experimental_mode */
-EIF_BOOLEAN F5_72 (EIF_REFERENCE Current)
+EIF_BOOLEAN F5_81 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -186,7 +186,7 @@ EIF_BOOLEAN F5_72 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.is_platform_valid */
-EIF_BOOLEAN F5_77 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F5_86 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -207,20 +207,20 @@ EIF_BOOLEAN F5_77 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	tb1 = '\01';
 	tb2 = '\01';
 	tr1 = RTMS_EX_H("windows",7,1657536371);
-	tb3 = F953_7783(RTCW(arg1), tr1);
+	tb3 = F986_8199(RTCW(arg1), tr1);
 	if (!tb3) {
 		tr1 = RTMS_EX_H("unix",4,1970170232);
-		tb3 = F953_7783(RTCW(arg1), tr1);
+		tb3 = F986_8199(RTCW(arg1), tr1);
 		tb2 = tb3;
 	}
 	if (!tb2) {
 		tr1 = RTMS_EX_H("macintosh",9,458551400);
-		tb2 = F953_7783(RTCW(arg1), tr1);
+		tb2 = F986_8199(RTCW(arg1), tr1);
 		tb1 = tb2;
 	}
 	if (!tb1) {
 		tr1 = RTMS_EX_H("vxworks",7,1368523123);
-		tb1 = F953_7783(RTCW(arg1), tr1);
+		tb1 = F986_8199(RTCW(arg1), tr1);
 		Result = tb1;
 	}
 	RTLE;
@@ -228,7 +228,7 @@ EIF_BOOLEAN F5_77 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {COMPILER_PROFILE}.is_capability_valid */
-EIF_BOOLEAN F5_82 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F5_91 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -247,16 +247,16 @@ EIF_BOOLEAN F5_82 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTGC;
 	Result = '\01';
 	tb1 = '\01';
-	tr1 = RTOUCR(283,F5_111, (Current));
-	tb2 = F953_7786(RTCW(arg1), tr1);
+	tr1 = RTOUCR(331,F5_120, (Current));
+	tb2 = F986_8202(RTCW(arg1), tr1);
 	if (!tb2) {
-		tr1 = RTOUCR(284,F5_112, (Current));
-		tb2 = F953_7786(RTCW(arg1), tr1);
+		tr1 = RTOUCR(332,F5_121, (Current));
+		tb2 = F986_8202(RTCW(arg1), tr1);
 		tb1 = tb2;
 	}
 	if (!tb1) {
-		tr1 = RTOUCR(285,F5_113, (Current));
-		tb1 = F953_7786(RTCW(arg1), tr1);
+		tr1 = RTOUCR(333,F5_122, (Current));
+		tb1 = F986_8202(RTCW(arg1), tr1);
 		Result = tb1;
 	}
 	RTLE;
@@ -264,7 +264,7 @@ EIF_BOOLEAN F5_82 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {COMPILER_PROFILE}.set_compatible_mode */
-void F5_86 (EIF_REFERENCE Current)
+void F5_95 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -282,7 +282,7 @@ void F5_86 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.set_experimental_mode */
-void F5_87 (EIF_REFERENCE Current)
+void F5_96 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -300,7 +300,7 @@ void F5_87 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.set_full_class_checking_mode */
-void F5_88 (EIF_REFERENCE Current)
+void F5_97 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -318,7 +318,7 @@ void F5_88 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.set_safe_mode */
-void F5_89 (EIF_REFERENCE Current)
+void F5_98 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -336,7 +336,7 @@ void F5_89 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.set_platform */
-void F5_90 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F5_99 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -351,24 +351,24 @@ void F5_90 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	tr1 = RTMS_EX_H("windows",7,1657536371);
-	tb1 = F953_7783(RTCW(arg1), tr1);
+	tb1 = F986_8199(RTCW(arg1), tr1);
 	if (tb1) {
-		F5_92(Current);
+		F5_101(Current);
 	} else {
 		tr1 = RTMS_EX_H("unix",4,1970170232);
-		tb1 = F953_7783(RTCW(arg1), tr1);
+		tb1 = F986_8199(RTCW(arg1), tr1);
 		if (tb1) {
-			F5_93(Current);
+			F5_102(Current);
 		} else {
 			tr1 = RTMS_EX_H("macintosh",9,458551400);
-			tb1 = F953_7783(RTCW(arg1), tr1);
+			tb1 = F986_8199(RTCW(arg1), tr1);
 			if (tb1) {
-				F5_94(Current);
+				F5_103(Current);
 			} else {
 				tr1 = RTMS_EX_H("vxworks",7,1368523123);
-				tb1 = F953_7783(RTCW(arg1), tr1);
+				tb1 = F986_8199(RTCW(arg1), tr1);
 				if (tb1) {
-					F5_95(Current);
+					F5_104(Current);
 				}
 			}
 		}
@@ -377,7 +377,7 @@ void F5_90 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {COMPILER_PROFILE}.set_capability */
-void F5_91 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F5_100 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -391,20 +391,20 @@ void F5_91 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(3);
 	
 	RTGC;
-	tr1 = RTOUCR(283,F5_111, (Current));
-	tb1 = F953_7786(RTCW(arg1), tr1);
+	tr1 = RTOUCR(331,F5_120, (Current));
+	tb1 = F986_8202(RTCW(arg1), tr1);
 	if (tb1) {
-		F5_96(Current);
+		F5_105(Current);
 	} else {
-		tr1 = RTOUCR(284,F5_112, (Current));
-		tb1 = F953_7786(RTCW(arg1), tr1);
+		tr1 = RTOUCR(332,F5_121, (Current));
+		tb1 = F986_8202(RTCW(arg1), tr1);
 		if (tb1) {
-			F5_97(Current);
+			F5_106(Current);
 		} else {
-			tr1 = RTOUCR(285,F5_113, (Current));
-			tb1 = F953_7786(RTCW(arg1), tr1);
+			tr1 = RTOUCR(333,F5_122, (Current));
+			tb1 = F986_8202(RTCW(arg1), tr1);
 			if (tb1) {
-				F5_98(Current);
+				F5_107(Current);
 			}
 		}
 	}
@@ -412,7 +412,7 @@ void F5_91 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {COMPILER_PROFILE}.set_is_windows_platform */
-void F5_92 (EIF_REFERENCE Current)
+void F5_101 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -427,13 +427,13 @@ void F5_92 (EIF_REFERENCE Current)
 	tu4_1 = *(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_);
 	tu4_2 = eif_bit_not(((EIF_NATURAL_32) 240U));
 	tu4_1 = eif_bit_and(tu4_1,tu4_2);
-	tu4_1 = eif_bit_or((tu4_1),((EIF_NATURAL_32) 32U));
+	tu4_1 = eif_bit_or(tu4_1,((EIF_NATURAL_32) 32U));
 	*(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_NATURAL_32) tu4_1;
 	RTLE;
 }
 
 /* {COMPILER_PROFILE}.set_is_unix_platform */
-void F5_93 (EIF_REFERENCE Current)
+void F5_102 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -448,13 +448,13 @@ void F5_93 (EIF_REFERENCE Current)
 	tu4_1 = *(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_);
 	tu4_2 = eif_bit_not(((EIF_NATURAL_32) 240U));
 	tu4_1 = eif_bit_and(tu4_1,tu4_2);
-	tu4_1 = eif_bit_or((tu4_1),((EIF_NATURAL_32) 16U));
+	tu4_1 = eif_bit_or(tu4_1,((EIF_NATURAL_32) 16U));
 	*(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_NATURAL_32) tu4_1;
 	RTLE;
 }
 
 /* {COMPILER_PROFILE}.set_is_mac_platform */
-void F5_94 (EIF_REFERENCE Current)
+void F5_103 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -469,13 +469,13 @@ void F5_94 (EIF_REFERENCE Current)
 	tu4_1 = *(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_);
 	tu4_2 = eif_bit_not(((EIF_NATURAL_32) 240U));
 	tu4_1 = eif_bit_and(tu4_1,tu4_2);
-	tu4_1 = eif_bit_or((tu4_1),((EIF_NATURAL_32) 48U));
+	tu4_1 = eif_bit_or(tu4_1,((EIF_NATURAL_32) 48U));
 	*(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_NATURAL_32) tu4_1;
 	RTLE;
 }
 
 /* {COMPILER_PROFILE}.set_is_vxworks_platform */
-void F5_95 (EIF_REFERENCE Current)
+void F5_104 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -490,13 +490,13 @@ void F5_95 (EIF_REFERENCE Current)
 	tu4_1 = *(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_);
 	tu4_2 = eif_bit_not(((EIF_NATURAL_32) 240U));
 	tu4_1 = eif_bit_and(tu4_1,tu4_2);
-	tu4_1 = eif_bit_or((tu4_1),((EIF_NATURAL_32) 64U));
+	tu4_1 = eif_bit_or(tu4_1,((EIF_NATURAL_32) 64U));
 	*(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_NATURAL_32) tu4_1;
 	RTLE;
 }
 
 /* {COMPILER_PROFILE}.set_capability_warning */
-void F5_96 (EIF_REFERENCE Current)
+void F5_105 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -511,13 +511,13 @@ void F5_96 (EIF_REFERENCE Current)
 	tu4_1 = *(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_);
 	tu4_2 = eif_bit_not(((EIF_NATURAL_32) 512U));
 	tu4_1 = eif_bit_and(tu4_1,tu4_2);
-	tu4_1 = eif_bit_or((tu4_1),((EIF_NATURAL_32) 256U));
+	tu4_1 = eif_bit_or(tu4_1,((EIF_NATURAL_32) 256U));
 	*(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_NATURAL_32) tu4_1;
 	RTLE;
 }
 
 /* {COMPILER_PROFILE}.set_capability_error */
-void F5_97 (EIF_REFERENCE Current)
+void F5_106 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -532,13 +532,13 @@ void F5_97 (EIF_REFERENCE Current)
 	tu4_1 = *(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_);
 	tu4_2 = eif_bit_not(((EIF_NATURAL_32) 256U));
 	tu4_1 = eif_bit_and(tu4_1,tu4_2);
-	tu4_1 = eif_bit_or((tu4_1),((EIF_NATURAL_32) 512U));
+	tu4_1 = eif_bit_or(tu4_1,((EIF_NATURAL_32) 512U));
 	*(EIF_NATURAL_32 *)(Current+ _LNGOFF_0_0_0_0_) = (EIF_NATURAL_32) tu4_1;
 	RTLE;
 }
 
 /* {COMPILER_PROFILE}.set_capability_strict */
-void F5_98 (EIF_REFERENCE Current)
+void F5_107 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_NATURAL_32 tu4_1;
@@ -556,7 +556,7 @@ void F5_98 (EIF_REFERENCE Current)
 }
 
 /* {COMPILER_PROFILE}.reset */
-void F5_99 (EIF_REFERENCE Current)
+void F5_108 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -566,26 +566,26 @@ void F5_99 (EIF_REFERENCE Current)
 
 /* {COMPILER_PROFILE}.capability_value_warning */
 
-EIF_REFERENCE F5_111 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_120 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (283,RTMS_EX_H("warning",7,1809215079));
+	RTOUC (331,RTMS_EX_H("warning",7,1809215079));
 }
 
 /* {COMPILER_PROFILE}.capability_value_error */
 
-EIF_REFERENCE F5_112 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_121 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (284,RTMS_EX_H("error",5,1920877938));
+	RTOUC (332,RTMS_EX_H("error",5,1920877938));
 }
 
 /* {COMPILER_PROFILE}.capability_value_strict */
 
-EIF_REFERENCE F5_113 (EIF_REFERENCE Current)
+EIF_REFERENCE F5_122 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (285,RTMS_EX_H("strict",6,2146499444));
+	RTOUC (333,RTMS_EX_H("strict",6,2146499444));
 }
 
 void EIF_Minit5 (void)
