@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {DESCRIPTOR_CACHE}.make */
-void F10_102 (EIF_REFERENCE Current)
+void F14_118 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTCFDT;
 	RTLD;
@@ -36,42 +35,36 @@ void F10_102 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make", 9, Current, 0, 0, 103);
 	RTGC;
-	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {1140,1465,1480,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,859,974,0xFF01,986,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
 		tr1 = RTLNSMART(typres0.id);
 	}
-	F1141_10660(RTCW(tr1), ((EIF_INTEGER_32) 2L));
+	F860_4837(RTCW(tr1), ((EIF_INTEGER_32) 2L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {1135,1480,1480,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,855,0xFF01,986,0xFF01,986,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
 		tr1 = RTLNSMART(typres0.id);
 	}
-	F1136_10660(RTCW(tr1), ((EIF_INTEGER_32) 2L));
+	F856_4837(RTCW(tr1), ((EIF_INTEGER_32) 2L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 }
 
 /* {DESCRIPTOR_CACHE}.put */
-void F10_103 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_REFERENCE arg2)
+void F14_119 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_REFERENCE arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -81,21 +74,16 @@ void F10_103 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_REFERENCE arg2)
 	RTLR(2,arg2);
 	RTLIU(3);
 	
-	RTEAA("put", 9, Current, 0, 2, 104);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	F1141_10707(RTCW(tr1), arg1, arg2);
-	RTHOOK(2);
+	F860_4884(RTCW(tr1), arg1, arg2);
 	RTLE;
-	RTEE;
 }
 
 /* {DESCRIPTOR_CACHE}.search */
-void F10_104 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F14_120 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -105,21 +93,16 @@ void F10_104 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,arg1);
 	RTLIU(3);
 	
-	RTEAA("search", 9, Current, 0, 1, 105);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	F1141_10702(RTCW(tr1), arg1);
-	RTHOOK(2);
+	F860_4879(RTCW(tr1), arg1);
 	RTLE;
-	RTEE;
 }
 
 /* {DESCRIPTOR_CACHE}.record_converted_pair */
-void F10_105 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+void F14_121 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
@@ -132,23 +115,17 @@ void F10_105 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	RTLR(4,tr1);
 	RTLIU(5);
 	
-	RTEAA("record_converted_pair", 9, Current, 1, 2, 106);
 	RTGC;
-	RTHOOK(1);
-	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R11107[Dtype(RTCW(arg1))-1476])(arg1, arg2);
-	RTHOOK(2);
+	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5204[Dtype(RTCW(arg1))-987])(arg1, arg2);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	F1136_10707(RTCW(tr1), loc1, loc1);
-	RTHOOK(3);
+	F856_4884(RTCW(tr1), loc1, loc1);
 	RTLE;
-	RTEE;
 }
 
 /* {DESCRIPTOR_CACHE}.found */
-EIF_BOOLEAN F10_106 (EIF_REFERENCE Current)
+EIF_BOOLEAN F14_122 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
@@ -159,22 +136,17 @@ EIF_BOOLEAN F10_106 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("found", 9, Current, 0, 0, 107);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	Result = F1141_10692(RTCW(tr1));
-	RTHOOK(2);
+	Result = F860_4869(RTCW(tr1));
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {DESCRIPTOR_CACHE}.found_item */
-EIF_POINTER F10_107 (EIF_REFERENCE Current)
+EIF_POINTER F14_123 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_POINTER Result = ((EIF_POINTER) 0);
 	
@@ -185,22 +157,17 @@ EIF_POINTER F10_107 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("found_item", 9, Current, 0, 0, 108);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	Result = *(EIF_POINTER *)(RTCW(tr1)+ _PTROFF_5_3_0_7_0_0_);
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {DESCRIPTOR_CACHE}.converted */
-EIF_BOOLEAN F10_108 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_BOOLEAN F14_124 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -215,15 +182,11 @@ EIF_BOOLEAN F10_108 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE ar
 	RTLR(4,tr2);
 	RTLIU(5);
 	
-	RTEAA("converted", 9, Current, 0, 2, 109);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R11107[Dtype(RTCW(arg1))-1476])(arg1, arg2);
-	Result = F1136_10667(RTCW(tr1), tr2);
-	RTHOOK(2);
+	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5204[Dtype(RTCW(arg1))-987])(arg1, arg2);
+	Result = F856_4845(RTCW(tr1), tr2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
