@@ -14,14 +14,14 @@ extern EIF_BOOLEAN F2_39(EIF_REFERENCE);
 extern EIF_POINTER F2_40(EIF_REFERENCE);
 extern EIF_BOOLEAN F2_41(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit2(void);
-extern void F659_3016(EIF_REFERENCE, EIF_POINTER, EIF_REFERENCE);
-extern void F655_3016(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
-extern void F659_2969(EIF_REFERENCE, EIF_INTEGER_32);
-extern EIF_BOOLEAN F655_2976(EIF_REFERENCE, EIF_REFERENCE);
-extern void F655_2969(EIF_REFERENCE, EIF_INTEGER_32);
-extern EIF_BOOLEAN F659_3001(EIF_REFERENCE);
-extern EIF_REFERENCE F797_4658(EIF_REFERENCE, EIF_REFERENCE);
-extern void F659_3011(EIF_REFERENCE, EIF_REFERENCE);
+extern void F676_3090(EIF_REFERENCE, EIF_INTEGER_32);
+extern void F673_3090(EIF_REFERENCE, EIF_INTEGER_32);
+extern void F673_3137(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
+extern void F676_3137(EIF_REFERENCE, EIF_POINTER, EIF_REFERENCE);
+extern void F676_3132(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_BOOLEAN F673_3098(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_BOOLEAN F676_3122(EIF_REFERENCE);
+extern char *(*R3672[])();
 
 #ifdef __cplusplus
 }
