@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {DESCRIPTOR_CACHE}.make */
-void F26_279 (EIF_REFERENCE Current)
+void F29_360 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -37,32 +37,32 @@ void F26_279 (EIF_REFERENCE Current)
 	
 	RTGC;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {842,990,1002,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,804,1047,0xFF01,1057,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
 		tr1 = RTLNSMART(typres0.id);
 	}
-	F843_6074(RTCW(tr1), ((EIF_INTEGER_32) 2L));
+	F805_5912(RTCW(tr1), ((EIF_INTEGER_32) 2L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {837,1002,1002,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,803,0xFF01,1057,0xFF01,1057,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
 		tr1 = RTLNSMART(typres0.id);
 	}
-	F838_6074(RTCW(tr1), ((EIF_INTEGER_32) 2L));
+	F804_5912(RTCW(tr1), ((EIF_INTEGER_32) 2L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
 /* {DESCRIPTOR_CACHE}.put */
-void F26_280 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_REFERENCE arg2)
+void F29_361 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -76,12 +76,12 @@ void F26_280 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_REFERENCE arg2)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	F843_6120(RTCW(tr1), arg1, arg2);
+	F805_5959(RTCW(tr1), arg1, arg2);
 	RTLE;
 }
 
 /* {DESCRIPTOR_CACHE}.search */
-void F26_281 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F29_362 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -95,12 +95,12 @@ void F26_281 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	F843_6115(RTCW(tr1), arg1);
+	F805_5954(RTCW(tr1), arg1);
 	RTLE;
 }
 
 /* {DESCRIPTOR_CACHE}.record_converted_pair */
-void F26_282 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+void F29_363 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -116,14 +116,14 @@ void F26_282 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	RTLIU(5);
 	
 	RTGC;
-	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R6238[Dtype(arg1)-1001])(RTCW(arg1), arg2);
+	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R6702[Dtype(RTCW(arg1))-1058])(arg1, arg2);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	F838_6120(RTCW(tr1), loc1, loc1);
+	F804_5959(RTCW(tr1), loc1, loc1);
 	RTLE;
 }
 
 /* {DESCRIPTOR_CACHE}.found */
-EIF_BOOLEAN F26_283 (EIF_REFERENCE Current)
+EIF_BOOLEAN F29_364 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -138,13 +138,13 @@ EIF_BOOLEAN F26_283 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	Result = F843_6105(RTCW(tr1));
+	Result = F805_5944(RTCW(tr1));
 	RTLE;
 	return Result;
 }
 
 /* {DESCRIPTOR_CACHE}.found_item */
-EIF_POINTER F26_284 (EIF_REFERENCE Current)
+EIF_POINTER F29_365 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -165,7 +165,7 @@ EIF_POINTER F26_284 (EIF_REFERENCE Current)
 }
 
 /* {DESCRIPTOR_CACHE}.converted */
-EIF_BOOLEAN F26_285 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_BOOLEAN F29_366 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -184,26 +184,12 @@ EIF_BOOLEAN F26_285 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE ar
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R6238[Dtype(arg1)-1001])(RTCW(arg1), arg2);
-	Result = F838_6080(RTCW(tr1), tr2);
+	tr2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R6702[Dtype(RTCW(arg1))-1058])(arg1, arg2);
+	Result = F804_5920(RTCW(tr1), tr2);
 	RTLE;
 	return Result;
 }
 
-/* {DESCRIPTOR_CACHE}.cache */
-EIF_REFERENCE F26_286 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
-/* {DESCRIPTOR_CACHE}.converted_pair */
-EIF_REFERENCE F26_287 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
-}
-
-
 void EIF_Minit26 (void)
 {
 	GTCX
