@@ -6,10 +6,10 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,893)
-static EIF_REFERENCE F80_893_body(EIF_REFERENCE);
-extern EIF_REFERENCE F80_893(EIF_REFERENCE);
+extern EIF_REFERENCE F69_954(EIF_REFERENCE, EIF_INTEGER_32);
 extern void EIF_Minit46(void);
+extern void F1260_13495(EIF_REFERENCE);
+extern void F1261_13651(EIF_REFERENCE, EIF_INTEGER_32);
 
 #ifdef __cplusplus
 }
