@@ -6,8 +6,11 @@
 extern "C" {
 #endif
 
-extern void F11_174(EIF_REFERENCE);
+extern void F16_210(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit11(void);
+extern void F151_2512(EIF_REFERENCE, EIF_REFERENCE);
+extern long O2344[];
+extern long O2345[];
 
 #ifdef __cplusplus
 }
