@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {I18N_PLURAL_TOOLS}.mo_header_to_plural_form */
-EIF_INTEGER_32 F14_237 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
+EIF_INTEGER_32 F14_145 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENCE arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
@@ -35,86 +34,70 @@ EIF_INTEGER_32 F14_237 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENC
 	
 	RTLD;
 	
-	RTLI(3);
+	RTLI(2);
 	RTLR(0,arg2);
 	RTLR(1,tr1);
-	RTLR(2,Current);
-	RTLIU(3);
+	RTLIU(2);
 	
-	RTEAA("mo_header_to_plural_form", 13, Current, 0, 2, 234);
 	RTGC;
-	RTHOOK(1);
 	switch (arg1) {
 		case 1L:
-			RTHOOK(2);
 			Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 			break;
 		case 2L:
-			RTHOOK(3);
 			tr1 = RTMS_EX_H("n != 1;",7,619025723);
-			tb1 = F1025_8480(RTCW(arg2), tr1);
+			tb1 = F1070_8314(RTCW(arg2), tr1);
 			if (tb1) {
-				RTHOOK(4);
 				Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 			} else {
-				RTHOOK(5);
 				Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
 			}
 			break;
 		case 3L:
-			RTHOOK(6);
 			tb1 = '\0';
 			tb2 = '\0';
 			tr1 = RTMS_EX_H("!=",2,8509);
-			tb3 = F1025_8479(RTCW(arg2), tr1);
+			tb3 = F1070_8313(RTCW(arg2), tr1);
 			if (tb3) {
 				tr1 = RTMS_EX_H("4",1,52);
-				tb3 = F1025_8479(RTCW(arg2), tr1);
+				tb3 = F1070_8313(RTCW(arg2), tr1);
 				tb2 = (EIF_BOOLEAN) !tb3;
 			}
 			if (tb2) {
 				tr1 = RTMS_EX_H("20",2,12848);
-				tb2 = F1025_8479(RTCW(arg2), tr1);
+				tb2 = F1070_8313(RTCW(arg2), tr1);
 				tb1 = (EIF_BOOLEAN) !tb2;
 			}
 			if (tb1) {
-				RTHOOK(7);
 				Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
 			} else {
-				RTHOOK(8);
 				tb1 = '\0';
 				tr1 = RTMS_EX_H("!=",2,8509);
-				tb2 = F1025_8479(RTCW(arg2), tr1);
+				tb2 = F1070_8313(RTCW(arg2), tr1);
 				if ((EIF_BOOLEAN) !tb2) {
 					tr1 = RTMS_EX_H("4",1,52);
-					tb2 = F1025_8479(RTCW(arg2), tr1);
+					tb2 = F1070_8313(RTCW(arg2), tr1);
 					tb1 = (EIF_BOOLEAN) !tb2;
 				}
 				if (tb1) {
-					RTHOOK(9);
 					Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
 				} else {
-					RTHOOK(10);
 					tb1 = '\0';
 					tr1 = RTMS_EX_H("20",2,12848);
-					tb2 = F1025_8479(RTCW(arg2), tr1);
+					tb2 = F1070_8313(RTCW(arg2), tr1);
 					if (tb2) {
 						tr1 = RTMS_EX_H("4",1,52);
-						tb2 = F1025_8479(RTCW(arg2), tr1);
+						tb2 = F1070_8313(RTCW(arg2), tr1);
 						tb1 = (EIF_BOOLEAN) !tb2;
 					}
 					if (tb1) {
-						RTHOOK(11);
 						Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
 					} else {
-						RTHOOK(12);
 						tr1 = RTMS_EX_H("!=",2,8509);
-						tb1 = F1025_8479(RTCW(arg2), tr1);
+						tb1 = F1070_8313(RTCW(arg2), tr1);
 						if (tb1) {
-							RTHOOK(13);
 							Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
 						} else {
-							RTHOOK(14);
 							Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 8L);
 						}
 					}
@@ -122,25 +105,20 @@ EIF_INTEGER_32 F14_237 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_REFERENC
 			}
 			break;
 		case 4L:
-			RTHOOK(15);
 			Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 9L);
 			break;
 		default:
-			RTHOOK(16);
 			Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 			break;
 	}
-	RTHOOK(17);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {I18N_PLURAL_TOOLS}.get_reduction_agent */
-EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F14_160 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_REFERENCE tr3 = NULL;
@@ -159,14 +137,11 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(5,Result);
 	RTLIU(6);
 	
-	RTEAA("get_reduction_agent", 13, Current, 0, 1, 249);
 	RTGC;
-	RTHOOK(1);
 	switch (arg1) {
 		case 1L:
-			RTHOOK(2);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -177,19 +152,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_50_2, (EIF_POINTER) _A14_50_2, (EIF_POINTER)(F14_254),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_50_2, (EIF_POINTER) _A14_50_2, (EIF_POINTER)(F14_162),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 2L:
-			RTHOOK(3);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -200,20 +174,19 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_51_2, (EIF_POINTER) _A14_51_2, (EIF_POINTER)(F14_255),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_51_2, (EIF_POINTER) _A14_51_2, (EIF_POINTER)(F14_163),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 0L:
 		case 3L:
-			RTHOOK(4);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -224,19 +197,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_52_2, (EIF_POINTER) _A14_52_2, (EIF_POINTER)(F14_256),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_52_2, (EIF_POINTER) _A14_52_2, (EIF_POINTER)(F14_164),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 4L:
-			RTHOOK(5);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -247,19 +219,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_53_2, (EIF_POINTER) _A14_53_2, (EIF_POINTER)(F14_257),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_53_2, (EIF_POINTER) _A14_53_2, (EIF_POINTER)(F14_165),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 5L:
-			RTHOOK(6);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -270,19 +241,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_54_2, (EIF_POINTER) _A14_54_2, (EIF_POINTER)(F14_258),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_54_2, (EIF_POINTER) _A14_54_2, (EIF_POINTER)(F14_166),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 6L:
-			RTHOOK(7);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -293,19 +263,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_55_2, (EIF_POINTER) _A14_55_2, (EIF_POINTER)(F14_259),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_55_2, (EIF_POINTER) _A14_55_2, (EIF_POINTER)(F14_167),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 7L:
-			RTHOOK(8);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -316,19 +285,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_56_2, (EIF_POINTER) _A14_56_2, (EIF_POINTER)(F14_260),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_56_2, (EIF_POINTER) _A14_56_2, (EIF_POINTER)(F14_168),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 8L:
-			RTHOOK(9);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -339,19 +307,18 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_57_2, (EIF_POINTER) _A14_57_2, (EIF_POINTER)(F14_261),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_57_2, (EIF_POINTER) _A14_57_2, (EIF_POINTER)(F14_169),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		case 9L:
-			RTHOOK(10);
 			{
-				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,945,0,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,1018,0,0xFFFF};
 				EIF_TYPE typres0;
 				typarr0[3] = dftype;
 				
@@ -362,181 +329,99 @@ EIF_REFERENCE F14_252 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTAR(tr1,Current);
 			
 			{
-				static EIF_TYPE_INDEX typarr0[] = {1022,0xFFF9,1,945,951,951,0xFFFF};
+				static EIF_TYPE_INDEX typarr0[] = {1067,0xFFF9,1,1018,1210,1210,0xFFFF};
 				EIF_TYPE typres0;
 				static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 				
 				typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
-				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_58_2, (EIF_POINTER) _A14_58_2, (EIF_POINTER)(F14_262),tr1, 1, 1);
+				tr4= RTLNRF(typres0.id, (EIF_POINTER) __A14_58_2, (EIF_POINTER) _A14_58_2, (EIF_POINTER)(F14_170),tr1, 1, 1);
 			}
 			Result = (EIF_REFERENCE) tr4;
 			break;
 		default:
 			RTEC(EN_WHEN);
 	}
-	RTHOOK(11);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {I18N_PLURAL_TOOLS}.get_nplural */
-EIF_INTEGER_32 F14_253 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_161 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("get_nplural", 13, Current, 0, 1, 250);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN) (arg1 <= ((EIF_INTEGER_32) 3L))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 	} else {
-		RTHOOK(4);
 		if ((EIF_BOOLEAN) (arg1 <= ((EIF_INTEGER_32) 1L))) {
-			RTHOOK(5);
 			Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(6);
 			if ((EIF_BOOLEAN) (arg1 <= ((EIF_INTEGER_32) 8L))) {
-				RTHOOK(7);
-				RTHOOK(8);
-				RTLE;
-				RTEE;
 				return (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
 			} else {
-				RTHOOK(9);
-				RTHOOK(10);
-				RTLE;
-				RTEE;
 				return (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
 			}
 		}
 	}
-	RTHOOK(11);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_one_plural_form */
-EIF_INTEGER_32 F14_254 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_162 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("reduce_one_plural_form", 13, Current, 0, 1, 251);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_two_plural_forms_singular_one */
-EIF_INTEGER_32 F14_255 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_163 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_two_plural_forms_singular_one", 13, Current, 0, 1, 252);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 1L))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
-		RTHOOK(5);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 	}/* NOTREACHED */
 	
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_two_plural_forms_singular_one_zero */
-EIF_INTEGER_32 F14_256 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_164 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_two_plural_forms_singular_one_zero", 13, Current, 0, 1, 253);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN) (arg1 > ((EIF_INTEGER_32) 1L))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 	} else {
-		RTHOOK(4);
-		RTHOOK(5);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	}/* NOTREACHED */
 	
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_three_plural_forms_special_zero */
-EIF_INTEGER_32 F14_257 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_165 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_three_plural_forms_special_zero", 13, Current, 0, 1, 254);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) == ((EIF_INTEGER_32) 1L)) && (EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) != ((EIF_INTEGER_32) 11L)))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
 		if ((EIF_BOOLEAN)(arg1 != ((EIF_INTEGER_32) 0L))) {
-			RTHOOK(5);
-			RTHOOK(6);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(7);
-			RTHOOK(8);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 		}
 	}/* NOTREACHED */
@@ -544,38 +429,18 @@ EIF_INTEGER_32 F14_257 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_three_plural_forms_special_one_two */
-EIF_INTEGER_32 F14_258 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_166 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_three_plural_forms_special_one_two", 13, Current, 0, 1, 255);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 1L))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
 		if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 2L))) {
-			RTHOOK(5);
-			RTHOOK(6);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(7);
-			RTHOOK(8);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 		}
 	}/* NOTREACHED */
@@ -583,38 +448,18 @@ EIF_INTEGER_32 F14_258 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_three_plural_forms_special_twelve_to_nineteen */
-EIF_INTEGER_32 F14_259 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_167 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_three_plural_forms_special_twelve_to_nineteen", 13, Current, 0, 1, 256);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) == ((EIF_INTEGER_32) 1L)) && (EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) != ((EIF_INTEGER_32) 11L)))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
-		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) >= ((EIF_INTEGER_32) 2L)) && ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) < ((EIF_INTEGER_32) 10L)) || (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) >= ((EIF_INTEGER_32) 20L)))))) {
-			RTHOOK(5);
-			RTHOOK(6);
-			RTLE;
-			RTEE;
+		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) >= ((EIF_INTEGER_32) 2L)) && (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) < ((EIF_INTEGER_32) 10L)) || (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) >= ((EIF_INTEGER_32) 20L))))) {
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(7);
-			RTHOOK(8);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 		}
 	}/* NOTREACHED */
@@ -622,38 +467,18 @@ EIF_INTEGER_32 F14_259 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_three_plural_forms_special_slavic */
-EIF_INTEGER_32 F14_260 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_168 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_three_plural_forms_special_slavic", 13, Current, 0, 1, 257);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) == ((EIF_INTEGER_32) 1L)) && (EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) != ((EIF_INTEGER_32) 11L)))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
-		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) >= ((EIF_INTEGER_32) 2L)) && (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) <= ((EIF_INTEGER_32) 4L))) && ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) < ((EIF_INTEGER_32) 10L)) || (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) >= ((EIF_INTEGER_32) 20L)))))) {
-			RTHOOK(5);
-			RTHOOK(6);
-			RTLE;
-			RTEE;
+		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) >= ((EIF_INTEGER_32) 2L)) && (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) <= ((EIF_INTEGER_32) 4L))) && (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) < ((EIF_INTEGER_32) 10L)) || (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) >= ((EIF_INTEGER_32) 20L))))) {
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(7);
-			RTHOOK(8);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 		}
 	}/* NOTREACHED */
@@ -661,38 +486,18 @@ EIF_INTEGER_32 F14_260 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_three_plural_forms_special_polish */
-EIF_INTEGER_32 F14_261 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_169 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_three_plural_forms_special_polish", 13, Current, 0, 1, 258);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 1L))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
-		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) >= ((EIF_INTEGER_32) 2L)) && (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) <= ((EIF_INTEGER_32) 4L))) && ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) < ((EIF_INTEGER_32) 10L)) || (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) >= ((EIF_INTEGER_32) 20L)))))) {
-			RTHOOK(5);
-			RTHOOK(6);
-			RTLE;
-			RTEE;
+		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) >= ((EIF_INTEGER_32) 2L)) && (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 10L)) <= ((EIF_INTEGER_32) 4L))) && (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) < ((EIF_INTEGER_32) 10L)) || (EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) >= ((EIF_INTEGER_32) 20L))))) {
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(7);
-			RTHOOK(8);
-			RTLE;
-			RTEE;
 			return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 		}
 	}/* NOTREACHED */
@@ -700,52 +505,27 @@ EIF_INTEGER_32 F14_261 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {I18N_PLURAL_TOOLS}.reduce_four_plural_forms_special_slovenian */
-EIF_INTEGER_32 F14_262 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F14_170 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("reduce_four_plural_forms_special_slovenian", 13, Current, 0, 1, 259);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) == ((EIF_INTEGER_32) 1L))) {
-		RTHOOK(2);
-		RTHOOK(3);
-		RTLE;
-		RTEE;
 		return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	} else {
-		RTHOOK(4);
 		if ((EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) == ((EIF_INTEGER_32) 2L))) {
-			RTHOOK(5);
 			Result = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		} else {
-			RTHOOK(6);
 			if ((EIF_BOOLEAN)((EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 100L)) == ((EIF_INTEGER_32) 3L))) {
-				RTHOOK(7);
-				RTHOOK(8);
-				RTLE;
-				RTEE;
 				return (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
 			} else {
-				RTHOOK(9);
-				RTHOOK(10);
-				RTLE;
-				RTEE;
 				return (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
 			}
 		}
 	}
-	RTHOOK(11);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
