@@ -24,21 +24,21 @@ extern "C" {
 #endif
 
 /* {I18N_FORMATTING_UTILITY}.pad_with_0_left */
-EIF_REFERENCE F20_168 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+EIF_REFERENCE F21_258 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("pad_with_0_left", 19, Current, 0, 2, 191);
+	RTEAA("pad_with_0_left", 20, Current, 0, 2, 292);
 	RTHOOK(1);
 	RTHOOK(2);
 	RTEE;
-	return (EIF_REFERENCE) F20_172(Current, arg1, arg2, (EIF_CHARACTER_8) '0');
+	return (EIF_REFERENCE) F21_262(Current, arg1, arg2, (EIF_CHARACTER_8) '0');
 }
 
 /* {I18N_FORMATTING_UTILITY}.pad_left */
-EIF_REFERENCE F20_172 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_CHARACTER_8 arg3)
+EIF_REFERENCE F21_262 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_CHARACTER_8 arg3)
 {
 	GTCX
 	RTEX;
@@ -57,22 +57,22 @@ EIF_REFERENCE F20_172 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_3
 	RTLR(3,Current);
 	RTLIU(4);
 	
-	RTEAA("pad_left", 19, Current, 1, 3, 195);
+	RTEAA("pad_left", 20, Current, 1, 3, 296);
 	RTGC;
 	RTHOOK(1);
-	Result = RTLNS(eif_new_type(1200, 0x00).id, 1200, _OBJSIZ_1_1_0_3_0_0_0_0_);
-	tr1 = c_outi(arg1);
-	F1201_10883(RTCW(Result), tr1);
+	Result = RTLNS(eif_new_type(1248, 0x00).id, 1248, _OBJSIZ_1_1_0_3_0_0_0_0_);
+	tr1 = eif_out__i4_s1(arg1);
+	F1249_11435(RTCW(Result), tr1);
 	RTHOOK(2);
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
 	if ((EIF_BOOLEAN) (ti4_1 < arg2)) {
 		RTHOOK(3);
-		loc1 = RTLNS(eif_new_type(1200, 0x00).id, 1200, _OBJSIZ_1_1_0_3_0_0_0_0_);
+		loc1 = RTLNS(eif_new_type(1248, 0x00).id, 1248, _OBJSIZ_1_1_0_3_0_0_0_0_);
 		tw1 = (EIF_CHARACTER_32) arg3;
 		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(Result)+ _LNGOFF_1_1_0_2_);
-		F1198_10777(RTCW(loc1), tw1, (EIF_INTEGER_32) (arg2 - ti4_1));
+		F1247_11360(RTCW(loc1), tw1, (EIF_INTEGER_32) (arg2 - ti4_1));
 		RTHOOK(4);
-		F1201_10915(RTCW(Result), loc1);
+		F1249_11466(RTCW(Result), loc1);
 	}
 	RTHOOK(6);
 	RTLE;
