@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {I18N_DATE_FORMATTER}.make */
-void F23_198 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F24_290 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	RTLD;
@@ -38,29 +37,23 @@ void F23_198 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr2);
 	RTLIU(4);
 	
-	RTEAA("make", 22, Current, 0, 1, 224);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSMART(eif_new_type(366, 1).id);
+	tr1 = RTLNSMART(eif_new_type(346, 1).id);
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_4_);
-	F367_3924(RTCW(tr1), tr2, arg1);
+	F347_3988(RTCW(tr1), tr2, arg1);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
-	tr1 = RTLNSMART(eif_new_type(366, 1).id);
+	tr1 = RTLNSMART(eif_new_type(346, 1).id);
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_6_);
-	F367_3924(RTCW(tr1), tr2, arg1);
+	F347_3988(RTCW(tr1), tr2, arg1);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
-	RTHOOK(3);
-	tr1 = RTLNSMART(eif_new_type(366, 1).id);
+	tr1 = RTLNSMART(eif_new_type(346, 1).id);
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
-	F367_3924(RTCW(tr1), tr2, arg1);
+	F347_3988(RTCW(tr1), tr2, arg1);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
-	RTHOOK(4);
 	RTLE;
-	RTEE;
 }
 
 void EIF_Minit19 (void)
