@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {I18N_LOCALE}.make */
-void F26_445 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+void F25_321 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -41,36 +41,27 @@ void F26_445 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg2;
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
-	tr1 = RTLNSMART(eif_new_type(14, 1).id);
-	F15_114(RTCW(tr1), arg2);
+	tr1 = RTLNSMART(eif_new_type(19, 1).id);
+	F20_306(RTCW(tr1), arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
-	tr1 = RTLNSMART(eif_new_type(13, 1).id);
-	F14_106(RTCW(tr1));
+	tr1 = RTLNSMART(eif_new_type(17, 1).id);
+	F18_293(RTCW(tr1));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
-	tr1 = RTLNSMART(eif_new_type(146, 1).id);
-	F147_2371(RTCW(tr1), arg2);
+	tr1 = RTLNSMART(eif_new_type(117, 1).id);
+	F118_1625(RTCW(tr1), arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
-	tr1 = RTLNSMART(eif_new_type(15, 1).id);
-	F16_121(RTCW(tr1), arg2);
+	tr1 = RTLNSMART(eif_new_type(18, 1).id);
+	F19_301(RTCW(tr1), arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
-/* {I18N_LOCALE}.translation */
-EIF_REFERENCE F26_447 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
-{
-	GTCX
-	
-	
-	return (EIF_REFERENCE) F26_449(Current, arg1, NULL);
-}
-
 /* {I18N_LOCALE}.translation_in_context */
-EIF_REFERENCE F26_449 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_REFERENCE F25_325 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -87,21 +78,59 @@ EIF_REFERENCE F26_449 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
-	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R3204[Dtype(RTCW(tr1))-220])(tr1, arg1, arg2);
+	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R2349[Dtype(RTCW(tr1))-169])(tr1, arg1, arg2);
 	loc1 = tr1;
 	if (EIF_TEST(loc1)) {
 		RTLE;
 		return (EIF_REFERENCE) loc1;
 	} else {
-		tr1 = F1125_9671(RTCW(arg1));
+		tr1 = F1055_8731(RTCW(arg1));
 		RTLE;
 		return (EIF_REFERENCE) tr1;
 	}/* NOTREACHED */
 	
 }
 
+/* {I18N_LOCALE}.plural_translation_in_context */
+EIF_REFERENCE F25_326 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_INTEGER_32 arg4)
+{
+	GTCX
+	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
+	EIF_REFERENCE tr1 = NULL;
+	RTLD;
+	
+	RTLI(6);
+	RTLR(0,loc1);
+	RTLR(1,Current);
+	RTLR(2,tr1);
+	RTLR(3,arg1);
+	RTLR(4,arg2);
+	RTLR(5,arg3);
+	RTLIU(6);
+	
+	RTGC;
+	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
+	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE)) R2350[Dtype(RTCW(tr1))-169])(tr1, arg1, arg2, arg4, arg3);
+	loc1 = tr1;
+	if (EIF_TEST(loc1)) {
+		RTLE;
+		return (EIF_REFERENCE) loc1;
+	} else {
+		if ((EIF_BOOLEAN)(arg4 == ((EIF_INTEGER_32) 1L))) {
+			tr1 = F1055_8731(RTCW(arg1));
+			RTLE;
+			return (EIF_REFERENCE) tr1;
+		} else {
+			tr1 = F1055_8731(RTCW(arg2));
+			RTLE;
+			return (EIF_REFERENCE) tr1;
+		}
+	}/* NOTREACHED */
+	
+}
+
 /* {I18N_LOCALE}.formatted_string */
-EIF_REFERENCE F26_451 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_REFERENCE F25_327 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -119,7 +148,7 @@ EIF_REFERENCE F26_451 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
-	Result = F14_110(RTCW(tr1), arg1, arg2);
+	Result = F18_297(RTCW(tr1), arg1, arg2);
 	RTLE;
 	return Result;
 }
