@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {I18N_LOCALE}.make */
-void F32_375 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+void F37_420 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	RTEX;
@@ -37,7 +37,7 @@ void F32_375 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("make", 31, Current, 0, 2, 392);
+	RTEAA("make", 36, Current, 0, 2, 461);
 	RTGC;
 	RTHOOK(1);
 	RTAR(Current, arg2);
@@ -46,53 +46,46 @@ void F32_375 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg1;
 	RTHOOK(3);
-	tr1 = RTLNSMART(eif_new_type(19, 0).id);
-	F20_243(RTCW(tr1), arg2);
+	tr1 = RTLNSMART(eif_new_type(28, 1).id);
+	F29_317(RTCW(tr1), arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 	RTHOOK(4);
-	tr1 = RTLNSMART(eif_new_type(17, 0).id);
-	F18_230(RTCW(tr1));
+	tr1 = RTLNSMART(eif_new_type(26, 1).id);
+	F27_304(RTCW(tr1));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
 	RTHOOK(5);
-	tr1 = RTLNSMART(eif_new_type(139, 0).id);
-	F140_1909(RTCW(tr1), arg2);
+	tr1 = RTLNSMART(eif_new_type(144, 1).id);
+	F145_2050(RTCW(tr1), arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
 	RTHOOK(6);
-	tr1 = RTLNSMART(eif_new_type(18, 0).id);
-	F19_238(RTCW(tr1), arg2);
+	tr1 = RTLNSMART(eif_new_type(27, 1).id);
+	F28_312(RTCW(tr1), arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
-	RTHOOK(7);
+	RTHOOK(9);
 	RTLE;
 	RTEE;
 }
 
-/* {I18N_LOCALE}.info */
-EIF_REFERENCE F32_376 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {I18N_LOCALE}.translation */
-EIF_REFERENCE F32_377 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_REFERENCE F37_422 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("translation", 31, Current, 0, 1, 394);
+	RTEAA("translation", 36, Current, 0, 1, 463);
 	RTHOOK(1);
 	RTHOOK(2);
 	RTEE;
-	return (EIF_REFERENCE) F32_379(Current, arg1, NULL);
+	return (EIF_REFERENCE) F37_424(Current, arg1, NULL);
 }
 
 /* {I18N_LOCALE}.translation_in_context */
-EIF_REFERENCE F32_379 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_REFERENCE F37_424 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	RTEX;
@@ -108,11 +101,11 @@ EIF_REFERENCE F32_379 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 	RTLR(4,arg2);
 	RTLIU(5);
 	
-	RTEAA("translation_in_context", 31, Current, 1, 2, 396);
+	RTEAA("translation_in_context", 36, Current, 1, 2, 465);
 	RTGC;
 	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
-	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R3119[Dtype(tr1)-228])(RTCW(tr1), arg1, arg2);
+	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE)) R2763[Dtype(RTCW(tr1))-220])(tr1, arg1, arg2);
 	loc1 = tr1;
 	if (EIF_TEST(loc1)) {
 		RTHOOK(2);
@@ -122,7 +115,7 @@ EIF_REFERENCE F32_379 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 		return (EIF_REFERENCE) loc1;
 	} else {
 		RTHOOK(4);
-		tr1 = F1062_9313(RTCW(arg1));
+		tr1 = F1085_8402(RTCW(arg1));
 		RTHOOK(5);
 		RTLE;
 		RTEE;
@@ -132,7 +125,7 @@ EIF_REFERENCE F32_379 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 }
 
 /* {I18N_LOCALE}.formatted_string */
-EIF_REFERENCE F32_381 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_REFERENCE F37_426 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
 	RTEX;
@@ -149,52 +142,17 @@ EIF_REFERENCE F32_381 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 	RTLR(4,Result);
 	RTLIU(5);
 	
-	RTEAA("formatted_string", 31, Current, 0, 2, 398);
+	RTEAA("formatted_string", 36, Current, 0, 2, 467);
 	RTGC;
 	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
-	Result = F18_234(RTCW(tr1), arg1, arg2);
-	RTHOOK(2);
+	Result = F27_308(RTCW(tr1), arg1, arg2);
+	RTHOOK(3);
 	RTLE;
 	RTEE;
 	return Result;
 }
 
-/* {I18N_LOCALE}.date_formatter */
-EIF_REFERENCE F32_382 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
-}
-
-
-/* {I18N_LOCALE}.value_formatter */
-EIF_REFERENCE F32_383 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
-}
-
-
-/* {I18N_LOCALE}.currency_formatter */
-EIF_REFERENCE F32_384 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
-}
-
-
-/* {I18N_LOCALE}.string_formatter */
-EIF_REFERENCE F32_385 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
-}
-
-
-/* {I18N_LOCALE}.dictionary */
-EIF_REFERENCE F32_386 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
-}
-
-
 void EIF_Minit32 (void)
 {
 	GTCX
