@@ -8,7 +8,6 @@
 
 #include "is43.h"
 #include "eif_built_in.h"
-#include "eif_copy.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -24,32 +23,20 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ISE_RUNTIME}.check_assert */
-EIF_BOOLEAN F52_721 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
-{
-	GTCX
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	
-	Result = (EIF_BOOLEAN) EIF_TEST(c_check_assert(arg1));
-	
-	return Result;
-}
-
 /* {ISE_RUNTIME}.type_conforms_to */
-EIF_BOOLEAN F52_725 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+EIF_BOOLEAN F43_896 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
 	
-	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_type_conforms_to (arg1, arg2);
+	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_type_conforms_to__i4_i4_b (arg1, arg2);
 	return Result;
 }
 
 /* {ISE_RUNTIME}.dynamic_type */
-EIF_INTEGER_32 F52_727 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_INTEGER_32 F43_898 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -60,20 +47,49 @@ EIF_INTEGER_32 F52_727 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(0,arg1);
 	RTLIU(1);
 	
-	Result = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_dynamic_type (arg1);
+	Result = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_dynamic_type__o_i4 (arg1);
 	RTLE;
 	return Result;
 }
 
+/* {ISE_RUNTIME}.new_tuple_instance_of */
+EIF_REFERENCE F43_903 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+{
+	GTCX
+	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
+	
+	RTLD;
+	
+	RTLI(1);
+	RTLR(0,Result);
+	RTLIU(1);
+	
+	Result = (EIF_REFERENCE) eif_builtin_ISE_RUNTIME_new_tuple_instance_of__i4_u (arg1);
+	RTLE;
+	return Result;
+}
+
+/* {ISE_RUNTIME}.is_attached_type */
+EIF_BOOLEAN F43_905 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+{
+	GTCX
+	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	
+	
+	
+	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_is_attached_type__i4_b (arg1);
+	return Result;
+}
+
 /* {ISE_RUNTIME}.detachable_type */
-EIF_INTEGER_32 F52_731 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F43_906 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_detachable_type (arg1);
+	Result = (EIF_INTEGER_32) eif_builtin_ISE_RUNTIME_detachable_type__i4_i4 (arg1);
 	return Result;
 }
 
