@@ -7,8 +7,8 @@
 #include "../E1/eoffsets.h"
 
 #include "is45.h"
-#include "eif_built_in.h"
 #include "eif_except.h"
+#include "eif_built_in.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {ISE_EXCEPTION_MANAGER}.last_exception */
-EIF_REFERENCE F80_861 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_880 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
@@ -38,13 +38,13 @@ EIF_REFERENCE F80_861 (EIF_REFERENCE Current)
 	RTLIU(2);
 	
 	RTGC;
-	Result = *(EIF_REFERENCE *)(RTCV(RTOSCF(879,F80_879, (Current))));
+	Result = *(EIF_REFERENCE *)(RTCV(RTOSCF(898,F73_898, (Current))));
 	RTLE;
 	return Result;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.raise */
-void F80_862 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F73_881 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER loc1 = (EIF_POINTER) 0;
@@ -64,13 +64,13 @@ void F80_862 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(4);
 	
 	RTGC;
-	tb1 = F127_1288(RTCW(arg1));
+	tb1 = F125_1395(RTCW(arg1));
 	if ((EIF_BOOLEAN) !tb1) {
 		if ((EIF_BOOLEAN) EIF_TEST(eif_is_in_rescue())) {
-			tr1 = F80_861(Current);
-			F127_1292(RTCW(arg1), tr1);
+			tr1 = F73_880(Current);
+			F125_1399(RTCW(arg1), tr1);
 		}
-		F80_873(Current, arg1);
+		F73_892(Current, arg1);
 		{
 			/* INLINED CODE (ANY.default_pointer) */
 			tp1 = (EIF_POINTER)  0;
@@ -80,7 +80,7 @@ void F80_862 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
 		loc3 = tr1;
 		if (EIF_TEST(loc3)) {
-			loc2 = F223_2202(loc3);
+			loc2 = F202_2083(loc3);
 		} else {
 			{
 				/* INLINED CODE (ANY.default_pointer) */
@@ -89,14 +89,14 @@ void F80_862 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 			}
 			loc2 = tp1;
 		}
-		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1229[Dtype(RTCW(arg1))-126])(arg1);
-		eif_builtin_ISE_EXCEPTION_MANAGER_developer_raise (ti4_1, loc1, loc2);
+		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1307[Dtype(RTCW(arg1))-124])(arg1);
+		eif_builtin_ISE_EXCEPTION_MANAGER_developer_raise__i4_p_p_ (ti4_1, loc1, loc2);
 	}
 	RTLE;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.is_ignored */
-EIF_BOOLEAN F80_868 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F73_887 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -112,15 +112,15 @@ EIF_BOOLEAN F80_868 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(3);
 	
 	RTGC;
-	tr1 = RTOSCF(875,F80_875, (Current));
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
-	Result = F719_3456(RTCW(tr1), ti4_1);
+	tr1 = RTOSCF(894,F73_894, (Current));
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
+	Result = F719_3415(RTCW(tr1), ti4_1);
 	RTLE;
 	return Result;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.type_of_code */
-EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F73_889 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -136,7 +136,7 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	switch (arg1) {
 		case 1L:
-			tr1 = RTLNTY2(eif_new_type(151, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(153, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 2L:
@@ -144,51 +144,51 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 3L:
-			tr1 = RTLNTY2(eif_new_type(159, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 4L:
-			tr1 = RTLNTY2(eif_new_type(164, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 5L:
-			tr1 = RTLNTY2(eif_new_type(130, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 6L:
 			tr1 = RTLNTY2(eif_new_type(163, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
-		case 7L:
+		case 4L:
+			tr1 = RTLNTY2(eif_new_type(158, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 5L:
+			tr1 = RTLNTY2(eif_new_type(129, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 6L:
 			tr1 = RTLNTY2(eif_new_type(162, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
-		case 8L:
-			tr1 = RTLNTY2(eif_new_type(153, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 9L:
-			tr1 = RTLNTY2(eif_new_type(154, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 10L:
+		case 7L:
 			tr1 = RTLNTY2(eif_new_type(161, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
-		case 11L:
+		case 8L:
+			tr1 = RTLNTY2(eif_new_type(152, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 9L:
+			tr1 = RTLNTY2(eif_new_type(151, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 10L:
 			tr1 = RTLNTY2(eif_new_type(160, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
+		case 11L:
+			tr1 = RTLNTY2(eif_new_type(159, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
 		case 12L:
-			tr1 = RTLNTY2(eif_new_type(134, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(131, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 13L:
-			tr1 = RTLNTY2(eif_new_type(141, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(139, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 14L:
-			tr1 = RTLNTY2(eif_new_type(138, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(137, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 15L:
@@ -196,27 +196,27 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 16L:
-			tr1 = RTLNTY2(eif_new_type(137, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 17L:
-			tr1 = RTLNTY2(eif_new_type(157, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 18L:
-			tr1 = RTLNTY2(eif_new_type(145, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 19L:
-			tr1 = RTLNTY2(eif_new_type(152, 0x01), 0x01);
-			Result = (EIF_REFERENCE) tr1;
-			break;
-		case 20L:
 			tr1 = RTLNTY2(eif_new_type(136, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
+		case 17L:
+			tr1 = RTLNTY2(eif_new_type(155, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 18L:
+			tr1 = RTLNTY2(eif_new_type(143, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 19L:
+			tr1 = RTLNTY2(eif_new_type(150, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
+		case 20L:
+			tr1 = RTLNTY2(eif_new_type(135, 0x01), 0x01);
+			Result = (EIF_REFERENCE) tr1;
+			break;
 		case 21L:
-			tr1 = RTLNTY2(eif_new_type(149, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(146, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 22L:
@@ -228,11 +228,11 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 24L:
-			tr1 = RTLNTY2(eif_new_type(127, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(125, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 25L:
-			tr1 = RTLNTY2(eif_new_type(141, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(139, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 26L:
@@ -240,7 +240,7 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 27L:
-			tr1 = RTLNTY2(eif_new_type(149, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(146, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 28L:
@@ -248,7 +248,7 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 29L:
-			tr1 = RTLNTY2(eif_new_type(162, 0x01), 0x01);
+			tr1 = RTLNTY2(eif_new_type(161, 0x01), 0x01);
 			Result = (EIF_REFERENCE) tr1;
 			break;
 		case 30L:
@@ -268,7 +268,7 @@ EIF_REFERENCE F80_870 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {ISE_EXCEPTION_MANAGER}.exception_from_code */
-EIF_REFERENCE F80_871 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F73_890 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -289,74 +289,74 @@ EIF_REFERENCE F80_871 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	switch (arg1) {
 		case 1L:
-			Result = RTLNS(eif_new_type(151, 0x01).id, 151, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(153, 0x01).id, 153, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 2L:
-			loc3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(880,F80_880, (Current))));
-			F145_1346(RTCW(loc3), ((EIF_INTEGER_32) 2L));
+			loc3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(899,F73_899, (Current))));
+			F145_1456(RTCW(loc3), ((EIF_INTEGER_32) 2L));
 			Result = (EIF_REFERENCE) loc3;
 			break;
 		case 3L:
-			Result = RTLNS(eif_new_type(159, 0x01).id, 159, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(163, 0x01).id, 163, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 4L:
-			Result = RTLNS(eif_new_type(164, 0x01).id, 164, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(158, 0x01).id, 158, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 5L:
-			Result = RTLNS(eif_new_type(130, 0x01).id, 130, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(129, 0x01).id, 129, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 6L:
-			Result = RTLNS(eif_new_type(163, 0x01).id, 163, _OBJSIZ_5_2_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(162, 0x01).id, 162, _OBJSIZ_5_2_0_1_0_0_0_0_);
 			break;
 		case 7L:
-			Result = RTLNS(eif_new_type(162, 0x01).id, 162, _OBJSIZ_5_1_0_1_0_0_0_0_);
-			break;
-		case 8L:
-			Result = RTLNS(eif_new_type(153, 0x01).id, 153, _OBJSIZ_7_1_0_1_0_0_0_0_);
-			break;
-		case 9L:
-			Result = RTLNS(eif_new_type(154, 0x01).id, 154, _OBJSIZ_5_1_0_1_0_0_0_0_);
-			break;
-		case 10L:
 			Result = RTLNS(eif_new_type(161, 0x01).id, 161, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
-		case 11L:
+		case 8L:
+			Result = RTLNS(eif_new_type(152, 0x01).id, 152, _OBJSIZ_7_1_0_1_0_0_0_0_);
+			break;
+		case 9L:
+			Result = RTLNS(eif_new_type(151, 0x01).id, 151, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			break;
+		case 10L:
 			Result = RTLNS(eif_new_type(160, 0x01).id, 160, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
+		case 11L:
+			Result = RTLNS(eif_new_type(159, 0x01).id, 159, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			break;
 		case 12L:
-			Result = RTLNS(eif_new_type(134, 0x01).id, 134, _OBJSIZ_5_1_0_2_0_0_0_0_);
+			Result = RTLNS(eif_new_type(131, 0x01).id, 131, _OBJSIZ_5_1_0_2_0_0_0_0_);
 			break;
 		case 13L:
-			loc1 = RTLNS(eif_new_type(141, 0x01).id, 141, _OBJSIZ_5_1_0_2_0_0_0_0_);
-			F142_1342(RTCW(loc1), ((EIF_INTEGER_32) 13L));
+			loc1 = RTLNS(eif_new_type(139, 0x01).id, 139, _OBJSIZ_5_1_0_2_0_0_0_0_);
+			F140_1448(RTCW(loc1), ((EIF_INTEGER_32) 13L));
 			Result = (EIF_REFERENCE) loc1;
 			break;
 		case 14L:
-			Result = RTLNS(eif_new_type(138, 0x01).id, 138, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(137, 0x01).id, 137, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 15L:
-			loc3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(880,F80_880, (Current))));
-			F145_1346(RTCW(loc3), ((EIF_INTEGER_32) 15L));
+			loc3 = *(EIF_REFERENCE *)(RTCV(RTOSCF(899,F73_899, (Current))));
+			F145_1456(RTCW(loc3), ((EIF_INTEGER_32) 15L));
 			Result = (EIF_REFERENCE) loc3;
 			break;
 		case 16L:
-			Result = RTLNS(eif_new_type(137, 0x01).id, 137, _OBJSIZ_5_1_0_1_0_0_0_0_);
-			break;
-		case 17L:
-			Result = RTLNS(eif_new_type(157, 0x01).id, 157, _OBJSIZ_5_1_0_1_0_0_0_0_);
-			break;
-		case 18L:
-			Result = RTLNS(eif_new_type(145, 0x01).id, 145, _OBJSIZ_5_1_0_1_0_0_0_0_);
-			break;
-		case 19L:
-			Result = RTLNS(eif_new_type(152, 0x01).id, 152, _OBJSIZ_5_1_0_1_0_0_0_0_);
-			break;
-		case 20L:
 			Result = RTLNS(eif_new_type(136, 0x01).id, 136, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
+		case 17L:
+			Result = RTLNS(eif_new_type(155, 0x01).id, 155, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			break;
+		case 18L:
+			Result = RTLNS(eif_new_type(143, 0x01).id, 143, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			break;
+		case 19L:
+			Result = RTLNS(eif_new_type(150, 0x01).id, 150, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			break;
+		case 20L:
+			Result = RTLNS(eif_new_type(135, 0x01).id, 135, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			break;
 		case 21L:
-			loc2 = RTLNS(eif_new_type(149, 0x01).id, 149, _OBJSIZ_5_1_0_3_0_0_0_0_);
-			F150_1358(RTCW(loc2), ((EIF_INTEGER_32) 21L));
+			loc2 = RTLNS(eif_new_type(146, 0x01).id, 146, _OBJSIZ_5_1_0_3_0_0_0_0_);
+			F147_1462(RTCW(loc2), ((EIF_INTEGER_32) 21L));
 			Result = (EIF_REFERENCE) loc2;
 			break;
 		case 22L:
@@ -366,26 +366,26 @@ EIF_REFERENCE F80_871 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			Result = RTLNS(eif_new_type(148, 0x01).id, 148, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 24L:
-			Result = RTLNS(eif_new_type(127, 0x01).id, 127, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(125, 0x01).id, 125, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 25L:
-			loc1 = RTLNS(eif_new_type(141, 0x01).id, 141, _OBJSIZ_5_1_0_2_0_0_0_0_);
-			F142_1342(RTCW(loc1), ((EIF_INTEGER_32) 25L));
+			loc1 = RTLNS(eif_new_type(139, 0x01).id, 139, _OBJSIZ_5_1_0_2_0_0_0_0_);
+			F140_1448(RTCW(loc1), ((EIF_INTEGER_32) 25L));
 			Result = (EIF_REFERENCE) loc1;
 			break;
 		case 26L:
 			Result = RTLNS(eif_new_type(156, 0x01).id, 156, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 27L:
-			loc2 = RTLNS(eif_new_type(149, 0x01).id, 149, _OBJSIZ_5_1_0_3_0_0_0_0_);
-			F150_1358(RTCW(loc2), ((EIF_INTEGER_32) 27L));
+			loc2 = RTLNS(eif_new_type(146, 0x01).id, 146, _OBJSIZ_5_1_0_3_0_0_0_0_);
+			F147_1462(RTCW(loc2), ((EIF_INTEGER_32) 27L));
 			Result = (EIF_REFERENCE) loc2;
 			break;
 		case 28L:
 			Result = RTLNS(eif_new_type(132, 0x01).id, 132, _OBJSIZ_6_1_0_3_0_0_0_0_);
 			break;
 		case 29L:
-			Result = RTLNS(eif_new_type(162, 0x01).id, 162, _OBJSIZ_5_1_0_1_0_0_0_0_);
+			Result = RTLNS(eif_new_type(161, 0x01).id, 161, _OBJSIZ_5_1_0_1_0_0_0_0_);
 			break;
 		case 30L:
 			Result = RTLNS(eif_new_type(140, 0x01).id, 140, _OBJSIZ_5_1_0_1_0_0_0_0_);
@@ -399,7 +399,7 @@ EIF_REFERENCE F80_871 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {ISE_EXCEPTION_MANAGER}.exception_data */
-EIF_REFERENCE F80_872 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_891 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
@@ -412,13 +412,13 @@ EIF_REFERENCE F80_872 (EIF_REFERENCE Current)
 	RTLIU(2);
 	
 	RTGC;
-	Result = *(EIF_REFERENCE *)(RTCV(RTOSCF(878,F80_878, (Current))));
+	Result = *(EIF_REFERENCE *)(RTCV(RTOSCF(897,F73_897, (Current))));
 	RTLE;
 	return Result;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.set_last_exception */
-void F80_873 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F73_892 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -431,13 +431,13 @@ void F80_873 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(3);
 	
 	RTGC;
-	tr1 = RTOSCF(879,F80_879, (Current));
-	F82_922(RTCW(tr1), arg1);
+	tr1 = RTOSCF(898,F73_898, (Current));
+	F75_941(RTCW(tr1), arg1);
 	RTLE;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.set_exception_data */
-void F80_874 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_BOOLEAN arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8, EIF_REFERENCE arg9, EIF_REFERENCE arg10, EIF_INTEGER_32 arg11, EIF_BOOLEAN arg12)
+void F73_893 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_BOOLEAN arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8, EIF_REFERENCE arg9, EIF_REFERENCE arg10, EIF_INTEGER_32 arg11, EIF_BOOLEAN arg12)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -461,9 +461,9 @@ void F80_874 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_BOOLEAN arg2, EIF_
 	RTLIU(11);
 	
 	RTGC;
-	tr1 = RTOSCF(878,F80_878, (Current));
+	tr1 = RTOSCF(897,F73_897, (Current));
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,0xFFF9,11,771,777,777,777,0xFF01,854,0xFF01,854,0xFF01,854,0xFF01,854,0xFF01,854,0xFF01,854,777,810,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,0xFFF9,11,786,792,792,792,0xFF01,869,0xFF01,869,0xFF01,869,0xFF01,869,0xFF01,869,0xFF01,869,792,825,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
@@ -487,31 +487,31 @@ void F80_874 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_BOOLEAN arg2, EIF_
 	RTAR(tr2,arg10);
 	((EIF_TYPED_VALUE *)tr2+10)->it_i4 = arg11;
 	((EIF_TYPED_VALUE *)tr2+11)->it_b = arg12;
-	F82_922(RTCW(tr1), tr2);
+	F75_941(RTCW(tr1), tr2);
 	if (arg2) {
-		tr1 = F80_882(Current);
+		tr1 = F73_901(Current);
 		loc1 = tr1;
 		if (EIF_TEST(loc1)) {
-			F80_873(Current, loc1);
+			F73_892(Current, loc1);
 		}
 	} else {
 		RTCT0("last_exception_attached", EX_CHECK);
-		tr1 = F80_861(Current);
+		tr1 = F73_880(Current);
 		loc2 = tr1;
 		if (EIF_TEST(loc2)) {
 			RTCK0;
 		} else {
 			RTCF0;
 		}
-		F127_1299(loc2, arg10);
-		F127_1293(loc2, arg6);
-		F127_1297(loc2, arg7);
+		F125_1406(loc2, arg10);
+		F125_1400(loc2, arg6);
+		F125_1404(loc2, arg7);
 	}
 	RTLE;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.ignored_exceptions */
-static EIF_REFERENCE F80_875_body (EIF_REFERENCE Current)
+static EIF_REFERENCE F73_894_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -526,34 +526,34 @@ static EIF_REFERENCE F80_875_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (875);
-#define Result RTOSR(875)
+	RTOSP (894);
+#define Result RTOSR(894)
 	RTOC_NEW(Result);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,718,777,777,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,718,792,792,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNS(typres0.id, 718, _OBJSIZ_4_3_0_10_0_0_0_0_);
 	}
-	F719_3449(RTCW(tr1), ((EIF_INTEGER_32) 0L));
+	F719_3407(RTCW(tr1), ((EIF_INTEGER_32) 0L));
 	Result = (EIF_REFERENCE) tr1;
-	RTOSE (875);
+	RTOSE (894);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F80_875 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_894 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(875,F80_875_body,(Current));
+	return RTOSCF(894,F73_894_body,(Current));
 }
 
 /* {ISE_EXCEPTION_MANAGER}.unignorable_exceptions */
-static EIF_REFERENCE F80_876_body (EIF_REFERENCE Current)
+static EIF_REFERENCE F73_895_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -569,37 +569,37 @@ static EIF_REFERENCE F80_876_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (876);
-#define Result RTOSR(876)
+	RTOSP (895);
+#define Result RTOSR(895)
 	RTOC_NEW(Result);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,718,777,777,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,718,792,792,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNS(typres0.id, 718, _OBJSIZ_4_3_0_10_0_0_0_0_);
 	}
-	F719_3449(RTCW(tr1), ((EIF_INTEGER_32) 1L));
+	F719_3407(RTCW(tr1), ((EIF_INTEGER_32) 1L));
 	Result = (EIF_REFERENCE) tr1;
-	tr1 = RTLNTY2(eif_new_type(151, 0x01), 0x01);
-	loc1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
-	F719_3496(RTCW(Result), loc1, loc1);
-	RTOSE (876);
+	tr1 = RTLNTY2(eif_new_type(153, 0x01), 0x01);
+	loc1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (tr1);
+	F719_3454(RTCW(Result), loc1, loc1);
+	RTOSE (895);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F80_876 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_895 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(876,F80_876_body,(Current));
+	return RTOSCF(895,F73_895_body,(Current));
 }
 
 /* {ISE_EXCEPTION_MANAGER}.unraisable_exceptions */
-static EIF_REFERENCE F80_877_body (EIF_REFERENCE Current)
+static EIF_REFERENCE F73_896_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -615,40 +615,40 @@ static EIF_REFERENCE F80_877_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (877);
-#define Result RTOSR(877)
+	RTOSP (896);
+#define Result RTOSR(896)
 	RTOC_NEW(Result);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,718,777,777,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,718,792,792,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNS(typres0.id, 718, _OBJSIZ_4_3_0_10_0_0_0_0_);
 	}
-	F719_3449(RTCW(tr1), ((EIF_INTEGER_32) 2L));
+	F719_3407(RTCW(tr1), ((EIF_INTEGER_32) 2L));
 	Result = (EIF_REFERENCE) tr1;
-	tr1 = RTLNTY2(eif_new_type(153, 0x01), 0x01);
-	loc1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
-	F719_3496(RTCW(Result), loc1, loc1);
+	tr1 = RTLNTY2(eif_new_type(152, 0x01), 0x01);
+	loc1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (tr1);
+	F719_3454(RTCW(Result), loc1, loc1);
 	tr1 = RTLNTY2(eif_new_type(140, 0x01), 0x01);
-	loc1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (tr1);
-	F719_3496(RTCW(Result), loc1, loc1);
-	RTOSE (877);
+	loc1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (tr1);
+	F719_3454(RTCW(Result), loc1, loc1);
+	RTOSE (896);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F80_877 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_896 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(877,F80_877_body,(Current));
+	return RTOSCF(896,F73_896_body,(Current));
 }
 
 /* {ISE_EXCEPTION_MANAGER}.exception_data_cell */
-static EIF_REFERENCE F80_878_body (EIF_REFERENCE Current)
+static EIF_REFERENCE F73_897_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -663,34 +663,34 @@ static EIF_REFERENCE F80_878_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (878);
-#define Result RTOSR(878)
+	RTOSP (897);
+#define Result RTOSR(897)
 	RTOC_NEW(Result);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,81,0xFFF9,11,771,777,777,777,0xFF01,854,0xFF01,854,0xFF01,854,0xFF01,854,0xFF01,854,0xFF01,854,777,810,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,74,0xFFF9,11,786,792,792,792,0xFF01,869,0xFF01,869,0xFF01,869,0xFF01,869,0xFF01,869,0xFF01,869,792,825,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
-		tr1 = RTLNS(typres0.id, 81, _OBJSIZ_1_0_0_0_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 74, _OBJSIZ_1_0_0_0_0_0_0_0_);
 	}
-	F82_922(RTCW(tr1), NULL);
+	F75_941(RTCW(tr1), NULL);
 	Result = (EIF_REFERENCE) tr1;
-	RTOSE (878);
+	RTOSE (897);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F80_878 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_897 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(878,F80_878_body,(Current));
+	return RTOSCF(897,F73_897_body,(Current));
 }
 
 /* {ISE_EXCEPTION_MANAGER}.last_exception_cell */
-static EIF_REFERENCE F80_879_body (EIF_REFERENCE Current)
+static EIF_REFERENCE F73_898_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -705,34 +705,34 @@ static EIF_REFERENCE F80_879_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (879);
-#define Result RTOSR(879)
+	RTOSP (898);
+#define Result RTOSR(898)
 	RTOC_NEW(Result);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,81,126,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,74,124,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
-		tr1 = RTLNS(typres0.id, 81, _OBJSIZ_1_0_0_0_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 74, _OBJSIZ_1_0_0_0_0_0_0_0_);
 	}
-	F82_922(RTCW(tr1), NULL);
+	F75_941(RTCW(tr1), NULL);
 	Result = (EIF_REFERENCE) tr1;
-	RTOSE (879);
+	RTOSE (898);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F80_879 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_898 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(879,F80_879_body,(Current));
+	return RTOSCF(898,F73_898_body,(Current));
 }
 
 /* {ISE_EXCEPTION_MANAGER}.no_memory_exception_object_cell */
-static EIF_REFERENCE F80_880_body (EIF_REFERENCE Current)
+static EIF_REFERENCE F73_899_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -749,38 +749,38 @@ static EIF_REFERENCE F80_880_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (880);
-#define Result RTOSR(880)
+	RTOSP (899);
+#define Result RTOSR(899)
 	RTOC_NEW(Result);
 	loc1 = RTLNS(eif_new_type(144, 0x01).id, 144, _OBJSIZ_5_1_0_2_0_0_0_0_);
-	tr1 = RTLNS(eif_new_type(854, 0x01).id, 854, _OBJSIZ_1_1_0_3_0_0_0_0_);
-	F852_4976(RTCW(tr1), ((EIF_INTEGER_32) 4096L));
-	F127_1299(RTCW(loc1), tr1);
+	tr1 = RTLNS(eif_new_type(869, 0x01).id, 869, _OBJSIZ_1_1_0_3_0_0_0_0_);
+	F868_5241(RTCW(tr1), ((EIF_INTEGER_32) 4096L));
+	F125_1406(RTCW(loc1), tr1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,81,0xFF01,144,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,74,0xFF01,144,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
-		tr1 = RTLNS(typres0.id, 81, _OBJSIZ_1_0_0_0_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 74, _OBJSIZ_1_0_0_0_0_0_0_0_);
 	}
-	F82_922(RTCW(tr1), loc1);
+	F75_941(RTCW(tr1), loc1);
 	Result = (EIF_REFERENCE) tr1;
-	RTOSE (880);
+	RTOSE (899);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F80_880 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_899 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(880,F80_880_body,(Current));
+	return RTOSCF(899,F73_899_body,(Current));
 }
 
 /* {ISE_EXCEPTION_MANAGER}.is_code_ignored */
-EIF_BOOLEAN F80_881 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F73_900 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -795,11 +795,11 @@ EIF_BOOLEAN F80_881 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(3);
 	
 	RTGC;
-	tr1 = F80_870(Current, arg1);
+	tr1 = F73_889(Current, arg1);
 	loc1 = tr1;
 	if (EIF_TEST(loc1)) {
 		RTLE;
-		return (EIF_BOOLEAN) F80_868(Current, loc1);
+		return (EIF_BOOLEAN) F73_887(Current, loc1);
 	} else {
 		RTLE;
 		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
@@ -808,7 +808,7 @@ EIF_BOOLEAN F80_881 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {ISE_EXCEPTION_MANAGER}.exception_from_data */
-EIF_REFERENCE F80_882 (EIF_REFERENCE Current)
+EIF_REFERENCE F73_901 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -844,88 +844,88 @@ EIF_REFERENCE F80_882 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tb1 = '\0';
-	tr1 = F80_872(Current);
+	tr1 = F73_891(Current);
 	loc2 = tr1;
 	if (EIF_TEST(loc2)) {
 		ti4_1 = eif_integer_32_item(loc2,1);
-		tr1 = F80_871(Current, ti4_1);
+		tr1 = F73_890(Current, ti4_1);
 		loc3 = tr1;
 		tb1 = EIF_TEST(loc3);
 	}
 	if (tb1) {
 		loc4 = loc3;
-		loc4 = RTRV(eif_new_type(153, 0x01),loc4);
+		loc4 = RTRV(eif_new_type(152, 0x01),loc4);
 		if (EIF_TEST(loc4)) {
-			loc1 = F80_861(Current);
+			loc1 = F73_880(Current);
 			if ((EIF_BOOLEAN)(loc1 != NULL)) {
-				F127_1292(loc3, loc1);
+				F125_1399(loc3, loc1);
 			}
 			tr1 = eif_boxed_item(loc2,7);
-			F154_1368(loc4, tr1);
+			F153_1476(loc4, tr1);
 			tr1 = eif_boxed_item(loc2,8);
-			F154_1369(loc4, tr1);
+			F153_1477(loc4, tr1);
 		} else {
 			loc5 = loc3;
 			loc5 = RTRV(eif_new_type(140, 0x01),loc5);
 			if (EIF_TEST(loc5)) {
-				loc1 = F80_861(Current);
+				loc1 = F73_880(Current);
 				if ((EIF_BOOLEAN)(loc1 != NULL)) {
-					F127_1292(loc3, loc1);
+					F125_1399(loc3, loc1);
 				}
 			} else {
 				loc6 = loc3;
-				loc6 = RTRV(eif_new_type(163, 0x01),loc6);
+				loc6 = RTRV(eif_new_type(162, 0x01),loc6);
 				if (EIF_TEST(loc6)) {
 					tb1 = eif_boolean_item(loc2,11);
-					F164_1385(loc6, tb1);
+					F163_1493(loc6, tb1);
 				} else {
 					loc7 = loc3;
-					loc7 = RTRV(eif_new_type(134, 0x01),loc7);
+					loc7 = RTRV(eif_new_type(131, 0x01),loc7);
 					if (EIF_TEST(loc7)) {
 						ti4_1 = eif_integer_32_item(loc2,2);
-						F135_1331(loc7, ti4_1);
+						F132_1416(loc7, ti4_1);
 					} else {
 						loc8 = loc3;
-						loc8 = RTRV(eif_new_type(149, 0x01),loc8);
+						loc8 = RTRV(eif_new_type(146, 0x01),loc8);
 						if (EIF_TEST(loc8)) {
 							ti4_1 = eif_integer_32_item(loc2,3);
-							F150_1357(loc8, ti4_1);
+							F147_1461(loc8, ti4_1);
 						} else {
 							loc9 = loc3;
 							loc9 = RTRV(eif_new_type(133, 0x01),loc9);
 							if (EIF_TEST(loc9)) {
 								ti4_1 = eif_integer_32_item(loc2,3);
-								F134_1327(loc9, ti4_1);
+								F134_1439(loc9, ti4_1);
 							} else {
 								loc10 = loc3;
 								loc10 = RTRV(eif_new_type(132, 0x01),loc10);
 								if (EIF_TEST(loc10)) {
 									ti4_1 = eif_integer_32_item(loc2,2);
-									F133_1309(loc10, ti4_1);
+									F133_1421(loc10, ti4_1);
 									tr1 = eif_boxed_item(loc2,4);
-									F133_1314(loc10, tr1);
+									F133_1426(loc10, tr1);
 								}
 							}
 						}
 					}
 				}
 				if ((EIF_BOOLEAN) EIF_TEST(eif_is_in_rescue())) {
-					loc1 = F80_861(Current);
+					loc1 = F73_880(Current);
 				}
 				if ((EIF_BOOLEAN)(loc1 == NULL)) {
 					loc1 = (EIF_REFERENCE) loc3;
 				}
-				F127_1292(loc3, loc1);
+				F125_1399(loc3, loc1);
 			}
 		}
 		tr1 = eif_boxed_item(loc2,9);
-		F127_1299(loc3, tr1);
+		F125_1406(loc3, tr1);
 		tr1 = eif_boxed_item(loc2,4);
-		F127_1285(loc3, tr1);
+		F125_1392(loc3, tr1);
 		tr1 = eif_boxed_item(loc2,5);
-		F127_1293(loc3, tr1);
+		F125_1400(loc3, tr1);
 		tr1 = eif_boxed_item(loc2,6);
-		F127_1297(loc3, tr1);
+		F125_1404(loc3, tr1);
 		RTLE;
 		return (EIF_REFERENCE) loc3;
 	}
@@ -934,7 +934,7 @@ EIF_REFERENCE F80_882 (EIF_REFERENCE Current)
 }
 
 /* {ISE_EXCEPTION_MANAGER}.once_raise */
-void F80_883 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F73_902 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER loc1 = (EIF_POINTER) 0;
@@ -956,14 +956,14 @@ void F80_883 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(5);
 	
 	RTGC;
-	tb1 = F127_1288(RTCW(arg1));
+	tb1 = F125_1395(RTCW(arg1));
 	if ((EIF_BOOLEAN) !tb1) {
 		if ((EIF_BOOLEAN) EIF_TEST(eif_is_in_rescue())) {
-			tr1 = F127_1278(RTCW(arg1));
-			tr2 = F80_861(Current);
-			F127_1292(RTCW(tr1), tr2);
+			tr1 = F125_1385(RTCW(arg1));
+			tr2 = F73_880(Current);
+			F125_1399(RTCW(tr1), tr2);
 		}
-		F80_873(Current, arg1);
+		F73_892(Current, arg1);
 		{
 			/* INLINED CODE (ANY.default_pointer) */
 			tp1 = (EIF_POINTER)  0;
@@ -973,7 +973,7 @@ void F80_883 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_3_);
 		loc3 = tr1;
 		if (EIF_TEST(loc3)) {
-			loc2 = F223_2202(loc3);
+			loc2 = F202_2083(loc3);
 		} else {
 			{
 				/* INLINED CODE (ANY.default_pointer) */
@@ -982,14 +982,14 @@ void F80_883 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 			}
 			loc2 = tp1;
 		}
-		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1229[Dtype(RTCW(arg1))-126])(arg1);
-		eif_builtin_ISE_EXCEPTION_MANAGER_developer_raise (ti4_1, loc1, loc2);
+		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1307[Dtype(RTCW(arg1))-124])(arg1);
+		eif_builtin_ISE_EXCEPTION_MANAGER_developer_raise__i4_p_p_ (ti4_1, loc1, loc2);
 	}
 	RTLE;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.init_exception_manager */
-void F80_884 (EIF_REFERENCE Current)
+void F73_903 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -1003,37 +1003,43 @@ void F80_884 (EIF_REFERENCE Current)
 	RTGC;
 	{
 		/* INLINED CODE (ANY.do_nothing) */
-		tr1 = RTOSCF(875,F80_875, (Current));
+		tr1 = RTOSCF(894,F73_894, (Current));
+		(void) RTCW(tr1);
 		/* END INLINED CODE */
 	}
 	;
 	{
 		/* INLINED CODE (ANY.do_nothing) */
-		tr1 = RTOSCF(876,F80_876, (Current));
+		tr1 = RTOSCF(895,F73_895, (Current));
+		(void) RTCW(tr1);
 		/* END INLINED CODE */
 	}
 	;
 	{
 		/* INLINED CODE (ANY.do_nothing) */
-		tr1 = RTOSCF(877,F80_877, (Current));
+		tr1 = RTOSCF(896,F73_896, (Current));
+		(void) RTCW(tr1);
 		/* END INLINED CODE */
 	}
 	;
 	{
 		/* INLINED CODE (ANY.do_nothing) */
-		tr1 = RTOSCF(878,F80_878, (Current));
+		tr1 = RTOSCF(897,F73_897, (Current));
+		(void) RTCW(tr1);
 		/* END INLINED CODE */
 	}
 	;
 	{
 		/* INLINED CODE (ANY.do_nothing) */
-		tr1 = RTOSCF(879,F80_879, (Current));
+		tr1 = RTOSCF(898,F73_898, (Current));
+		(void) RTCW(tr1);
 		/* END INLINED CODE */
 	}
 	;
 	{
 		/* INLINED CODE (ANY.do_nothing) */
-		tr1 = RTOSCF(880,F80_880, (Current));
+		tr1 = RTOSCF(899,F73_899, (Current));
+		(void) RTCW(tr1);
 		/* END INLINED CODE */
 	}
 	;
@@ -1041,7 +1047,7 @@ void F80_884 (EIF_REFERENCE Current)
 }
 
 /* {ISE_EXCEPTION_MANAGER}.free_preallocated_trace */
-void F80_885 (EIF_REFERENCE Current)
+void F73_904 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -1053,24 +1059,24 @@ void F80_885 (EIF_REFERENCE Current)
 	RTLIU(2);
 	
 	RTGC;
-	loc1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(880,F80_880, (Current))));
+	loc1 = *(EIF_REFERENCE *)(RTCV(RTOSCF(899,F73_899, (Current))));
 	if ((EIF_BOOLEAN)(loc1 != NULL)) {
-		F127_1285(RTCW(loc1), NULL);
+		F125_1392(RTCW(loc1), NULL);
 	}
 	RTLE;
 }
 
 /* {ISE_EXCEPTION_MANAGER}.developer_raise */
-void F80_886 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_POINTER arg2, EIF_POINTER arg3)
+void F73_905 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_POINTER arg2, EIF_POINTER arg3)
 {
 	GTCX
 	
 	
-	eif_builtin_ISE_EXCEPTION_MANAGER_developer_raise (arg1, arg2, arg3);
+	eif_builtin_ISE_EXCEPTION_MANAGER_developer_raise__i4_p_p_ (arg1, arg2, arg3);
 }
 
 /* {ISE_EXCEPTION_MANAGER}.in_rescue */
-EIF_BOOLEAN F80_887 (EIF_REFERENCE Current)
+EIF_BOOLEAN F73_906 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
