@@ -6,9 +6,7 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,196)
-static EIF_REFERENCE F14_196_body(EIF_REFERENCE);
-extern EIF_REFERENCE F14_196(EIF_REFERENCE);
+extern EIF_BOOLEAN F19_252(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit14(void);
 
 #ifdef __cplusplus
