@@ -59,7 +59,7 @@ static EIF_BOOLEAN F2_35_body (EIF_REFERENCE Current)
 	}
 	if (tb1) {
 		tr1 = RTMS_EX_H("windows",7,1657536371);
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(loc2))-0])(loc2, tr1);
+		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(loc2))-1])(loc2, tr1);
 		if (tb1) {
 			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 		}
@@ -69,7 +69,7 @@ static EIF_BOOLEAN F2_35_body (EIF_REFERENCE Current)
 		tb1 = '\0';
 		if ((EIF_BOOLEAN)(loc3 != NULL)) {
 			tr1 = RTMS_EX_H("Windows_NT",10,121334100);
-			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(loc3))-0])(loc3, tr1);
+			tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(loc3))-1])(loc3, tr1);
 			tb1 = tb2;
 		}
 		if (tb1) {
@@ -79,18 +79,18 @@ static EIF_BOOLEAN F2_35_body (EIF_REFERENCE Current)
 			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
 			if ((EIF_BOOLEAN) (ti4_1 >= ((EIF_INTEGER_32) 3L))) {
 				tb1 = '\0';
-				tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2656[Dtype(RTCW(loc1))-627])(loc1, ((EIF_INTEGER_32) 2L)));
+				tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2553[Dtype(RTCW(loc1))-607])(loc1, ((EIF_INTEGER_32) 2L)));
 				if ((EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) ':')) {
-					tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2656[Dtype(RTCW(loc1))-627])(loc1, ((EIF_INTEGER_32) 3L)));
+					tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2553[Dtype(RTCW(loc1))-607])(loc1, ((EIF_INTEGER_32) 3L)));
 					tb1 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '\\');
 				}
 				if (tb1) {
 					Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 				} else {
 					tb1 = '\0';
-					tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2656[Dtype(RTCW(loc1))-627])(loc1, ((EIF_INTEGER_32) 1L)));
+					tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2553[Dtype(RTCW(loc1))-607])(loc1, ((EIF_INTEGER_32) 1L)));
 					if ((EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '\\')) {
-						tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2656[Dtype(RTCW(loc1))-627])(loc1, ((EIF_INTEGER_32) 2L)));
+						tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2553[Dtype(RTCW(loc1))-607])(loc1, ((EIF_INTEGER_32) 2L)));
 						tb1 = (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '\\');
 					}
 					if (tb1) {
@@ -147,7 +147,7 @@ static EIF_BOOLEAN F2_36_body (EIF_REFERENCE Current)
 	}
 	if (tb1) {
 		tr1 = RTMS_EX_H("unix",4,1970170232);
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(loc2))-0])(loc2, tr1);
+		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(loc2))-1])(loc2, tr1);
 		if (tb1) {
 			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 		}
@@ -155,7 +155,7 @@ static EIF_BOOLEAN F2_36_body (EIF_REFERENCE Current)
 		loc1 = F2_38(Current);
 		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_1_0_2_);
 		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
-			tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2656[Dtype(RTCW(loc1))-627])(loc1, ((EIF_INTEGER_32) 1L)));
+			tc1 = (eif_optimize_return = 1, *(EIF_CHARACTER_8 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R2553[Dtype(RTCW(loc1))-607])(loc1, ((EIF_INTEGER_32) 1L)));
 			Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tc1 == (EIF_CHARACTER_8) '/');
 		}
 	}
@@ -176,19 +176,20 @@ EIF_BOOLEAN F2_36 (EIF_REFERENCE Current)
 EIF_REFERENCE F2_38 (EIF_REFERENCE Current)
 {
 	GTCX
+	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
 	
-	RTLI(2);
+	RTLI(3);
 	RTLR(0,Current);
-	RTLR(1,Result);
-	RTLIU(2);
+	RTLR(1,tr1);
+	RTLR(2,Result);
+	RTLIU(3);
 	
 	RTGC;
-	Result = RTOSCF(40,F2_40, (Current));
-	Result = F236_2041(RTCW(Result));
-	Result = F744_3655(RTCW(Result));
+	tr1 = F194_1890(RTCV(RTOSCF(40,F2_40, (Current))));
+	Result = F755_3845(RTCW(tr1));
 	RTLE;
 	return Result;
 }
@@ -199,26 +200,36 @@ EIF_REFERENCE F2_39 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
+	EIF_BOOLEAN tb1;
+	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
+	
 	RTLD;
 	
-	RTLI(4);
+	RTLI(5);
 	RTLR(0,loc1);
 	RTLR(1,Current);
 	RTLR(2,tr1);
 	RTLR(3,arg1);
-	RTLIU(4);
+	RTLR(4,Result);
+	RTLIU(5);
 	
 	RTGC;
 	tr1 = RTOSCF(40,F2_40, (Current));
-	tr1 = F236_2045(RTCW(tr1), arg1);
+	tr1 = F194_1894(RTCW(tr1), arg1);
 	loc1 = tr1;
 	if (EIF_TEST(loc1)) {
-		tr1 = F868_4956(loc1);
-		RTLE;
-		return (EIF_REFERENCE) tr1;
+		tb1 = F868_5292(loc1);
+		if (tb1) {
+			tr1 = F865_5183(loc1);
+			RTLE;
+			return (EIF_REFERENCE) tr1;
+		} else {
+			tr1 = RTLNS(eif_new_type(739, 0x01).id, 739, _OBJSIZ_0_0_0_0_0_0_0_0_);
+			Result = F740_3707(RTCW(tr1), loc1);
+		}
 	}
 	RTLE;
-	return (EIF_REFERENCE) 0;
+	return Result;
 }
 
 /* {KL_OPERATING_SYSTEM}.execution_environment */
@@ -239,7 +250,7 @@ static EIF_REFERENCE F2_40_body (EIF_REFERENCE Current)
 	RTOSP (40);
 #define Result RTOSR(40)
 	RTOC_NEW(Result);
-	tr1 = RTLNS(eif_new_type(235, 0x01).id, 235, _OBJSIZ_0_0_0_1_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(193, 0x01).id, 193, _OBJSIZ_0_0_0_1_0_0_0_0_);
 	Result = (EIF_REFERENCE) tr1;
 	RTOSE (40);
 	RTLE;
