@@ -6,8 +6,7 @@
 extern "C" {
 #endif
 
-static EIF_REFERENCE F37_483_body(EIF_REFERENCE);
-extern EIF_REFERENCE F37_483(EIF_REFERENCE);
+extern EIF_BOOLEAN F20_340(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit20(void);
 
 #ifdef __cplusplus
