@@ -6,8 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F31_402(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
-extern EIF_BOOLEAN F31_403(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
+RTOSHF (EIF_REFERENCE,656)
+static EIF_REFERENCE F45_656_body(EIF_REFERENCE);
+extern EIF_REFERENCE F45_656(EIF_REFERENCE);
 extern void EIF_Minit27(void);
 
 #ifdef __cplusplus
