@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,566)
-static EIF_REFERENCE F50_566_body(EIF_REFERENCE);
-extern EIF_REFERENCE F50_566(EIF_REFERENCE);
+extern EIF_BOOLEAN F32_368(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_BOOLEAN F32_369(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit28(void);
 
 #ifdef __cplusplus
