@@ -1,5 +1,5 @@
 /*
- * Code for class KL_SHARED_EXECUTION_ENVIRONMENT
+ * Code for class KL_SHARED_PLATFORM
  */
 
 #include "eif_eiffel.h"
@@ -22,16 +22,14 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {KL_SHARED_EXECUTION_ENVIRONMENT}.execution_environment */
-static EIF_REFERENCE F60_658_body (EIF_REFERENCE Current)
+/* {KL_SHARED_PLATFORM}.platform */
+static EIF_REFERENCE F63_750_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
-#define Result RTOTRR
-	RTOUDR(31)
 
 	RTLI(1);
 	RTLR(0,tr1);
@@ -39,20 +37,22 @@ static EIF_REFERENCE F60_658_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOTP;
-	tr1 = RTLNS(eif_new_type(842, 0x01).id, 842, _OBJSIZ_0_0_0_0_0_0_0_0_);
+	RTOSP (750);
+#define Result RTOSR(750)
+	RTOC_NEW(Result);
+	tr1 = RTLNS(eif_new_type(149, 0x01).id, 149, _OBJSIZ_0_0_0_0_0_0_0_0_);
 	Result = (EIF_REFERENCE) tr1;
-	RTOTE;
+	RTOSE (750);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F60_658 (EIF_REFERENCE Current)
+EIF_REFERENCE F63_750 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOUCR(31,F60_658_body,(Current));
+	return RTOSCF(750,F63_750_body,(Current));
 }
 
 void EIF_Minit36 (void)
