@@ -6,9 +6,7 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,55)
-static EIF_REFERENCE F5_55_body(EIF_REFERENCE);
-extern EIF_REFERENCE F5_55(EIF_REFERENCE);
+extern EIF_BOOLEAN F5_55(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit5(void);
 
 #ifdef __cplusplus
