@@ -6,8 +6,7 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F63_875(EIF_REFERENCE);
-extern void F63_878(EIF_REFERENCE, EIF_INTEGER_32);
+extern EIF_BOOLEAN F68_951(EIF_REFERENCE);
 extern void EIF_Minit45(void);
 
 #ifdef __cplusplus
