@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {PCRE_CHARACTER_SET}.make_empty */
-void F23_225 (EIF_REFERENCE Current)
+void F24_275 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -35,18 +35,18 @@ void F23_225 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_empty", 22, Current, 0, 0, 248);
+	RTEAA("make_empty", 23, Current, 0, 0, 316);
 	RTGC;
 	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {1387,1155,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {1419,1202,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNSP2(typres0.id,0,((EIF_INTEGER_32) 256L),sizeof(EIF_BOOLEAN), EIF_TRUE);
 	}
-	F1388_13061(RTCW(tr1), (EIF_BOOLEAN) 0, ((EIF_INTEGER_32) 256L));
+	F1420_13631(RTCW(tr1), (EIF_BOOLEAN) 0, ((EIF_INTEGER_32) 256L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTHOOK(3);
@@ -55,7 +55,7 @@ void F23_225 (EIF_REFERENCE Current)
 }
 
 /* {PCRE_CHARACTER_SET}.make */
-void F23_226 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F24_276 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -66,19 +66,19 @@ void F23_226 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,arg1);
 	RTLIU(2);
 	
-	RTEAA("make", 22, Current, 0, 1, 249);
+	RTEAA("make", 23, Current, 0, 1, 317);
 	RTGC;
 	RTHOOK(1);
-	F23_225(Current);
+	F24_275(Current);
 	RTHOOK(2);
-	F23_229(Current, arg1);
+	F24_279(Current, arg1);
 	RTHOOK(4);
 	RTLE;
 	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.has */
-EIF_BOOLEAN F23_228 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F24_278 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -94,7 +94,7 @@ EIF_BOOLEAN F23_228 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("has", 22, Current, 0, 1, 251);
+	RTEAA("has", 23, Current, 0, 1, 319);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN) (arg1 < ((EIF_INTEGER_32) 256L))) {
@@ -112,7 +112,7 @@ EIF_BOOLEAN F23_228 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_string */
-void F23_229 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F24_279 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -126,7 +126,7 @@ void F23_229 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("add_string", 22, Current, 2, 1, 252);
+	RTEAA("add_string", 23, Current, 2, 1, 309);
 	RTGC;
 	RTHOOK(1);
 	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
@@ -136,8 +136,8 @@ void F23_229 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 		RTHOOK(3);
 		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
 		RTHOOK(4);
-		ti4_1 = F1204_11054(RTCW(arg1), loc1);
-		F23_230(Current, ti4_1);
+		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R9971[Dtype(RTCW(arg1))-1251])(arg1, loc1);
+		F24_280(Current, ti4_1);
 		RTHOOK(5);
 		loc1++;
 	}
@@ -147,13 +147,12 @@ void F23_229 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_character */
-void F23_230 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F24_280 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(2);
@@ -161,7 +160,7 @@ void F23_230 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("add_character", 22, Current, 1, 1, 253);
+	RTEAA("add_character", 23, Current, 1, 1, 310);
 	RTGC;
 	RTHOOK(1);
 	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 256L));
@@ -177,7 +176,7 @@ void F23_230 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_set */
-void F23_231 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F24_281 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -195,7 +194,7 @@ void F23_231 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("add_set", 22, Current, 2, 1, 254);
+	RTEAA("add_set", 23, Current, 2, 1, 311);
 	RTGC;
 	RTHOOK(1);
 	loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
@@ -226,7 +225,7 @@ void F23_231 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_negated_set */
-void F23_232 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F24_282 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -244,7 +243,7 @@ void F23_232 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("add_negated_set", 22, Current, 2, 1, 255);
+	RTEAA("add_negated_set", 23, Current, 2, 1, 312);
 	RTGC;
 	RTHOOK(1);
 	loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
@@ -275,13 +274,12 @@ void F23_232 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.wipe_out */
-void F23_233 (EIF_REFERENCE Current)
+void F24_283 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(2);
@@ -289,7 +287,7 @@ void F23_233 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("wipe_out", 22, Current, 1, 0, 256);
+	RTEAA("wipe_out", 23, Current, 1, 0, 313);
 	RTGC;
 	RTHOOK(1);
 	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
