@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {PCRE_CHARACTER_SET}.make_empty */
-void F26_218 (EIF_REFERENCE Current)
+void F27_374 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -36,21 +36,21 @@ void F26_218 (EIF_REFERENCE Current)
 	
 	RTGC;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1105,977,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1252,1141,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNSP2(typres0.id,0,((EIF_INTEGER_32) 256L),sizeof(EIF_BOOLEAN), EIF_TRUE);
 	}
-	F1106_8919(RTCW(tr1), (EIF_BOOLEAN) 0, ((EIF_INTEGER_32) 256L));
+	F1253_11331(RTCW(tr1), (EIF_BOOLEAN) 0, ((EIF_INTEGER_32) 256L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
 /* {PCRE_CHARACTER_SET}.make */
-void F26_219 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F27_375 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTLD;
@@ -61,13 +61,13 @@ void F26_219 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F26_218(Current);
-	F26_222(Current, arg1);
+	F27_374(Current);
+	F27_378(Current, arg1);
 	RTLE;
 }
 
 /* {PCRE_CHARACTER_SET}.has */
-EIF_BOOLEAN F26_221 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F27_377 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -95,7 +95,7 @@ EIF_BOOLEAN F26_221 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_string */
-void F26_222 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F27_378 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -109,24 +109,23 @@ void F26_222 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
+	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8893[Dtype(arg1)-1187]);
 	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 	for (;;) {
 		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
-		ti4_1 = F1029_8107(RTCW(arg1), loc1);
-		F26_223(Current, ti4_1);
+		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R8869[Dtype(RTCW(arg1))-1189])(arg1, loc1);
+		F27_379(Current, ti4_1);
 		loc1++;
 	}
 	RTLE;
 }
 
 /* {PCRE_CHARACTER_SET}.add_character */
-void F26_223 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F27_379 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(2);
@@ -145,7 +144,7 @@ void F26_223 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_set */
-void F26_224 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F27_380 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -184,7 +183,7 @@ void F26_224 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.add_negated_set */
-void F26_225 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F27_381 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -223,12 +222,11 @@ void F26_225 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {PCRE_CHARACTER_SET}.wipe_out */
-void F26_226 (EIF_REFERENCE Current)
+void F27_382 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(2);
