@@ -23,9 +23,10 @@ extern "C" {
 #endif
 
 /* {PCRE_CHARACTER_SET}.make_empty */
-void F30_534 (EIF_REFERENCE Current)
+void F26_401 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -34,25 +35,30 @@ void F30_534 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
+	RTEAA("make_empty", 25, Current, 0, 0, 423);
 	RTGC;
+	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1209,1084,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,1180,1071,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNSP2(typres0.id,0,((EIF_INTEGER_32) 256L),sizeof(EIF_BOOLEAN), EIF_TRUE);
 	}
-	F1210_10713(RTCW(tr1), (EIF_BOOLEAN) 0, ((EIF_INTEGER_32) 256L));
+	F1181_11165(RTCW(tr1), (EIF_BOOLEAN) 0, ((EIF_INTEGER_32) 256L));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
+	RTHOOK(3);
 	RTLE;
+	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.make */
-void F30_535 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F26_402 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
+	RTEX;
 	RTLD;
 	
 	RTLI(2);
@@ -60,16 +66,22 @@ void F30_535 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,arg1);
 	RTLIU(2);
 	
+	RTEAA("make", 25, Current, 0, 1, 424);
 	RTGC;
-	F30_534(Current);
-	F30_538(Current, arg1);
+	RTHOOK(1);
+	F26_401(Current);
+	RTHOOK(2);
+	F26_405(Current, arg1);
+	RTHOOK(4);
 	RTLE;
+	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.has */
-EIF_BOOLEAN F30_537 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F26_404 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
+	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
@@ -82,22 +94,28 @@ EIF_BOOLEAN F30_537 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
+	RTEAA("has", 25, Current, 0, 1, 415);
 	RTGC;
+	RTHOOK(1);
 	if ((EIF_BOOLEAN) (arg1 < ((EIF_INTEGER_32) 256L))) {
+		RTHOOK(2);
 		tr1 = *(EIF_REFERENCE *)(Current);
 		/* INLINED CODE (SPECIAL.item) */
 		tb2 = *((EIF_BOOLEAN *)RTCW(tr1) + (arg1));
 		/* END INLINED CODE */
 		Result = tb2;
 	}
+	RTHOOK(3);
 	RTLE;
+	RTEE;
 	return Result;
 }
 
 /* {PCRE_CHARACTER_SET}.add_string */
-void F30_538 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F26_405 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 ti4_1;
@@ -108,25 +126,33 @@ void F30_538 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
+	RTEAA("add_string", 25, Current, 2, 1, 416);
 	RTGC;
-	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8435[Dtype(arg1)-1130]);
+	RTHOOK(1);
+	loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
+	RTHOOK(2);
 	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 	for (;;) {
+		RTHOOK(3);
 		if ((EIF_BOOLEAN) (loc1 > loc2)) break;
-		ti4_1 = F1133_9986(RTCW(arg1), loc1);
-		F30_539(Current, ti4_1);
+		RTHOOK(4);
+		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R8191[Dtype(RTCW(arg1))-1121])(arg1, loc1);
+		F26_406(Current, ti4_1);
+		RTHOOK(5);
 		loc1++;
 	}
+	RTHOOK(7);
 	RTLE;
+	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.add_character */
-void F30_539 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F26_406 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(2);
@@ -134,20 +160,26 @@ void F30_539 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
+	RTEAA("add_character", 25, Current, 1, 1, 417);
 	RTGC;
+	RTHOOK(1);
 	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 % ((EIF_INTEGER_32) 256L));
+	RTHOOK(2);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.put) */
 	*((EIF_BOOLEAN *)RTCW(tr1) + (loc1)) = (EIF_BOOLEAN) 1;
 	/* END INLINED CODE */
 	;
+	RTHOOK(4);
 	RTLE;
+	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.add_set */
-void F30_540 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F26_407 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
@@ -162,31 +194,41 @@ void F30_540 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
+	RTEAA("add_set", 25, Current, 2, 1, 418);
 	RTGC;
+	RTHOOK(1);
 	loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
+	RTHOOK(2);
 	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	for (;;) {
+		RTHOOK(3);
 		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 255L))) break;
+		RTHOOK(4);
 		/* INLINED CODE (SPECIAL.item) */
 		tb2 = *((EIF_BOOLEAN *)RTCW(loc2) + (loc1));
 		/* END INLINED CODE */
 		tb1 = tb2;
 		if (tb1) {
+			RTHOOK(5);
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.put) */
 			*((EIF_BOOLEAN *)RTCW(tr1) + (loc1)) = (EIF_BOOLEAN) 1;
 			/* END INLINED CODE */
 			;
 		}
+		RTHOOK(6);
 		loc1++;
 	}
+	RTHOOK(7);
 	RTLE;
+	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.add_negated_set */
-void F30_541 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F26_408 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
@@ -201,34 +243,43 @@ void F30_541 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
+	RTEAA("add_negated_set", 25, Current, 2, 1, 419);
 	RTGC;
+	RTHOOK(1);
 	loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
+	RTHOOK(2);
 	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	for (;;) {
+		RTHOOK(3);
 		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 255L))) break;
+		RTHOOK(4);
 		/* INLINED CODE (SPECIAL.item) */
 		tb2 = *((EIF_BOOLEAN *)RTCW(loc2) + (loc1));
 		/* END INLINED CODE */
 		tb1 = tb2;
 		if ((EIF_BOOLEAN) !tb1) {
+			RTHOOK(5);
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.put) */
 			*((EIF_BOOLEAN *)RTCW(tr1) + (loc1)) = (EIF_BOOLEAN) 1;
 			/* END INLINED CODE */
 			;
 		}
+		RTHOOK(6);
 		loc1++;
 	}
+	RTHOOK(7);
 	RTLE;
+	RTEE;
 }
 
 /* {PCRE_CHARACTER_SET}.wipe_out */
-void F30_542 (EIF_REFERENCE Current)
+void F26_409 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(2);
@@ -236,18 +287,25 @@ void F30_542 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
+	RTEAA("wipe_out", 25, Current, 1, 0, 420);
 	RTGC;
+	RTHOOK(1);
 	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 	for (;;) {
+		RTHOOK(2);
 		if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 255L))) break;
+		RTHOOK(3);
 		tr1 = *(EIF_REFERENCE *)(Current);
 		/* INLINED CODE (SPECIAL.put) */
 		*((EIF_BOOLEAN *)RTCW(tr1) + (loc1)) = (EIF_BOOLEAN) 0;
 		/* END INLINED CODE */
 		;
+		RTHOOK(4);
 		loc1++;
 	}
+	RTHOOK(6);
 	RTLE;
+	RTEE;
 }
 
 void EIF_Minit26 (void)
