@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F46_1729(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
+extern void F41_1509(EIF_REFERENCE, EIF_INTEGER_32, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit41(void);
-extern void F776_7631(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
