@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,784)
-static EIF_REFERENCE F58_784_body(EIF_REFERENCE);
-extern EIF_REFERENCE F58_784(EIF_REFERENCE);
+RTOSHF (EIF_CHARACTER_32,757)
+static EIF_CHARACTER_32 F65_757_body(EIF_REFERENCE);
+extern EIF_CHARACTER_32 F65_757(EIF_REFERENCE);
 extern void EIF_Minit38(void);
 
 #ifdef __cplusplus
