@@ -6,8 +6,10 @@
 extern "C" {
 #endif
 
-extern void F26_263(EIF_REFERENCE, EIF_INTEGER_32);
-extern void F26_266(EIF_REFERENCE);
+extern void F26_294(EIF_REFERENCE);
+extern EIF_BOOLEAN F26_296(EIF_REFERENCE);
+extern void F26_299(EIF_REFERENCE);
+extern void F26_300(EIF_REFERENCE);
 extern void EIF_Minit22(void);
 
 #ifdef __cplusplus
