@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.make */
-void F36_562 (EIF_REFERENCE Current)
+void F31_307 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -35,30 +34,25 @@ void F36_562 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make", 35, Current, 0, 0, 664);
 	RTGC;
-	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {937,966,1175,1177,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {911,819,1077,1079,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
 		tr1 = RTLNSMART(typres0.id);
 	}
-	F938_8125(RTCW(tr1));
+	F912_6921(RTCW(tr1));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.reset */
-void F36_563 (EIF_REFERENCE Current)
+void F31_308 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -67,21 +61,16 @@ void F36_563 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("reset", 35, Current, 0, 0, 665);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5784[Dtype(tr1)-590])(RTCW(tr1));
-	RTHOOK(2);
+	F912_6957(RTCW(tr1));
 	RTLE;
-	RTEE;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.add_default */
-void F36_564 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F31_309 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -91,21 +80,16 @@ void F36_564 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("add_default", 35, Current, 0, 1, 666);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTOUCR(545,F36_576,(Current));
-	F36_565(Current, arg1, tr1);
-	RTHOOK(2);
+	tr1 = RTOSCF(321,F31_321, (Current));
+	F31_310(Current, arg1, tr1);
 	RTLE;
-	RTEE;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.add */
-void F36_565 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+void F31_310 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	RTLD;
@@ -118,23 +102,18 @@ void F36_565 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 	RTLR(4,tr2);
 	RTLIU(5);
 	
-	RTEAA("add", 35, Current, 0, 2, 667);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	tr1 = F938_8127(RTCW(tr1));
-	tr2 = F36_573(Current, arg2);
-	F967_8426(RTCW(tr1), arg1, tr2);
-	RTHOOK(2);
+	tr1 = F912_6924(RTCW(tr1));
+	tr2 = F31_318(Current, arg2);
+	F820_6688(RTCW(tr1), arg1, tr2);
 	RTLE;
-	RTEE;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.shallow_has */
-EIF_BOOLEAN F36_567 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F31_312 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
@@ -150,30 +129,25 @@ EIF_BOOLEAN F36_567 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr2);
 	RTLIU(4);
 	
-	RTEAA("shallow_has", 35, Current, 0, 1, 669);
 	RTGC;
-	RTHOOK(1);
 	Result = '\0';
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1) + O7391[Dtype(tr1)-937]);
+	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_2_3_0_0_);
 	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = F938_8127(RTCW(tr1));
-		tr2 = F36_573(Current, arg1);
-		tb1 = F967_8386(RTCW(tr1), tr2);
+		tr1 = F912_6924(RTCW(tr1));
+		tr2 = F31_318(Current, arg1);
+		tb1 = F820_6649(RTCW(tr1), tr2);
 		Result = tb1;
 	}
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.has */
-EIF_BOOLEAN F36_568 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F31_313 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
@@ -192,38 +166,29 @@ EIF_BOOLEAN F36_568 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(4,tr1);
 	RTLIU(5);
 	
-	RTEAA("has", 35, Current, 2, 1, 670);
 	RTGC;
-	RTHOOK(1);
-	loc1 = F36_573(Current, arg1);
-	RTHOOK(2);
-	RTHOOK(3);
+	loc1 = F31_318(Current, arg1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	loc2 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7056[Dtype(tr1)-739])(RTCW(tr1));
+	loc2 = F912_6928(RTCW(tr1));
 	tb1 = EIF_FALSE;
 	for (;;) {
 		if (tb1) break;
-		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5991[Dtype(loc2)-650])(loc2);
+		tb2 = F515_5981(loc2);
 		if (tb2) break;
-		RTHOOK(4);
-		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5990[Dtype(loc2)-650])(loc2);
-		tb3 = F967_8386(RTCW(tr1), loc1);
+		tr1 = F515_5980(loc2);
+		tb3 = F820_6649(RTCW(tr1), loc1);
 		tb1 = tb3;
-		RTHOOK(5);
-		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5992[Dtype(loc2)-650])(loc2);
+		F515_5983(loc2);
 	}
 	Result = (EIF_BOOLEAN) tb1;
-	RTHOOK(6);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.resolve_default */
-EIF_REFERENCE F36_569 (EIF_REFERENCE Current)
+EIF_REFERENCE F31_314 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
@@ -235,22 +200,17 @@ EIF_REFERENCE F36_569 (EIF_REFERENCE Current)
 	RTLR(2,Result);
 	RTLIU(3);
 	
-	RTEAA("resolve_default", 35, Current, 0, 0, 671);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTOUCR(545,F36_576,(Current));
-	Result = F36_570(Current, tr1);
-	RTHOOK(2);
+	tr1 = RTOSCF(321,F31_321, (Current));
+	Result = F31_315(Current, tr1);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.resolve */
-EIF_REFERENCE F36_570 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_REFERENCE F31_315 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_BOOLEAN loc2 = (EIF_BOOLEAN) 0;
 	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
@@ -275,50 +235,37 @@ EIF_REFERENCE F36_570 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(7,loc5);
 	RTLIU(8);
 	
-	RTEAA("resolve", 35, Current, 5, 1, 672);
 	RTGC;
-	RTHOOK(1);
-	Result = RTOUCR(546,F36_577,(Current));
-	RTHOOK(2);
-	loc3 = F36_573(Current, arg1);
-	RTHOOK(3);
+	Result = RTOSCF(322,F31_322, (Current));
+	loc3 = F31_318(Current, arg1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	loc4 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R7056[Dtype(tr1)-739])(RTCW(tr1));
+	loc4 = F912_6928(RTCW(tr1));
 	for (;;) {
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5991[Dtype(loc4)-650])(loc4);
+		tb1 = F515_5981(loc4);
 		if (tb1) break;
-		RTHOOK(4);
 		if (loc2) break;
-		RTHOOK(5);
-		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5990[Dtype(loc4)-650])(loc4);
-		RTHOOK(6);
+		loc1 = F515_5980(loc4);
 		tb2 = '\0';
-		tb3 = F967_8386(RTCW(loc1), loc3);
+		tb3 = F820_6649(RTCW(loc1), loc3);
 		if (tb3) {
-			tr1 = F967_8384(RTCW(loc1), loc3);
+			tr1 = F820_6647(RTCW(loc1), loc3);
 			loc5 = tr1;
 			tb2 = EIF_TEST(loc5);
 		}
 		if (tb2) {
-			RTHOOK(7);
 			Result = (EIF_REFERENCE) loc5;
-			RTHOOK(8);
 			loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 		}
-		RTHOOK(9);
-		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5992[Dtype(loc4)-650])(loc4);
+		F515_5983(loc4);
 	}
-	RTHOOK(10);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.push */
-void F36_571 (EIF_REFERENCE Current)
+void F31_316 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	RTLD;
@@ -329,22 +276,17 @@ void F36_571 (EIF_REFERENCE Current)
 	RTLR(2,tr2);
 	RTLIU(3);
 	
-	RTEAA("push", 35, Current, 0, 0, 673);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	tr2 = F36_575(Current);
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R7371[Dtype(tr1)-937])(RTCW(tr1), tr2);
-	RTHOOK(2);
+	tr2 = F31_320(Current);
+	F912_6947(RTCW(tr1), tr2);
 	RTLE;
-	RTEE;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.pop */
-void F36_572 (EIF_REFERENCE Current)
+void F31_317 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	RTLD;
@@ -354,52 +296,33 @@ void F36_572 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("pop", 35, Current, 0, 0, 674);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1) + O7391[Dtype(tr1)-937]);
+	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_2_3_0_0_);
 	if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
-		RTHOOK(2);
 		tr1 = *(EIF_REFERENCE *)(Current);
-		F938_8143(RTCW(tr1));
-		RTHOOK(3);
+		F912_6940(RTCW(tr1));
 		tr1 = *(EIF_REFERENCE *)(Current);
-		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5797[Dtype(tr1)-590])(RTCW(tr1));
+		(FUNCTION_CAST(void, (EIF_REFERENCE)) R5465[Dtype(RTCW(tr1))-768])(tr1);
 	}
-	RTHOOK(4);
 	RTLE;
-	RTEE;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.to_context_key */
-EIF_REFERENCE F36_573 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_REFERENCE F31_318 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	
 	
-	RTEAA("to_context_key", 35, Current, 0, 1, 675);
-	RTHOOK(1);
-	tr1 = F1173_10497(RTCW(arg1));
-	RTHOOK(2);
-	RTEE;
+	tr1 = F1070_8329(RTCW(arg1));
 	return (EIF_REFERENCE) tr1;
 }
 
-/* {XML_NAMESPACE_RESOLVER_CONTEXT}.context */
-EIF_REFERENCE F36_574 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.new_string_string_table */
-EIF_REFERENCE F36_575 (EIF_REFERENCE Current)
+EIF_REFERENCE F31_320 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -408,38 +331,34 @@ EIF_REFERENCE F36_575 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("new_string_string_table", 35, Current, 0, 0, 677);
 	RTGC;
-	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {966,1175,1177,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {819,1077,1079,0xFFFF};
 		EIF_TYPE typres0;
 		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
 		
 		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
-		tr1 = RTLNS(typres0.id, 966, _OBJSIZ_7_3_0_7_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 819, _OBJSIZ_7_3_0_7_0_0_0_0_);
 	}
-	F967_8380(RTCW(tr1), ((EIF_INTEGER_32) 5L));
-	RTHOOK(2);
+	F820_6641(RTCW(tr1), ((EIF_INTEGER_32) 5L));
 	RTLE;
-	RTEE;
 	return (EIF_REFERENCE) tr1;
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.default_pseudo_prefix */
 
-EIF_REFERENCE F36_576 (EIF_REFERENCE Current)
+EIF_REFERENCE F31_321 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (545,RTMS32_EX_H("",0,0));
+	RTOSC (321,RTMS32_EX_H("",0,0));
 }
 
 /* {XML_NAMESPACE_RESOLVER_CONTEXT}.default_namespace */
 
-EIF_REFERENCE F36_577 (EIF_REFERENCE Current)
+EIF_REFERENCE F31_322 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (546,RTMS32_EX_H("",0,0));
+	RTOSC (322,RTMS32_EX_H("",0,0));
 }
 
 void EIF_Minit31 (void)
