@@ -24,11 +24,27 @@ extern "C" {
 extern "C" {
 #endif
 
+/* {ARRAY}.make_empty */
+void F684_3620 (EIF_REFERENCE Current)
+{
+	GTCX
+	RTLD;
+	
+	RTLI(1);
+	RTLR(0,Current);
+	RTLIU(1);
+	
+	RTGC;
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
+	F231_2365(Current, ((EIF_INTEGER_32) 0L));
+	RTLE;
+}
+
 /* {ARRAY}.make_filled */
-void F561_3322 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F684_3621 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	RTLD;
 	
@@ -36,29 +52,20 @@ void F561_3322 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EI
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("make_filled", 560, Current, 1, 3, 4690);
 	RTGC;
-	RTHOOK(1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg2;
-	RTHOOK(2);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg3;
-	RTHOOK(3);
 	if ((EIF_BOOLEAN) (arg2 <= arg3)) {
-		RTHOOK(4);
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L));
 	}
-	RTHOOK(5);
-	F187_2353(Current, arg1, loc1);
-	RTHOOK(9);
+	F231_2366(Current, arg1, loc1);
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAY}.make */
-void F561_3323 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F684_3622 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
@@ -68,32 +75,47 @@ void F561_3323 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make", 560, Current, 0, 2, 4691);
 	RTGC;
-	RTHOOK(1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg1;
-	RTHOOK(2);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg2;
-	RTHOOK(3);
 	if ((EIF_BOOLEAN) (arg1 <= arg2)) {
-		RTHOOK(4);
-		tr1 = RTLNTY2(eif_final_id(Y2407,Y2407_gen_type,Dftype(Current),229), 0x00);
-		tp1 = F757_4285(tr1);
-		F187_2353(Current, tp1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
+		tr1 = RTLNTY2(eif_final_id(Y2634,Y2634_gen_type,Dftype(Current),323), 0x00);
+		tp1 = F781_4176(tr1);
+		F231_2366(Current, tp1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
 	} else {
-		RTHOOK(5);
-		F187_2352(Current, ((EIF_INTEGER_32) 0L));
+		F231_2365(Current, ((EIF_INTEGER_32) 0L));
 	}
-	RTHOOK(9);
 	RTLE;
-	RTEE;
+}
+
+/* {ARRAY}.make_from_array */
+void F684_3623 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+{
+	GTCX
+	EIF_REFERENCE tr1 = NULL;
+	EIF_INTEGER_32 ti4_1;
+	RTLD;
+	
+	RTLI(3);
+	RTLR(0,arg1);
+	RTLR(1,tr1);
+	RTLR(2,Current);
+	RTLIU(3);
+	
+	RTGC;
+	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
+	F231_2372(Current, tr1);
+	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ti4_1;
+	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
+	RTLE;
 }
 
 /* {ARRAY}.make_from_special */
-void F561_3325 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F684_3624 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	RTLD;
 	
@@ -102,25 +124,18 @@ void F561_3325 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("make_from_special", 560, Current, 0, 1, 4693);
 	RTGC;
-	RTHOOK(1);
-	F187_2359(Current, arg1);
-	RTHOOK(2);
+	F231_2372(Current, arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	RTHOOK(3);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
-	RTHOOK(7);
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAY}.item */
-EIF_POINTER F561_3327 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F684_3626 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
@@ -134,99 +149,52 @@ EIF_POINTER F561_3327 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("item", 560, Current, 0, 1, 4695);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.item) */
 	tp2 = *((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
 	/* END INLINED CODE */
 	Result = tp2;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
-	return Result;
-}
-
-/* {ARRAY}.at */
-EIF_POINTER F561_3328 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	RTEX;
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTEAA("at", 560, Current, 0, 1, 4696);
-	RTGC;
-	RTHOOK(1);
-	tr1 = *(EIF_REFERENCE *)(Current);
-	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
-	/* END INLINED CODE */
-	Result = tp2;
-	RTHOOK(2);
-	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {ARRAY}.lower */
-EIF_INTEGER_32 F561_3332 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F684_3631 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 }
 
 
 /* {ARRAY}.upper */
-EIF_INTEGER_32 F561_3333 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F684_3632 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 }
 
 
 /* {ARRAY}.count */
-EIF_INTEGER_32 F561_3334 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F684_3633 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("count", 560, Current, 0, 0, 4702);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
 	return (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L));
 }
 
 /* {ARRAY}.capacity */
-EIF_INTEGER_32 F561_3335 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F684_3634 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("capacity", 560, Current, 0, 0, 4703);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
 	return (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L));
 }
 
 /* {ARRAY}.is_equal */
-EIF_BOOLEAN F561_3337 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F684_3636 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_POINTER tp1;
 	EIF_POINTER tp2;
@@ -246,17 +214,11 @@ EIF_BOOLEAN F561_3337 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr2);
 	RTLIU(4);
 	
-	RTEAA("is_equal", 560, Current, 1, 1, 4705);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == Current)) {
-		RTHOOK(2);
-		RTHOOK(3);
 		RTLE;
-		RTEE;
 		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 	} else {
-		RTHOOK(4);
 		tb1 = '\0';
 		tb2 = '\0';
 		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
@@ -269,63 +231,41 @@ EIF_BOOLEAN F561_3337 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 			tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) == tb2);
 		}
 		if (tb1) {
-			RTHOOK(5);
 			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
-				RTHOOK(6);
 				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-				RTHOOK(7);
 				loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 				for (;;) {
-					RTHOOK(8);
 					if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !Result || (EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)))) break;
-					RTHOOK(9);
-					tp1 = F561_3327(Current, loc1);
-					tp2 = F561_3327(RTCW(arg1), loc1);
+					tp1 = F684_3626(Current, loc1);
+					tp2 = F684_3626(RTCW(arg1), loc1);
 					Result = (EIF_BOOLEAN) (tp1 == tp2);
-					RTHOOK(10);
 					loc1++;
 				}
 			} else {
-				RTHOOK(11);
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-				ti4_1 = F561_3334(Current);
-				Result = F660_3946(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
+				ti4_1 = F684_3633(Current);
+				Result = F659_3548(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
 			}
 		}
 	}
-	RTHOOK(12);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {ARRAY}.valid_index */
-EIF_BOOLEAN F561_3342 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F684_3641 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
-	
-	RTEAA("valid_index", 560, Current, 0, 1, 4710);
-	RTHOOK(1);
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 <= arg1) && (EIF_BOOLEAN) (arg1 <= ti4_2));
-	RTHOOK(2);
-	RTEE;
-	return Result;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) <= arg1) && (EIF_BOOLEAN) (arg1 <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)));
 }
 
 /* {ARRAY}.put */
-void F561_3346 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+void F684_3645 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	RTLD;
@@ -335,65 +275,59 @@ void F561_3346 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("put", 560, Current, 0, 2, 4714);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.put) */
 	*((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 	/* END INLINED CODE */
 	;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 }
 
-/* {ARRAY}.grow */
-void F561_3365 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+/* {ARRAY}.subcopy */
+void F684_3650 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
-	RTEX;
 	EIF_POINTER tp1;
 	EIF_REFERENCE tr1 = NULL;
+	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
+	EIF_INTEGER_32 ti4_4;
+	EIF_INTEGER_32 ti4_5;
+	EIF_INTEGER_32 ti4_6;
 	RTLD;
 	
-	RTLI(2);
+	RTLI(4);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLIU(2);
+	RTLR(2,arg1);
+	RTLR(3,tr2);
+	RTLIU(4);
 	
-	RTEAA("grow", 560, Current, 0, 1, 4733);
 	RTGC;
-	RTHOOK(1);
-	if ((EIF_BOOLEAN) (arg1 > F561_3335(Current))) {
-		RTHOOK(2);
-		tr1 = RTLNTY2(eif_final_id(Y2407,Y2407_gen_type,Dftype(Current),229), 0x00);
-		tp1 = F757_4285(tr1);
-		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-		ti4_3 = F561_3335(Current);
-		F561_3367(Current, tp1, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_2 + arg1) - ti4_3));
-	}
-	RTHOOK(3);
+	tr1 = *(EIF_REFERENCE *)(Current);
+	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
+	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
+	/* INLINED CODE (SPECIAL.copy_data) */
+	memmove((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_POINTER *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	/* END INLINED CODE */
+	;
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAY}.conservative_resize_with_default */
-void F561_3367 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F684_3666 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
 	RTLD;
 	
 	RTLI(2);
@@ -401,65 +335,46 @@ void F561_3367 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EI
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("conservative_resize_with_default", 560, Current, 4, 3, 4735);
 	RTGC;
-	RTHOOK(1);
-	if (F561_3379(Current)) {
-		RTHOOK(2);
+	if (F684_3678(Current)) {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = F660_3966(RTCW(tr1), arg1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
-		F187_2359(Current, tr1);
-		RTHOOK(3);
+		tr1 = F659_3568(RTCW(tr1), arg1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+		F231_2372(Current, tr1);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg2;
-		RTHOOK(4);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg3;
 	} else {
-		RTHOOK(5);
 		loc2 = eif_min_int32 (arg2,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_));
-		RTHOOK(6);
 		loc3 = eif_max_int32 (arg3,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
-		RTHOOK(7);
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 - loc2) + ((EIF_INTEGER_32) 1L));
-		RTHOOK(8);
 		tr1 = *(EIF_REFERENCE *)(Current);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 		if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
-			RTHOOK(9);
 			tr1 = *(EIF_REFERENCE *)(Current);
-			tr1 = F660_3966(RTCW(tr1), arg1, loc1);
-			F187_2359(Current, tr1);
+			tr1 = F659_3568(RTCW(tr1), arg1, loc1);
+			F231_2372(Current, tr1);
 		}
-		RTHOOK(10);
 		if ((EIF_BOOLEAN) (loc2 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
-			RTHOOK(11);
 			loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 			loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - loc2);
-			RTHOOK(12);
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.overlapping_move) */
 			memmove((EIF_POINTER *)RTCW(tr1) + (loc4),(EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
 			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc4 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
 			/* END INLINED CODE */
 			;
-			RTHOOK(13);
 			tr1 = *(EIF_REFERENCE *)(Current);
-			F660_3952(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc4 - ((EIF_INTEGER_32) 1L)));
+			F659_3554(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc4 - ((EIF_INTEGER_32) 1L)));
 		}
-		RTHOOK(14);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc2;
-		RTHOOK(15);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc3;
 	}
-	RTHOOK(18);
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAY}.copy */
-void F561_3375 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F684_3674 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -469,27 +384,20 @@ void F561_3375 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("copy", 560, Current, 0, 1, 4743);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
-		RTHOOK(2);
-		eif_builtin_ANY_standard_copy (Current, arg1);
-		RTHOOK(3);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
-		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
-		F187_2359(Current, tr1);
+		tr1 = F1_14(tr1);
+		F231_2372(Current, tr1);
 	}
-	RTHOOK(5);
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAY}.empty_area */
-EIF_BOOLEAN F561_3379 (EIF_REFERENCE Current)
+EIF_BOOLEAN F684_3678 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -501,15 +409,11 @@ EIF_BOOLEAN F561_3379 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("empty_area", 560, Current, 0, 0, 4747);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
