@@ -1,5 +1,5 @@
 /*
- * Code for class reference CHARACTER_32
+ * Code for class reference CHARACTER_8
  */
 
 #include "eif_eiffel.h"
@@ -22,8 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CHARACTER_32}.code */
-EIF_INTEGER_32 F980_7762 (EIF_REFERENCE Current)
+/* {CHARACTER_8}.code */
+EIF_INTEGER_32 F1098_10749 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -35,27 +35,18 @@ EIF_INTEGER_32 F980_7762 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	Result = (EIF_INTEGER_32) F980_7763(Current);
+	Result = (EIF_INTEGER_32) F1097_10703(Current);
 	RTLE;
 	return Result;
 }
 
-/* {CHARACTER_32}.natural_32_code */
-EIF_NATURAL_32 F980_7763 (EIF_REFERENCE Current)
+/* {CHARACTER_8}.to_character_32 */
+EIF_CHARACTER_32 F1098_10750 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_32) F979_7729(Current);
-}
-
-/* {CHARACTER_32}.to_character_8 */
-EIF_CHARACTER_8 F980_7764 (EIF_REFERENCE Current)
-{
-	GTCX
-	
-	
-	return (EIF_CHARACTER_8) F979_7744(Current);
+	return (EIF_CHARACTER_32) F1097_10720(Current);
 }
 
 void EIF_Minit459 (void)
