@@ -1,5 +1,5 @@
 /*
- * Code for class reference CHARACTER_8
+ * Code for class CHARACTER_32
  */
 
 #include "eif_eiffel.h"
@@ -22,8 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CHARACTER_8}.code */
-EIF_INTEGER_32 F1101_9726 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.code */
+EIF_INTEGER_32 F1024_8110 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -35,18 +35,27 @@ EIF_INTEGER_32 F1101_9726 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	Result = (EIF_INTEGER_32) F1100_9683(Current);
+	Result = (EIF_INTEGER_32) F1024_8111(Current);
 	RTLE;
 	return Result;
 }
 
-/* {CHARACTER_8}.to_character_32 */
-EIF_CHARACTER_32 F1101_9727 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.natural_32_code */
+EIF_NATURAL_32 F1024_8111 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_CHARACTER_32) F1100_9700(Current);
+	return (EIF_NATURAL_32) F1022_8076(Current);
+}
+
+/* {CHARACTER_32}.to_character_8 */
+EIF_CHARACTER_8 F1024_8112 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_CHARACTER_8) F1022_8091(Current);
 }
 
 void EIF_Minit477 (void)
