@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {CHARACTER_32}.code */
-EIF_INTEGER_32 F1004_7753 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1127_10052 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
@@ -35,42 +34,28 @@ EIF_INTEGER_32 F1004_7753 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("code", 1003, Current, 0, 0, 11719);
 	RTGC;
-	RTHOOK(1);
-	Result = (EIF_INTEGER_32) F1004_7754(Current);
-	RTHOOK(2);
+	Result = (EIF_INTEGER_32) F1127_10053(Current);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {CHARACTER_32}.natural_32_code */
-EIF_NATURAL_32 F1004_7754 (EIF_REFERENCE Current)
+EIF_NATURAL_32 F1127_10053 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("natural_32_code", 1003, Current, 0, 0, 11720);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
-	return (EIF_NATURAL_32) F1003_7720(Current);
+	return (EIF_NATURAL_32) F1126_10018(Current);
 }
 
 /* {CHARACTER_32}.to_character_8 */
-EIF_CHARACTER_8 F1004_7755 (EIF_REFERENCE Current)
+EIF_CHARACTER_8 F1127_10054 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("to_character_8", 1003, Current, 0, 0, 11721);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
-	return (EIF_CHARACTER_8) F1003_7735(Current);
+	return (EIF_CHARACTER_8) F1126_10033(Current);
 }
 
 void EIF_Minit482 (void)
