@@ -1,5 +1,5 @@
 /*
- * Code for class CHARACTER_8
+ * Code for class CHARACTER_32
  */
 
 #include "eif_eiffel.h"
@@ -22,11 +22,10 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CHARACTER_8}.code */
-EIF_INTEGER_32 F1012_7845 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.code */
+EIF_INTEGER_32 F1129_10076 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
@@ -35,28 +34,28 @@ EIF_INTEGER_32 F1012_7845 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("code", 1011, Current, 0, 0, 11816);
 	RTGC;
-	RTHOOK(1);
-	Result = (EIF_INTEGER_32) F1010_7802(Current);
-	RTHOOK(2);
+	Result = (EIF_INTEGER_32) F1129_10077(Current);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
-/* {CHARACTER_8}.to_character_32 */
-EIF_CHARACTER_32 F1012_7846 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.natural_32_code */
+EIF_NATURAL_32 F1129_10077 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("to_character_32", 1011, Current, 0, 0, 11817);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
-	return (EIF_CHARACTER_32) F1010_7819(Current);
+	return (EIF_NATURAL_32) F1127_10042(Current);
+}
+
+/* {CHARACTER_32}.to_character_8 */
+EIF_CHARACTER_8 F1129_10078 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_CHARACTER_8) F1127_10057(Current);
 }
 
 void EIF_Minit488 (void)
