@@ -1,5 +1,5 @@
 /*
- * Code for class CONF_NOTABLE
+ * Code for class CONTAINER [POINTER]
  */
 
 #include "eif_eiffel.h"
@@ -22,14 +22,13 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CONF_NOTABLE}.set_note_node */
-void F531_7333 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+/* {CONTAINER}.compare_objects */
+void F439_3057 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	RTAR(Current, arg1);
-	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
+	*(EIF_BOOLEAN *)(Current + O2736[Dtype(Current)-437]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
 void EIF_Minit469 (void)
