@@ -6,8 +6,9 @@
 extern "C" {
 #endif
 
-extern void F531_7333(EIF_REFERENCE, EIF_REFERENCE);
+extern void F439_3057(EIF_REFERENCE);
 extern void EIF_Minit469(void);
+extern long O2736[];
 
 #ifdef __cplusplus
 }
