@@ -6,10 +6,9 @@
 extern "C" {
 #endif
 
-extern void F1037_6621(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
+extern void F1093_7293(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit469(void);
-extern char *(*R5022[])();
-extern char *(*R5029[])();
+extern void F77_1057(EIF_REFERENCE, EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
