@@ -6,12 +6,10 @@
 extern "C" {
 #endif
 
-extern void F1084_9817(EIF_REFERENCE);
-extern void F1084_9819(EIF_REFERENCE);
+extern EIF_REFERENCE F1096_9682(EIF_REFERENCE);
 extern void EIF_Minit454(void);
-extern char *(*R10593[])();
-extern char *(*R10594[])();
-extern long O7741[];
+extern EIF_REFERENCE F88_1308(EIF_REFERENCE);
+extern char *(*R7905[])();
 
 #ifdef __cplusplus
 }
