@@ -5,13 +5,11 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+RTOSHF (EIF_REFERENCE, 9619)
 
-extern void F1093_9407(EIF_REFERENCE);
-extern void F1093_9409(EIF_REFERENCE);
+
+extern EIF_REFERENCE F1105_9619(EIF_REFERENCE);
 extern void EIF_Minit461(void);
-extern char *(*R9064[])();
-extern char *(*R9065[])();
-extern long O7343[];
 
 #ifdef __cplusplus
 }
