@@ -6,10 +6,9 @@
 extern "C" {
 #endif
 
-extern void F1094_9412(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F1097_9804(EIF_REFERENCE);
 extern void EIF_Minit462(void);
-extern char *(*R9047[])();
-extern long O7343[];
+extern EIF_REFERENCE F1094_9783(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
