@@ -6,8 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1108_9967(EIF_REFERENCE);
+extern void F1119_10024(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit480(void);
+extern char *(*R9720[])();
+extern long O7928[];
 
 #ifdef __cplusplus
 }
