@@ -6,10 +6,11 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1123_10303(EIF_REFERENCE);
+extern EIF_REFERENCE F1127_10104(EIF_REFERENCE);
 extern void EIF_Minit491(void);
-extern EIF_REFERENCE F70_1937(EIF_REFERENCE);
-extern char *(*R8380[])();
+extern EIF_REFERENCE F1190_11269(EIF_REFERENCE);
+extern long O8104[];
+extern long O7125[];
 
 #ifdef __cplusplus
 }
