@@ -1,5 +1,5 @@
 /*
- * Code for class FINITE [CHARACTER_32]
+ * Code for class FINITE [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,9 +23,10 @@ extern "C" {
 #endif
 
 /* {FINITE}.is_empty */
-EIF_BOOLEAN F487_2687 (EIF_REFERENCE Current)
+EIF_BOOLEAN F503_2965 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
@@ -35,10 +36,14 @@ EIF_BOOLEAN F487_2687 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
+	RTEAA("is_empty", 502, Current, 0, 0, 4043);
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2420[Dtype(Current)-612])(Current);
+	RTHOOK(1);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2598[Dtype(Current)-563])(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
+	RTHOOK(2);
 	RTLE;
+	RTEE;
 	return Result;
 }
 
