@@ -6,7 +6,9 @@
 extern "C" {
 #endif
 
-extern void F666_3243(EIF_REFERENCE, EIF_INTEGER_32);
+RTOSHF (EIF_REFERENCE,8543)
+static EIF_REFERENCE F1164_8543_body(EIF_REFERENCE);
+extern EIF_REFERENCE F1164_8543(EIF_REFERENCE);
 extern void EIF_Minit461(void);
 
 #ifdef __cplusplus
