@@ -5,11 +5,13 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+RTOSHF (EIF_REFERENCE, 12458)
 
-RTOSHF (EIF_REFERENCE,10724)
-static EIF_REFERENCE F1127_10724_body(EIF_REFERENCE);
-extern EIF_REFERENCE F1127_10724(EIF_REFERENCE);
+
+extern EIF_REFERENCE F1372_12458(EIF_REFERENCE);
+extern void F1372_12459(EIF_REFERENCE);
 extern void EIF_Minit473(void);
+extern void F691_5666(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
