@@ -1,5 +1,5 @@
 /*
- * Code for class KL_IMPORTED_STRING_ROUTINES
+ * Code for class KL_IMPORTED_ANY_ROUTINES
  */
 
 #include "eif_eiffel.h"
@@ -22,8 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {KL_IMPORTED_STRING_ROUTINES}.string_ */
-static EIF_REFERENCE F1141_10813_body (EIF_REFERENCE Current)
+/* {KL_IMPORTED_ANY_ROUTINES}.any_ */
+static EIF_REFERENCE F1044_9574_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -31,28 +31,31 @@ static EIF_REFERENCE F1141_10813_body (EIF_REFERENCE Current)
 	RTLD;
 	
 
-	RTLI(1);
+	RTLI(2);
 	RTLR(0,tr1);
-	RTLIU(1);
+	RTLR(1,Current);
+	RTLIU(2);
 	
-	RTEV;
+	RTEAA("any_", 1043, Current, 0, 0, 13409);
 	RTGC;
-	RTOSP (10813);
-#define Result RTOSR(10813)
+	RTOSP (9574);
+#define Result RTOSR(9574)
 	RTOC_NEW(Result);
-	tr1 = RTLNS(eif_new_type(1127, 0x00).id, 1127, _OBJSIZ_0_0_0_0_0_0_0_0_);
+	RTHOOK(1);
+	tr1 = RTLNS(eif_new_type(19, 0x01).id, 19, _OBJSIZ_0_0_0_0_0_0_0_0_);
 	Result = (EIF_REFERENCE) tr1;
-	RTOSE (10813);
+	RTOSE (9574);
+	RTHOOK(3);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F1141_10813 (EIF_REFERENCE Current)
+EIF_REFERENCE F1044_9574 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(10813,F1141_10813_body,(Current));
+	return RTOSCF(9574,F1044_9574_body,(Current));
 }
 
 void EIF_Minit483 (void)
