@@ -6,10 +6,11 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,10852)
-static EIF_REFERENCE F1143_10852_body(EIF_REFERENCE);
-extern EIF_REFERENCE F1143_10852(EIF_REFERENCE);
+extern void F1300_9395(EIF_REFERENCE);
+extern void F1300_9396(EIF_REFERENCE);
 extern void EIF_Minit484(void);
+extern void F733_4212(EIF_REFERENCE);
+extern void F733_4213(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
