@@ -5,8 +5,10 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+RTOSHF (EIF_REFERENCE, 9397)
 
-extern EIF_BOOLEAN F189_1689(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
+
+extern EIF_REFERENCE F1301_9397(EIF_REFERENCE);
 extern void EIF_Minit485(void);
 
 #ifdef __cplusplus
