@@ -6,8 +6,8 @@
 extern "C" {
 #endif
 
-extern void F208_1699(EIF_REFERENCE);
-extern EIF_BOOLEAN F208_1700(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
+static EIF_REFERENCE F1175_11509_body(EIF_REFERENCE);
+extern EIF_REFERENCE F1175_11509(EIF_REFERENCE);
 extern void EIF_Minit492(void);
 
 #ifdef __cplusplus
