@@ -1,5 +1,5 @@
 /*
- * Code for class reference NATURAL_16
+ * Code for class NATURAL_16
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {NATURAL_16}.is_less */
-EIF_BOOLEAN F1082_9355 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+EIF_BOOLEAN F1089_9573 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -37,15 +37,15 @@ EIF_BOOLEAN F1082_9355 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1082, 0x00).id, 1082, _OBJSIZ_0_0_1_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1088, 0x00).id, 1088, _OBJSIZ_0_0_1_0_0_0_0_0_);
 	*(EIF_NATURAL_16 *)tr1 = arg1;
-	Result = F1081_9299(Current, tr1);
+	Result = F1087_9513(Current, tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_16}.plus */
-EIF_NATURAL_16 F1082_9356 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+EIF_NATURAL_16 F1089_9574 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -59,16 +59,16 @@ EIF_NATURAL_16 F1082_9356 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1082, 0x00).id, 1082, _OBJSIZ_0_0_1_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1088, 0x00).id, 1088, _OBJSIZ_0_0_1_0_0_0_0_0_);
 	*(EIF_NATURAL_16 *)tr1 = arg1;
-	tr1 = F1081_9308(Current, tr1);
+	tr1 = F1087_9522(Current, tr1);
 	Result = *(EIF_NATURAL_16 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_16}.integer_quotient */
-EIF_NATURAL_16 F1082_9361 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+EIF_NATURAL_16 F1089_9579 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -82,16 +82,16 @@ EIF_NATURAL_16 F1082_9361 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1082, 0x00).id, 1082, _OBJSIZ_0_0_1_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1088, 0x00).id, 1088, _OBJSIZ_0_0_1_0_0_0_0_0_);
 	*(EIF_NATURAL_16 *)tr1 = arg1;
-	tr1 = F1081_9314(Current, tr1);
+	tr1 = F1087_9528(Current, tr1);
 	Result = *(EIF_NATURAL_16 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_16}.integer_remainder */
-EIF_NATURAL_16 F1082_9362 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+EIF_NATURAL_16 F1089_9580 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -105,70 +105,70 @@ EIF_NATURAL_16 F1082_9362 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1082, 0x00).id, 1082, _OBJSIZ_0_0_1_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1088, 0x00).id, 1088, _OBJSIZ_0_0_1_0_0_0_0_0_);
 	*(EIF_NATURAL_16 *)tr1 = arg1;
-	tr1 = F1081_9315(Current, tr1);
+	tr1 = F1087_9529(Current, tr1);
 	Result = *(EIF_NATURAL_16 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_16}.as_natural_8 */
-EIF_NATURAL_8 F1082_9364 (EIF_REFERENCE Current)
+EIF_NATURAL_8 F1089_9582 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_8) F1081_9321(Current);
+	return (EIF_NATURAL_8) F1087_9535(Current);
 }
 
 /* {NATURAL_16}.as_natural_32 */
-EIF_NATURAL_32 F1082_9366 (EIF_REFERENCE Current)
+EIF_NATURAL_32 F1089_9584 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_32) F1081_9323(Current);
+	return (EIF_NATURAL_32) F1087_9537(Current);
 }
 
 /* {NATURAL_16}.as_natural_64 */
-EIF_NATURAL_64 F1082_9367 (EIF_REFERENCE Current)
+EIF_NATURAL_64 F1089_9585 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_64) F1081_9324(Current);
+	return (EIF_NATURAL_64) F1087_9538(Current);
 }
 
 /* {NATURAL_16}.as_integer_32 */
-EIF_INTEGER_32 F1082_9370 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1089_9588 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_INTEGER_32) F1081_9327(Current);
+	return (EIF_INTEGER_32) F1087_9541(Current);
 }
 
 /* {NATURAL_16}.to_character_8 */
-EIF_CHARACTER_8 F1082_9374 (EIF_REFERENCE Current)
+EIF_CHARACTER_8 F1089_9592 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_CHARACTER_8) F1081_9342(Current);
+	return (EIF_CHARACTER_8) F1087_9560(Current);
 }
 
 /* {NATURAL_16}.to_character_32 */
-EIF_CHARACTER_32 F1082_9375 (EIF_REFERENCE Current)
+EIF_CHARACTER_32 F1089_9593 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_CHARACTER_32) F1081_9343(Current);
+	return (EIF_CHARACTER_32) F1087_9561(Current);
 }
 
 /* {NATURAL_16}.bit_and */
-EIF_NATURAL_16 F1082_9376 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+EIF_NATURAL_16 F1089_9594 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -182,21 +182,30 @@ EIF_NATURAL_16 F1082_9376 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1082, 0x00).id, 1082, _OBJSIZ_0_0_1_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1088, 0x00).id, 1088, _OBJSIZ_0_0_1_0_0_0_0_0_);
 	*(EIF_NATURAL_16 *)tr1 = arg1;
-	tr1 = F1081_9344(Current, tr1);
+	tr1 = F1087_9562(Current, tr1);
 	Result = *(EIF_NATURAL_16 *)(tr1);
 	RTLE;
 	return Result;
 }
 
-/* {NATURAL_16}.bit_shift_right */
-EIF_NATURAL_16 F1082_9381 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+/* {NATURAL_16}.bit_shift_left */
+EIF_NATURAL_16 F1089_9598 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	return *(EIF_NATURAL_16 *)F1081_9350(Current, arg1);
+	return *(EIF_NATURAL_16 *)F1087_9567(Current, arg1);
+}
+
+/* {NATURAL_16}.bit_shift_right */
+EIF_NATURAL_16 F1089_9599 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+{
+	GTCX
+	
+	
+	return *(EIF_NATURAL_16 *)F1087_9568(Current, arg1);
 }
 
 void EIF_Minit452 (void)
