@@ -1,5 +1,5 @@
 /*
- * Code for class reference NATURAL_8
+ * Code for class NATURAL_8
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {NATURAL_8}.is_less */
-EIF_BOOLEAN F1085_9446 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+EIF_BOOLEAN F1092_9668 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -37,15 +37,15 @@ EIF_BOOLEAN F1085_9446 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
 	*(EIF_NATURAL_8 *)tr1 = arg1;
-	Result = F1084_9390(Current, tr1);
+	Result = F1090_9608(Current, tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_8}.plus */
-EIF_NATURAL_8 F1085_9447 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+EIF_NATURAL_8 F1092_9669 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -59,16 +59,39 @@ EIF_NATURAL_8 F1085_9447 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
 	*(EIF_NATURAL_8 *)tr1 = arg1;
-	tr1 = F1084_9399(Current, tr1);
+	tr1 = F1090_9617(Current, tr1);
+	Result = *(EIF_NATURAL_8 *)(tr1);
+	RTLE;
+	return Result;
+}
+
+/* {NATURAL_8}.minus */
+EIF_NATURAL_8 F1092_9670 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+{
+	GTCX
+	EIF_REFERENCE tr1 = NULL;
+	EIF_NATURAL_8 Result = ((EIF_NATURAL_8) 0);
+	
+	RTLD;
+	
+	RTLI(2);
+	RTLR(0,tr1);
+	RTLR(1,Current);
+	RTLIU(2);
+	
+	RTGC;
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	*(EIF_NATURAL_8 *)tr1 = arg1;
+	tr1 = F1090_9618(Current, tr1);
 	Result = *(EIF_NATURAL_8 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_8}.integer_quotient */
-EIF_NATURAL_8 F1085_9452 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+EIF_NATURAL_8 F1092_9674 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -82,16 +105,16 @@ EIF_NATURAL_8 F1085_9452 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
 	*(EIF_NATURAL_8 *)tr1 = arg1;
-	tr1 = F1084_9405(Current, tr1);
+	tr1 = F1090_9623(Current, tr1);
 	Result = *(EIF_NATURAL_8 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_8}.integer_remainder */
-EIF_NATURAL_8 F1085_9453 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+EIF_NATURAL_8 F1092_9675 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -105,70 +128,79 @@ EIF_NATURAL_8 F1085_9453 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
 	*(EIF_NATURAL_8 *)tr1 = arg1;
-	tr1 = F1084_9406(Current, tr1);
+	tr1 = F1090_9624(Current, tr1);
 	Result = *(EIF_NATURAL_8 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_8}.as_natural_16 */
-EIF_NATURAL_16 F1085_9456 (EIF_REFERENCE Current)
+EIF_NATURAL_16 F1092_9678 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_16) F1084_9413(Current);
+	return (EIF_NATURAL_16) F1090_9631(Current);
 }
 
 /* {NATURAL_8}.as_natural_32 */
-EIF_NATURAL_32 F1085_9457 (EIF_REFERENCE Current)
+EIF_NATURAL_32 F1092_9679 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_32) F1084_9414(Current);
+	return (EIF_NATURAL_32) F1090_9632(Current);
 }
 
 /* {NATURAL_8}.as_natural_64 */
-EIF_NATURAL_64 F1085_9458 (EIF_REFERENCE Current)
+EIF_NATURAL_64 F1092_9680 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_NATURAL_64) F1084_9415(Current);
+	return (EIF_NATURAL_64) F1090_9633(Current);
+}
+
+/* {NATURAL_8}.as_integer_8 */
+EIF_INTEGER_8 F1092_9681 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_INTEGER_8) F1090_9634(Current);
 }
 
 /* {NATURAL_8}.as_integer_32 */
-EIF_INTEGER_32 F1085_9461 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1092_9683 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_INTEGER_32) F1084_9418(Current);
+	return (EIF_INTEGER_32) F1090_9636(Current);
 }
 
 /* {NATURAL_8}.to_character_8 */
-EIF_CHARACTER_8 F1085_9465 (EIF_REFERENCE Current)
+EIF_CHARACTER_8 F1092_9687 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_CHARACTER_8) F1084_9433(Current);
+	return (EIF_CHARACTER_8) F1090_9655(Current);
 }
 
 /* {NATURAL_8}.to_character_32 */
-EIF_CHARACTER_32 F1085_9466 (EIF_REFERENCE Current)
+EIF_CHARACTER_32 F1092_9688 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_CHARACTER_32) F1084_9434(Current);
+	return (EIF_CHARACTER_32) F1090_9656(Current);
 }
 
 /* {NATURAL_8}.bit_and */
-EIF_NATURAL_8 F1085_9467 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+EIF_NATURAL_8 F1092_9689 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -182,16 +214,16 @@ EIF_NATURAL_8 F1085_9467 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
 	*(EIF_NATURAL_8 *)tr1 = arg1;
-	tr1 = F1084_9435(Current, tr1);
+	tr1 = F1090_9657(Current, tr1);
 	Result = *(EIF_NATURAL_8 *)(tr1);
 	RTLE;
 	return Result;
 }
 
 /* {NATURAL_8}.bit_or */
-EIF_NATURAL_8 F1085_9468 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
+EIF_NATURAL_8 F1092_9690 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -205,14 +237,41 @@ EIF_NATURAL_8 F1085_9468 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1085, 0x00).id, 1085, _OBJSIZ_0_1_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(1091, 0x00).id, 1091, _OBJSIZ_0_1_0_0_0_0_0_0_);
 	*(EIF_NATURAL_8 *)tr1 = arg1;
-	tr1 = F1084_9436(Current, tr1);
+	tr1 = F1090_9658(Current, tr1);
 	Result = *(EIF_NATURAL_8 *)(tr1);
 	RTLE;
 	return Result;
 }
 
+/* {NATURAL_8}.bit_not */
+EIF_NATURAL_8 F1092_9692 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return *(EIF_NATURAL_8 *)F1090_9660(Current);
+}
+
+/* {NATURAL_8}.bit_shift_left */
+EIF_NATURAL_8 F1092_9693 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+{
+	GTCX
+	
+	
+	return *(EIF_NATURAL_8 *)F1090_9662(Current, arg1);
+}
+
+/* {NATURAL_8}.bit_shift_right */
+EIF_NATURAL_8 F1092_9694 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+{
+	GTCX
+	
+	
+	return *(EIF_NATURAL_8 *)F1090_9663(Current, arg1);
+}
+
 void EIF_Minit455 (void)
 {
 	GTCX
