@@ -26,7 +26,7 @@ extern "C" {
 #endif
 
 /* {POINTER_REF}.hash_code */
-EIF_INTEGER_32 F977_7315 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1055_9713 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -46,7 +46,7 @@ EIF_INTEGER_32 F977_7315 (EIF_REFERENCE Current)
 }
 
 /* {POINTER_REF}.set_item */
-void F977_7316 (EIF_REFERENCE Current, EIF_POINTER arg1)
+void F1055_9714 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	
@@ -55,7 +55,7 @@ void F977_7316 (EIF_REFERENCE Current, EIF_POINTER arg1)
 }
 
 /* {POINTER_REF}.is_equal */
-EIF_BOOLEAN F977_7317 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F1055_9715 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -78,7 +78,7 @@ EIF_BOOLEAN F977_7317 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {POINTER_REF}.memory_compare */
-EIF_BOOLEAN F977_7318 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+EIF_BOOLEAN F1055_9716 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -99,8 +99,36 @@ EIF_BOOLEAN F977_7318 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 a
 	return Result;
 }
 
+/* {POINTER_REF}.is_default_pointer */
+EIF_BOOLEAN F1055_9718 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_POINTER tp1;
+	EIF_POINTER tp2;
+	EIF_POINTER tp3;
+	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	
+	RTLD;
+	
+	RTLI(1);
+	RTLR(0,Current);
+	RTLIU(1);
+	
+	RTGC;
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_);
+	{
+		/* INLINED CODE (ANY.default_pointer) */
+		tp2 = (EIF_POINTER)  0;
+		/* END INLINED CODE */
+	}
+	tp3 = tp2;
+	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tp1 == tp3);
+	RTLE;
+	return Result;
+}
+
 /* {POINTER_REF}.plus */
-EIF_POINTER F977_7321 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1055_9719 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -120,7 +148,7 @@ EIF_POINTER F977_7321 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.memory_copy */
-void F977_7325 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+void F1055_9723 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -131,7 +159,7 @@ void F977_7325 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 }
 
 /* {POINTER_REF}.memory_set */
-void F977_7327 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F1055_9725 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -142,7 +170,7 @@ void F977_7327 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 }
 
 /* {POINTER_REF}.memory_alloc */
-EIF_POINTER F977_7328 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1055_9726 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
@@ -151,7 +179,7 @@ EIF_POINTER F977_7328 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.memory_calloc */
-EIF_POINTER F977_7329 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+EIF_POINTER F1055_9727 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	
@@ -160,7 +188,7 @@ EIF_POINTER F977_7329 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_3
 }
 
 /* {POINTER_REF}.memory_realloc */
-EIF_POINTER F977_7330 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1055_9728 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -171,7 +199,7 @@ EIF_POINTER F977_7330 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.memory_free */
-void F977_7331 (EIF_REFERENCE Current)
+void F1055_9729 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -186,17 +214,17 @@ void F977_7331 (EIF_REFERENCE Current)
 	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_);
 	free((void*) tp1);
 	{
-		/* INLINED CODE (default_pointer) */
+		/* INLINED CODE (ANY.default_pointer) */
 		tp1 = (EIF_POINTER)  0;
 		/* END INLINED CODE */
 	}
 	tp2 = tp1;
-	F977_7316(Current, tp2);
+	F1055_9714(Current, tp2);
 	RTLE;
 }
 
 /* {POINTER_REF}.out */
-EIF_REFERENCE F977_7332 (EIF_REFERENCE Current)
+EIF_REFERENCE F1055_9730 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -211,13 +239,13 @@ EIF_REFERENCE F977_7332 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_);
-	Result = c_outp(tp1);
+	Result = eif_out__p_s1(tp1);
 	RTLE;
 	return Result;
 }
 
 /* {POINTER_REF}.c_memcpy */
-void F977_7333 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
+void F1055_9731 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	
@@ -226,7 +254,7 @@ void F977_7333 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_I
 }
 
 /* {POINTER_REF}.c_memset */
-void F977_7335 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F1055_9733 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	
@@ -235,7 +263,7 @@ void F977_7335 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EI
 }
 
 /* {POINTER_REF}.c_memcmp */
-EIF_INTEGER_32 F977_7336 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
+EIF_INTEGER_32 F1055_9734 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -247,7 +275,7 @@ EIF_INTEGER_32 F977_7336 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER a
 }
 
 /* {POINTER_REF}.c_malloc */
-EIF_POINTER F977_7337 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1055_9735 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -259,7 +287,7 @@ EIF_POINTER F977_7337 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.c_calloc */
-EIF_POINTER F977_7338 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+EIF_POINTER F1055_9736 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -271,7 +299,7 @@ EIF_POINTER F977_7338 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_3
 }
 
 /* {POINTER_REF}.c_realloc */
-EIF_POINTER F977_7339 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+EIF_POINTER F1055_9737 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -283,7 +311,7 @@ EIF_POINTER F977_7339 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 a
 }
 
 /* {POINTER_REF}.c_free */
-void F977_7340 (EIF_REFERENCE Current, EIF_POINTER arg1)
+void F1055_9738 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	
