@@ -8,6 +8,7 @@
 
 #include "po485.h"
 #include <string.h>
+#include "eif_out.h"
 #include <stdlib.h>
 
 #ifdef __cplusplus
@@ -25,7 +26,7 @@ extern "C" {
 #endif
 
 /* {POINTER_REF}.hash_code */
-EIF_INTEGER_32 F1110_9790 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1031_8185 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -45,7 +46,7 @@ EIF_INTEGER_32 F1110_9790 (EIF_REFERENCE Current)
 }
 
 /* {POINTER_REF}.set_item */
-void F1110_9791 (EIF_REFERENCE Current, EIF_POINTER arg1)
+void F1031_8186 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	
@@ -54,7 +55,7 @@ void F1110_9791 (EIF_REFERENCE Current, EIF_POINTER arg1)
 }
 
 /* {POINTER_REF}.is_equal */
-EIF_BOOLEAN F1110_9792 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F1031_8187 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -77,7 +78,7 @@ EIF_BOOLEAN F1110_9792 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {POINTER_REF}.memory_compare */
-EIF_BOOLEAN F1110_9793 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+EIF_BOOLEAN F1031_8188 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -99,7 +100,7 @@ EIF_BOOLEAN F1110_9793 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32
 }
 
 /* {POINTER_REF}.is_default_pointer */
-EIF_BOOLEAN F1110_9795 (EIF_REFERENCE Current)
+EIF_BOOLEAN F1031_8190 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -127,7 +128,7 @@ EIF_BOOLEAN F1110_9795 (EIF_REFERENCE Current)
 }
 
 /* {POINTER_REF}.plus */
-EIF_POINTER F1110_9796 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1031_8191 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -147,7 +148,7 @@ EIF_POINTER F1110_9796 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.memory_copy */
-void F1110_9800 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+void F1031_8195 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -158,7 +159,7 @@ void F1110_9800 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 }
 
 /* {POINTER_REF}.memory_set */
-void F1110_9802 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F1031_8197 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -169,7 +170,7 @@ void F1110_9802 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2
 }
 
 /* {POINTER_REF}.memory_alloc */
-EIF_POINTER F1110_9803 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1031_8198 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
@@ -178,7 +179,7 @@ EIF_POINTER F1110_9803 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.memory_calloc */
-EIF_POINTER F1110_9804 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+EIF_POINTER F1031_8199 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	
@@ -187,7 +188,7 @@ EIF_POINTER F1110_9804 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_
 }
 
 /* {POINTER_REF}.memory_realloc */
-EIF_POINTER F1110_9805 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1031_8200 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -198,7 +199,7 @@ EIF_POINTER F1110_9805 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.memory_free */
-void F1110_9806 (EIF_REFERENCE Current)
+void F1031_8201 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -218,12 +219,33 @@ void F1110_9806 (EIF_REFERENCE Current)
 		/* END INLINED CODE */
 	}
 	tp2 = tp1;
-	F1110_9791(Current, tp2);
+	F1031_8186(Current, tp2);
 	RTLE;
 }
 
+/* {POINTER_REF}.out */
+EIF_REFERENCE F1031_8202 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_POINTER tp1;
+	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
+	
+	RTLD;
+	
+	RTLI(2);
+	RTLR(0,Current);
+	RTLR(1,Result);
+	RTLIU(2);
+	
+	RTGC;
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_0_0_0_0_0_0_);
+	Result = eif_out__p_s1(tp1);
+	RTLE;
+	return Result;
+}
+
 /* {POINTER_REF}.c_memcpy */
-void F1110_9808 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
+void F1031_8203 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	
@@ -232,7 +254,7 @@ void F1110_9808 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_
 }
 
 /* {POINTER_REF}.c_memset */
-void F1110_9810 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F1031_8205 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	
@@ -241,7 +263,7 @@ void F1110_9810 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, E
 }
 
 /* {POINTER_REF}.c_memcmp */
-EIF_INTEGER_32 F1110_9811 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
+EIF_INTEGER_32 F1031_8206 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -253,7 +275,7 @@ EIF_INTEGER_32 F1110_9811 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER
 }
 
 /* {POINTER_REF}.c_malloc */
-EIF_POINTER F1110_9812 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1031_8207 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -265,7 +287,7 @@ EIF_POINTER F1110_9812 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {POINTER_REF}.c_calloc */
-EIF_POINTER F1110_9813 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+EIF_POINTER F1031_8208 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -277,7 +299,7 @@ EIF_POINTER F1110_9813 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_
 }
 
 /* {POINTER_REF}.c_realloc */
-EIF_POINTER F1110_9814 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+EIF_POINTER F1031_8209 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -289,7 +311,7 @@ EIF_POINTER F1110_9814 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32
 }
 
 /* {POINTER_REF}.c_free */
-void F1110_9815 (EIF_REFERENCE Current, EIF_POINTER arg1)
+void F1031_8210 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	
