@@ -23,30 +23,39 @@ extern "C" {
 #endif
 
 /* {POINTER}.hash_code */
-EIF_INTEGER_32 F1142_9816 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1063_8211 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_INTEGER_32) F1110_9790(Current);
+	return (EIF_INTEGER_32) F1031_8185(Current);
 }
 
 /* {POINTER}.is_default_pointer */
-EIF_BOOLEAN F1142_9817 (EIF_REFERENCE Current)
+EIF_BOOLEAN F1063_8212 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_BOOLEAN) F1110_9795(Current);
+	return (EIF_BOOLEAN) F1031_8190(Current);
 }
 
 /* {POINTER}.plus */
-EIF_POINTER F1142_9818 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1063_8213 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	return (EIF_POINTER) F1110_9796(Current, arg1);
+	return (EIF_POINTER) F1031_8191(Current, arg1);
+}
+
+/* {POINTER}.out */
+EIF_REFERENCE F1063_8215 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_REFERENCE) F1031_8202(Current);
 }
 
 void EIF_Minit486 (void)
