@@ -1,5 +1,5 @@
 /*
- * Code for class RESIZABLE [BOOLEAN]
+ * Code for class RESIZABLE [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -24,7 +24,7 @@ extern "C" {
 #endif
 
 /* {RESIZABLE}.additional_space */
-EIF_INTEGER_32 F456_2342 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F563_2699 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -37,7 +37,7 @@ EIF_INTEGER_32 F456_2342 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2096[Dtype(Current)-595])(Current);
+	ti4_1 = F638_3165(Current);
 	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
 	RTLE;
 	return Result;
