@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F434_2157(EIF_REFERENCE);
+extern void F559_7711(EIF_REFERENCE, EIF_REFERENCE);
+extern void F559_7720(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit494(void);
-extern char *(*R1917[])();
 
 #ifdef __cplusplus
 }
