@@ -1,5 +1,5 @@
 /*
- * Code for class SPECIAL [BOOLEAN]
+ * Code for class SPECIAL [POINTER]
  */
 
 #include "eif_eiffel.h"
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {SPECIAL}.make_empty */
-void F525_2470 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F551_2548 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -35,7 +35,7 @@ void F525_2470 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("make_empty", 524, Current, 0, 1, 4764);
+	RTEAA("make_empty", 550, Current, 0, 1, 4813);
 	RTGC;
 	RTHOOK(3);
 	RTLE;
@@ -43,7 +43,7 @@ void F525_2470 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {SPECIAL}.make_filled */
-void F525_2471 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F551_2549 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	RTEX;
@@ -53,7 +53,7 @@ void F525_2471 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("make_filled", 524, Current, 0, 2, 4765);
+	RTEAA("make_filled", 550, Current, 0, 2, 4814);
 	RTGC;
 	RTHOOK(1);
 	{
@@ -62,59 +62,59 @@ void F525_2471 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	}
 	;
 	RTHOOK(2);
-	F525_2492(Current, arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
+	F551_2570(Current, arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
 	RTHOOK(6);
 	RTLE;
 	RTEE;
 }
 
 /* {SPECIAL}.item */
-EIF_BOOLEAN F525_2473 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F551_2551 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	return *((EIF_BOOLEAN *) Current + arg1);
+	return *((EIF_POINTER *) Current + arg1);
 }
 
-EIF_REFERENCE F525_24731 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F551_25511 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	EIF_REFERENCE Result;
-	EIF_BOOLEAN r = *((EIF_BOOLEAN *) Current + arg1);
-	Result = RTLNS(eif_new_type(712, 0x00).id, 712, _OBJSIZ_0_1_0_0_0_0_0_0_);
-	*(EIF_BOOLEAN *)Result = r;
+	EIF_POINTER r = *((EIF_POINTER *) Current + arg1);
+	Result = RTLNS(eif_new_type(759, 0x00).id, 759, _OBJSIZ_0_0_0_0_0_1_0_0_);
+	*(EIF_POINTER *)Result = r;
 	return Result;
 }
 
 /* {SPECIAL}.at */
-EIF_BOOLEAN F525_2474 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F551_2552 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	return *((EIF_BOOLEAN *) Current + arg1);
+	return *((EIF_POINTER *) Current + arg1);
 }
 
-EIF_REFERENCE F525_24741 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F551_25521 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	EIF_REFERENCE Result;
-	EIF_BOOLEAN r = *((EIF_BOOLEAN *) Current + arg1);
-	Result = RTLNS(eif_new_type(712, 0x00).id, 712, _OBJSIZ_0_1_0_0_0_0_0_0_);
-	*(EIF_BOOLEAN *)Result = r;
+	EIF_POINTER r = *((EIF_POINTER *) Current + arg1);
+	Result = RTLNS(eif_new_type(759, 0x00).id, 759, _OBJSIZ_0_0_0_0_0_1_0_0_);
+	*(EIF_POINTER *)Result = r;
 	return Result;
 }
 
 /* {SPECIAL}.item_address */
-EIF_POINTER F525_2476 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F551_2554 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	return (EIF_POINTER) (Current + (rt_uint_ptr) arg1 * (rt_uint_ptr)sizeof(EIF_BOOLEAN));
+	return (EIF_POINTER) (Current + (rt_uint_ptr) arg1 * (rt_uint_ptr)sizeof(EIF_POINTER));
 }
 
 /* {SPECIAL}.base_address */
-EIF_POINTER F525_2477 (EIF_REFERENCE Current)
+EIF_POINTER F551_2555 (EIF_REFERENCE Current)
 {
 	return (EIF_POINTER) Current;
 }
 
 /* {SPECIAL}.to_array */
-EIF_REFERENCE F525_2479 (EIF_REFERENCE Current)
+EIF_REFERENCE F551_2557 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -126,23 +126,23 @@ EIF_REFERENCE F525_2479 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("to_array", 524, Current, 0, 0, 4773);
+	RTEAA("to_array", 550, Current, 0, 0, 4772);
 	RTGC;
 	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {549,0,0,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {575,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y1708,Y1708_gen_type,Dftype(Current),202);
+			l_type = eif_final_id(Y1758,Y1758_gen_type,Dftype(Current),211);
 			typarr0[1] = l_type.annotations | 0xFF00;
 			typarr0[2] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 549, _OBJSIZ_1_1_0_2_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 575, _OBJSIZ_1_1_0_2_0_0_0_0_);
 	}
-	F550_2562(RTCW(tr1), Current);
+	F576_2640(RTCW(tr1), Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -150,13 +150,13 @@ EIF_REFERENCE F525_2479 (EIF_REFERENCE Current)
 }
 
 /* {SPECIAL}.lower */
-EIF_INTEGER_32 F525_2481 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F551_2559 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 }
 
 /* {SPECIAL}.upper */
-EIF_INTEGER_32 F525_2482 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F551_2560 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -168,10 +168,10 @@ EIF_INTEGER_32 F525_2482 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("upper", 524, Current, 0, 0, 4776);
+	RTEAA("upper", 550, Current, 0, 0, 4775);
 	RTGC;
 	RTHOOK(1);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result - ((EIF_INTEGER_32) 1L));
 	RTHOOK(2);
 	RTLE;
@@ -180,7 +180,7 @@ EIF_INTEGER_32 F525_2482 (EIF_REFERENCE Current)
 }
 
 /* {SPECIAL}.count */
-EIF_INTEGER_32 F525_2483 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F551_2561 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -192,8 +192,8 @@ EIF_INTEGER_32 F525_2483 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("count", 524, Current, 0, 0, 4777);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+	RTEAA("count", 550, Current, 0, 0, 4776);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 	RTHOOK(1);
 	RTLE;
 	RTEE;
@@ -201,7 +201,7 @@ EIF_INTEGER_32 F525_2483 (EIF_REFERENCE Current)
 }
 
 /* {SPECIAL}.capacity */
-EIF_INTEGER_32 F525_2484 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F551_2562 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -213,8 +213,8 @@ EIF_INTEGER_32 F525_2484 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("capacity", 524, Current, 0, 0, 4778);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (Current);
+	RTEAA("capacity", 550, Current, 0, 0, 4777);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (Current);
 	RTHOOK(1);
 	RTLE;
 	RTEE;
@@ -222,16 +222,16 @@ EIF_INTEGER_32 F525_2484 (EIF_REFERENCE Current)
 }
 
 /* {SPECIAL}.same_items */
-EIF_BOOLEAN F525_2486 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+EIF_BOOLEAN F551_2564 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
-	EIF_BOOLEAN tb3;
+	EIF_POINTER tp1;
+	EIF_POINTER tp2;
+	EIF_POINTER tp3;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	RTLD;
@@ -241,12 +241,12 @@ EIF_BOOLEAN F525_2486 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("same_items", 524, Current, 3, 4, 4730);
+	RTEAA("same_items", 550, Current, 3, 4, 4779);
 	RTGC;
 	RTHOOK(1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 	RTHOOK(2);
-	if ((EIF_BOOLEAN)(arg1 != Current)) {
+	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 != Current) || (EIF_BOOLEAN)(arg2 != arg3))) {
 		RTHOOK(3);
 		loc1 = (EIF_INTEGER_32) arg2;
 		RTHOOK(4);
@@ -258,22 +258,23 @@ EIF_BOOLEAN F525_2486 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32
 			if ((EIF_BOOLEAN)(loc1 == loc3)) break;
 			RTHOOK(7);
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)RTCW(arg1) + (loc1));
+			tp2 = *((EIF_POINTER *)RTCW(arg1) + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
+			tp1 = tp2;
 			/* INLINED CODE (SPECIAL.item) */
-			tb3 = *((EIF_BOOLEAN *)Current + (loc2));
+			tp3 = *((EIF_POINTER *)Current + (loc2));
 			/* END INLINED CODE */
-			if ((EIF_BOOLEAN)(tb1 != tb3)) {
+			if ((EIF_BOOLEAN)(tp1 != tp3)) {
 				RTHOOK(8);
 				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 				RTHOOK(9);
-				loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
+				loc1 = (EIF_INTEGER_32) loc3;
+			} else {
+				RTHOOK(10);
+				loc1++;
+				RTHOOK(11);
+				loc2++;
 			}
-			RTHOOK(10);
-			loc1++;
-			RTHOOK(11);
-			loc2++;
 		}
 	}
 	RTHOOK(13);
@@ -283,77 +284,77 @@ EIF_BOOLEAN F525_2486 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32
 }
 
 /* {SPECIAL}.put */
-void F525_2488 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F551_2566 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	*((EIF_BOOLEAN *) Current + arg2) = arg1;
+	*((EIF_POINTER *) Current + arg2) = arg1;
 }
 
-void F525_24882 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
+void F551_25662 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
 {
-	*((EIF_BOOLEAN *) Current + arg2) = *(EIF_BOOLEAN *)arg1;
+	*((EIF_POINTER *) Current + arg2) = *(EIF_POINTER *)arg1;
 }
 
 /* {SPECIAL}.force */
-void F525_2489 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F551_2567 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_INTEGER_32 arg3 = RT_SPECIAL_COUNT(Current);
-	*((EIF_BOOLEAN *) Current + arg2) = arg1;
+	*((EIF_POINTER *) Current + arg2) = arg1;
 	if (arg2 == arg3) { RT_SPECIAL_COUNT(Current) = arg3 + 1; }
 }
 
-void F525_24892 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
+void F551_25672 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
 {
-	*((EIF_BOOLEAN *) Current + arg2) = *(EIF_BOOLEAN *)arg1;
+	*((EIF_POINTER *) Current + arg2) = *(EIF_POINTER *)arg1;
 }
 
 /* {SPECIAL}.extend */
-void F525_2490 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
+void F551_2568 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	EIF_INTEGER_32 arg2 = RT_SPECIAL_COUNT(Current)++;
-	*((EIF_BOOLEAN *) Current + arg2) = arg1;
+	*((EIF_POINTER *) Current + arg2) = arg1;
 }
 
-void F525_24902 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F551_25682 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	
 	EIF_INTEGER_32 arg2 = RT_SPECIAL_COUNT(Current)++;
-	*((EIF_BOOLEAN *) Current + arg2) = *(EIF_BOOLEAN *)arg1;
+	*((EIF_POINTER *) Current + arg2) = *(EIF_POINTER *)arg1;
 }
 
 /* {SPECIAL}.fill_with */
-void F525_2492 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F551_2570 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 i;
 	for (i = arg2; i <= arg3; i++) {
-		*((EIF_BOOLEAN *) Current + i) = arg1;
+		*((EIF_POINTER *) Current + i) = arg1;
 	}
 	RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg3 + 1);
 }
 
-void F525_24922 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F551_25702 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	EIF_INTEGER_32 i;
-	EIF_BOOLEAN arg1x = *(EIF_BOOLEAN *)arg1;
+	EIF_POINTER arg1x = *(EIF_POINTER *)arg1;
 	for (i = arg2; i < arg3; i++) {
-	*((EIF_BOOLEAN *) Current + i) = arg1x;
+	*((EIF_POINTER *) Current + i) = arg1x;
 	}
 	RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg3 + 1);
 }
 
 /* {SPECIAL}.copy_data */
-void F525_2495 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+void F551_2573 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
+	EIF_POINTER tp1;
+	EIF_POINTER tp2;
 	RTLD;
 	
 	RTLI(2);
@@ -361,13 +362,13 @@ void F525_2495 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("copy_data", 524, Current, 3, 4, 4739);
+	RTEAA("copy_data", 550, Current, 3, 4, 4788);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == Current)) {
 		RTHOOK(2);
 		/* INLINED CODE (SPECIAL.overlapping_move) */
-		memmove((EIF_BOOLEAN *)Current + (arg3),(EIF_BOOLEAN *)Current + arg2, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg4);
+		memmove((EIF_POINTER *)Current + (arg3),(EIF_POINTER *)Current + arg2, (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)arg4);
 		RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg3 + arg4);
 		/* END INLINED CODE */
 		;
@@ -383,10 +384,10 @@ void F525_2495 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 			if ((EIF_BOOLEAN)(loc1 == loc3)) break;
 			RTHOOK(7);
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)RTCW(arg1) + (loc1));
+			tp2 = *((EIF_POINTER *)RTCW(arg1) + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
-			F525_2489(Current, tb1, loc2);
+			tp1 = tp2;
+			F551_2567(Current, tp1, loc2);
 			RTHOOK(8);
 			loc1++;
 			RTHOOK(9);
@@ -399,22 +400,22 @@ void F525_2495 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.move_data */
-void F525_2496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F551_2574 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	RTEX;
+	EIF_POINTER tp1;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
 	EIF_INTEGER_32 ti4_4;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
 	RTLI(1);
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("move_data", 524, Current, 0, 3, 4740);
+	RTEAA("move_data", 550, Current, 0, 3, 4789);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == arg2)) {
@@ -425,14 +426,14 @@ void F525_2496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 			if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg2 + arg3) < arg1)) {
 				RTHOOK(4);
 				/* INLINED CODE (SPECIAL.move_data) */
-				memcpy((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memcpy((EIF_POINTER *)Current + (arg2),(EIF_POINTER *)Current + arg1, (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
 			} else {
 				RTHOOK(5);
 				/* INLINED CODE (SPECIAL.overlapping_move) */
-				memmove((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memmove((EIF_POINTER *)Current + (arg2),(EIF_POINTER *)Current + arg1, (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
@@ -442,14 +443,14 @@ void F525_2496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 			if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 + arg3) < arg2)) {
 				RTHOOK(7);
 				/* INLINED CODE (SPECIAL.move_data) */
-				memcpy((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memcpy((EIF_POINTER *)Current + (arg2),(EIF_POINTER *)Current + arg1, (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
 			} else {
 				RTHOOK(8);
 				/* INLINED CODE (SPECIAL.overlapping_move) */
-				memmove((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memmove((EIF_POINTER *)Current + (arg2),(EIF_POINTER *)Current + arg1, (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
@@ -462,23 +463,23 @@ void F525_2496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.overlapping_move */
-void F525_2497 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F551_2575 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
+	EIF_POINTER tp1;
+	EIF_POINTER tp2;
 	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
 	RTLD;
 	
 	RTLI(1);
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("overlapping_move", 524, Current, 3, 3, 4741);
+	RTEAA("overlapping_move", 550, Current, 3, 3, 4790);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN) (arg1 < arg2)) {
@@ -489,14 +490,14 @@ void F525_2497 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 		RTHOOK(4);
 		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg2 - arg1);
 		RTHOOK(5);
-		if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg2 + arg3) >= (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current))) {
+		if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg2 + arg3) >= (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current))) {
 			RTHOOK(6);
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)Current + (arg1));
+			tp2 = *((EIF_POINTER *)Current + (arg1));
 			/* END INLINED CODE */
-			tb1 = tb2;
-			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
-			F525_2492(Current, tb1, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 + arg3) - ((EIF_INTEGER_32) 1L)));
+			tp1 = tp2;
+			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
+			F551_2570(Current, tp1, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 + arg3) - ((EIF_INTEGER_32) 1L)));
 		}
 		
 		for (;;) {
@@ -504,11 +505,11 @@ void F525_2497 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 			if ((EIF_BOOLEAN)(loc1 == loc2)) break;
 			RTHOOK(9);
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)Current + (loc1));
+			tp2 = *((EIF_POINTER *)Current + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
+			tp1 = tp2;
 			/* INLINED CODE (SPECIAL.put) */
-			*((EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) (loc1 + loc3))) = tb1;
+			*((EIF_POINTER *)Current + ((EIF_INTEGER_32) (loc1 + loc3))) = tp1;
 			/* END INLINED CODE */
 			;
 			RTHOOK(10);
@@ -527,10 +528,10 @@ void F525_2497 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 			if ((EIF_BOOLEAN)(loc1 == loc2)) break;
 			RTHOOK(16);
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)Current + (loc1));
+			tp2 = *((EIF_POINTER *)Current + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
-			F525_2489(Current, tb1, (EIF_INTEGER_32) (loc1 - loc3));
+			tp1 = tp2;
+			F551_2567(Current, tp1, (EIF_INTEGER_32) (loc1 - loc3));
 			RTHOOK(17);
 			loc1++;
 		}
@@ -541,22 +542,22 @@ void F525_2497 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.non_overlapping_move */
-void F525_2498 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F551_2576 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
+	EIF_POINTER tp1;
+	EIF_POINTER tp2;
 	RTLD;
 	
 	RTLI(1);
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("non_overlapping_move", 524, Current, 3, 3, 4742);
+	RTEAA("non_overlapping_move", 550, Current, 3, 3, 4791);
 	RTGC;
 	RTHOOK(1);
 	loc1 = (EIF_INTEGER_32) arg1;
@@ -569,10 +570,10 @@ void F525_2498 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 		if ((EIF_BOOLEAN)(loc1 == loc2)) break;
 		RTHOOK(5);
 		/* INLINED CODE (SPECIAL.item) */
-		tb2 = *((EIF_BOOLEAN *)Current + (loc1));
+		tp2 = *((EIF_POINTER *)Current + (loc1));
 		/* END INLINED CODE */
-		tb1 = tb2;
-		F525_2489(Current, tb1, (EIF_INTEGER_32) (loc1 + loc3));
+		tp1 = tp2;
+		F551_2567(Current, tp1, (EIF_INTEGER_32) (loc1 + loc3));
 		RTHOOK(6);
 		loc1++;
 	}
@@ -582,17 +583,15 @@ void F525_2498 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.resized_area */
-EIF_REFERENCE F525_2503 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F551_2581 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
+	EIF_POINTER tp1;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
 	EIF_INTEGER_32 ti4_4;
-	EIF_INTEGER_32 ti4_5;
-	EIF_INTEGER_32 ti4_6;
-	EIF_BOOLEAN tb1;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
@@ -602,16 +601,16 @@ EIF_REFERENCE F525_2503 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("resized_area", 524, Current, 0, 1, 4747);
+	RTEAA("resized_area", 550, Current, 0, 1, 4796);
 	RTGC;
 	RTHOOK(1);
-	Result = RTLNSP2(Dftype(Current),0,arg1,sizeof(EIF_BOOLEAN), EIF_TRUE);
+	Result = RTLNSP2(Dftype(Current),0,arg1,sizeof(EIF_POINTER), EIF_TRUE);
 	RT_SPECIAL_COUNT(Result) = 0;
 	RTHOOK(2);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 	ti4_1 = eif_min_int32 (arg1,ti4_1);
 	/* INLINED CODE (SPECIAL.copy_data) */
-	memmove((EIF_BOOLEAN *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)ti4_1);
+	memmove((EIF_POINTER *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_POINTER *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)ti4_1);
 	RT_SPECIAL_COUNT(Result) = eif_max_int32(RT_SPECIAL_COUNT(Result), ((EIF_INTEGER_32) 0L) + ti4_1);
 	/* END INLINED CODE */
 	;
@@ -622,17 +621,15 @@ EIF_REFERENCE F525_2503 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {SPECIAL}.resized_area_with_default */
-EIF_REFERENCE F525_2504 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+EIF_REFERENCE F551_2582 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	RTEX;
+	EIF_POINTER tp1;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
 	EIF_INTEGER_32 ti4_4;
-	EIF_INTEGER_32 ti4_5;
-	EIF_INTEGER_32 ti4_6;
-	EIF_BOOLEAN tb1;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
@@ -642,27 +639,27 @@ EIF_REFERENCE F525_2504 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("resized_area_with_default", 524, Current, 0, 2, 4748);
+	RTEAA("resized_area_with_default", 550, Current, 0, 2, 4797);
 	RTGC;
 	RTHOOK(1);
-	Result = RTLNSP2(Dftype(Current),0,arg2,sizeof(EIF_BOOLEAN), EIF_TRUE);
+	Result = RTLNSP2(Dftype(Current),0,arg2,sizeof(EIF_POINTER), EIF_TRUE);
 	RT_SPECIAL_COUNT(Result) = 0;
 	RTHOOK(2);
-	if ((EIF_BOOLEAN) (arg2 > (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current))) {
+	if ((EIF_BOOLEAN) (arg2 > (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current))) {
 		RTHOOK(3);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 		/* INLINED CODE (SPECIAL.copy_data) */
-		memmove((EIF_BOOLEAN *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)ti4_1);
+		memmove((EIF_POINTER *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_POINTER *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)ti4_1);
 		RT_SPECIAL_COUNT(Result) = eif_max_int32(RT_SPECIAL_COUNT(Result), ((EIF_INTEGER_32) 0L) + ti4_1);
 		/* END INLINED CODE */
 		;
 		RTHOOK(4);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
-		F525_2492(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
+		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
+		F551_2570(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
 	} else {
 		RTHOOK(5);
 		/* INLINED CODE (SPECIAL.copy_data) */
-		memmove((EIF_BOOLEAN *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg2);
+		memmove((EIF_POINTER *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_POINTER *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)arg2);
 		RT_SPECIAL_COUNT(Result) = eif_max_int32(RT_SPECIAL_COUNT(Result), ((EIF_INTEGER_32) 0L) + arg2);
 		/* END INLINED CODE */
 		;
@@ -674,7 +671,7 @@ EIF_REFERENCE F525_2504 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32
 }
 
 /* {SPECIAL}.aliased_resized_area */
-EIF_REFERENCE F525_2505 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F551_2583 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -687,8 +684,8 @@ EIF_REFERENCE F525_2505 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("aliased_resized_area", 524, Current, 0, 1, 4749);
-	Result = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (Current, arg1);
+	RTEAA("aliased_resized_area", 550, Current, 0, 1, 4798);
+	Result = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area__i4_s (Current, arg1);
 	RTHOOK(5);
 	RTLE;
 	RTEE;
@@ -696,7 +693,7 @@ EIF_REFERENCE F525_2505 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {SPECIAL}.aliased_resized_area_with_default */
-EIF_REFERENCE F525_2506 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+EIF_REFERENCE F551_2584 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	RTEX;
@@ -710,13 +707,13 @@ EIF_REFERENCE F525_2506 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("aliased_resized_area_with_default", 524, Current, 0, 2, 4750);
+	RTEAA("aliased_resized_area_with_default", 550, Current, 0, 2, 4799);
 	RTGC;
 	RTHOOK(1);
-	Result = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (Current, arg2);
+	Result = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area__i4_s (Current, arg2);
 	RTHOOK(2);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Result);
-	F525_2492(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Result);
+	F551_2570(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
 	RTHOOK(7);
 	RTLE;
 	RTEE;
@@ -724,27 +721,27 @@ EIF_REFERENCE F525_2506 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32
 }
 
 /* {SPECIAL}.wipe_out */
-void F525_2508 (EIF_REFERENCE Current)
+void F551_2586 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("wipe_out", 524, Current, 0, 0, 4752);
+	RTEAA("wipe_out", 550, Current, 0, 0, 4801);
 	RTHOOK(1);
-	eif_builtin_SPECIAL_set_count (Current, ((EIF_INTEGER_32) 0L));
+	eif_builtin_SPECIAL_set_count__i4_ (Current, ((EIF_INTEGER_32) 0L));
 	RTHOOK(4);
 	RTEE;
 }
 
 /* {SPECIAL}.clear_all */
-void F525_2509 (EIF_REFERENCE Current)
+void F551_2587 (EIF_REFERENCE Current)
 {
 	memset (Current, 0, RT_SPECIAL_VISIBLE_SIZE(Current));
 }
 
 /* {SPECIAL}.element_size */
-EIF_INTEGER_32 F525_2517 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F551_2595 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -756,8 +753,8 @@ EIF_INTEGER_32 F525_2517 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("element_size", 524, Current, 0, 0, 4761);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_element_size (Current);
+	RTEAA("element_size", 550, Current, 0, 0, 4810);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_element_size__i4 (Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -765,7 +762,7 @@ EIF_INTEGER_32 F525_2517 (EIF_REFERENCE Current)
 }
 
 /* {SPECIAL}.set_count */
-void F525_2518 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F551_2596 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -775,8 +772,8 @@ void F525_2518 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("set_count", 524, Current, 0, 1, 4762);
-	eif_builtin_SPECIAL_set_count (Current, arg1);
+	RTEAA("set_count", 550, Current, 0, 1, 4811);
+	eif_builtin_SPECIAL_set_count__i4_ (Current, arg1);
 	RTHOOK(3);
 	RTLE;
 	RTEE;
