@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [NATURAL_8]
+ * Code for class TO_SPECIAL [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F395_2273 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F184_1858 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -35,23 +34,18 @@ void F395_2273 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_empty_area", 394, Current, 0, 1, 2834);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1994,Y1994_gen_type,Dftype(Current),392).id,0,arg1,sizeof(EIF_NATURAL_8), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),181).id,0,arg1,sizeof(EIF_INTEGER_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F395_2274 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
+void F184_1859 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -60,38 +54,22 @@ void F395_2274 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_filled_area", 394, Current, 0, 2, 2835);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1994,Y1994_gen_type,Dftype(Current),392).id,0,arg2,sizeof(EIF_NATURAL_8), EIF_TRUE);
-	F671_3958(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),181).id,0,arg2,sizeof(EIF_INTEGER_32), EIF_TRUE);
+	F613_3064(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 }
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F395_2275 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.set_area */
-void F395_2280 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F184_1865 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("set_area", 394, Current, 0, 1, 2841);
-	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
-	RTHOOK(2);
-	RTEE;
 }
 
 void EIF_Minit469 (void)
