@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [INTEGER_32]
+ * Code for class TO_SPECIAL [NATURAL_16]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F123_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F195_2153 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -35,10 +35,10 @@ void F123_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_empty_area", 122, Current, 0, 1, 1571);
+	RTEAA("make_empty_area", 194, Current, 0, 1, 2216);
 	RTGC;
 	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1387,Y1387_gen_type,Dftype(Current),115).id,0,arg1,sizeof(EIF_INTEGER_32), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y1916,Y1916_gen_type,Dftype(Current),192).id,0,arg1,sizeof(EIF_NATURAL_16), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -48,7 +48,7 @@ void F123_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F123_1496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F195_2154 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	RTEX;
@@ -60,11 +60,11 @@ void F123_1496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_filled_area", 122, Current, 0, 2, 1572);
+	RTEAA("make_filled_area", 194, Current, 0, 2, 2217);
 	RTGC;
 	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1387,Y1387_gen_type,Dftype(Current),115).id,0,arg2,sizeof(EIF_INTEGER_32), EIF_TRUE);
-	F526_2471(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1916,Y1916_gen_type,Dftype(Current),192).id,0,arg2,sizeof(EIF_NATURAL_16), EIF_TRUE);
+	F701_4006(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTHOOK(6);
@@ -73,13 +73,13 @@ void F123_1496 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 }
 
 /* {TO_SPECIAL}.set_area */
-void F123_1502 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F195_2160 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("set_area", 122, Current, 0, 1, 1578);
+	RTEAA("set_area", 194, Current, 0, 1, 2223);
 	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
