@@ -1,5 +1,5 @@
 /*
- * Code for class ES_RUNNING_TEST_GRID_ROW
+ * Code for class ES_DISCARDABLE_QUESTION_WARNING_PROMPT
  */
 
 #include "eif_eiffel.h"
@@ -22,8 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ES_RUNNING_TEST_GRID_ROW}.pixmap */
-EIF_REFERENCE F6412_92106 (EIF_REFERENCE Current)
+/* {ES_DISCARDABLE_QUESTION_WARNING_PROMPT}.large_icon */
+EIF_REFERENCE F6387_86469 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -36,10 +36,10 @@ EIF_REFERENCE F6412_92106 (EIF_REFERENCE Current)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("pixmap", 6411, Current, 0, 0, 95814);
+	RTEAA("large_icon", 6386, Current, 0, 0, 90191);
 	RTGC;
 	RTHOOK(1);
-	Result = RTOUCR(1878,F6976_99319,(RTCV(RTOUCR(542,F6398_91966,(Current)))));
+	Result = RTOUCR(858,F1541_21551, (RTCV(RTOUCR(781,F6372_86358, (Current)))));
 	RTHOOK(2);
 	RTLE;
 	RTEE;
