@@ -23,13 +23,11 @@ extern "C" {
 #endif
 
 /* {ARRAY_ITERATION_CURSOR}.make */
-void F506_3197 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F326_2205 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
 	RTLD;
 	
 	RTLI(3);
@@ -38,48 +36,34 @@ void F506_3197 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("make", 505, Current, 0, 1, 4316);
 	RTGC;
-	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
-	RTHOOK(2);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
 	tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(3);
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_) = (EIF_INTEGER_32) ti4_1;
-	RTHOOK(4);
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ti4_2);
-	RTHOOK(5);
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_));
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAY_ITERATION_CURSOR}.first_index */
-EIF_INTEGER_32 F506_3198 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F326_2206 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_2_);
 }
 
 
 /* {ARRAY_ITERATION_CURSOR}.target */
-EIF_REFERENCE F506_3201 (EIF_REFERENCE Current)
+EIF_REFERENCE F326_2209 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
 }
 
 
-/* {ARRAY_ITERATION_CURSOR}.area_first_index */
-EIF_INTEGER_32 F506_3202 (EIF_REFERENCE Current)
-{
-	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-}
-
 void EIF_Minit509 (void)
 {
 	GTCX
