@@ -1,5 +1,5 @@
 /*
- * Code for class CA_ERROR
+ * Code for class CASE_AS
  */
 
 #include "eif_eiffel.h"
@@ -22,20 +22,13 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CA_ERROR}.name */
-
-EIF_REFERENCE F850_8572 (EIF_REFERENCE Current)
+/* {CASE_AS}.process */
+void F1184_13026 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTOSC (8572,RTMS32_EX_H("E\000\000\000r\000\000\000r\000\000\000o\000\000\000r\000\000\000",5,1920632178));
-}
-
-/* {CA_ERROR}.short_form */
-
-EIF_REFERENCE F850_8573 (EIF_REFERENCE Current)
-{
-	GTCX
-	RTOSC (8573,RTMS32_EX_H("E\000\000\000",1,69));
+	
+	
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2988[Dtype(RTCW(arg1))-223])(arg1, Current);
 }
 
 void EIF_Minit514 (void)
