@@ -5,14 +5,10 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-RTOSHF (EIF_REFERENCE, 8572)
 
-
-extern EIF_REFERENCE F850_8572(EIF_REFERENCE);RTOSHF (EIF_REFERENCE, 8573)
-
-
-extern EIF_REFERENCE F850_8573(EIF_REFERENCE);
+extern void F1184_13026(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit514(void);
+extern char *(*R2988[])();
 
 #ifdef __cplusplus
 }
