@@ -1,5 +1,5 @@
 /*
- * Code for class CHARACTER_8
+ * Code for class reference CHARACTER_32
  */
 
 #include "eif_eiffel.h"
@@ -22,8 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CHARACTER_8}.code */
-EIF_INTEGER_32 F1090_9957 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.code */
+EIF_INTEGER_32 F1065_9930 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -35,28 +35,42 @@ EIF_INTEGER_32 F1090_9957 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("code", 1089, Current, 0, 0, 15569);
+	RTEAA("code", 1064, Current, 0, 0, 13797);
 	RTGC;
 	RTHOOK(1);
-	Result = (EIF_INTEGER_32) F1088_9914(Current);
+	Result = (EIF_INTEGER_32) F1065_9931(Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
 	return Result;
 }
 
-/* {CHARACTER_8}.to_character_32 */
-EIF_CHARACTER_32 F1090_9958 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.natural_32_code */
+EIF_NATURAL_32 F1065_9931 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("to_character_32", 1089, Current, 0, 0, 15570);
+	RTEAA("natural_32_code", 1064, Current, 0, 0, 13798);
 	RTHOOK(1);
 	RTHOOK(2);
 	RTEE;
-	return (EIF_CHARACTER_32) F1088_9931(Current);
+	return (EIF_NATURAL_32) F1064_9896(Current);
+}
+
+/* {CHARACTER_32}.to_character_8 */
+EIF_CHARACTER_8 F1065_9932 (EIF_REFERENCE Current)
+{
+	GTCX
+	RTEX;
+	
+	
+	RTEAA("to_character_8", 1064, Current, 0, 0, 13799);
+	RTHOOK(1);
+	RTHOOK(2);
+	RTEE;
+	return (EIF_CHARACTER_8) F1064_9911(Current);
 }
 
 void EIF_Minit500 (void)
