@@ -1,5 +1,5 @@
 /*
- * Code for class CONTAINER [NATURAL_16]
+ * Code for class CONTAINER [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -23,17 +23,12 @@ extern "C" {
 #endif
 
 /* {CONTAINER}.compare_objects */
-void F347_2832 (EIF_REFERENCE Current)
+void F412_2672 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("compare_objects", 346, Current, 0, 0, 3577);
-	RTHOOK(1);
-	*(EIF_BOOLEAN *)(Current + O2505[Dtype(Current)-341]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-	RTHOOK(3);
-	RTEE;
+	*(EIF_BOOLEAN *)(Current + O2402[Dtype(Current)-409]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
 void EIF_Minit506 (void)
