@@ -1,5 +1,5 @@
 /*
- * Code for class CONTAINER [BOOLEAN]
+ * Code for class CONTAINER [CHARACTER_8]
  */
 
 #include "eif_eiffel.h"
@@ -23,12 +23,17 @@ extern "C" {
 #endif
 
 /* {CONTAINER}.compare_objects */
-void F426_2656 (EIF_REFERENCE Current)
+void F356_2830 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	
 	
-	*(EIF_BOOLEAN *)(Current + O2396[Dtype(Current)-423]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+	RTEAA("compare_objects", 355, Current, 0, 0, 3570);
+	RTHOOK(1);
+	*(EIF_BOOLEAN *)(Current + O2499[Dtype(Current)-351]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+	RTHOOK(3);
+	RTEE;
 }
 
 void EIF_Minit535 (void)
