@@ -6,11 +6,8 @@
 extern "C" {
 #endif
 
-extern void F1370_12840(EIF_REFERENCE);
+extern EIF_REFERENCE F1447_13511(EIF_REFERENCE);
 extern void EIF_Minit548(void);
-extern void F1362_12821(EIF_REFERENCE);
-extern void F1295_12291(EIF_REFERENCE);
-extern void F1304_12382(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
