@@ -1,5 +1,5 @@
 /*
- * Code for class EV_ITEM
+ * Code for class EV_PICK_AND_DROPABLE
  */
 
 #include "eif_eiffel.h"
@@ -22,10 +22,11 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {EV_ITEM}.parent */
-EIF_REFERENCE F1139_10394 (EIF_REFERENCE Current)
+/* {EV_PICK_AND_DROPABLE}.configurable_target_menu_handler */
+EIF_REFERENCE F1149_10302 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
@@ -37,10 +38,14 @@ EIF_REFERENCE F1139_10394 (EIF_REFERENCE Current)
 	RTLR(2,Result);
 	RTLIU(3);
 	
+	RTEAA("configurable_target_menu_handler", 1148, Current, 0, 0, 16509);
 	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current + O7741[Dtype(Current)-1058]);
-	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R11866[Dtype(RTCW(tr1))-1447])(tr1);
+	RTHOOK(1);
+	tr1 = *(EIF_REFERENCE *)(Current + O7976[Dtype(Current)-1107]);
+	Result = *(EIF_REFERENCE *)(RTCW(tr1) + O9820[Dtype(tr1)-1291]);
+	RTHOOK(2);
 	RTLE;
+	RTEE;
 	return Result;
 }
 
