@@ -6,10 +6,11 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1149_10449(EIF_REFERENCE);
-extern void F1149_10450(EIF_REFERENCE);
+extern EIF_REFERENCE F1157_10876(EIF_REFERENCE);
+extern EIF_REFERENCE F1157_10877(EIF_REFERENCE);
 extern void EIF_Minit517(void);
-extern void F1470_15520(EIF_REFERENCE);
+extern char *(*R8711[])();
+extern char *(*R8712[])();
 
 #ifdef __cplusplus
 }
