@@ -6,9 +6,12 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1157_10483(EIF_REFERENCE);
+extern EIF_REFERENCE F1197_10785(EIF_REFERENCE);
+extern EIF_BOOLEAN F1197_10786(EIF_REFERENCE);
 extern void EIF_Minit525(void);
-extern EIF_REFERENCE F134_2602(EIF_REFERENCE);
+extern long O10445[];
+extern long O10446[];
+extern long O8686[];
 
 #ifdef __cplusplus
 }
