@@ -5,11 +5,11 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-RTOSHF (EIF_REFERENCE, 10389)
 
-
-extern EIF_REFERENCE F1163_10389(EIF_REFERENCE);
+extern void F1200_10804(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit528(void);
+extern char *(*R10467[])();
+extern long O8686[];
 
 #ifdef __cplusplus
 }
