@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F607_10803(EIF_REFERENCE);
-extern void F607_10806(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F1181_11121(EIF_REFERENCE);
 extern void EIF_Minit539(void);
+extern long O11091[];
+extern long O8398[];
 
 #ifdef __cplusplus
 }
