@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F208_1561(EIF_REFERENCE);
+extern EIF_BOOLEAN F555_2770(EIF_REFERENCE);
 extern void EIF_Minit507(void);
-extern char *(*R1389[])();
+extern EIF_INTEGER_32 F657_3248(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
