@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F489_2687(EIF_REFERENCE);
+extern EIF_BOOLEAN F539_2686(EIF_REFERENCE);
 extern void EIF_Minit515(void);
-extern char *(*R2420[])();
+extern EIF_INTEGER_32 F639_3164(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
