@@ -23,52 +23,36 @@ extern "C" {
 #endif
 
 /* {JSON_BOOLEAN}.make */
-void F1193_9125 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
+void F1201_9623 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("make", 1192, Current, 0, 1, 15746);
-	RTHOOK(1);
 	*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_) = (EIF_BOOLEAN) arg1;
-	RTHOOK(2);
-	RTEE;
 }
 
 /* {JSON_BOOLEAN}.make_true */
-void F1193_9126 (EIF_REFERENCE Current)
+void F1201_9624 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("make_true", 1192, Current, 0, 0, 15747);
-	RTHOOK(1);
-	F1193_9125(Current, (EIF_BOOLEAN) 1);
-	RTHOOK(2);
-	RTEE;
+	F1201_9623(Current, (EIF_BOOLEAN) 1);
 }
 
 /* {JSON_BOOLEAN}.make_false */
-void F1193_9127 (EIF_REFERENCE Current)
+void F1201_9625 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("make_false", 1192, Current, 0, 0, 15748);
-	RTHOOK(1);
-	F1193_9125(Current, (EIF_BOOLEAN) 0);
-	RTHOOK(2);
-	RTEE;
+	F1201_9623(Current, (EIF_BOOLEAN) 0);
 }
 
 /* {JSON_BOOLEAN}.hash_code */
-EIF_INTEGER_32 F1193_9130 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1201_9628 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_BOOLEAN tb1;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
@@ -78,22 +62,17 @@ EIF_INTEGER_32 F1193_9130 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("hash_code", 1192, Current, 0, 0, 15751);
 	RTGC;
-	RTHOOK(1);
 	tb1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_);
 	Result = (tb1 ? 1L : 0L);
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {JSON_BOOLEAN}.representation */
-EIF_REFERENCE F1193_9131 (EIF_REFERENCE Current)
+EIF_REFERENCE F1201_9629 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
@@ -103,19 +82,13 @@ EIF_REFERENCE F1193_9131 (EIF_REFERENCE Current)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("representation", 1192, Current, 0, 0, 15752);
 	RTGC;
-	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_0_0_)) {
-		RTHOOK(2);
 		Result = RTMS_EX_H("true",4,1953658213);
 	} else {
-		RTHOOK(3);
 		Result = RTMS_EX_H("false",5,1635280741);
 	}
-	RTHOOK(4);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
