@@ -6,10 +6,11 @@
 extern "C" {
 #endif
 
-extern void F71_793(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32, EIF_INTEGER_32);
+extern void F1209_12674(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1209_12675(EIF_REFERENCE);
 extern void EIF_Minit526(void);
-extern char *(*R793[])();
-extern char *(*R795[])();
+extern char *(*R9437[])();
+extern char *(*R9417[])();
 
 #ifdef __cplusplus
 }
