@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern void F1214_11422(EIF_REFERENCE, EIF_REFERENCE);
-extern void F1214_11423(EIF_REFERENCE);
+extern EIF_BOOLEAN F89_980(EIF_REFERENCE);
+extern void F89_987(EIF_REFERENCE);
 extern void EIF_Minit548(void);
-extern char *(*R9185[])();
-extern char *(*R9205[])();
 
 #ifdef __cplusplus
 }
