@@ -5,10 +5,9 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-RTOSHF (EIF_REFERENCE, 13100)
 
-
-extern EIF_REFERENCE F1347_13100(EIF_REFERENCE);
+static EIF_REFERENCE F1197_10868_body(EIF_REFERENCE);
+extern EIF_REFERENCE F1197_10868(EIF_REFERENCE);
 extern void EIF_Minit521(void);
 
 #ifdef __cplusplus
