@@ -1,5 +1,5 @@
 /*
- * Code for class KL_SHARED_STANDARD_FILES
+ * Code for class KL_IMPORTED_STRING_ROUTINES
  */
 
 #include "eif_eiffel.h"
@@ -22,14 +22,16 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {KL_SHARED_STANDARD_FILES}.std */
-static EIF_REFERENCE F877_8661_body (EIF_REFERENCE Current)
+/* {KL_IMPORTED_STRING_ROUTINES}.string_ */
+static EIF_REFERENCE F1215_10993_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
+#define Result RTOTRR
+	RTOUDR(10)
 
 	RTLI(1);
 	RTLR(0,tr1);
@@ -37,22 +39,20 @@ static EIF_REFERENCE F877_8661_body (EIF_REFERENCE Current)
 	
 	RTEV;
 	RTGC;
-	RTOSP (8661);
-#define Result RTOSR(8661)
-	RTOC_NEW(Result);
-	tr1 = RTLNS(eif_new_type(81, 0x00).id, 81, _OBJSIZ_0_0_0_0_0_0_0_0_);
+	RTOTP;
+	tr1 = RTLNS(eif_new_type(1010, 0x01).id, 1010, _OBJSIZ_0_0_0_0_0_0_0_0_);
 	Result = (EIF_REFERENCE) tr1;
-	RTOSE (8661);
+	RTOTE;
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F877_8661 (EIF_REFERENCE Current)
+EIF_REFERENCE F1215_10993 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(8661,F877_8661_body,(Current));
+	return RTOUCR(10,F1215_10993_body,(Current));
 }
 
 void EIF_Minit526 (void)
