@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F620_2791(EIF_REFERENCE);
+extern void F50_626(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit543(void);
-extern EIF_INTEGER_32 F649_2915(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
