@@ -6,10 +6,10 @@
 extern "C" {
 #endif
 
-RTOSHF (EIF_REFERENCE,8654)
-static EIF_REFERENCE F883_8654_body(EIF_REFERENCE);
-extern EIF_REFERENCE F883_8654(EIF_REFERENCE);
+static EIF_REFERENCE F577_10089_body(EIF_REFERENCE);
+extern EIF_REFERENCE F577_10089(EIF_REFERENCE);
 extern void EIF_Minit525(void);
+extern void F4745_59456(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
