@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [NATURAL_64]
+ * Code for class TO_SPECIAL [NATURAL_8]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F124_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F185_1858 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -35,23 +34,18 @@ void F124_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_empty_area", 123, Current, 0, 1, 1579);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1387,Y1387_gen_type,Dftype(Current),115).id,0,arg1,sizeof(EIF_NATURAL_64), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),181).id,0,arg1,sizeof(EIF_NATURAL_8), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(5);
 	RTLE;
-	RTEE;
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F124_1496 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1, EIF_INTEGER_32 arg2)
+void F185_1859 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -60,38 +54,22 @@ void F124_1496 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_filled_area", 123, Current, 0, 2, 1580);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1387,Y1387_gen_type,Dftype(Current),115).id,0,arg2,sizeof(EIF_NATURAL_64), EIF_TRUE);
-	F527_2464(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),181).id,0,arg2,sizeof(EIF_NATURAL_8), EIF_TRUE);
+	F614_3064(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(6);
 	RTLE;
-	RTEE;
 }
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F124_1497 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.set_area */
-void F124_1502 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F185_1865 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("set_area", 123, Current, 0, 1, 1586);
-	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
-	RTHOOK(3);
-	RTEE;
 }
 
 void EIF_Minit538 (void)
