@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {UC_STRING_EQUALITY_TESTER}.test */
-EIF_BOOLEAN F1063_8996 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+EIF_BOOLEAN F1192_11737 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
@@ -39,38 +38,24 @@ EIF_BOOLEAN F1063_8996 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("test", 1062, Current, 0, 2, 13186);
 	RTGC;
-	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == arg2)) {
-		RTHOOK(2);
-		RTHOOK(3);
 		RTLE;
-		RTEE;
 		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 	} else {
-		RTHOOK(4);
 		if ((EIF_BOOLEAN)(arg1 == NULL)) {
-			RTHOOK(5);
 			Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 		} else {
-			RTHOOK(6);
 			if ((EIF_BOOLEAN)(arg2 == NULL)) {
-				RTHOOK(7);
-				RTHOOK(8);
 				RTLE;
-				RTEE;
 				return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 			} else {
-				RTHOOK(9);
-				tr1 = RTOUCR(643,F1062_8995,(Current));
-				Result = F1082_9173(RTCW(tr1), arg1, arg2);
+				tr1 = RTOUCR(4,F1175_11509, (Current));
+				Result = F1022_9379(RTCW(tr1), arg1, arg2);
 			}
 		}
 	}
-	RTHOOK(10);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
