@@ -1,5 +1,5 @@
 /*
- * Code for class XML_SHARED_UTILITIES
+ * Code for class XML_PARSER_FACTORY
  */
 
 #include "eif_eiffel.h"
@@ -22,40 +22,42 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {XML_SHARED_UTILITIES}.xml_utilities */
-static EIF_REFERENCE F613_9449_body (EIF_REFERENCE Current)
+/* {XML_PARSER_FACTORY}.new_parser */
+EIF_REFERENCE F596_10256 (EIF_REFERENCE Current)
+{
+	GTCX
+	RTEX;
+	
+	
+	RTEAA("new_parser", 595, Current, 0, 0, 9209);
+	RTHOOK(1);
+	RTHOOK(2);
+	RTEE;
+	return (EIF_REFERENCE) F596_10257(Current);
+}
+
+/* {XML_PARSER_FACTORY}.new_standard_parser */
+EIF_REFERENCE F596_10257 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
-#define Result RTOTRR
-	RTOUDR(3052)
-
 	RTLI(2);
 	RTLR(0,tr1);
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("xml_utilities", 612, Current, 0, 0, 9500);
+	RTEAA("new_standard_parser", 595, Current, 0, 0, 9210);
 	RTGC;
-	RTOTP;
 	RTHOOK(1);
-	tr1 = RTLNS(eif_new_type(277, 0x00).id, 277, _OBJSIZ_0_0_0_0_0_0_0_0_);
-	Result = (EIF_REFERENCE) tr1;
-	RTOTE;
+	tr1 = RTLNS(eif_new_type(1332, 0x00).id, 1332, _OBJSIZ_5_3_0_2_0_0_0_0_);
+	F1333_19462(RTCW(tr1));
 	RTHOOK(2);
 	RTLE;
 	RTEE;
-	return Result;
-#undef Result
-}
-
-EIF_REFERENCE F613_9449 (EIF_REFERENCE Current)
-{
-	GTCX
-	return RTOUCR(3052,F613_9449_body,(Current));
+	return (EIF_REFERENCE) tr1;
 }
 
 void EIF_Minit543 (void)
