@@ -1,5 +1,5 @@
 /*
- * Code for class XML_SHARED_UTILITIES
+ * Code for class XML_PARSER_FACTORY
  */
 
 #include "eif_eiffel.h"
@@ -22,40 +22,42 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {XML_SHARED_UTILITIES}.xml_utilities */
-static EIF_REFERENCE F614_9430_body (EIF_REFERENCE Current)
+/* {XML_PARSER_FACTORY}.new_parser */
+EIF_REFERENCE F597_10256 (EIF_REFERENCE Current)
+{
+	GTCX
+	RTEX;
+	
+	
+	RTEAA("new_parser", 596, Current, 0, 0, 9239);
+	RTHOOK(1);
+	RTHOOK(2);
+	RTEE;
+	return (EIF_REFERENCE) F597_10257(Current);
+}
+
+/* {XML_PARSER_FACTORY}.new_standard_parser */
+EIF_REFERENCE F597_10257 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
-#define Result RTOTRR
-	RTOUDR(3029)
-
 	RTLI(2);
 	RTLR(0,tr1);
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("xml_utilities", 613, Current, 0, 0, 9490);
+	RTEAA("new_standard_parser", 596, Current, 0, 0, 9240);
 	RTGC;
-	RTOTP;
 	RTHOOK(1);
-	tr1 = RTLNS(eif_new_type(278, 0x00).id, 278, _OBJSIZ_0_0_0_0_0_0_0_0_);
-	Result = (EIF_REFERENCE) tr1;
-	RTOTE;
+	tr1 = RTLNS(eif_new_type(1335, 0x00).id, 1335, _OBJSIZ_5_3_0_2_0_0_0_0_);
+	F1336_19490(RTCW(tr1));
 	RTHOOK(2);
 	RTLE;
 	RTEE;
-	return Result;
-#undef Result
-}
-
-EIF_REFERENCE F614_9430 (EIF_REFERENCE Current)
-{
-	GTCX
-	return RTOUCR(3029,F614_9430_body,(Current));
+	return (EIF_REFERENCE) tr1;
 }
 
 void EIF_Minit544 (void)
