@@ -1,5 +1,5 @@
 /*
- * Code for class CHARACTER_8
+ * Code for class CHARACTER_32
  */
 
 #include "eif_eiffel.h"
@@ -22,11 +22,10 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {CHARACTER_8}.code */
-EIF_INTEGER_32 F1139_10407 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.code */
+EIF_INTEGER_32 F1136_10067 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
@@ -35,28 +34,28 @@ EIF_INTEGER_32 F1139_10407 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("code", 1138, Current, 0, 0, 14466);
 	RTGC;
-	RTHOOK(1);
-	Result = (EIF_INTEGER_32) F1137_10364(Current);
-	RTHOOK(2);
+	Result = (EIF_INTEGER_32) F1136_10068(Current);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
-/* {CHARACTER_8}.to_character_32 */
-EIF_CHARACTER_32 F1139_10408 (EIF_REFERENCE Current)
+/* {CHARACTER_32}.natural_32_code */
+EIF_NATURAL_32 F1136_10068 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("to_character_32", 1138, Current, 0, 0, 14467);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
-	return (EIF_CHARACTER_32) F1137_10381(Current);
+	return (EIF_NATURAL_32) F1134_10033(Current);
+}
+
+/* {CHARACTER_32}.to_character_8 */
+EIF_CHARACTER_8 F1136_10069 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_CHARACTER_8) F1134_10048(Current);
 }
 
 void EIF_Minit583 (void)
