@@ -7,8 +7,8 @@
 #include "../E1/eoffsets.h"
 
 #include "co572.h"
-#include "eif_console.h"
 #include "eif_helpers.h"
+#include "eif_console.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {CONSOLE}.make_open_stdin */
-void F1243_11913 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F1268_12198 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -37,15 +37,15 @@ void F1243_11913 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F759_6358(Current, arg1);
+	F812_6855(Current, arg1);
 	tp1 = (EIF_POINTER) console_def(((EIF_INTEGER_32) 0L));
-	*(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_) = (EIF_POINTER) tp1;
-	F759_6582(Current);
+	*(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_) = (EIF_POINTER) tp1;
+	F810_6800(Current);
 	RTLE;
 }
 
 /* {CONSOLE}.make_open_stdout */
-void F1243_11914 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F1268_12199 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -57,15 +57,15 @@ void F1243_11914 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F759_6358(Current, arg1);
+	F812_6855(Current, arg1);
 	tp1 = (EIF_POINTER) console_def(((EIF_INTEGER_32) 1L));
-	*(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_) = (EIF_POINTER) tp1;
-	F759_6583(Current);
+	*(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_) = (EIF_POINTER) tp1;
+	F810_6801(Current);
 	RTLE;
 }
 
 /* {CONSOLE}.make_open_stderr */
-void F1243_11915 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F1268_12200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -77,26 +77,26 @@ void F1243_11915 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F759_6358(Current, arg1);
+	F812_6855(Current, arg1);
 	tp1 = (EIF_POINTER) console_def(((EIF_INTEGER_32) 2L));
-	*(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_) = (EIF_POINTER) tp1;
-	F759_6583(Current);
+	*(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_) = (EIF_POINTER) tp1;
+	F810_6801(Current);
 	RTLE;
 }
 
 /* {CONSOLE}.end_of_file */
-EIF_BOOLEAN F1243_11916 (EIF_REFERENCE Current)
+EIF_BOOLEAN F1268_12203 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
 	
 	
-	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_);
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_);
 	return (EIF_BOOLEAN) (EIF_BOOLEAN) EIF_TEST(console_eof((FILE*) tp1));
 }
 
 /* {CONSOLE}.exists */
-EIF_BOOLEAN F1243_11917 (EIF_REFERENCE Current)
+EIF_BOOLEAN F1268_12204 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -105,13 +105,13 @@ EIF_BOOLEAN F1243_11917 (EIF_REFERENCE Current)
 }
 
 /* {CONSOLE}.count */
-EIF_INTEGER_32 F1243_11918 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F1268_12205 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 }
 
 /* {CONSOLE}.dispose */
-void F1243_11919 (EIF_REFERENCE Current)
+void F1268_12206 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -120,16 +120,16 @@ void F1243_11919 (EIF_REFERENCE Current)
 }
 
 /* {CONSOLE}.read_line */
-void F1243_11926 (EIF_REFERENCE Current)
+void F1268_12213 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	F1243_11928(Current);
+	F1268_12215(Current);
 }
 
 /* {CONSOLE}.read_line_thread_aware */
-void F1243_11928 (EIF_REFERENCE Current)
+void F1268_12215 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -152,37 +152,37 @@ void F1243_11928 (EIF_REFERENCE Current)
 	
 	RTGC;
 	loc4 = *(EIF_REFERENCE *)(Current);
-	loc7 = RTOUCR(1249,F759_6526, (Current));
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R8235[Dtype(RTCW(loc4))-1162])(loc4);
-	loc1 = F403_5446(RTCW(loc7));
+	loc7 = RTOUCR(2827,F810_6744, (Current));
+	(FUNCTION_CAST(void, (EIF_REFERENCE)) R8573[Dtype(RTCW(loc4))-1190])(loc4);
+	loc1 = F444_6038(RTCW(loc7));
 	for (;;) {
 		if (loc3) break;
-		tp1 = *(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_);
-		tp2 = F403_5444(RTCW(loc7));
-		loc2 = F1243_11969(Current, tp1, tp2, loc1, ((EIF_INTEGER_32) 0L));
+		tp1 = *(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_);
+		tp2 = F444_6036(RTCW(loc7));
+		loc2 = F1268_12256(Current, tp1, tp2, loc1, ((EIF_INTEGER_32) 0L));
 		loc5 = *(EIF_INTEGER_32 *)(RTCW(loc4)+ _LNGOFF_1_1_0_2_);
 		loc6 = eif_min_int32 (loc2,loc1);
 		loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc5 + loc6);
 		loc3 = (EIF_BOOLEAN) (EIF_BOOLEAN) (loc2 <= loc1);
-		F1163_10398(RTCW(loc4), loc6);
-		F1163_10414(RTCW(loc4), loc6);
+		F1194_10824(RTCW(loc4), loc6);
+		F1194_10840(RTCW(loc4), loc6);
 		ti4_1 = eif_min_int32 (loc2,loc1);
-		F403_5439(RTCW(loc7), loc4, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc5 + ((EIF_INTEGER_32) 1L)), ti4_1);
+		F444_6030(RTCW(loc7), loc4, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc5 + ((EIF_INTEGER_32) 1L)), ti4_1);
 	}
 	RTLE;
 }
 
 /* {CONSOLE}.read_stream */
-void F1243_11929 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F1268_12216 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	F1243_11931(Current, arg1);
+	F1268_12218(Current, arg1);
 }
 
 /* {CONSOLE}.read_stream_thread_aware */
-void F1243_11931 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F1268_12218 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -200,20 +200,20 @@ void F1243_11931 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	
 	RTGC;
 	loc3 = *(EIF_REFERENCE *)(Current);
-	loc2 = RTOUCR(1249,F759_6526, (Current));
-	F403_5452(RTCW(loc2), arg1);
-	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_);
-	tp2 = F403_5444(RTCW(loc2));
-	loc1 = F1243_11971(Current, tp1, tp2, arg1);
-	F403_5452(RTCW(loc2), loc1);
-	F1163_10398(RTCW(loc3), loc1);
-	F1163_10414(RTCW(loc3), loc1);
-	F403_5441(RTCW(loc2), loc3);
+	loc2 = RTOUCR(2827,F810_6744, (Current));
+	F444_6044(RTCW(loc2), arg1);
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_);
+	tp2 = F444_6036(RTCW(loc2));
+	loc1 = F1268_12258(Current, tp1, tp2, arg1);
+	F444_6044(RTCW(loc2), loc1);
+	F1194_10824(RTCW(loc3), loc1);
+	F1194_10840(RTCW(loc3), loc1);
+	F444_6032(RTCW(loc2), loc3);
 	RTLE;
 }
 
 /* {CONSOLE}.read_character */
-void F1243_11935 (EIF_REFERENCE Current)
+void F1268_12222 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_POINTER tp1;
@@ -225,51 +225,50 @@ void F1243_11935 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_);
-	tc1 = F1243_11965(Current, tp1);
-	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_3_0_) = (EIF_CHARACTER_8) tc1;
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_);
+	tc1 = F1268_12252(Current, tp1);
+	*(EIF_CHARACTER_8 *)(Current+ _CHROFF_5_0_) = (EIF_CHARACTER_8) tc1;
 	RTLE;
 }
 
 /* {CONSOLE}.put_character */
-void F1243_11938 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
+void F1268_12225 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
 {
 	GTCX
 	EIF_POINTER tp1;
 	
 	
-	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_);
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_);
 	console_pc((FILE*) tp1, (EIF_CHARACTER) arg1);
 }
 
 /* {CONSOLE}.put_string */
-void F1243_11940 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F1268_12227 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
+	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
+	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_POINTER tp1;
-	EIF_INTEGER_32 ti4_1;
 	RTLD;
 	
 	RTLI(3);
 	RTLR(0,arg1);
-	RTLR(1,loc1);
+	RTLR(1,loc2);
 	RTLR(2,Current);
 	RTLIU(3);
 	
 	RTGC;
-	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
-	if ((EIF_BOOLEAN)(ti4_1 != ((EIF_INTEGER_32) 0L))) {
-		loc1 = *(EIF_REFERENCE *)(RTCW(arg1));
-		tp1 = *(EIF_POINTER *)(Current+ _PTROFF_3_7_2_4_1_0_);
-		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_2_);
-		console_ps((FILE*) tp1, (char*) loc1, (EIF_INTEGER) ti4_1);
+	loc1 = *(EIF_INTEGER_32 *)(RTCW(arg1) + O8684[Dtype(arg1)-1191]);
+	if ((EIF_BOOLEAN) (loc1 > ((EIF_INTEGER_32) 0L))) {
+		loc2 = *(EIF_REFERENCE *)(RTCW(arg1));
+		tp1 = *(EIF_POINTER *)(Current+ _PTROFF_5_7_2_4_1_0_);
+		console_ps((FILE*) tp1, (char*) loc2, (EIF_INTEGER) loc1);
 	}
 	RTLE;
 }
 
 /* {CONSOLE}.console_def */
-EIF_POINTER F1243_11951 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F1268_12238 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_POINTER Result = ((EIF_POINTER) 0);
@@ -281,7 +280,7 @@ EIF_POINTER F1243_11951 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {CONSOLE}.console_eof */
-EIF_BOOLEAN F1243_11956 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_BOOLEAN F1268_12243 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -293,7 +292,7 @@ EIF_BOOLEAN F1243_11956 (EIF_REFERENCE Current, EIF_POINTER arg1)
 }
 
 /* {CONSOLE}.console_ps */
-void F1243_11958 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
+void F1268_12245 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	
@@ -302,7 +301,7 @@ void F1243_11958 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF
 }
 
 /* {CONSOLE}.console_pc */
-void F1243_11960 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_CHARACTER_8 arg2)
+void F1268_12247 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_CHARACTER_8 arg2)
 {
 	GTCX
 	
@@ -311,7 +310,7 @@ void F1243_11960 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_CHARACTER_8 arg2)
 }
 
 /* {CONSOLE}.console_readchar */
-EIF_CHARACTER_8 F1243_11965 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_CHARACTER_8 F1268_12252 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	EIF_CHARACTER_8 Result = ((EIF_CHARACTER_8) 0);
@@ -326,7 +325,7 @@ EIF_CHARACTER_8 F1243_11965 (EIF_REFERENCE Current, EIF_POINTER arg1)
 }
 
 /* {CONSOLE}.console_readline */
-EIF_INTEGER_32 F1243_11969 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+EIF_INTEGER_32 F1268_12256 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -341,7 +340,7 @@ EIF_INTEGER_32 F1243_11969 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER
 }
 
 /* {CONSOLE}.console_readstream */
-EIF_INTEGER_32 F1243_11971 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
+EIF_INTEGER_32 F1268_12258 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -356,7 +355,7 @@ EIF_INTEGER_32 F1243_11971 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_POINTER
 }
 
 /* {CONSOLE}.file_close */
-void F1243_11972 (EIF_REFERENCE Current, EIF_POINTER arg1)
+void F1268_12259 (EIF_REFERENCE Current, EIF_POINTER arg1)
 {
 	GTCX
 	
