@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern void F693_9871(EIF_REFERENCE, EIF_REFERENCE);
+extern void F415_2672(EIF_REFERENCE);
 extern void EIF_Minit590(void);
-extern void F683_9823(EIF_REFERENCE, EIF_REFERENCE);
+extern long O2402[];
 
 #ifdef __cplusplus
 }
