@@ -6,7 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F956_10319(EIF_REFERENCE);
+extern void F649_10768(EIF_REFERENCE, EIF_REFERENCE);
+extern void F649_10769(EIF_REFERENCE);
 extern void EIF_Minit591(void);
 
 #ifdef __cplusplus
