@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F901_5744(EIF_REFERENCE);
-extern EIF_REFERENCE F901_5745(EIF_REFERENCE);
+extern void F1092_7293(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit554(void);
-extern long O4412[];
-extern long O4380[];
+extern char *(*R1053[])();
 
 #ifdef __cplusplus
 }
