@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F1075_7191(EIF_REFERENCE);
+extern void F61_801(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit573(void);
-extern char *(*R5522[])();
+extern long O803[];
 
 #ifdef __cplusplus
 }
