@@ -1,5 +1,5 @@
 /*
- * Code for class ET_ONCE_PROCEDURE_INLINE_AGENT
+ * Code for class ET_ASSERTION
  */
 
 #include "eif_eiffel.h"
@@ -22,13 +22,32 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ET_ONCE_PROCEDURE_INLINE_AGENT}.process */
-void F1374_12842 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+/* {ET_ASSERTION}.reset */
+void F1451_13530 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1296[Dtype(RTCW(arg1))-135])(arg1, Current);
+	RTGC;
+}
+
+/* {ET_ASSERTION}.is_class_assertion */
+EIF_BOOLEAN F1451_13531 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	RTGC;
+	return (EIF_BOOLEAN) 0;
+}
+
+/* {ET_ASSERTION}.assertion */
+EIF_REFERENCE F1451_13533 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_REFERENCE) Current;
 }
 
 void EIF_Minit552 (void)
