@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern void F1374_12842(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1451_13530(EIF_REFERENCE);
+extern EIF_BOOLEAN F1451_13531(EIF_REFERENCE);
+extern EIF_REFERENCE F1451_13533(EIF_REFERENCE);
 extern void EIF_Minit552(void);
-extern char *(*R1296[])();
 
 #ifdef __cplusplus
 }
