@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F1271_12600(EIF_REFERENCE);
-extern EIF_REFERENCE F1271_12601(EIF_REFERENCE);
+extern void F1493_13779(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit594(void);
+extern char *(*R1696[])();
 
 #ifdef __cplusplus
 }
