@@ -6,10 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1216_11221(EIF_REFERENCE);
+extern EIF_REFERENCE F1225_11834(EIF_REFERENCE);
 extern void EIF_Minit577(void);
-extern EIF_REFERENCE F71_2344(EIF_REFERENCE);
-RTOSHF(EIF_REFERENCE,2344)
+extern EIF_REFERENCE F1233_11958(EIF_REFERENCE);
+extern long O7511[];
 
 #ifdef __cplusplus
 }
