@@ -1,5 +1,5 @@
 /*
- * Code for class EV_WINDOW_ACTION_SEQUENCES
+ * Code for class EV_ITEM
  */
 
 #include "eif_eiffel.h"
@@ -22,11 +22,10 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {EV_WINDOW_ACTION_SEQUENCES}.close_request_actions */
-EIF_REFERENCE F1139_10313 (EIF_REFERENCE Current)
+/* {EV_ITEM}.parent */
+EIF_REFERENCE F1254_11540 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
@@ -38,14 +37,10 @@ EIF_REFERENCE F1139_10313 (EIF_REFERENCE Current)
 	RTLR(2,Result);
 	RTLIU(3);
 	
-	RTEAA("close_request_actions", 1138, Current, 0, 0, 14407);
 	RTGC;
-	RTHOOK(1);
-	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R8940[Dtype(Current)-1256])(Current);
-	Result = F182_3394(RTCW(tr1));
-	RTHOOK(3);
+	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
+	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R11251[Dtype(RTCW(tr1))-1428])(tr1);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
