@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F246_1691(EIF_REFERENCE);
+extern EIF_BOOLEAN F556_2770(EIF_REFERENCE);
 extern void EIF_Minit555(void);
-extern char *(*R1525[])();
+extern EIF_INTEGER_32 F658_3248(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
