@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F438_2336(EIF_REFERENCE);
+extern EIF_BOOLEAN F584_3155(EIF_REFERENCE);
 extern void EIF_Minit581(void);
-extern char *(*R2095[])();
+extern EIF_INTEGER_32 F686_3633(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
