@@ -6,10 +6,11 @@
 extern "C" {
 #endif
 
-extern void F70_763(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32, EIF_INTEGER_32);
+extern void F1244_11844(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1244_11845(EIF_REFERENCE);
 extern void EIF_Minit561(void);
-extern char *(*R763[])();
-extern char *(*R765[])();
+extern char *(*R9503[])();
+extern char *(*R9523[])();
 
 #ifdef __cplusplus
 }
