@@ -6,8 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_CHARACTER_8 F1237_11545(EIF_REFERENCE);
-extern EIF_REFERENCE F1237_11546(EIF_REFERENCE);
+RTOSHF (EIF_REFERENCE,9206)
+static EIF_REFERENCE F660_9206_body(EIF_REFERENCE);
+extern EIF_REFERENCE F660_9206(EIF_REFERENCE);
 extern void EIF_Minit571(void);
 
 #ifdef __cplusplus
