@@ -5,10 +5,9 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
-RTOSHF (EIF_REFERENCE, 11218)
 
-
-extern EIF_REFERENCE F1246_11218(EIF_REFERENCE);
+static EIF_REFERENCE F636_10631_body(EIF_REFERENCE);
+extern EIF_REFERENCE F636_10631(EIF_REFERENCE);
 extern void EIF_Minit578(void);
 
 #ifdef __cplusplus
