@@ -6,10 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F59_724(EIF_REFERENCE);
-extern void F59_725(EIF_REFERENCE, EIF_REFERENCE);
-extern void F59_726(EIF_REFERENCE);
+extern EIF_BOOLEAN F616_2734(EIF_REFERENCE);
 extern void EIF_Minit578(void);
+extern EIF_INTEGER_32 F643_2846(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
