@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F513_2698(EIF_REFERENCE);
+extern void F1254_13766(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit580(void);
-extern char *(*R2423[])();
+extern char *(*R2998[])();
 
 #ifdef __cplusplus
 }
