@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F514_2693(EIF_REFERENCE);
+extern void F1256_13780(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit582(void);
-extern char *(*R2421[])();
+extern char *(*R2999[])();
 
 #ifdef __cplusplus
 }
