@@ -1,5 +1,5 @@
 /*
- * Code for class TYPE [REAL_64]
+ * Code for class TYPE [TYPED_POINTER [INTEGER_64]]
  */
 
 #include "eif_eiffel.h"
@@ -23,8 +23,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TYPE}.name */
-EIF_REFERENCE F677_3165 (EIF_REFERENCE Current)
+/* {TYPE}.name_32 */
+EIF_REFERENCE F816_4246 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -39,20 +39,20 @@ EIF_REFERENCE F677_3165 (EIF_REFERENCE Current)
 	RTLIU(3);
 	
 	RTGC;
-	Result = *(EIF_REFERENCE *)(Current + _REFACS_1_);
+	Result = *(EIF_REFERENCE *)(Current);
 	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
-		Result = RTLNS(eif_new_type(794, 0x01).id, 794, _OBJSIZ_1_0_0_4_0_0_0_0_);
-		tr1 = F677_3193(Current);
-		F794_4513(RTCW(Result), tr1);
+		Result = RTLNS(eif_new_type(912, 0x01).id, 912, _OBJSIZ_1_0_0_4_0_0_0_0_);
+		tr1 = F816_4275(Current);
+		F913_5692(RTCW(Result), tr1);
 		RTAR(Current, Result);
-		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) Result;
+		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
 	}
 	RTLE;
 	return Result;
 }
 
 /* {TYPE}.generic_parameter_type */
-EIF_REFERENCE F677_3166 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F816_4248 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -65,8 +65,8 @@ EIF_REFERENCE F677_3166 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("generic_parameter_type", 676, Current, 0, 1, 8874);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type (Current, arg1);
+	RTEAA("generic_parameter_type", 815, Current, 0, 1, 9669);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type__i4_t (Current, arg1);
 	if (!Result) {RTEC(EN_FAIL);}
 	RTLE;
 	RTEE;
@@ -74,40 +74,40 @@ EIF_REFERENCE F677_3166 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TYPE}.type_id */
-EIF_INTEGER_32 F677_3167 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F816_4249 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 	return Result;
 }
 
 /* {TYPE}.hash_code */
-EIF_INTEGER_32 F677_3168 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F816_4250 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 }
 
 /* {TYPE}.is_attached */
-EIF_BOOLEAN F677_3173 (EIF_REFERENCE Current)
+EIF_BOOLEAN F816_4255 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
 	
-	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached (Current);
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached__b (Current);
 	return Result;
 }
 
 /* {TYPE}.is_equal */
-EIF_BOOLEAN F677_3174 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F816_4256 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -122,49 +122,26 @@ EIF_BOOLEAN F677_3174 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
+	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
 	RTLE;
 	return Result;
 }
 
 /* {TYPE}.default */
-EIF_REAL_64 F677_3181 (EIF_REFERENCE Current)
+EIF_INTEGER_64* F816_4263 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_REAL_64 loc1 = (EIF_REAL_64) 0;
+	EIF_INTEGER_64* loc1 = (EIF_INTEGER_64*) 0;
 	
 	
 	RTGC;
-	return (EIF_REAL_64) 0;
-}
-
-/* {TYPE}.out */
-EIF_REFERENCE F677_3182 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
-	
-	RTLD;
-	
-	RTLI(3);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLR(2,Result);
-	RTLIU(3);
-	
-	RTGC;
-	Result = RTLNS(eif_new_type(796, 0x01).id, 796, _OBJSIZ_1_1_0_3_0_0_0_0_);
-	tr1 = F677_3165(Current);
-	F794_4513(RTCW(Result), tr1);
-	RTLE;
-	return Result;
+	return (EIF_INTEGER_64*) 0;
 }
 
 /* {TYPE}.runtime_name */
-EIF_REFERENCE F677_3193 (EIF_REFERENCE Current)
+EIF_REFERENCE F816_4275 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -177,8 +154,8 @@ EIF_REFERENCE F677_3193 (EIF_REFERENCE Current)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("runtime_name", 676, Current, 0, 0, 8901);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
+	RTEAA("runtime_name", 815, Current, 0, 0, 9666);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
 	if (!Result) {RTEC(EN_FAIL);}
 	RTLE;
 	RTEE;
