@@ -1,5 +1,5 @@
 /*
- * Code for class TYPE [TYPED_POINTER [NATURAL_64]]
+ * Code for class TYPE [TYPED_POINTER [NATURAL_16]]
  */
 
 #include "eif_eiffel.h"
@@ -23,8 +23,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TYPE}.name */
-EIF_REFERENCE F667_3018 (EIF_REFERENCE Current)
+/* {TYPE}.name_32 */
+EIF_REFERENCE F815_4351 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -39,19 +39,19 @@ EIF_REFERENCE F667_3018 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("name", 666, Current, 0, 0, 8726);
+	RTEAA("name_32", 814, Current, 0, 0, 9799);
 	RTGC;
 	RTHOOK(1);
-	Result = *(EIF_REFERENCE *)(Current + _REFACS_1_);
+	Result = *(EIF_REFERENCE *)(Current);
 	RTHOOK(2);
 	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
 		RTHOOK(3);
-		Result = RTLNS(eif_new_type(758, 0x00).id, 758, _OBJSIZ_1_0_0_4_0_0_0_0_);
-		tr1 = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
-		F758_4536(RTCW(Result), tr1);
+		Result = RTLNS(eif_new_type(913, 0x00).id, 913, _OBJSIZ_1_0_0_4_0_0_0_0_);
+		tr1 = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
+		F914_5995(RTCW(Result), tr1);
 		RTHOOK(4);
 		RTAR(Current, Result);
-		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) Result;
+		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
 	}
 	RTHOOK(6);
 	RTLE;
@@ -60,7 +60,7 @@ EIF_REFERENCE F667_3018 (EIF_REFERENCE Current)
 }
 
 /* {TYPE}.generic_parameter_type */
-EIF_REFERENCE F667_3019 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F815_4353 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -73,8 +73,8 @@ EIF_REFERENCE F667_3019 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("generic_parameter_type", 666, Current, 0, 1, 8727);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type (Current, arg1);
+	RTEAA("generic_parameter_type", 814, Current, 0, 1, 9801);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type__i4_t (Current, arg1);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -82,7 +82,7 @@ EIF_REFERENCE F667_3019 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TYPE}.type_id */
-EIF_INTEGER_32 F667_3020 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F815_4354 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -94,8 +94,8 @@ EIF_INTEGER_32 F667_3020 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("type_id", 666, Current, 0, 0, 8728);
-	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	RTEAA("type_id", 814, Current, 0, 0, 9802);
+	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -103,21 +103,21 @@ EIF_INTEGER_32 F667_3020 (EIF_REFERENCE Current)
 }
 
 /* {TYPE}.hash_code */
-EIF_INTEGER_32 F667_3021 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F815_4355 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("hash_code", 666, Current, 0, 0, 8729);
+	RTEAA("hash_code", 814, Current, 0, 0, 9803);
 	RTHOOK(1);
 	RTHOOK(2);
 	RTEE;
-	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 }
 
 /* {TYPE}.is_attached */
-EIF_BOOLEAN F667_3026 (EIF_REFERENCE Current)
+EIF_BOOLEAN F815_4360 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -129,8 +129,8 @@ EIF_BOOLEAN F667_3026 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("is_attached", 666, Current, 0, 0, 8734);
-	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached (Current);
+	RTEAA("is_attached", 814, Current, 0, 0, 9808);
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached__b (Current);
 	RTHOOK(1);
 	RTLE;
 	RTEE;
@@ -138,7 +138,7 @@ EIF_BOOLEAN F667_3026 (EIF_REFERENCE Current)
 }
 
 /* {TYPE}.is_equal */
-EIF_BOOLEAN F667_3027 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F815_4361 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -153,11 +153,11 @@ EIF_BOOLEAN F667_3027 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,arg1);
 	RTLIU(2);
 	
-	RTEAA("is_equal", 666, Current, 0, 1, 8735);
+	RTEAA("is_equal", 814, Current, 0, 1, 9809);
 	RTGC;
 	RTHOOK(1);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
+	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
 	RTHOOK(2);
 	RTLE;
@@ -165,28 +165,85 @@ EIF_BOOLEAN F667_3027 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	return Result;
 }
 
-/* {TYPE}.default */
-EIF_NATURAL_64* F667_3034 (EIF_REFERENCE Current)
+/* {TYPE}.is_strictly_conforming_to */
+EIF_BOOLEAN F815_4362 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
-	EIF_NATURAL_64* loc1 = (EIF_NATURAL_64*) 0;
+	EIF_INTEGER_32 ti4_1;
+	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	
+	RTLD;
+	
+	RTLI(2);
+	RTLR(0,Current);
+	RTLR(1,arg1);
+	RTLIU(2);
+	
+	RTEAA("is_strictly_conforming_to", 814, Current, 0, 1, 9810);
+	RTGC;
+	RTHOOK(1);
+	Result = '\0';
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
+	if ((EIF_BOOLEAN)((EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current) != ti4_1)) {
+		Result = F815_4363(Current, arg1);
+	}
+	RTHOOK(2);
+	RTLE;
+	RTEE;
+	return Result;
+}
+
+/* {TYPE}.is_conforming_to */
+EIF_BOOLEAN F815_4363 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+{
+	GTCX
+	RTEX;
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
+	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	
+	RTLD;
+	
+	RTLI(2);
+	RTLR(0,Current);
+	RTLR(1,arg1);
+	RTLIU(2);
+	
+	RTEAA("is_conforming_to", 814, Current, 0, 1, 9811);
+	RTGC;
+	RTHOOK(1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
+	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
+	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_type_conforms_to__i4_i4_b (ti4_1, ti4_2);
+	RTHOOK(2);
+	RTLE;
+	RTEE;
+	return Result;
+}
+
+/* {TYPE}.default */
+EIF_NATURAL_16* F815_4368 (EIF_REFERENCE Current)
+{
+	GTCX
+	RTEX;
+	EIF_NATURAL_16* loc1 = (EIF_NATURAL_16*) 0;
 	RTLD;
 	
 	RTLI(1);
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("default", 666, Current, 1, 0, 8742);
+	RTEAA("default", 814, Current, 1, 0, 9816);
 	RTGC;
 	RTHOOK(1);
 	RTLE;
 	RTEE;
-	return (EIF_NATURAL_64*) 0;
+	return (EIF_NATURAL_16*) 0;
 }
 
 /* {TYPE}.runtime_name */
-EIF_REFERENCE F667_3046 (EIF_REFERENCE Current)
+EIF_REFERENCE F815_4380 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -199,8 +256,8 @@ EIF_REFERENCE F667_3046 (EIF_REFERENCE Current)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("runtime_name", 666, Current, 0, 0, 8754);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
+	RTEAA("runtime_name", 814, Current, 0, 0, 9828);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
