@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F2447_29313(EIF_REFERENCE);
-extern void F2447_29315(EIF_REFERENCE);
+extern void F7901_115892(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit6373(void);
-extern char *(*R25582[])();
-extern char *(*R25588[])();
+extern char *(*R20611[])();
 
 #ifdef __cplusplus
 }
