@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAYED_LIST_ITERATION_CURSOR [G#1]
+ * Code for class ARRAYED_LIST_ITERATION_CURSOR [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {ARRAYED_LIST_ITERATION_CURSOR}.make */
-void F500_5149 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F315_2187 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -40,33 +40,27 @@ void F500_5149 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R5252[Dtype(RTCW(tr1))-859])(tr1);
+	tr1 = F669_3018(RTCW(tr1));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5256[Dtype(RTCW(arg1))-859])(arg1);
+	ti4_1 = F669_3037(RTCW(arg1));
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L));
 	RTLE;
 }
 
 /* {ARRAYED_LIST_ITERATION_CURSOR}.first_index */
-EIF_INTEGER_32 F500_5150 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F315_2188 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 }
 
 /* {ARRAYED_LIST_ITERATION_CURSOR}.target */
-EIF_REFERENCE F500_5153 (EIF_REFERENCE Current)
+EIF_REFERENCE F315_2191 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
 }
 
 
-/* {ARRAYED_LIST_ITERATION_CURSOR}.area_first_index */
-EIF_INTEGER_32 F500_5154 (EIF_REFERENCE Current)
-{
-	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-}
-
 void EIF_Minit629 (void)
 {
 	GTCX
