@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern void F352_2113(EIF_REFERENCE);
+extern void F1302_11663(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit621(void);
-extern long O1888[];
 
 #ifdef __cplusplus
 }
