@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F994_6611(EIF_REFERENCE);
-extern EIF_INTEGER_32 F994_6613(EIF_REFERENCE, EIF_INTEGER_32);
+extern EIF_REFERENCE F1023_6781(EIF_REFERENCE);
 extern void EIF_Minit613(void);
-extern char *(*R4709[])();
-extern char *(*R4900[])();
+extern char *(*R5673[])();
 
 #ifdef __cplusplus
 }
