@@ -6,7 +6,7 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F972_6325(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F1031_6787(EIF_REFERENCE);
 extern void EIF_Minit621(void);
 
 #ifdef __cplusplus
