@@ -24,10 +24,10 @@ extern "C" {
 
 /* {EC_EIFFEL_LAYOUT}.application_name */
 
-EIF_REFERENCE F1266_12834 (EIF_REFERENCE Current)
+EIF_REFERENCE F1315_13177 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (173,RTMS_EX_H("ec",2,25955));
+	RTOSC (13177,RTMS_EX_H("ec",2,25955));
 }
 
 void EIF_Minit637 (void)
