@@ -1,5 +1,5 @@
 /*
- * Code for class ET_BUILTIN_CONVERT_FEATURE
+ * Code for class ET_FEATURE_ADDRESS
  */
 
 #include "eif_eiffel.h"
@@ -22,38 +22,48 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ET_BUILTIN_CONVERT_FEATURE}.make */
-void F1426_13088 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+/* {ET_FEATURE_ADDRESS}.make */
+void F1503_13808 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE tr2 = NULL;
 	RTLD;
 	
-	RTLI(4);
+	RTLI(3);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLR(2,tr2);
-	RTLR(3,arg1);
-	RTLIU(4);
+	RTLR(2,arg1);
+	RTLIU(3);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(1638, 0x01).id, 1638, _OBJSIZ_2_1_0_4_0_0_0_0_);
-	tr2 = RTMS_EX_H("_builtin_",9,102395743);
-	F1639_15207(RTCW(tr1), tr2);
+	tr1 = RTOSCF(3640,F284_3640, (RTCV(RTOSCF(6575,F874_6575, (Current)))));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	tr1 = RTLNS(eif_new_type(1324, 0x01).id, 1324, _OBJSIZ_3_0_0_1_0_0_0_0_);
-	F1325_12562(RTCW(tr1));
-	RTAR(Current, tr1);
-	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 	RTAR(Current, arg1);
-	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
+	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
 	RTLE;
 }
 
-/* {ET_BUILTIN_CONVERT_FEATURE}.last_leaf */
-EIF_REFERENCE F1426_13090 (EIF_REFERENCE Current)
+/* {ET_FEATURE_ADDRESS}.reset */
+void F1503_13809 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_REFERENCE tr1 = NULL;
+	RTLD;
+	
+	RTLI(2);
+	RTLR(0,Current);
+	RTLR(1,tr1);
+	RTLIU(2);
+	
+	RTGC;
+	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
+	(FUNCTION_CAST(void, (EIF_REFERENCE)) R10937[Dtype(RTCW(tr1))-1600])(tr1);
+	RTLE;
+}
+
+/* {ET_FEATURE_ADDRESS}.last_leaf */
+EIF_REFERENCE F1503_13811 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -69,11 +79,20 @@ EIF_REFERENCE F1426_13090 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	Result = F1325_12568(RTCW(tr1));
+	Result = F1698_15645(RTCW(tr1));
 	RTLE;
 	return Result;
 }
 
+/* {ET_FEATURE_ADDRESS}.process */
+void F1503_13812 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+{
+	GTCX
+	
+	
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R1630[Dtype(RTCW(arg1))-159])(arg1, Current);
+}
+
 void EIF_Minit604 (void)
 {
 	GTCX
