@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1493_14134(EIF_REFERENCE);
-extern EIF_INTEGER_32 F1493_14135(EIF_REFERENCE);
+extern void F1532_13971(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit633(void);
+extern char *(*R1685[])();
 
 #ifdef __cplusplus
 }
