@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern void F1457_13241(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1574_15529(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_BOOLEAN F1574_15530(EIF_REFERENCE);
+extern EIF_REFERENCE F1574_15532(EIF_REFERENCE);
 extern void EIF_Minit635(void);
-extern char *(*R1301[])();
 
 #ifdef __cplusplus
 }
