@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F312_3089(EIF_REFERENCE);
+extern EIF_BOOLEAN F542_2686(EIF_REFERENCE);
 extern void EIF_Minit635(void);
-extern char *(*R2893[])();
+extern EIF_INTEGER_32 F642_3164(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
