@@ -1,5 +1,5 @@
 /*
- * Code for class FINITE [G#1]
+ * Code for class FINITE [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -23,9 +23,10 @@ extern "C" {
 #endif
 
 /* {FINITE}.is_empty */
-EIF_BOOLEAN F396_3519 (EIF_REFERENCE Current)
+EIF_BOOLEAN F479_2169 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
@@ -35,10 +36,14 @@ EIF_BOOLEAN F396_3519 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
+	RTEAA("is_empty", 478, Current, 0, 0, 3966);
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3260[Dtype(Current)-625])(Current);
+	RTHOOK(1);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1918[Dtype(Current)-530])(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
+	RTHOOK(2);
 	RTLE;
+	RTEE;
 	return Result;
 }
 
