@@ -23,13 +23,12 @@ extern "C" {
 #endif
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.item */
-EIF_REFERENCE F502_5617 (EIF_REFERENCE Current)
+EIF_REFERENCE F478_3964 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
-	RTCDT;
 	RTLD;
 	
 	RTLI(3);
@@ -39,14 +38,14 @@ EIF_REFERENCE F502_5617 (EIF_REFERENCE Current)
 	RTLIU(3);
 	
 	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current + O5059[dtype-501]);
-	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R5413[Dtype(tr1)-778])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current + O5060[dtype-501]));
+	tr1 = *(EIF_REFERENCE *)(Current);
+	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3774[Dtype(RTCW(tr1))-747])(tr1, *(EIF_INTEGER_32 *)(Current + O3484[Dtype(Current)-477]));
 	RTLE;
 	return Result;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.target_index */
-EIF_INTEGER_32 F502_5619 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F478_3966 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -61,49 +60,26 @@ EIF_INTEGER_32 F502_5619 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	Result = *(EIF_INTEGER_32 *)(Current + O5060[dtype-501]);
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5034[dtype-479])(Current);
-	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5061[dtype-513])(Current);
+	Result = *(EIF_INTEGER_32 *)(Current + O3484[dtype-477]);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3458[dtype-458])(Current);
+	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3485[dtype-489])(Current);
 	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (Result + ti4_1) - ti4_2);
 	RTLE;
 	return Result;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.after */
-EIF_BOOLEAN F502_5626 (EIF_REFERENCE Current)
+EIF_BOOLEAN F478_3973 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTCDT;
 	
 	
-	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current + O5060[dtype-501]) > *(EIF_INTEGER_32 *)(Current + O5062[dtype-501]));
-}
-
-/* {GENERAL_SPECIAL_ITERATION_CURSOR}.is_first */
-EIF_BOOLEAN F502_5629 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTCDT;
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	ti4_1 = *(EIF_INTEGER_32 *)(Current + O5060[dtype-501]);
-	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5061[dtype-513])(Current);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
-	RTLE;
-	return Result;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current + O3484[dtype-477]) > *(EIF_INTEGER_32 *)(Current + O3486[dtype-477]));
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.start */
-void F502_5631 (EIF_REFERENCE Current)
+void F478_3978 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -115,25 +91,25 @@ void F502_5631 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5061[dtype-513])(Current);
-	*(EIF_INTEGER_32 *)(Current + O5060[dtype-501]) = (EIF_INTEGER_32) ti4_1;
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3485[dtype-489])(Current);
+	*(EIF_INTEGER_32 *)(Current + O3484[dtype-477]) = (EIF_INTEGER_32) ti4_1;
 	RTLE;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.forth */
-void F502_5632 (EIF_REFERENCE Current)
+void F478_3979 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTCDT;
 	
 	
-	(*(EIF_INTEGER_32 *)(Current + O5060[dtype-501]))++;
+	(*(EIF_INTEGER_32 *)(Current + O3484[dtype-477]))++;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.area */
-EIF_REFERENCE F502_5633 (EIF_REFERENCE Current)
+EIF_REFERENCE F478_3980 (EIF_REFERENCE Current)
 {
-	return *(EIF_REFERENCE *)(Current + O5059[Dtype(Current) - 501]);
+	return *(EIF_REFERENCE *)(Current);
 }
 
 
