@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern void F1494_12511(EIF_REFERENCE);
+extern EIF_REFERENCE F1423_13367(EIF_REFERENCE);
 extern void EIF_Minit625(void);
-extern void F797_3881(EIF_REFERENCE);
+extern EIF_REFERENCE F1_14(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
