@@ -6,7 +6,7 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1301_12033(EIF_REFERENCE);
+extern void F753_4124(EIF_REFERENCE, EIF_INTEGER_32);
 extern void EIF_Minit632(void);
 
 #ifdef __cplusplus
