@@ -5,9 +5,13 @@
 #ifdef __cplusplus
 extern "C" {
 #endif
+RTOSHF (EIF_REFERENCE, 12759)
 
-extern EIF_REFERENCE F1530_15477(EIF_REFERENCE);
+
+extern EIF_REFERENCE F1558_12759(EIF_REFERENCE);
+extern void F1558_12760(EIF_REFERENCE);
 extern void EIF_Minit639(void);
+extern void F837_3998(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
