@@ -6,8 +6,9 @@
 extern "C" {
 #endif
 
-extern void F59_725(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_BOOLEAN F617_2734(EIF_REFERENCE);
 extern void EIF_Minit614(void);
+extern EIF_INTEGER_32 F644_2846(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
