@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {READABLE_INDEXABLE}.new_cursor */
-EIF_REFERENCE F436_3905 (EIF_REFERENCE Current)
+EIF_REFERENCE F736_4487 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
@@ -37,20 +37,20 @@ EIF_REFERENCE F436_3905 (EIF_REFERENCE Current)
 	
 	RTGC;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {702,0,0,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,458,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y3449,Y3449_gen_type,Dftype(Current),215);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
+			l_type = eif_final_id(Y3400,Y3400_gen_type,Dftype(Current),413);
+			typarr0[2] = l_type.annotations | 0xFF00;
+			typarr0[3] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		Result = RTLNS(typres0.id, 702, _OBJSIZ_1_1_0_5_0_0_0_0_);
+		Result = RTLNS(typres0.id, 458, _OBJSIZ_1_1_0_5_0_0_0_0_);
 	}
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4387[Dtype(RTCW(Result))-702])(Result, Current);
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R4384[Dtype(RTCW(Result))-702])(Result);
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3472[Dtype(RTCW(Result))-458])(Result, Current);
+	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3469[Dtype(RTCW(Result))-458])(Result);
 	RTLE;
 	return Result;
 }
