@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F239_1600(EIF_REFERENCE);
-extern void F239_1602(EIF_REFERENCE);
+extern EIF_INTEGER_32 F562_2675(EIF_REFERENCE);
 extern void EIF_Minit631(void);
-extern char *(*R1423[])();
-extern char *(*R1429[])();
+extern EIF_INTEGER_32 F638_3141(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
