@@ -24,7 +24,7 @@ extern "C" {
 #endif
 
 /* {RESIZABLE}.additional_space */
-EIF_INTEGER_32 F391_3849 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F697_4128 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -37,12 +37,32 @@ EIF_INTEGER_32 F391_3849 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3651[Dtype(Current)-461])(Current);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3567[Dtype(Current)-771])(Current);
 	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
 	RTLE;
 	return Result;
 }
 
+/* {RESIZABLE}.automatic_grow */
+void F697_4130 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
+	RTCDT;
+	RTLD;
+	
+	RTLI(1);
+	RTLR(0,Current);
+	RTLIU(1);
+	
+	RTGC;
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3567[dtype-771])(Current);
+	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3571[dtype-771])(Current);
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R3573[dtype-771])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_2));
+	RTLE;
+}
+
 void EIF_Minit642 (void)
 {
 	GTCX
