@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F235_1567(EIF_REFERENCE);
-extern void F235_1569(EIF_REFERENCE);
+extern EIF_INTEGER_32 F567_2699(EIF_REFERENCE);
 extern void EIF_Minit644(void);
-extern char *(*R1390[])();
-extern char *(*R1396[])();
+extern EIF_INTEGER_32 F642_3165(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
