@@ -1,5 +1,5 @@
 /*
- * Code for class RESIZABLE [G#1]
+ * Code for class RESIZABLE [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -24,9 +24,10 @@ extern "C" {
 #endif
 
 /* {RESIZABLE}.additional_space */
-EIF_INTEGER_32 F713_5841 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F504_2182 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
@@ -36,33 +37,17 @@ EIF_INTEGER_32 F713_5841 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
+	RTEAA("additional_space", 503, Current, 0, 0, 4058);
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5196[Dtype(Current)-727])(Current);
+	RTHOOK(1);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1921[Dtype(Current)-570])(Current);
 	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
+	RTHOOK(3);
 	RTLE;
+	RTEE;
 	return Result;
 }
 
-/* {RESIZABLE}.automatic_grow */
-void F713_5843 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	RTCDT;
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5196[dtype-727])(Current);
-	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5200[dtype-712])(Current);
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R5202[dtype-727])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_2));
-	RTLE;
-}
-
 void EIF_Minit646 (void)
 {
 	GTCX
