@@ -6,7 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F745_10467(EIF_REFERENCE, EIF_INTEGER_32);
+RTOSHF (EIF_REFERENCE,10212)
+static EIF_REFERENCE F743_10212_body(EIF_REFERENCE);
+extern EIF_REFERENCE F743_10212(EIF_REFERENCE);
 extern void EIF_Minit642(void);
 
 #ifdef __cplusplus
