@@ -1,5 +1,5 @@
 /*
- * Code for class SPECIAL [BOOLEAN]
+ * Code for class SPECIAL [NATURAL_32]
  */
 
 #include "eif_eiffel.h"
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {SPECIAL}.make_empty */
-void F561_2597 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F662_3532 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
@@ -34,7 +34,7 @@ void F561_2597 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {SPECIAL}.make_filled */
-void F561_2598 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F662_3533 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	RTLD;
@@ -49,57 +49,57 @@ void F561_2598 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 		/* END INLINED CODE */
 	}
 	;
-	F561_2619(Current, arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
+	F662_3554(Current, arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
 	RTLE;
 }
 
 /* {SPECIAL}.item */
-EIF_BOOLEAN F561_2600 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_NATURAL_32 F662_3535 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	return *((EIF_BOOLEAN *) Current + arg1);
+	return *((EIF_NATURAL_32 *) Current + arg1);
 }
 
-EIF_REFERENCE F561_26001 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F662_35351 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	EIF_REFERENCE Result;
-	EIF_BOOLEAN r = *((EIF_BOOLEAN *) Current + arg1);
-	Result = RTLNS(eif_new_type(752, 0x00).id, 752, _OBJSIZ_0_1_0_0_0_0_0_0_);
-	*(EIF_BOOLEAN *)Result = r;
+	EIF_NATURAL_32 r = *((EIF_NATURAL_32 *) Current + arg1);
+	Result = RTLNS(eif_new_type(828, 0x00).id, 828, _OBJSIZ_0_0_0_1_0_0_0_0_);
+	*(EIF_NATURAL_32 *)Result = r;
 	return Result;
 }
 
 /* {SPECIAL}.at */
-EIF_BOOLEAN F561_2601 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_NATURAL_32 F662_3536 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	return *((EIF_BOOLEAN *) Current + arg1);
+	return *((EIF_NATURAL_32 *) Current + arg1);
 }
 
-EIF_REFERENCE F561_26011 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F662_35361 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	EIF_REFERENCE Result;
-	EIF_BOOLEAN r = *((EIF_BOOLEAN *) Current + arg1);
-	Result = RTLNS(eif_new_type(752, 0x00).id, 752, _OBJSIZ_0_1_0_0_0_0_0_0_);
-	*(EIF_BOOLEAN *)Result = r;
+	EIF_NATURAL_32 r = *((EIF_NATURAL_32 *) Current + arg1);
+	Result = RTLNS(eif_new_type(828, 0x00).id, 828, _OBJSIZ_0_0_0_1_0_0_0_0_);
+	*(EIF_NATURAL_32 *)Result = r;
 	return Result;
 }
 
 /* {SPECIAL}.item_address */
-EIF_POINTER F561_2603 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_POINTER F662_3538 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	return (EIF_POINTER) (Current + (rt_uint_ptr) arg1 * (rt_uint_ptr)sizeof(EIF_BOOLEAN));
+	return (EIF_POINTER) (Current + (rt_uint_ptr) arg1 * (rt_uint_ptr)sizeof(EIF_NATURAL_32));
 }
 
 /* {SPECIAL}.base_address */
-EIF_POINTER F561_2604 (EIF_REFERENCE Current)
+EIF_POINTER F662_3539 (EIF_REFERENCE Current)
 {
 	return (EIF_POINTER) Current;
 }
 
 /* {SPECIAL}.to_array */
-EIF_REFERENCE F561_2606 (EIF_REFERENCE Current)
+EIF_REFERENCE F662_3541 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -112,31 +112,31 @@ EIF_REFERENCE F561_2606 (EIF_REFERENCE Current)
 	
 	RTGC;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,585,0,0,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,686,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y1792,Y1792_gen_type,Dftype(Current),226);
+			l_type = eif_final_id(Y2634,Y2634_gen_type,Dftype(Current),323);
 			typarr0[2] = l_type.annotations | 0xFF00;
 			typarr0[3] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 585, _OBJSIZ_1_1_0_2_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 686, _OBJSIZ_1_1_0_2_0_0_0_0_);
 	}
-	F586_2689(RTCW(tr1), Current);
+	F687_3624(RTCW(tr1), Current);
 	RTLE;
 	return (EIF_REFERENCE) tr1;
 }
 
 /* {SPECIAL}.lower */
-EIF_INTEGER_32 F561_2608 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F662_3543 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 }
 
 /* {SPECIAL}.upper */
-EIF_INTEGER_32 F561_2609 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F662_3544 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
@@ -148,46 +148,46 @@ EIF_INTEGER_32 F561_2609 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) (Result - ((EIF_INTEGER_32) 1L));
 	RTLE;
 	return Result;
 }
 
 /* {SPECIAL}.count */
-EIF_INTEGER_32 F561_2610 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F662_3545 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 	return Result;
 }
 
 /* {SPECIAL}.capacity */
-EIF_INTEGER_32 F561_2611 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F662_3546 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (Current);
 	return Result;
 }
 
 /* {SPECIAL}.same_items */
-EIF_BOOLEAN F561_2613 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+EIF_BOOLEAN F662_3548 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
-	EIF_BOOLEAN tb3;
+	EIF_NATURAL_32 tu4_1;
+	EIF_NATURAL_32 tu4_2;
+	EIF_NATURAL_32 tu4_3;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	RTLD;
@@ -199,25 +199,26 @@ EIF_BOOLEAN F561_2613 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32
 	
 	RTGC;
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-	if ((EIF_BOOLEAN)(arg1 != Current)) {
+	if ((EIF_BOOLEAN) ((EIF_BOOLEAN)(arg1 != Current) || (EIF_BOOLEAN)(arg2 != arg3))) {
 		loc1 = (EIF_INTEGER_32) arg2;
 		loc2 = (EIF_INTEGER_32) arg3;
 		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg2 + arg4);
 		for (;;) {
 			if ((EIF_BOOLEAN)(loc1 == loc3)) break;
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)RTCW(arg1) + (loc1));
+			tu4_2 = *((EIF_NATURAL_32 *)RTCW(arg1) + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
+			tu4_1 = tu4_2;
 			/* INLINED CODE (SPECIAL.item) */
-			tb3 = *((EIF_BOOLEAN *)Current + (loc2));
+			tu4_3 = *((EIF_NATURAL_32 *)Current + (loc2));
 			/* END INLINED CODE */
-			if ((EIF_BOOLEAN)(tb1 != tb3)) {
+			if ((EIF_BOOLEAN)(tu4_1 != tu4_3)) {
 				Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
-				loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
+				loc1 = (EIF_INTEGER_32) loc3;
+			} else {
+				loc1++;
+				loc2++;
 			}
-			loc1++;
-			loc2++;
 		}
 	}
 	RTLE;
@@ -225,76 +226,76 @@ EIF_BOOLEAN F561_2613 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32
 }
 
 /* {SPECIAL}.put */
-void F561_2615 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F662_3550 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	*((EIF_BOOLEAN *) Current + arg2) = arg1;
+	*((EIF_NATURAL_32 *) Current + arg2) = arg1;
 }
 
-void F561_26152 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
+void F662_35502 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
 {
-	*((EIF_BOOLEAN *) Current + arg2) = *(EIF_BOOLEAN *)arg1;
+	*((EIF_NATURAL_32 *) Current + arg2) = *(EIF_NATURAL_32 *)arg1;
 }
 
 /* {SPECIAL}.force */
-void F561_2616 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F662_3551 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_INTEGER_32 arg3 = RT_SPECIAL_COUNT(Current);
-	*((EIF_BOOLEAN *) Current + arg2) = arg1;
+	*((EIF_NATURAL_32 *) Current + arg2) = arg1;
 	if (arg2 == arg3) { RT_SPECIAL_COUNT(Current) = arg3 + 1; }
 }
 
-void F561_26162 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
+void F662_35512 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
 {
-	*((EIF_BOOLEAN *) Current + arg2) = *(EIF_BOOLEAN *)arg1;
+	*((EIF_NATURAL_32 *) Current + arg2) = *(EIF_NATURAL_32 *)arg1;
 }
 
 /* {SPECIAL}.extend */
-void F561_2617 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
+void F662_3552 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1)
 {
 	GTCX
 	EIF_INTEGER_32 arg2 = RT_SPECIAL_COUNT(Current)++;
-	*((EIF_BOOLEAN *) Current + arg2) = arg1;
+	*((EIF_NATURAL_32 *) Current + arg2) = arg1;
 }
 
-void F561_26172 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F662_35522 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	
 	EIF_INTEGER_32 arg2 = RT_SPECIAL_COUNT(Current)++;
-	*((EIF_BOOLEAN *) Current + arg2) = *(EIF_BOOLEAN *)arg1;
+	*((EIF_NATURAL_32 *) Current + arg2) = *(EIF_NATURAL_32 *)arg1;
 }
 
 /* {SPECIAL}.fill_with */
-void F561_2619 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F662_3554 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 i;
 	for (i = arg2; i <= arg3; i++) {
-		*((EIF_BOOLEAN *) Current + i) = arg1;
+		*((EIF_NATURAL_32 *) Current + i) = arg1;
 	}
 	RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg3 + 1);
 }
 
-void F561_26192 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F662_35542 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	EIF_INTEGER_32 i;
-	EIF_BOOLEAN arg1x = *(EIF_BOOLEAN *)arg1;
+	EIF_NATURAL_32 arg1x = *(EIF_NATURAL_32 *)arg1;
 	for (i = arg2; i < arg3; i++) {
-	*((EIF_BOOLEAN *) Current + i) = arg1x;
+	*((EIF_NATURAL_32 *) Current + i) = arg1x;
 	}
 	RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg3 + 1);
 }
 
 /* {SPECIAL}.copy_data */
-void F561_2622 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+void F662_3557 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
+	EIF_NATURAL_32 tu4_1;
+	EIF_NATURAL_32 tu4_2;
 	RTLD;
 	
 	RTLI(2);
@@ -305,7 +306,7 @@ void F561_2622 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	RTGC;
 	if ((EIF_BOOLEAN)(arg1 == Current)) {
 		/* INLINED CODE (SPECIAL.overlapping_move) */
-		memmove((EIF_BOOLEAN *)Current + (arg3),(EIF_BOOLEAN *)Current + arg2, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg4);
+		memmove((EIF_NATURAL_32 *)Current + (arg3),(EIF_NATURAL_32 *)Current + arg2, (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)arg4);
 		RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg3 + arg4);
 		/* END INLINED CODE */
 		;
@@ -316,10 +317,10 @@ void F561_2622 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 		for (;;) {
 			if ((EIF_BOOLEAN)(loc1 == loc3)) break;
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)RTCW(arg1) + (loc1));
+			tu4_2 = *((EIF_NATURAL_32 *)RTCW(arg1) + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
-			F561_2616(Current, tb1, loc2);
+			tu4_1 = tu4_2;
+			F662_3551(Current, tu4_1, loc2);
 			loc1++;
 			loc2++;
 		}
@@ -328,14 +329,14 @@ void F561_2622 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.move_data */
-void F561_2623 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F662_3558 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
 	EIF_INTEGER_32 ti4_4;
-	EIF_BOOLEAN tb1;
+	EIF_NATURAL_32 tu4_1;
 	RTLD;
 	
 	RTLI(1);
@@ -348,13 +349,13 @@ void F561_2623 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 		if ((EIF_BOOLEAN) (arg1 > arg2)) {
 			if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg2 + arg3) < arg1)) {
 				/* INLINED CODE (SPECIAL.move_data) */
-				memcpy((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memcpy((EIF_NATURAL_32 *)Current + (arg2),(EIF_NATURAL_32 *)Current + arg1, (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
 			} else {
 				/* INLINED CODE (SPECIAL.overlapping_move) */
-				memmove((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memmove((EIF_NATURAL_32 *)Current + (arg2),(EIF_NATURAL_32 *)Current + arg1, (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
@@ -362,13 +363,13 @@ void F561_2623 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 		} else {
 			if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg1 + arg3) < arg2)) {
 				/* INLINED CODE (SPECIAL.move_data) */
-				memcpy((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memcpy((EIF_NATURAL_32 *)Current + (arg2),(EIF_NATURAL_32 *)Current + arg1, (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
 			} else {
 				/* INLINED CODE (SPECIAL.overlapping_move) */
-				memmove((EIF_BOOLEAN *)Current + (arg2),(EIF_BOOLEAN *)Current + arg1, (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg3);
+				memmove((EIF_NATURAL_32 *)Current + (arg2),(EIF_NATURAL_32 *)Current + arg1, (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)arg3);
 				RT_SPECIAL_COUNT(Current) = eif_max_int32(RT_SPECIAL_COUNT(Current), arg2 + arg3);
 				/* END INLINED CODE */
 				;
@@ -379,15 +380,15 @@ void F561_2623 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.overlapping_move */
-void F561_2624 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F662_3559 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
+	EIF_NATURAL_32 tu4_1;
+	EIF_NATURAL_32 tu4_2;
 	RTLD;
 	
 	RTLI(1);
@@ -399,22 +400,22 @@ void F561_2624 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg1 + arg3) - ((EIF_INTEGER_32) 1L));
 		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg1 - ((EIF_INTEGER_32) 1L));
 		loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (arg2 - arg1);
-		if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg2 + arg3) >= (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current))) {
+		if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (arg2 + arg3) >= (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current))) {
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)Current + (arg1));
+			tu4_2 = *((EIF_NATURAL_32 *)Current + (arg1));
 			/* END INLINED CODE */
-			tb1 = tb2;
-			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
-			F561_2619(Current, tb1, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 + arg3) - ((EIF_INTEGER_32) 1L)));
+			tu4_1 = tu4_2;
+			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
+			F662_3554(Current, tu4_1, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 + arg3) - ((EIF_INTEGER_32) 1L)));
 		}
 		for (;;) {
 			if ((EIF_BOOLEAN)(loc1 == loc2)) break;
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)Current + (loc1));
+			tu4_2 = *((EIF_NATURAL_32 *)Current + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
+			tu4_1 = tu4_2;
 			/* INLINED CODE (SPECIAL.put) */
-			*((EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) (loc1 + loc3))) = tb1;
+			*((EIF_NATURAL_32 *)Current + ((EIF_INTEGER_32) (loc1 + loc3))) = tu4_1;
 			/* END INLINED CODE */
 			;
 			loc1--;
@@ -426,10 +427,10 @@ void F561_2624 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 		for (;;) {
 			if ((EIF_BOOLEAN)(loc1 == loc2)) break;
 			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)Current + (loc1));
+			tu4_2 = *((EIF_NATURAL_32 *)Current + (loc1));
 			/* END INLINED CODE */
-			tb1 = tb2;
-			F561_2616(Current, tb1, (EIF_INTEGER_32) (loc1 - loc3));
+			tu4_1 = tu4_2;
+			F662_3551(Current, tu4_1, (EIF_INTEGER_32) (loc1 - loc3));
 			loc1++;
 		}
 	}
@@ -437,14 +438,14 @@ void F561_2624 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 }
 
 /* {SPECIAL}.non_overlapping_move */
-void F561_2625 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F662_3560 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
+	EIF_NATURAL_32 tu4_1;
+	EIF_NATURAL_32 tu4_2;
 	RTLD;
 	
 	RTLI(1);
@@ -458,52 +459,33 @@ void F561_2625 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 	for (;;) {
 		if ((EIF_BOOLEAN)(loc1 == loc2)) break;
 		/* INLINED CODE (SPECIAL.item) */
-		tb2 = *((EIF_BOOLEAN *)Current + (loc1));
+		tu4_2 = *((EIF_NATURAL_32 *)Current + (loc1));
 		/* END INLINED CODE */
-		tb1 = tb2;
-		F561_2616(Current, tb1, (EIF_INTEGER_32) (loc1 + loc3));
+		tu4_1 = tu4_2;
+		F662_3551(Current, tu4_1, (EIF_INTEGER_32) (loc1 + loc3));
 		loc1++;
 	}
 	RTLE;
 }
 
 /* {SPECIAL}.keep_head */
-void F561_2626 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F662_3561 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	eif_builtin_SPECIAL_set_count (Current, arg1);
-}
-
-/* {SPECIAL}.remove_tail */
-void F561_2629 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
-	F561_2626(Current, (EIF_INTEGER_32) (ti4_1 - arg1));
-	RTLE;
+	eif_builtin_SPECIAL_set_count__i4_ (Current, arg1);
 }
 
 /* {SPECIAL}.resized_area */
-EIF_REFERENCE F561_2630 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F662_3565 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
 	EIF_INTEGER_32 ti4_4;
-	EIF_INTEGER_32 ti4_5;
-	EIF_INTEGER_32 ti4_6;
-	EIF_BOOLEAN tb1;
+	EIF_NATURAL_32 tu4_1;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
@@ -514,12 +496,12 @@ EIF_REFERENCE F561_2630 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	Result = RTLNSP2(Dftype(Current),0,arg1,sizeof(EIF_BOOLEAN), EIF_TRUE);
+	Result = RTLNSP2(Dftype(Current),0,arg1,sizeof(EIF_NATURAL_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(Result) = 0;
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Current);
 	ti4_1 = eif_min_int32 (arg1,ti4_1);
 	/* INLINED CODE (SPECIAL.copy_data) */
-	memmove((EIF_BOOLEAN *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)ti4_1);
+	memmove((EIF_NATURAL_32 *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_NATURAL_32 *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)ti4_1);
 	RT_SPECIAL_COUNT(Result) = eif_max_int32(RT_SPECIAL_COUNT(Result), ((EIF_INTEGER_32) 0L) + ti4_1);
 	/* END INLINED CODE */
 	;
@@ -527,51 +509,8 @@ EIF_REFERENCE F561_2630 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	return Result;
 }
 
-/* {SPECIAL}.resized_area_with_default */
-EIF_REFERENCE F561_2631 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 ti4_4;
-	EIF_INTEGER_32 ti4_5;
-	EIF_INTEGER_32 ti4_6;
-	EIF_BOOLEAN tb1;
-	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,Result);
-	RTLIU(2);
-	
-	RTGC;
-	Result = RTLNSP2(Dftype(Current),0,arg2,sizeof(EIF_BOOLEAN), EIF_TRUE);
-	RT_SPECIAL_COUNT(Result) = 0;
-	if ((EIF_BOOLEAN) (arg2 > (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current))) {
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
-		/* INLINED CODE (SPECIAL.copy_data) */
-		memmove((EIF_BOOLEAN *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)ti4_1);
-		RT_SPECIAL_COUNT(Result) = eif_max_int32(RT_SPECIAL_COUNT(Result), ((EIF_INTEGER_32) 0L) + ti4_1);
-		/* END INLINED CODE */
-		;
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Current);
-		F561_2619(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
-	} else {
-		/* INLINED CODE (SPECIAL.copy_data) */
-		memmove((EIF_BOOLEAN *)RTCW(Result) + (((EIF_INTEGER_32) 0L)),(EIF_BOOLEAN *)Current + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)arg2);
-		RT_SPECIAL_COUNT(Result) = eif_max_int32(RT_SPECIAL_COUNT(Result), ((EIF_INTEGER_32) 0L) + arg2);
-		/* END INLINED CODE */
-		;
-	}
-	RTLE;
-	return Result;
-}
-
 /* {SPECIAL}.aliased_resized_area */
-EIF_REFERENCE F561_2632 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F662_3567 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
@@ -582,13 +521,13 @@ EIF_REFERENCE F561_2632 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(0,Result);
 	RTLIU(1);
 	
-	Result = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (Current, arg1);
+	Result = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area__i4_s (Current, arg1);
 	RTLE;
 	return Result;
 }
 
 /* {SPECIAL}.aliased_resized_area_with_default */
-EIF_REFERENCE F561_2633 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+EIF_REFERENCE F662_3568 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -602,83 +541,47 @@ EIF_REFERENCE F561_2633 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32
 	RTLIU(2);
 	
 	RTGC;
-	Result = F561_2632(Current, arg2);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (Result);
-	F561_2619(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
+	Result = F662_3567(Current, arg2);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (Result);
+	F662_3554(RTCW(Result), arg1, ti4_1, (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)));
 	RTLE;
 	return Result;
 }
 
 /* {SPECIAL}.wipe_out */
-void F561_2635 (EIF_REFERENCE Current)
+void F662_3570 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	eif_builtin_SPECIAL_set_count (Current, ((EIF_INTEGER_32) 0L));
+	eif_builtin_SPECIAL_set_count__i4_ (Current, ((EIF_INTEGER_32) 0L));
 }
 
 /* {SPECIAL}.clear_all */
-void F561_2636 (EIF_REFERENCE Current)
+void F662_3571 (EIF_REFERENCE Current)
 {
 	memset (Current, 0, RT_SPECIAL_VISIBLE_SIZE(Current));
 }
 
-/* {SPECIAL}.for_all_in_bounds */
-EIF_BOOLEAN F561_2640 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,arg1);
-	RTLR(1,Current);
-	RTLIU(2);
-	
-	RTGC;
-	loc1 = (EIF_INTEGER_32) arg2;
-	loc2 = (EIF_INTEGER_32) arg3;
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-	for (;;) {
-		if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || (EIF_BOOLEAN) !Result)) break;
-		tb1 = 
-			/* INLINED CODE (SPECIAL.item) */
-			*((EIF_BOOLEAN *)Current + (loc1))
-			/* END INLINED CODE */;
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_POINTER, EIF_REFERENCE, EIF_BOOLEAN)) *(EIF_POINTER *)(RTCW(arg1)+ _PTROFF_4_3_0_3_0_0_))(
-			*(EIF_POINTER *)(RTCW(arg1)+ _PTROFF_4_3_0_3_0_1_),
-			*(EIF_REFERENCE *)(RTCW(arg1) + _REFACS_1_), tb1);
-		Result = tb1;
-		loc1++;
-	}
-	RTLE;
-	return Result;
-}
-
 /* {SPECIAL}.element_size */
-EIF_INTEGER_32 F561_2644 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F662_3579 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_element_size (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_element_size__i4 (Current);
 	return Result;
 }
 
 /* {SPECIAL}.set_count */
-void F561_2645 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F662_3580 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	eif_builtin_SPECIAL_set_count (Current, arg1);
+	eif_builtin_SPECIAL_set_count__i4_ (Current, arg1);
 }
 
 void EIF_Minit603 (void)
