@@ -1,5 +1,5 @@
 /*
- * Code for class TYPE [TYPED_POINTER [NATURAL_16]]
+ * Code for class TYPE [INTEGER_64]
  */
 
 #include "eif_eiffel.h"
@@ -23,8 +23,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TYPE}.name */
-EIF_REFERENCE F765_3658 (EIF_REFERENCE Current)
+/* {TYPE}.name_32 */
+EIF_REFERENCE F850_4625 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -39,20 +39,20 @@ EIF_REFERENCE F765_3658 (EIF_REFERENCE Current)
 	RTLIU(3);
 	
 	RTGC;
-	Result = *(EIF_REFERENCE *)(Current + _REFACS_1_);
+	Result = *(EIF_REFERENCE *)(Current);
 	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
-		Result = RTLNS(eif_new_type(852, 0x01).id, 852, _OBJSIZ_1_0_0_4_0_0_0_0_);
-		tr1 = F765_3686(Current);
-		F852_4978(RTCW(Result), tr1);
+		Result = RTLNS(eif_new_type(950, 0x01).id, 950, _OBJSIZ_1_0_0_4_0_0_0_0_);
+		tr1 = F850_4654(Current);
+		F951_6071(RTCW(Result), tr1);
 		RTAR(Current, Result);
-		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) Result;
+		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
 	}
 	RTLE;
 	return Result;
 }
 
 /* {TYPE}.generic_parameter_type */
-EIF_REFERENCE F765_3659 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F850_4627 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -65,8 +65,8 @@ EIF_REFERENCE F765_3659 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("generic_parameter_type", 764, Current, 0, 1, 9409);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type (Current, arg1);
+	RTEAA("generic_parameter_type", 849, Current, 0, 1, 9847);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type__i4_t (Current, arg1);
 	if (!Result) {RTEC(EN_FAIL);}
 	RTLE;
 	RTEE;
@@ -74,40 +74,52 @@ EIF_REFERENCE F765_3659 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TYPE}.type_id */
-EIF_INTEGER_32 F765_3660 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F850_4628 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 	return Result;
 }
 
 /* {TYPE}.hash_code */
-EIF_INTEGER_32 F765_3661 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F850_4629 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 }
 
-/* {TYPE}.is_attached */
-EIF_BOOLEAN F765_3666 (EIF_REFERENCE Current)
+/* {TYPE}.has_default */
+EIF_BOOLEAN F850_4631 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
 	
-	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached (Current);
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_has_default__b (Current);
+	return Result;
+}
+
+/* {TYPE}.is_attached */
+EIF_BOOLEAN F850_4634 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	
+	
+	
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached__b (Current);
 	return Result;
 }
 
 /* {TYPE}.is_equal */
-EIF_BOOLEAN F765_3667 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F850_4635 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -122,26 +134,26 @@ EIF_BOOLEAN F765_3667 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
+	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
 	RTLE;
 	return Result;
 }
 
 /* {TYPE}.default */
-EIF_NATURAL_16* F765_3674 (EIF_REFERENCE Current)
+EIF_INTEGER_64 F850_4642 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_NATURAL_16* loc1 = (EIF_NATURAL_16*) 0;
+	EIF_INTEGER_64 loc1 = (EIF_INTEGER_64) 0;
 	
 	
 	RTGC;
-	return (EIF_NATURAL_16*) 0;
+	return (EIF_INTEGER_64) 0;
 }
 
 /* {TYPE}.runtime_name */
-EIF_REFERENCE F765_3686 (EIF_REFERENCE Current)
+EIF_REFERENCE F850_4654 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -154,8 +166,8 @@ EIF_REFERENCE F765_3686 (EIF_REFERENCE Current)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("runtime_name", 764, Current, 0, 0, 9436);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
+	RTEAA("runtime_name", 849, Current, 0, 0, 9874);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
 	if (!Result) {RTEC(EN_FAIL);}
 	RTLE;
 	RTEE;
