@@ -1,5 +1,5 @@
 /*
- * Code for class DYNAMIC_LIST [INTEGER_16]
+ * Code for class DYNAMIC_TABLE [G#1, G#2]
  */
 
 #include "eif_eiffel.h"
@@ -22,26 +22,18 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {DYNAMIC_LIST}.wipe_out */
-void F2512_25997 (EIF_REFERENCE Current)
+/* {DYNAMIC_TABLE}.prunable */
+EIF_BOOLEAN F2584_32529 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("wipe_out", 2511, Current, 0, 0, 27616);
-	RTGC;
+	RTEAA("prunable", 2583, Current, 0, 0, 30726);
 	RTHOOK(1);
-	F2476_25912(Current);
 	RTHOOK(2);
-	F2640_26841(Current);
-	RTHOOK(3);
-	RTLE;
 	RTEE;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
 void EIF_Minit6632 (void)
