@@ -6,10 +6,8 @@
 extern "C" {
 #endif
 
-extern void F2512_25997(EIF_REFERENCE);
+extern EIF_BOOLEAN F2584_32529(EIF_REFERENCE);
 extern void EIF_Minit6632(void);
-extern void F2476_25912(EIF_REFERENCE);
-extern void F2640_26841(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
