@@ -1,5 +1,5 @@
 /*
- * Code for class DYNAMIC_LIST [CHARACTER_8]
+ * Code for class DYNAMIC_TABLE [G#1, POINTER]
  */
 
 #include "eif_eiffel.h"
@@ -22,26 +22,18 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {DYNAMIC_LIST}.wipe_out */
-void F2546_26421 (EIF_REFERENCE Current)
+/* {DYNAMIC_TABLE}.prunable */
+EIF_BOOLEAN F2592_32529 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTEAA("wipe_out", 2545, Current, 0, 0, 28078);
-	RTGC;
+	RTEAA("prunable", 2591, Current, 0, 0, 30730);
 	RTHOOK(1);
-	F2510_26335(Current);
 	RTHOOK(2);
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R22648[Dtype(Current)-2183])(Current);
-	RTHOOK(4);
-	RTLE;
 	RTEE;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
 void EIF_Minit6834 (void)
