@@ -6,10 +6,8 @@
 extern "C" {
 #endif
 
-extern void F2546_26421(EIF_REFERENCE);
+extern EIF_BOOLEAN F2592_32529(EIF_REFERENCE);
 extern void EIF_Minit6834(void);
-extern void F2510_26335(EIF_REFERENCE);
-extern char *(*R22648[])();
 
 #ifdef __cplusplus
 }
