@@ -1,5 +1,5 @@
 /*
- * Code for class LINKED_LIST [NATURAL_16]
+ * Code for class LINKED_LIST [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -24,13 +24,13 @@ extern "C" {
 #endif
 
 /* {LINKED_LIST}.make */
-void F2607_29744 (EIF_REFERENCE Current)
+void F2917_33194 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("make", 2606, Current, 0, 0, 28693);
+	RTEAA("make", 2916, Current, 0, 0, 32204);
 	RTHOOK(1);
 	*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 	RTHOOK(3);
@@ -38,12 +38,12 @@ void F2607_29744 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.make_from_iterable */
-void F2607_29745 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F2917_33195 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
-	EIF_NATURAL_16 tu2_1;
+	EIF_NATURAL_64 tu8_1;
 	EIF_BOOLEAN tb1;
 	RTLD;
 	
@@ -53,20 +53,20 @@ void F2607_29745 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,arg1);
 	RTLIU(3);
 	
-	RTEAA("make_from_iterable", 2606, Current, 1, 1, 28694);
+	RTEAA("make_from_iterable", 2916, Current, 1, 1, 32205);
 	RTGC;
 	RTHOOK(1);
-	F2607_29744(Current);
+	F2917_33194(Current);
 	RTHOOK(2);
-	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R25041[Dtype(RTCW(arg1))-2019])(arg1);
+	loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R28240[Dtype(RTCW(arg1))-2289])(arg1);
 	for (;;) {
-		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R24802[Dtype(loc1)-1954])(loc1);
+		tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R27251[Dtype(loc1)-2182])(loc1);
 		if (tb1) break;
 		RTHOOK(3);
-		tu2_1 = (eif_optimize_return = 1, *(EIF_NATURAL_16 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R24801[Dtype(loc1)-1954])(loc1));
-		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R25435[Dtype(Current)-2351])(Current, (EIF_REFERENCE) &tu2_1);
+		tu8_1 = (eif_optimize_return = 1, *(EIF_NATURAL_64 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R27250[Dtype(loc1)-2182])(loc1));
+		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R28644[Dtype(Current)-2660])(Current, (EIF_REFERENCE) &tu8_1);
 		RTHOOK(4);
-		(FUNCTION_CAST(void, (EIF_REFERENCE)) R24803[Dtype(loc1)-1954])(loc1);
+		(FUNCTION_CAST(void, (EIF_REFERENCE)) R27252[Dtype(loc1)-2182])(loc1);
 	}
 	RTHOOK(5);
 	RTLE;
@@ -74,13 +74,13 @@ void F2607_29745 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {LINKED_LIST}.item */
-EIF_NATURAL_16 F2607_29746 (EIF_REFERENCE Current)
+EIF_NATURAL_64 F2917_33196 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_NATURAL_16 Result = ((EIF_NATURAL_16) 0);
+	EIF_NATURAL_64 Result = ((EIF_NATURAL_64) 0);
 	
 	RTCFDT;
 	RTLD;
@@ -91,7 +91,7 @@ EIF_NATURAL_16 F2607_29746 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("item", 2606, Current, 1, 0, 28695);
+	RTEAA("item", 2916, Current, 1, 0, 32206);
 	RTGC;
 	RTHOOK(1);
 	RTCT0("attached active as a", EX_CHECK);
@@ -103,7 +103,7 @@ EIF_NATURAL_16 F2607_29746 (EIF_REFERENCE Current)
 		RTCF0;
 	}
 	RTHOOK(2);
-	Result = *(EIF_NATURAL_16 *)(loc1+ _I16OFF_1_0_0_);
+	Result = *(EIF_NATURAL_64 *)(loc1+ _I64OFF_1_0_0_0_0_0_0_);
 	RTHOOK(3);
 	RTLE;
 	RTEE;
@@ -111,13 +111,13 @@ EIF_NATURAL_16 F2607_29746 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.first */
-EIF_NATURAL_16 F2607_29747 (EIF_REFERENCE Current)
+EIF_NATURAL_64 F2917_33197 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_NATURAL_16 Result = ((EIF_NATURAL_16) 0);
+	EIF_NATURAL_64 Result = ((EIF_NATURAL_64) 0);
 	
 	RTCFDT;
 	RTLD;
@@ -128,7 +128,7 @@ EIF_NATURAL_16 F2607_29747 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("first", 2606, Current, 1, 0, 28696);
+	RTEAA("first", 2916, Current, 1, 0, 32207);
 	RTGC;
 	RTHOOK(1);
 	RTCT0("attached first_element as f", EX_CHECK);
@@ -140,7 +140,7 @@ EIF_NATURAL_16 F2607_29747 (EIF_REFERENCE Current)
 		RTCF0;
 	}
 	RTHOOK(2);
-	Result = *(EIF_NATURAL_16 *)(loc1+ _I16OFF_1_0_0_);
+	Result = *(EIF_NATURAL_64 *)(loc1+ _I64OFF_1_0_0_0_0_0_0_);
 	RTHOOK(3);
 	RTLE;
 	RTEE;
@@ -148,13 +148,13 @@ EIF_NATURAL_16 F2607_29747 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.last */
-EIF_NATURAL_16 F2607_29748 (EIF_REFERENCE Current)
+EIF_NATURAL_64 F2917_33198 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_NATURAL_16 Result = ((EIF_NATURAL_16) 0);
+	EIF_NATURAL_64 Result = ((EIF_NATURAL_64) 0);
 	
 	RTCFDT;
 	RTLD;
@@ -165,11 +165,11 @@ EIF_NATURAL_16 F2607_29748 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("last", 2606, Current, 1, 0, 28697);
+	RTEAA("last", 2916, Current, 1, 0, 32208);
 	RTGC;
 	RTHOOK(1);
 	RTCT0("attached last_element as l", EX_CHECK);
-	tr1 = F2607_29787(Current);
+	tr1 = F2917_33237(Current);
 	loc1 = tr1;
 	if (EIF_TEST(loc1)) {
 		RTCK0;
@@ -177,7 +177,7 @@ EIF_NATURAL_16 F2607_29748 (EIF_REFERENCE Current)
 		RTCF0;
 	}
 	RTHOOK(2);
-	Result = *(EIF_NATURAL_16 *)(loc1+ _I16OFF_1_0_0_);
+	Result = *(EIF_NATURAL_64 *)(loc1+ _I64OFF_1_0_0_0_0_0_0_);
 	RTHOOK(3);
 	RTLE;
 	RTEE;
@@ -185,7 +185,7 @@ EIF_NATURAL_16 F2607_29748 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.index */
-EIF_INTEGER_32 F2607_29749 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F2917_33199 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -203,7 +203,7 @@ EIF_INTEGER_32 F2607_29749 (EIF_REFERENCE Current)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("index", 2606, Current, 2, 0, 28651);
+	RTEAA("index", 2916, Current, 2, 0, 32209);
 	RTGC;
 	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
@@ -239,7 +239,7 @@ EIF_INTEGER_32 F2607_29749 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.cursor */
-EIF_REFERENCE F2607_29750 (EIF_REFERENCE Current)
+EIF_REFERENCE F2917_33200 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -251,23 +251,23 @@ EIF_REFERENCE F2607_29750 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("cursor", 2606, Current, 0, 0, 28652);
+	RTEAA("cursor", 2916, Current, 0, 0, 32210);
 	RTGC;
 	RTHOOK(1);
 	{
-		EIF_TYPE_INDEX typarr0[] = {1719,0,0,0xFFFF};
+		EIF_TYPE_INDEX typarr0[] = {1894,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y25042,Y25042_gen_type,Dftype(Current),2004);
+			l_type = eif_final_id(Y28241,Y28241_gen_type,Dftype(Current),2274);
 			typarr0[1] = l_type.annotations | 0xFF00;
 			typarr0[2] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 1719, _OBJSIZ_1_2_0_0_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 1894, _OBJSIZ_1_2_0_0_0_0_0_0_);
 	}
-	F1720_24396(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_1_), *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_), *(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_));
+	F1895_26616(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_1_), *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_), *(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_));
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -275,7 +275,7 @@ EIF_REFERENCE F2607_29750 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.new_cursor */
-EIF_REFERENCE F2607_29751 (EIF_REFERENCE Current)
+EIF_REFERENCE F2917_33201 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -288,25 +288,25 @@ EIF_REFERENCE F2607_29751 (EIF_REFERENCE Current)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("new_cursor", 2606, Current, 0, 0, 28653);
+	RTEAA("new_cursor", 2916, Current, 0, 0, 32211);
 	RTGC;
 	RTHOOK(1);
 	{
-		EIF_TYPE_INDEX typarr0[] = {2095,0,0,0xFFFF};
+		EIF_TYPE_INDEX typarr0[] = {2365,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y25042,Y25042_gen_type,Dftype(Current),2004);
+			l_type = eif_final_id(Y28241,Y28241_gen_type,Dftype(Current),2274);
 			typarr0[1] = l_type.annotations | 0xFF00;
 			typarr0[2] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		Result = RTLNS(typres0.id, 2095, _OBJSIZ_2_1_0_5_0_0_0_0_);
+		Result = RTLNS(typres0.id, 2365, _OBJSIZ_2_1_0_5_0_0_0_0_);
 	}
-	F2059_28444(RTCW(Result), Current);
+	F2330_31914(RTCW(Result), Current);
 	RTHOOK(2);
-	F2096_28474(RTCW(Result));
+	F2366_31944(RTCW(Result));
 	RTHOOK(3);
 	RTLE;
 	RTEE;
@@ -314,34 +314,34 @@ EIF_REFERENCE F2607_29751 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.count */
-EIF_INTEGER_32 F2607_29753 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F2917_33203 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_3_0_0_);
 }
 
 
 /* {LINKED_LIST}.after */
-EIF_BOOLEAN F2607_29755 (EIF_REFERENCE Current)
+EIF_BOOLEAN F2917_33205 (EIF_REFERENCE Current)
 {
 	return *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_);
 }
 
 
 /* {LINKED_LIST}.before */
-EIF_BOOLEAN F2607_29756 (EIF_REFERENCE Current)
+EIF_BOOLEAN F2917_33206 (EIF_REFERENCE Current)
 {
 	return *(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_);
 }
 
 
 /* {LINKED_LIST}.off */
-EIF_BOOLEAN F2607_29757 (EIF_REFERENCE Current)
+EIF_BOOLEAN F2917_33207 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("off", 2606, Current, 0, 0, 28659);
+	RTEAA("off", 2916, Current, 0, 0, 32217);
 	RTHOOK(1);
 	RTHOOK(2);
 	RTEE;
@@ -349,29 +349,21 @@ EIF_BOOLEAN F2607_29757 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.isfirst */
-EIF_BOOLEAN F2607_29758 (EIF_REFERENCE Current)
+EIF_BOOLEAN F2917_33208 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE tr2 = NULL;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
-	
-	RTEAA("isfirst", 2606, Current, 0, 0, 28660);
+	RTEAA("isfirst", 2916, Current, 0, 0, 32218);
 	RTHOOK(1);
-	Result = *(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_);
-	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	tr2 = *(EIF_REFERENCE *)(Current);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) !Result && (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) && (EIF_BOOLEAN)(tr1 == tr2));
 	RTHOOK(2);
 	RTEE;
-	return Result;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) && (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) && (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) == *(EIF_REFERENCE *)(Current)));
 }
 
 /* {LINKED_LIST}.islast */
-EIF_BOOLEAN F2607_29759 (EIF_REFERENCE Current)
+EIF_BOOLEAN F2917_33209 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -387,7 +379,7 @@ EIF_BOOLEAN F2607_29759 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("islast", 2606, Current, 1, 0, 28661);
+	RTEAA("islast", 2916, Current, 1, 0, 32219);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) && (EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_))) {
@@ -407,7 +399,7 @@ EIF_BOOLEAN F2607_29759 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.valid_cursor */
-EIF_BOOLEAN F2607_29760 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F2917_33210 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -430,11 +422,11 @@ EIF_BOOLEAN F2607_29760 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(5,tr1);
 	RTLIU(6);
 	
-	RTEAA("valid_cursor", 2606, Current, 3, 1, 28662);
+	RTEAA("valid_cursor", 2916, Current, 3, 1, 32220);
 	RTGC;
 	RTHOOK(1);
 	loc3 = arg1;
-	loc3 = RTRV(eif_final_id(Y25453,Y25453_gen_type,dftype,2325),loc3);
+	loc3 = RTRV(eif_final_id(Y28663,Y28663_gen_type,dftype,2634),loc3);
 	if (EIF_TEST(loc3)) {
 		RTHOOK(2);
 		loc1 = *(EIF_REFERENCE *)(Current);
@@ -464,7 +456,7 @@ EIF_BOOLEAN F2607_29760 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {LINKED_LIST}.start */
-void F2607_29763 (EIF_REFERENCE Current)
+void F2917_33213 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -476,7 +468,7 @@ void F2607_29763 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("start", 2606, Current, 0, 0, 28665);
+	RTEAA("start", 2916, Current, 0, 0, 32223);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current) != NULL)) {
@@ -498,7 +490,7 @@ void F2607_29763 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.finish */
-void F2607_29764 (EIF_REFERENCE Current)
+void F2917_33214 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -512,7 +504,7 @@ void F2607_29764 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("finish", 2606, Current, 1, 0, 28666);
+	RTEAA("finish", 2916, Current, 1, 0, 32224);
 	RTGC;
 	RTHOOK(1);
 	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
@@ -536,7 +528,7 @@ void F2607_29764 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.forth */
-void F2607_29765 (EIF_REFERENCE Current)
+void F2917_33215 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -551,14 +543,14 @@ void F2607_29765 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("forth", 2606, Current, 1, 0, 28667);
+	RTEAA("forth", 2916, Current, 1, 0, 32225);
 	RTGC;
 	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) {
 		RTHOOK(2);
 		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 		RTHOOK(3);
-		if (F2384_29294(Current)) {
+		if (F2693_32768(Current)) {
 			RTHOOK(4);
 			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 		}
@@ -587,7 +579,7 @@ void F2607_29765 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.back */
-void F2607_29766 (EIF_REFERENCE Current)
+void F2917_33216 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -599,10 +591,10 @@ void F2607_29766 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("back", 2606, Current, 0, 0, 28668);
+	RTEAA("back", 2916, Current, 0, 0, 32226);
 	RTGC;
 	RTHOOK(1);
-	if (F2384_29294(Current)) {
+	if (F2693_32768(Current)) {
 		RTHOOK(2);
 		*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 		RTHOOK(3);
@@ -614,12 +606,12 @@ void F2607_29766 (EIF_REFERENCE Current)
 			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 		} else {
 			RTHOOK(6);
-			if (F2607_29758(Current)) {
+			if (F2917_33208(Current)) {
 				RTHOOK(7);
 				*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 			} else {
 				RTHOOK(8);
-				tr1 = F2607_29784(Current);
+				tr1 = F2917_33234(Current);
 				RTAR(Current, tr1);
 				*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 			}
@@ -631,7 +623,7 @@ void F2607_29766 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.move */
-void F2607_29767 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F2917_33217 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -647,7 +639,7 @@ void F2607_29767 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("move", 2606, Current, 3, 1, 28669);
+	RTEAA("move", 2916, Current, 3, 1, 32227);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN) (arg1 > ((EIF_INTEGER_32) 0L))) {
@@ -685,7 +677,7 @@ void F2607_29767 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 		RTHOOK(13);
 		if ((EIF_BOOLEAN) (arg1 < ((EIF_INTEGER_32) 0L))) {
 			RTHOOK(14);
-			loc2 = F2607_29749(Current);
+			loc2 = F2917_33199(Current);
 			loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + arg1);
 			RTHOOK(15);
 			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
@@ -698,7 +690,7 @@ void F2607_29767 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTHOOK(18);
 			if ((EIF_BOOLEAN) (loc2 > ((EIF_INTEGER_32) 0L))) {
 				RTHOOK(19);
-				F2607_29767(Current, loc2);
+				F2917_33217(Current, loc2);
 			}
 		}
 	}
@@ -708,7 +700,7 @@ void F2607_29767 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {LINKED_LIST}.go_i_th */
-void F2607_29768 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F2917_33218 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -721,7 +713,7 @@ void F2607_29768 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("go_i_th", 2606, Current, 0, 1, 28670);
+	RTEAA("go_i_th", 2916, Current, 0, 1, 32228);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 == ((EIF_INTEGER_32) 0L))) {
@@ -741,13 +733,13 @@ void F2607_29768 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 			RTHOOK(7);
 			*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 			RTHOOK(8);
-			tr1 = F2607_29787(Current);
+			tr1 = F2917_33237(Current);
 			RTAR(Current, tr1);
 			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 		} else {
 			RTHOOK(9);
-			ti4_1 = F2607_29749(Current);
-			F2607_29767(Current, (EIF_INTEGER_32) (arg1 - ti4_1));
+			ti4_1 = F2917_33199(Current);
+			F2917_33217(Current, (EIF_INTEGER_32) (arg1 - ti4_1));
 		}
 	}
 	RTHOOK(10);
@@ -756,7 +748,7 @@ void F2607_29768 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {LINKED_LIST}.go_to */
-void F2607_29769 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F2917_33219 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -773,11 +765,11 @@ void F2607_29769 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("go_to", 2606, Current, 1, 1, 28671);
+	RTEAA("go_to", 2916, Current, 1, 1, 32229);
 	RTGC;
 	RTHOOK(1);
 	loc1 = arg1;
-	loc1 = RTRV(eif_final_id(Y25453,Y25453_gen_type,dftype,2325),loc1);
+	loc1 = RTRV(eif_final_id(Y28663,Y28663_gen_type,dftype,2634),loc1);
 	if (EIF_TEST(loc1)) {
 		RTHOOK(2);
 		tb1 = *(EIF_BOOLEAN *)(loc1+ _CHROFF_1_0_);
@@ -795,7 +787,7 @@ void F2607_29769 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 			RTHOOK(6);
 			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
 				RTHOOK(7);
-				tr1 = F2607_29787(Current);
+				tr1 = F2917_33237(Current);
 				RTAR(Current, tr1);
 				*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 			} else {
@@ -814,7 +806,7 @@ void F2607_29769 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {LINKED_LIST}.put_front */
-void F2607_29770 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+void F2917_33220 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 {
 	GTCX
 	RTEX;
@@ -827,19 +819,19 @@ void F2607_29770 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("put_front", 2606, Current, 1, 1, 28672);
+	RTEAA("put_front", 2916, Current, 1, 1, 32230);
 	RTGC;
 	RTHOOK(1);
-	loc1 = F2607_29783(Current, arg1);
+	loc1 = F2917_33233(Current, arg1);
 	RTHOOK(2);
-	F1484_21299(RTCW(loc1), *(EIF_REFERENCE *)(Current));
+	F1711_24143(RTCW(loc1), *(EIF_REFERENCE *)(Current));
 	RTHOOK(3);
 	RTAR(Current, loc1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
 	RTHOOK(4);
 	tb1 = '\01';
 	if (!*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) {
-		tb1 = F2384_29294(Current);
+		tb1 = F2693_32768(Current);
 	}
 	if (tb1) {
 		RTHOOK(5);
@@ -854,7 +846,7 @@ void F2607_29770 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 }
 
 /* {LINKED_LIST}.extend */
-void F2607_29771 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+void F2917_33221 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 {
 	GTCX
 	RTEX;
@@ -868,12 +860,12 @@ void F2607_29771 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLR(2,loc2);
 	RTLIU(3);
 	
-	RTEAA("extend", 2606, Current, 2, 1, 28673);
+	RTEAA("extend", 2916, Current, 2, 1, 32231);
 	RTGC;
 	RTHOOK(1);
-	loc1 = F2607_29783(Current, arg1);
+	loc1 = F2917_33233(Current, arg1);
 	RTHOOK(2);
-	if (F2384_29294(Current)) {
+	if (F2693_32768(Current)) {
 		RTHOOK(3);
 		RTAR(Current, loc1);
 		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
@@ -882,11 +874,11 @@ void F2607_29771 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
 	} else {
 		RTHOOK(5);
-		loc2 = F2607_29787(Current);
+		loc2 = F2917_33237(Current);
 		RTHOOK(6);
 		if ((EIF_BOOLEAN)(loc2 != NULL)) {
 			RTHOOK(7);
-			F1484_21299(RTCW(loc2), loc1);
+			F1711_24143(RTCW(loc2), loc1);
 			RTHOOK(8);
 			if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
 				RTHOOK(9);
@@ -903,7 +895,7 @@ void F2607_29771 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 }
 
 /* {LINKED_LIST}.put_left */
-void F2607_29772 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+void F2917_33222 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 {
 	GTCX
 	RTEX;
@@ -911,7 +903,7 @@ void F2607_29772 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_NATURAL_16 tu2_1;
+	EIF_NATURAL_64 tu8_1;
 	RTLD;
 	
 	RTLI(4);
@@ -921,34 +913,34 @@ void F2607_29772 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("put_left", 2606, Current, 3, 1, 28674);
+	RTEAA("put_left", 2916, Current, 3, 1, 32232);
 	RTGC;
 	RTHOOK(1);
 	loc2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
 	RTHOOK(2);
 	if ((EIF_BOOLEAN)(loc2 == NULL)) {
 		RTHOOK(3);
-		F2607_29770(Current, arg1);
+		F2917_33220(Current, arg1);
 	} else {
 		RTHOOK(4);
 		if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
 			RTHOOK(5);
-			F2607_29766(Current);
+			F2917_33216(Current);
 			RTHOOK(6);
-			F2607_29773(Current, arg1);
+			F2917_33223(Current, arg1);
 			RTHOOK(7);
-			F2607_29767(Current, ((EIF_INTEGER_32) 2L));
+			F2917_33217(Current, ((EIF_INTEGER_32) 2L));
 		} else {
 			RTHOOK(8);
-			tu2_1 = *(EIF_NATURAL_16 *)(RTCW(loc2)+ _I16OFF_1_0_0_);
-			loc1 = F2607_29783(Current, tu2_1);
+			tu8_1 = *(EIF_NATURAL_64 *)(RTCW(loc2)+ _I64OFF_1_0_0_0_0_0_0_);
+			loc1 = F2917_33233(Current, tu8_1);
 			RTHOOK(9);
 			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
-			F1484_21299(RTCW(loc1), tr1);
+			F1711_24143(RTCW(loc1), tr1);
 			RTHOOK(10);
-			F1469_21292(RTCW(loc2), arg1);
+			F1694_24136(RTCW(loc2), arg1);
 			RTHOOK(11);
-			F1484_21299(RTCW(loc2), loc1);
+			F1711_24143(RTCW(loc2), loc1);
 			RTHOOK(12);
 			RTAR(Current, loc1);
 			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
@@ -962,7 +954,7 @@ void F2607_29772 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 }
 
 /* {LINKED_LIST}.put_right */
-void F2607_29773 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+void F2917_33223 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 {
 	GTCX
 	RTEX;
@@ -980,15 +972,15 @@ void F2607_29773 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("put_right", 2606, Current, 4, 1, 28675);
+	RTEAA("put_right", 2916, Current, 4, 1, 32233);
 	RTGC;
 	RTHOOK(1);
-	loc1 = F2607_29783(Current, arg1);
+	loc1 = F2917_33233(Current, arg1);
 	
 	RTHOOK(3);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) {
 		RTHOOK(4);
-		F1484_21299(RTCW(loc1), *(EIF_REFERENCE *)(Current));
+		F1711_24143(RTCW(loc1), *(EIF_REFERENCE *)(Current));
 		RTHOOK(5);
 		RTAR(Current, loc1);
 		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc1;
@@ -1002,9 +994,9 @@ void F2607_29773 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 		if ((EIF_BOOLEAN)(loc2 != NULL)) {
 			RTHOOK(9);
 			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
-			F1484_21299(RTCW(loc1), tr1);
+			F1711_24143(RTCW(loc1), tr1);
 			RTHOOK(10);
-			F1484_21299(RTCW(loc2), loc1);
+			F1711_24143(RTCW(loc2), loc1);
 		}
 	}
 	RTHOOK(11);
@@ -1015,7 +1007,7 @@ void F2607_29773 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 }
 
 /* {LINKED_LIST}.replace */
-void F2607_29774 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+void F2917_33224 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 {
 	GTCX
 	RTEX;
@@ -1027,14 +1019,14 @@ void F2607_29774 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("replace", 2606, Current, 1, 1, 28676);
+	RTEAA("replace", 2916, Current, 1, 1, 32234);
 	RTGC;
 	RTHOOK(1);
 	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
 	RTHOOK(2);
 	if ((EIF_BOOLEAN)(loc1 != NULL)) {
 		RTHOOK(3);
-		F1469_21292(RTCW(loc1), arg1);
+		F1694_24136(RTCW(loc1), arg1);
 	}
 	RTHOOK(4);
 	RTLE;
@@ -1042,7 +1034,7 @@ void F2607_29774 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 }
 
 /* {LINKED_LIST}.merge_right */
-void F2607_29776 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F2917_33226 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -1063,10 +1055,10 @@ void F2607_29776 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(5,loc3);
 	RTLIU(6);
 	
-	RTEAA("merge_right", 2606, Current, 4, 1, 28678);
+	RTEAA("merge_right", 2916, Current, 4, 1, 32236);
 	RTGC;
 	RTHOOK(1);
-	tr1 = F2607_29787(RTCW(arg1));
+	tr1 = F2917_33237(RTCW(arg1));
 	loc4 = tr1;
 	if (EIF_TEST(loc4)) {
 		RTHOOK(2);
@@ -1074,7 +1066,7 @@ void F2607_29776 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 		RTHOOK(3);
 		loc2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_2_3_0_0_);
 		RTHOOK(4);
-		F2607_29780(RTCW(arg1));
+		F2917_33230(RTCW(arg1));
 		
 		RTHOOK(6);
 		loc3 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
@@ -1089,13 +1081,13 @@ void F2607_29776 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 		} else {
 			RTHOOK(10);
-			if ((EIF_BOOLEAN) !F2607_29759(Current)) {
+			if ((EIF_BOOLEAN) !F2917_33209(Current)) {
 				RTHOOK(11);
 				tr1 = *(EIF_REFERENCE *)(RTCW(loc3));
-				F1484_21299(loc4, tr1);
+				F1711_24143(loc4, tr1);
 			}
 			RTHOOK(12);
-			F1484_21299(RTCW(loc3), loc1);
+			F1711_24143(RTCW(loc3), loc1);
 		}
 		RTHOOK(13);
 		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_3_0_0_)) += loc2;
@@ -1106,7 +1098,7 @@ void F2607_29776 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {LINKED_LIST}.remove */
-void F2607_29777 (EIF_REFERENCE Current)
+void F2917_33227 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -1126,20 +1118,20 @@ void F2607_29777 (EIF_REFERENCE Current)
 	RTLR(5,loc4);
 	RTLIU(6);
 	
-	RTEAA("remove", 2606, Current, 4, 0, 28679);
+	RTEAA("remove", 2916, Current, 4, 0, 32237);
 	RTGC;
 	RTHOOK(1);
 	loc2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
 	RTHOOK(2);
 	if ((EIF_BOOLEAN)(loc2 != NULL)) {
 		RTHOOK(3);
-		if (F2607_29758(Current)) {
+		if (F2917_33208(Current)) {
 			RTHOOK(4);
 			tr1 = *(EIF_REFERENCE *)(RTCW(loc2));
 			RTAR(Current, tr1);
 			*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 			RTHOOK(5);
-			F1484_21300(RTCW(loc2));
+			F1711_24144(RTCW(loc2));
 			RTHOOK(6);
 			tr1 = *(EIF_REFERENCE *)(Current);
 			RTAR(Current, tr1);
@@ -1152,9 +1144,9 @@ void F2607_29777 (EIF_REFERENCE Current)
 			}
 		} else {
 			RTHOOK(10);
-			if (F2607_29759(Current)) {
+			if (F2917_33209(Current)) {
 				RTHOOK(11);
-				tr1 = F2607_29784(Current);
+				tr1 = F2917_33234(Current);
 				RTAR(Current, tr1);
 				*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 				RTHOOK(12);
@@ -1162,7 +1154,7 @@ void F2607_29777 (EIF_REFERENCE Current)
 				RTHOOK(13);
 				if ((EIF_BOOLEAN)(loc3 != NULL)) {
 					RTHOOK(14);
-					F1484_21300(RTCW(loc3));
+					F1711_24144(RTCW(loc3));
 				}
 				RTHOOK(15);
 				*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
@@ -1170,14 +1162,14 @@ void F2607_29777 (EIF_REFERENCE Current)
 				RTHOOK(16);
 				loc1 = *(EIF_REFERENCE *)(RTCW(loc2));
 				RTHOOK(17);
-				loc4 = F2607_29784(Current);
+				loc4 = F2917_33234(Current);
 				RTHOOK(18);
 				if ((EIF_BOOLEAN)(loc4 != NULL)) {
 					RTHOOK(19);
-					F1484_21299(RTCW(loc4), loc1);
+					F1711_24143(RTCW(loc4), loc1);
 				}
 				RTHOOK(20);
-				F1484_21300(RTCW(loc2));
+				F1711_24144(RTCW(loc2));
 				RTHOOK(21);
 				RTAR(Current, loc1);
 				*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) loc1;
@@ -1198,7 +1190,7 @@ void F2607_29777 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.remove_left */
-void F2607_29778 (EIF_REFERENCE Current)
+void F2917_33228 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -1208,21 +1200,21 @@ void F2607_29778 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("remove_left", 2606, Current, 0, 0, 28680);
+	RTEAA("remove_left", 2916, Current, 0, 0, 32191);
 	RTGC;
 	RTHOOK(1);
-	F2607_29767(Current, ((EIF_INTEGER_32) -2L));
+	F2917_33217(Current, ((EIF_INTEGER_32) -2L));
 	RTHOOK(2);
-	F2607_29779(Current);
+	F2917_33229(Current);
 	RTHOOK(3);
-	F2607_29765(Current);
+	F2917_33215(Current);
 	RTHOOK(4);
 	RTLE;
 	RTEE;
 }
 
 /* {LINKED_LIST}.remove_right */
-void F2607_29779 (EIF_REFERENCE Current)
+void F2917_33229 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -1242,7 +1234,7 @@ void F2607_29779 (EIF_REFERENCE Current)
 	RTLR(5,loc4);
 	RTLIU(6);
 	
-	RTEAA("remove_right", 2606, Current, 4, 0, 28681);
+	RTEAA("remove_right", 2916, Current, 4, 0, 32192);
 	RTGC;
 	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_)) {
@@ -1261,7 +1253,7 @@ void F2607_29779 (EIF_REFERENCE Current)
 			RTHOOK(7);
 			if ((EIF_BOOLEAN)(loc3 != NULL)) {
 				RTHOOK(8);
-				F1484_21300(RTCW(loc3));
+				F1711_24144(RTCW(loc3));
 			}
 			RTHOOK(9);
 			tr1 = *(EIF_REFERENCE *)(Current);
@@ -1281,9 +1273,9 @@ void F2607_29779 (EIF_REFERENCE Current)
 				loc1 = (EIF_REFERENCE) loc4;
 				RTHOOK(15);
 				tr1 = *(EIF_REFERENCE *)(RTCW(loc4));
-				F1484_21299(RTCW(loc3), tr1);
+				F1711_24143(RTCW(loc3), tr1);
 				RTHOOK(16);
-				F1484_21300(RTCW(loc4));
+				F1711_24144(RTCW(loc4));
 			}
 		}
 	}
@@ -1301,26 +1293,26 @@ void F2607_29779 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.wipe_out */
-void F2607_29780 (EIF_REFERENCE Current)
+void F2917_33230 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("wipe_out", 2606, Current, 0, 0, 28682);
+	RTEAA("wipe_out", 2916, Current, 0, 0, 32193);
 	RTHOOK(1);
-	F2607_29789(Current);
+	F2917_33239(Current);
 	RTHOOK(2);
 	RTEE;
 }
 
 /* {LINKED_LIST}.copy */
-void F2607_29781 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F2917_33231 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
-	EIF_NATURAL_16 tu2_1;
+	EIF_NATURAL_64 tu8_1;
 	EIF_BOOLEAN tb1;
 	RTLD;
 	
@@ -1330,37 +1322,37 @@ void F2607_29781 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,loc1);
 	RTLIU(3);
 	
-	RTEAA("copy", 2606, Current, 1, 1, 28683);
+	RTEAA("copy", 2916, Current, 1, 1, 32194);
 	RTGC;
 	RTHOOK(1);
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
 		RTHOOK(2);
-		eif_builtin_ANY_standard_copy (Current, arg1);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		RTHOOK(3);
-		tb1 = F2384_29294(RTCW(arg1));
+		tb1 = F2693_32768(RTCW(arg1));
 		if ((EIF_BOOLEAN) !tb1) {
 			RTHOOK(4);
-			F2607_29789(Current);
+			F2917_33239(Current);
 			RTHOOK(5);
-			loc1 = F2607_29750(RTCW(arg1));
+			loc1 = F2917_33200(RTCW(arg1));
 			RTHOOK(6);
-			F2607_29763(RTCW(arg1));
+			F2917_33213(RTCW(arg1));
 			for (;;) {
 				RTHOOK(7);
-				tb1 = F2607_29757(RTCW(arg1));
+				tb1 = F2917_33207(RTCW(arg1));
 				if (tb1) break;
 				RTHOOK(8);
-				tu2_1 = (eif_optimize_return = 1, *(EIF_NATURAL_16 *)(FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R25447[Dtype(RTCW(arg1))-2374])(arg1));
-				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R25435[Dtype(Current)-2351])(Current, (EIF_REFERENCE) &tu2_1);
+				tu8_1 = F2917_33196(RTCW(arg1));
+				(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R28644[Dtype(Current)-2660])(Current, (EIF_REFERENCE) &tu8_1);
 				RTHOOK(9);
-				F2607_29764(Current);
+				F2917_33214(Current);
 				RTHOOK(10);
-				F2607_29765(RTCW(arg1));
+				F2917_33215(RTCW(arg1));
 			}
 			RTHOOK(11);
 			if ((EIF_BOOLEAN)(loc1 != NULL)) {
 				RTHOOK(12);
-				F2607_29769(RTCW(arg1), loc1);
+				F2917_33219(RTCW(arg1), loc1);
 			}
 		}
 	}
@@ -1370,7 +1362,7 @@ void F2607_29781 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {LINKED_LIST}.new_cell */
-EIF_REFERENCE F2607_29783 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
+EIF_REFERENCE F2917_33233 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 {
 	GTCX
 	RTEX;
@@ -1382,23 +1374,23 @@ EIF_REFERENCE F2607_29783 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("new_cell", 2606, Current, 0, 1, 28685);
+	RTEAA("new_cell", 2916, Current, 0, 1, 32196);
 	RTGC;
 	RTHOOK(1);
 	{
-		EIF_TYPE_INDEX typarr0[] = {1483,0,0,0xFFFF};
+		EIF_TYPE_INDEX typarr0[] = {1710,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y25447,Y25447_gen_type,Dftype(Current),2310);
+			l_type = eif_final_id(Y28657,Y28657_gen_type,Dftype(Current),2619);
 			typarr0[1] = l_type.annotations | 0xFF00;
 			typarr0[2] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 1483, _OBJSIZ_1_0_1_0_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 1710, _OBJSIZ_1_0_0_0_0_0_1_0_);
 	}
-	F1469_21292(RTCW(tr1), arg1);
+	F1694_24136(RTCW(tr1), arg1);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -1406,7 +1398,7 @@ EIF_REFERENCE F2607_29783 (EIF_REFERENCE Current, EIF_NATURAL_16 arg1)
 }
 
 /* {LINKED_LIST}.previous */
-EIF_REFERENCE F2607_29784 (EIF_REFERENCE Current)
+EIF_REFERENCE F2917_33234 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -1421,7 +1413,7 @@ EIF_REFERENCE F2607_29784 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("previous", 2606, Current, 1, 0, 28686);
+	RTEAA("previous", 2916, Current, 1, 0, 32197);
 	RTGC;
 	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_2_)) {
@@ -1433,7 +1425,7 @@ EIF_REFERENCE F2607_29784 (EIF_REFERENCE Current)
 	} else {
 		RTHOOK(4);
 		tb1 = '\01';
-		if (!F2607_29758(Current)) {
+		if (!F2917_33208(Current)) {
 			tb1 = *(EIF_BOOLEAN *)(Current+ _CHROFF_2_1_);
 		}
 		if ((EIF_BOOLEAN) !tb1) {
@@ -1465,7 +1457,7 @@ EIF_REFERENCE F2607_29784 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.last_element */
-EIF_REFERENCE F2607_29787 (EIF_REFERENCE Current)
+EIF_REFERENCE F2917_33237 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -1482,7 +1474,7 @@ EIF_REFERENCE F2607_29787 (EIF_REFERENCE Current)
 	RTLR(3,tr1);
 	RTLIU(4);
 	
-	RTEAA("last_element", 2606, Current, 1, 0, 28689);
+	RTEAA("last_element", 2916, Current, 1, 0, 32200);
 	RTGC;
 	RTHOOK(1);
 	loc1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
@@ -1502,7 +1494,7 @@ EIF_REFERENCE F2607_29787 (EIF_REFERENCE Current)
 }
 
 /* {LINKED_LIST}.cleanup_after_remove */
-void F2607_29788 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F2917_33238 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -1512,7 +1504,7 @@ void F2607_29788 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("cleanup_after_remove", 2606, Current, 0, 1, 28690);
+	RTEAA("cleanup_after_remove", 2916, Current, 0, 1, 32201);
 	RTGC;
 	RTHOOK(1);
 	RTLE;
@@ -1520,7 +1512,7 @@ void F2607_29788 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {LINKED_LIST}.internal_wipe_out */
-void F2607_29789 (EIF_REFERENCE Current)
+void F2917_33239 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -1530,7 +1522,7 @@ void F2607_29789 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("internal_wipe_out", 2606, Current, 0, 0, 28691);
+	RTEAA("internal_wipe_out", 2916, Current, 0, 0, 32202);
 	RTGC;
 	RTHOOK(1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) NULL;
