@@ -1,5 +1,5 @@
 /*
- * Code for class CONTAINER [CHARACTER_32]
+ * Code for class CONTAINER [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -23,12 +23,21 @@ extern "C" {
 #endif
 
 /* {CONTAINER}.compare_objects */
-void F377_2295 (EIF_REFERENCE Current)
+void F302_4511 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	*(EIF_BOOLEAN *)(Current + O2067[Dtype(Current)-367]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+	*(EIF_BOOLEAN *)(Current + O4328[Dtype(Current)-301]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+}
+
+/* {CONTAINER}.compare_references */
+void F302_4512 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	*(EIF_BOOLEAN *)(Current + O4328[Dtype(Current)-301]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 }
 
 void EIF_Minit678 (void)
