@@ -1,5 +1,5 @@
 /*
- * Code for class CONTAINER [G#1]
+ * Code for class CONTAINER [NATURAL_16]
  */
 
 #include "eif_eiffel.h"
@@ -23,21 +23,12 @@ extern "C" {
 #endif
 
 /* {CONTAINER}.compare_objects */
-void F279_4136 (EIF_REFERENCE Current)
+void F417_2672 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	*(EIF_BOOLEAN *)(Current + O3936[Dtype(Current)-278]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-}
-
-/* {CONTAINER}.compare_references */
-void F279_4137 (EIF_REFERENCE Current)
-{
-	GTCX
-	
-	
-	*(EIF_BOOLEAN *)(Current + O3936[Dtype(Current)-278]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
+	*(EIF_BOOLEAN *)(Current + O2402[Dtype(Current)-409]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
 void EIF_Minit679 (void)
