@@ -6,7 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F1370_16112(EIF_REFERENCE);
+extern void F744_11649(EIF_REFERENCE);
+extern void F744_11650(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit681(void);
 
 #ifdef __cplusplus
