@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F952_6028(EIF_REFERENCE);
-extern EIF_REFERENCE F952_6029(EIF_REFERENCE);
+extern EIF_BOOLEAN F1195_8501(EIF_REFERENCE);
 extern void EIF_Minit658(void);
-extern long O4542[];
-extern long O4574[];
+extern char *(*R6552[])();
 
 #ifdef __cplusplus
 }
