@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F954_6030(EIF_REFERENCE);
-extern EIF_REFERENCE F954_6031(EIF_REFERENCE);
+extern EIF_BOOLEAN F1214_8549(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1214_8553(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit660(void);
-extern long O4542[];
-extern long O4574[];
 
 #ifdef __cplusplus
 }
