@@ -6,10 +6,9 @@
 extern "C" {
 #endif
 
-extern void F1045_6715(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
+extern void F895_5949(EIF_REFERENCE);
 extern void EIF_Minit678(void);
-extern char *(*R5060[])();
-extern char *(*R5067[])();
+extern void F942_6438(EIF_REFERENCE, EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
