@@ -1,5 +1,5 @@
 /*
- * Code for class DS_SORTABLE [CHARACTER_8]
+ * Code for class DS_HASH_TABLE_CURSOR [G#1, G#2]
  */
 
 #include "eif_eiffel.h"
@@ -22,15 +22,13 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {DS_SORTABLE}.sort */
-void F1077_7154 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+/* {DS_HASH_TABLE_CURSOR}.container */
+EIF_REFERENCE F1100_7465 (EIF_REFERENCE Current)
 {
-	GTCX
-	
-	
-	(RTNR(NULL));
+	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
 }
 
+
 void EIF_Minit679 (void)
 {
 	GTCX
