@@ -6,7 +6,7 @@
 extern "C" {
 #endif
 
-extern void F1077_7154(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F1100_7465(EIF_REFERENCE);
 extern void EIF_Minit679(void);
 
 #ifdef __cplusplus
