@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F1089_7239(EIF_REFERENCE, EIF_REFERENCE);
-extern void F1089_7243(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_BOOLEAN F920_6170(EIF_REFERENCE);
 extern void EIF_Minit681(void);
+extern char *(*R4601[])();
 
 #ifdef __cplusplus
 }
