@@ -1,5 +1,5 @@
 /*
- * Code for class DYNAMIC_LIST [G#1]
+ * Code for class DYNAMIC_TABLE [G#1, INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -22,21 +22,13 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {DYNAMIC_LIST}.wipe_out */
-void F626_4222 (EIF_REFERENCE Current)
+/* {DYNAMIC_TABLE}.prunable */
+EIF_BOOLEAN F354_4217 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTCDT;
-	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
 	
-	RTGC;
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R3834[dtype-625])(Current);
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R2844[dtype-229])(Current);
-	RTLE;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
 void EIF_Minit660 (void)
