@@ -6,10 +6,8 @@
 extern "C" {
 #endif
 
-extern void F626_4222(EIF_REFERENCE);
+extern EIF_BOOLEAN F354_4217(EIF_REFERENCE);
 extern void EIF_Minit660(void);
-extern char *(*R3834[])();
-extern char *(*R2844[])();
 
 #ifdef __cplusplus
 }
