@@ -1,5 +1,5 @@
 /*
- * Code for class DYNAMIC_CHAIN [CHARACTER_32]
+ * Code for class DYNAMIC_CHAIN [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -23,16 +23,11 @@ extern "C" {
 #endif
 
 /* {DYNAMIC_CHAIN}.extendible */
-EIF_BOOLEAN F861_6497 (EIF_REFERENCE Current)
+EIF_BOOLEAN F868_6653 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("extendible", 860, Current, 0, 0, 9378);
-	RTHOOK(1);
-	RTHOOK(2);
-	RTEE;
 	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 }
 
