@@ -24,10 +24,10 @@ extern "C" {
 
 /* {EC_EIFFEL_LAYOUT}.application_name */
 
-EIF_REFERENCE F1318_12558 (EIF_REFERENCE Current)
+EIF_REFERENCE F1331_13206 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTOUC (501,RTMS_EX_H("ec",2,25955));
+	RTOSC (13206,RTMS_EX_H("ec",2,25955));
 }
 
 void EIF_Minit650 (void)
