@@ -1,5 +1,5 @@
 /*
- * Code for class ET_WHEN_PART
+ * Code for class ET_RENAME
  */
 
 #include "eif_eiffel.h"
@@ -22,53 +22,62 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ET_WHEN_PART}.make */
-void F1563_14954 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
+/* {ET_RENAME}.make */
+void F1624_16296 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
 {
 	GTCX
+	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
-	RTLI(3);
+	RTLI(4);
 	RTLR(0,Current);
 	RTLR(1,arg1);
-	RTLR(2,arg2);
-	RTLIU(3);
+	RTLR(2,tr1);
+	RTLR(3,arg2);
+	RTLIU(4);
 	
 	RTGC;
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
+	tr1 = RTOUCR(390,F372_4945, (RTCV(RTOUCR(70,F981_7889, (Current)))));
+	RTAR(Current, tr1);
+	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
 	RTAR(Current, arg2);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg2;
 	RTLE;
 }
 
-/* {ET_WHEN_PART}.reset */
-void F1563_14955 (EIF_REFERENCE Current)
+/* {ET_RENAME}.reset */
+void F1624_16297 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
-	RTLI(3);
+	RTLI(2);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLR(2,loc1);
-	RTLIU(3);
+	RTLIU(2);
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	F1578_15100(RTCW(tr1));
+	(FUNCTION_CAST(void, (EIF_REFERENCE)) R12373[Dtype(RTCW(tr1))-1792])(tr1);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	loc1 = tr1;
-	if (EIF_TEST(loc1)) {
-		F1576_15079(loc1);
-	}
+	(FUNCTION_CAST(void, (EIF_REFERENCE)) R12373[Dtype(RTCW(tr1))-1792])(tr1);
 	RTLE;
 }
 
-/* {ET_WHEN_PART}.position */
-EIF_REFERENCE F1563_14958 (EIF_REFERENCE Current)
+/* {ET_RENAME}.rename_pair */
+EIF_REFERENCE F1624_16301 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	return (EIF_REFERENCE) Current;
+}
+
+/* {ET_RENAME}.position */
+EIF_REFERENCE F1624_16302 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -84,43 +93,52 @@ EIF_REFERENCE F1563_14958 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	Result = F1578_15103(RTCW(tr1));
+	Result = F1886_18329(RTCW(tr1));
 	RTLE;
 	return Result;
 }
 
-/* {ET_WHEN_PART}.last_leaf */
-EIF_REFERENCE F1563_14960 (EIF_REFERENCE Current)
+/* {ET_RENAME}.last_leaf */
+EIF_REFERENCE F1624_16304 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
 	
-	RTLI(4);
-	RTLR(0,loc1);
-	RTLR(1,Current);
-	RTLR(2,tr1);
-	RTLR(3,Result);
-	RTLIU(4);
+	RTLI(3);
+	RTLR(0,Current);
+	RTLR(1,tr1);
+	RTLR(2,Result);
+	RTLIU(3);
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	loc1 = tr1;
-	if (EIF_TEST(loc1)) {
-		tr1 = F1576_15084(loc1);
-		RTLE;
-		return (EIF_REFERENCE) tr1;
-	} else {
-		tr1 = *(EIF_REFERENCE *)(Current);
-		Result = F1578_15105(RTCW(tr1));
-	}
+	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R11771[Dtype(RTCW(tr1))-1591])(tr1);
 	RTLE;
 	return Result;
 }
 
+/* {ET_RENAME}.set_as_keyword */
+void F1624_16305 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+{
+	GTCX
+	
+	
+	RTAR(Current, arg1);
+	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
+}
+
+/* {ET_RENAME}.process */
+void F1624_16306 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+{
+	GTCX
+	
+	
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2807[Dtype(RTCW(arg1))-308])(arg1, Current);
+}
+
 void EIF_Minit685 (void)
 {
 	GTCX
