@@ -6,9 +6,7 @@
 extern "C" {
 #endif
 
-extern void F1262_11958(EIF_REFERENCE, EIF_REFERENCE);
-extern void F1262_11959(EIF_REFERENCE, EIF_INTEGER_32);
-extern void F1262_11960(EIF_REFERENCE);
+extern void F1309_13464(EIF_REFERENCE, EIF_INTEGER_32);
 extern void EIF_Minit667(void);
 
 #ifdef __cplusplus
