@@ -6,10 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1320_12085(EIF_REFERENCE);
+extern void F1372_13285(EIF_REFERENCE);
 extern void EIF_Minit694(void);
-extern EIF_REFERENCE F1680_17037(EIF_REFERENCE);
-extern long O9812[];
+extern void F1365_13200(EIF_REFERENCE);
+extern void F1306_12429(EIF_REFERENCE, EIF_POINTER);
 
 #ifdef __cplusplus
 }
