@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F595_5047(EIF_REFERENCE);
+extern EIF_BOOLEAN F586_3155(EIF_REFERENCE);
 extern void EIF_Minit658(void);
-extern char *(*R4078[])();
+extern EIF_INTEGER_32 F688_3633(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
