@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F414_2905(EIF_REFERENCE);
+extern void F1249_11954(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit664(void);
-extern char *(*R2568[])();
 
 #ifdef __cplusplus
 }
