@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F436_3762(EIF_REFERENCE);
+extern EIF_BOOLEAN F605_3221(EIF_REFERENCE);
 extern void EIF_Minit676(void);
-extern char *(*R3519[])();
+extern EIF_INTEGER_32 F706_3699(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
