@@ -1,5 +1,5 @@
 /*
- * Code for class FINITE [REAL_64]
+ * Code for class FINITE [BOOLEAN]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {FINITE}.is_empty */
-EIF_BOOLEAN F200_1410 (EIF_REFERENCE Current)
+EIF_BOOLEAN F538_2662 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
@@ -36,14 +35,10 @@ EIF_BOOLEAN F200_1410 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("is_empty", 199, Current, 0, 0, 1757);
 	RTGC;
-	RTHOOK(1);
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1280[Dtype(Current)-396])(Current);
+	ti4_1 = F639_3140(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
