@@ -24,7 +24,7 @@ extern "C" {
 #endif
 
 /* {HASH_TABLE_ITERATION_CURSOR}.item */
-EIF_INTEGER_32 F292_2796 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F299_2796 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -41,7 +41,7 @@ EIF_INTEGER_32 F292_2796 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("item", 291, Current, 0, 0, 3132);
+	RTEAA("item", 298, Current, 0, 0, 3109);
 	RTGC;
 	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
@@ -57,7 +57,7 @@ EIF_INTEGER_32 F292_2796 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.key */
-EIF_POINTER F292_2797 (EIF_REFERENCE Current)
+EIF_POINTER F299_2797 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -74,7 +74,7 @@ EIF_POINTER F292_2797 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("key", 291, Current, 0, 0, 3133);
+	RTEAA("key", 298, Current, 0, 0, 3110);
 	RTGC;
 	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
@@ -90,7 +90,7 @@ EIF_POINTER F292_2797 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.after */
-EIF_BOOLEAN F292_2799 (EIF_REFERENCE Current)
+EIF_BOOLEAN F299_2799 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -107,20 +107,20 @@ EIF_BOOLEAN F292_2799 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("after", 291, Current, 1, 0, 3135);
+	RTEAA("after", 298, Current, 1, 0, 3112);
 	RTGC;
 	RTHOOK(1);
 	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_);
 	RTHOOK(2);
 	Result = '\01';
 	tb1 = '\01';
-	if (!(EIF_BOOLEAN) !F279_2788(Current)) {
+	if (!(EIF_BOOLEAN) !F287_2788(Current)) {
 		tb1 = (EIF_BOOLEAN) (loc1 < ((EIF_INTEGER_32) 0L));
 	}
 	if (!tb1) {
 		tr1 = *(EIF_REFERENCE *)(Current);
 		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 		Result = (EIF_BOOLEAN) (loc1 >= ti4_1);
 	}
 	RTHOOK(3);
@@ -130,7 +130,7 @@ EIF_BOOLEAN F292_2799 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.forth */
-void F292_2800 (EIF_REFERENCE Current)
+void F299_2800 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -147,7 +147,7 @@ void F292_2800 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("forth", 291, Current, 3, 0, 3136);
+	RTEAA("forth", 298, Current, 3, 0, 3113);
 	RTGC;
 	RTHOOK(1);
 	loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_);
@@ -162,7 +162,8 @@ void F292_2800 (EIF_REFERENCE Current)
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || (EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L)))) break;
 			RTHOOK(6);
 			tr1 = *(EIF_REFERENCE *)(Current);
-			loc3 = F663_3812(RTCW(tr1), loc3);
+			ti4_1 = F688_3821(RTCW(tr1), loc3);
+			loc3 = (EIF_INTEGER_32) ti4_1;
 			RTHOOK(7);
 			loc1++;
 		}
@@ -175,13 +176,14 @@ void F292_2800 (EIF_REFERENCE Current)
 			if (!(EIF_BOOLEAN) (loc1 > loc2)) {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 				tb1 = (EIF_BOOLEAN) (loc3 >= ti4_1);
 			}
 			if (tb1) break;
 			RTHOOK(10);
 			tr1 = *(EIF_REFERENCE *)(Current);
-			loc3 = F663_3811(RTCW(tr1), loc3);
+			ti4_1 = F688_3820(RTCW(tr1), loc3);
+			loc3 = (EIF_INTEGER_32) ti4_1;
 			RTHOOK(11);
 			loc1++;
 		}
@@ -194,7 +196,7 @@ void F292_2800 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.target */
-EIF_REFERENCE F292_2801 (EIF_REFERENCE Current)
+EIF_REFERENCE F299_2801 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current);
 }
