@@ -6,7 +6,7 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1357_12865(EIF_REFERENCE);
+extern EIF_BOOLEAN F165_1493(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit684(void);
 
 #ifdef __cplusplus
