@@ -1,5 +1,5 @@
 /*
- * Code for class KL_INPUT_FILE
+ * Code for class KL_EQUALITY_TESTER [NATURAL_32]
  */
 
 #include "eif_eiffel.h"
@@ -22,22 +22,19 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {KL_INPUT_FILE}.is_open_read */
-EIF_BOOLEAN F1361_13006 (EIF_REFERENCE Current)
+/* {KL_EQUALITY_TESTER}.test */
+EIF_BOOLEAN F216_2107 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_NATURAL_32 arg2)
 {
 	GTCX
 	
 	
-	return (EIF_BOOLEAN) F876_7765(Current);
-}
-
-/* {KL_INPUT_FILE}.file_readable */
-EIF_BOOLEAN F1361_13016 (EIF_REFERENCE Current)
-{
-	GTCX
+	RTGC;
+	if ((EIF_BOOLEAN)(arg1 == arg2)) {
+		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+	} else {
+		return (EIF_BOOLEAN) (arg1 == arg2);
+	}/* NOTREACHED */
 	
-	
-	return (EIF_BOOLEAN) F1361_13006(Current);
 }
 
 void EIF_Minit687 (void)
