@@ -6,10 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F1361_13006(EIF_REFERENCE);
-extern EIF_BOOLEAN F1361_13016(EIF_REFERENCE);
+extern EIF_BOOLEAN F216_2107(EIF_REFERENCE, EIF_NATURAL_32, EIF_NATURAL_32);
 extern void EIF_Minit687(void);
-extern EIF_BOOLEAN F876_7765(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
