@@ -6,7 +6,8 @@
 extern "C" {
 #endif
 
-extern void F706_3783(EIF_REFERENCE, EIF_INTEGER_32);
+extern void F266_2468(EIF_REFERENCE);
+extern EIF_BOOLEAN F266_2469(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
 extern void EIF_Minit697(void);
 
 #ifdef __cplusplus
