@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F438_2909(EIF_REFERENCE);
-extern void F438_2911(EIF_REFERENCE);
+extern EIF_INTEGER_32 F612_3168(EIF_REFERENCE);
 extern void EIF_Minit663(void);
-extern char *(*R2567[])();
-extern char *(*R2573[])();
+extern EIF_INTEGER_32 F688_3634(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
