@@ -6,11 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F219_1383(EIF_REFERENCE);
-extern void F219_1385(EIF_REFERENCE);
+extern void F1258_12018(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1258_12019(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit673(void);
-extern char *(*R1248[])();
-extern char *(*R1254[])();
 
 #ifdef __cplusplus
 }
