@@ -1,5 +1,5 @@
 /*
- * Code for class READABLE_INDEXABLE [CHARACTER_32]
+ * Code for class READABLE_INDEXABLE [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -23,37 +23,34 @@ extern "C" {
 #endif
 
 /* {READABLE_INDEXABLE}.new_cursor */
-EIF_REFERENCE F768_6231 (EIF_REFERENCE Current)
+EIF_REFERENCE F702_5587 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
 	
-	RTLI(3);
+	RTLI(2);
 	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLR(2,Result);
-	RTLIU(3);
+	RTLR(1,Result);
+	RTLIU(2);
 	
 	RTGC;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {0xFF01,480,0,0,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,416,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y4981,Y4981_gen_type,Dftype(Current),440);
+			l_type = eif_final_id(Y4392,Y4392_gen_type,Dftype(Current),372);
 			typarr0[2] = l_type.annotations | 0xFF00;
 			typarr0[3] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 480, _OBJSIZ_1_1_0_5_0_0_0_0_);
+		Result = RTLNS(typres0.id, 416, _OBJSIZ_1_1_0_5_0_0_0_0_);
 	}
-	F481_5583(RTCW(tr1), Current);
-	Result = (EIF_REFERENCE) tr1;
-	(FUNCTION_CAST(void, (EIF_REFERENCE)) R5045[Dtype(Result)-479])(RTCW(Result));
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4437[Dtype(RTCW(Result))-416])(Result, Current);
+	(FUNCTION_CAST(void, (EIF_REFERENCE)) R4434[Dtype(RTCW(Result))-416])(Result);
 	RTLE;
 	return Result;
 }
