@@ -1,5 +1,5 @@
 /*
- * Code for class RESIZABLE [NATURAL_16]
+ * Code for class RESIZABLE [POINTER]
  */
 
 #include "eif_eiffel.h"
@@ -24,9 +24,10 @@ extern "C" {
 #endif
 
 /* {RESIZABLE}.additional_space */
-EIF_INTEGER_32 F353_3454 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F534_2978 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
@@ -36,17 +37,22 @@ EIF_INTEGER_32 F353_3454 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
+	RTEAA("additional_space", 533, Current, 0, 0, 4134);
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3201[Dtype(Current)-774])(Current);
+	RTHOOK(1);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2601[Dtype(Current)-590])(Current);
 	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
+	RTHOOK(3);
 	RTLE;
+	RTEE;
 	return Result;
 }
 
 /* {RESIZABLE}.automatic_grow */
-void F353_3456 (EIF_REFERENCE Current)
+void F534_2980 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	RTCDT;
@@ -56,11 +62,15 @@ void F353_3456 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
+	RTEAA("automatic_grow", 533, Current, 0, 0, 4136);
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3201[dtype-774])(Current);
-	ti4_2 = F353_3454(Current);
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R3207[dtype-774])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_2));
+	RTHOOK(1);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R2601[dtype-590])(Current);
+	ti4_2 = F534_2978(Current);
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R2607[dtype-590])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_2));
+	RTHOOK(3);
 	RTLE;
+	RTEE;
 }
 
 void EIF_Minit678 (void)
