@@ -1,5 +1,5 @@
 /*
- * Code for class SEQUENCE [INTEGER_32]
+ * Code for class SEQUENCE [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {SEQUENCE}.readable */
-EIF_BOOLEAN F438_3542 (EIF_REFERENCE Current)
+EIF_BOOLEAN F772_6267 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -35,24 +35,28 @@ EIF_BOOLEAN F438_3542 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3163[Dtype(Current)-283])(Current);
+	Result = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5426[Dtype(Current)-727])(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
 	RTLE;
 	return Result;
 }
 
 /* {SEQUENCE}.force */
-void F438_3544 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F772_6269 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
+	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
+	RTLI(3);
+	RTLR(0,arg1);
+	RTLR(1,tr1);
+	RTLR(2,Current);
+	RTLIU(3);
 	
 	RTGC;
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R3185[Dtype(Current)-392])(Current, (EIF_REFERENCE) &arg1);
+	tr1 = RTCCL(arg1);
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5447[Dtype(Current)-727])(Current, tr1);
 	RTLE;
 }
 
