@@ -6,11 +6,11 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F438_3542(EIF_REFERENCE);
-extern void F438_3544(EIF_REFERENCE, EIF_INTEGER_32);
+extern EIF_BOOLEAN F772_6267(EIF_REFERENCE);
+extern void F772_6269(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit686(void);
-extern char *(*R3163[])();
-extern char *(*R3185[])();
+extern char *(*R5447[])();
+extern char *(*R5426[])();
 
 #ifdef __cplusplus
 }
