@@ -1,5 +1,5 @@
 /*
- * Code for class SHARED_INST_CONTEXT
+ * Code for class SHARED_INSTANTIATOR
  */
 
 #include "eif_eiffel.h"
@@ -22,37 +22,35 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {SHARED_INST_CONTEXT}.inst_context */
-static EIF_REFERENCE F1020_11237_body (EIF_REFERENCE Current)
+/* {SHARED_INSTANTIATOR}.instantiator */
+static EIF_REFERENCE F757_10282_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
-	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
 
 	RTLI(1);
-	RTLR(0,tr1);
+	RTLR(0,Current);
 	RTLIU(1);
 	
 	RTEV;
 	RTGC;
-	RTOSP (11237);
-#define Result RTOSR(11237)
+	RTOSP (10282);
+#define Result RTOSR(10282)
 	RTOC_NEW(Result);
-	tr1 = RTLNS(eif_new_type(75, 0x00).id, 75, _OBJSIZ_1_0_0_0_0_0_0_0_);
-	Result = (EIF_REFERENCE) tr1;
-	RTOSE (11237);
+	Result = *(EIF_REFERENCE *)(RTCV(RTOSCF(10214,F744_10214, (Current))) + _REFACS_83_);
+	RTOSE (10282);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F1020_11237 (EIF_REFERENCE Current)
+EIF_REFERENCE F757_10282 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOSCF(11237,F1020_11237_body,(Current));
+	return RTOSCF(10282,F757_10282_body,(Current));
 }
 
 void EIF_Minit656 (void)
