@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [BOOLEAN]
+ * Code for class TO_SPECIAL [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F414_2106 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F235_2365 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -35,7 +35,7 @@ void F414_2106 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1899,Y1899_gen_type,Dftype(Current),408).id,0,arg1,sizeof(EIF_BOOLEAN), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y2181,Y2181_gen_type,Dftype(Current),229).id,0,arg1,sizeof(EIF_NATURAL_64), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -43,7 +43,7 @@ void F414_2106 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F414_2107 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F235_2366 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -55,22 +55,15 @@ void F414_2107 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1899,Y1899_gen_type,Dftype(Current),408).id,0,arg2,sizeof(EIF_BOOLEAN), EIF_TRUE);
-	F612_3030(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y2181,Y2181_gen_type,Dftype(Current),229).id,0,arg2,sizeof(EIF_NATURAL_64), EIF_TRUE);
+	F663_3533(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F414_2108 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.set_area */
-void F414_2113 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F235_2372 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	
