@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [G#1]
+ * Code for class TO_SPECIAL [NATURAL_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F256_2500 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F204_1937 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -35,7 +35,7 @@ void F256_2500 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y2251,Y2251_gen_type,Dftype(Current),255).id,EO_REF,arg1,sizeof(EIF_REFERENCE), EIF_FALSE);
+	tr1 = RTLNSP2(eif_final_id(Y1793,Y1793_gen_type,Dftype(Current),199).id,0,arg1,sizeof(EIF_NATURAL_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -43,31 +43,27 @@ void F256_2500 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F256_2501 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
+void F204_1938 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE tr2 = NULL;
 	RTLD;
 	
-	RTLI(4);
+	RTLI(2);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLR(2,arg1);
-	RTLR(3,tr2);
-	RTLIU(4);
+	RTLIU(2);
 	
 	RTGC;
-	tr2 = RTCCL(arg1);
-	tr1 = RTLNSP2(eif_final_id(Y2251,Y2251_gen_type,Dftype(Current),255).id,EO_REF,arg2,sizeof(EIF_REFERENCE), EIF_FALSE);
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R3097[Dtype(RTCW(tr1))-668])(tr1, tr2, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1793,Y1793_gen_type,Dftype(Current),199).id,0,arg2,sizeof(EIF_NATURAL_32), EIF_TRUE);
+	F634_3148(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
 /* {TO_SPECIAL}.set_area */
-void F256_2507 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F204_1944 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	
