@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [NATURAL_64]
+ * Code for class TO_SPECIAL [CHARACTER_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F362_1754 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F189_1858 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -35,7 +35,7 @@ void F362_1754 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1578,Y1578_gen_type,Dftype(Current),351).id,0,arg1,sizeof(EIF_NATURAL_64), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),181).id,0,arg1,sizeof(EIF_CHARACTER_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -43,7 +43,7 @@ void F362_1754 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F362_1755 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1, EIF_INTEGER_32 arg2)
+void F189_1859 (EIF_REFERENCE Current, EIF_CHARACTER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -55,22 +55,15 @@ void F362_1755 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1, EIF_INTEGER_32 arg2)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1578,Y1578_gen_type,Dftype(Current),351).id,0,arg2,sizeof(EIF_NATURAL_64), EIF_TRUE);
-	F560_2556(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),181).id,0,arg2,sizeof(EIF_CHARACTER_32), EIF_TRUE);
+	F618_3064(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F362_1756 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.set_area */
-void F362_1761 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F189_1865 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	
