@@ -1,5 +1,5 @@
 /*
- * Code for class TYPE [REAL_32]
+ * Code for class TYPE [TYPED_POINTER [REAL_64]]
  */
 
 #include "eif_eiffel.h"
@@ -23,8 +23,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TYPE}.name */
-EIF_REFERENCE F907_6734 (EIF_REFERENCE Current)
+/* {TYPE}.name_32 */
+EIF_REFERENCE F785_3867 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -39,20 +39,20 @@ EIF_REFERENCE F907_6734 (EIF_REFERENCE Current)
 	RTLIU(3);
 	
 	RTGC;
-	Result = *(EIF_REFERENCE *)(Current + _REFACS_1_);
+	Result = *(EIF_REFERENCE *)(Current);
 	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
-		Result = RTLNS(eif_new_type(1027, 0x01).id, 1027, _OBJSIZ_1_0_0_4_0_0_0_0_);
-		tr1 = F907_6762(Current);
-		F1027_8054(RTCW(Result), tr1);
+		Result = RTLNS(eif_new_type(868, 0x01).id, 868, _OBJSIZ_1_0_0_4_0_0_0_0_);
+		tr1 = F785_3896(Current);
+		F869_5313(RTCW(Result), tr1);
 		RTAR(Current, Result);
-		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) Result;
+		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
 	}
 	RTLE;
 	return Result;
 }
 
 /* {TYPE}.generic_parameter_type */
-EIF_REFERENCE F907_6735 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F785_3869 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -65,8 +65,8 @@ EIF_REFERENCE F907_6735 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("generic_parameter_type", 906, Current, 0, 1, 11688);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type (Current, arg1);
+	RTEAA("generic_parameter_type", 784, Current, 0, 1, 9576);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type__i4_t (Current, arg1);
 	if (!Result) {RTEC(EN_FAIL);}
 	RTLE;
 	RTEE;
@@ -74,40 +74,52 @@ EIF_REFERENCE F907_6735 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TYPE}.type_id */
-EIF_INTEGER_32 F907_6736 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F785_3870 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	
 	
-	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 	return Result;
 }
 
 /* {TYPE}.hash_code */
-EIF_INTEGER_32 F907_6737 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F785_3871 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 }
 
-/* {TYPE}.is_attached */
-EIF_BOOLEAN F907_6742 (EIF_REFERENCE Current)
+/* {TYPE}.has_default */
+EIF_BOOLEAN F785_3873 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
 	
-	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached (Current);
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_has_default__b (Current);
+	return Result;
+}
+
+/* {TYPE}.is_attached */
+EIF_BOOLEAN F785_3876 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	
+	
+	
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached__b (Current);
 	return Result;
 }
 
 /* {TYPE}.is_equal */
-EIF_BOOLEAN F907_6743 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F785_3877 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -122,61 +134,26 @@ EIF_BOOLEAN F907_6743 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
+	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
 	RTLE;
 	return Result;
 }
 
-/* {TYPE}.is_conforming_to */
-EIF_BOOLEAN F907_6745 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,arg1);
-	RTLIU(2);
-	
-	RTGC;
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
-	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_type_conforms_to (ti4_1, ti4_2);
-	RTLE;
-	return Result;
-}
-
 /* {TYPE}.default */
-EIF_REFERENCE F907_6750 (EIF_REFERENCE Current)
+EIF_REAL_64* F785_3884 (EIF_REFERENCE Current)
 {
 	GTCX
-	struct eif_ex_351 sloc1;
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) sloc1.data;
-	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
+	EIF_REAL_64* loc1 = (EIF_REAL_64*) 0;
 	
-	RTLD;
-	
-	memset (&sloc1.overhead, 0, OVERHEAD + _OBJSIZ_0_0_0_0_1_0_0_0_);
-	sloc1.overhead.ov_flags = EO_EXP | EO_STACK;
-	RT_DFS(&sloc1.overhead, eif_gen_param(Dftype(Current), 1).id);
-	RTLI(1);
-	RTLR(0,Result);
-	RTLIU(1);
 	
 	RTGC;
-	Result= RTLN(eif_gen_param(Dftype(Current), 1).id);
-	RTLE;
-	return Result;
+	return (EIF_REAL_64*) 0;
 }
 
 /* {TYPE}.runtime_name */
-EIF_REFERENCE F907_6762 (EIF_REFERENCE Current)
+EIF_REFERENCE F785_3896 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -189,8 +166,8 @@ EIF_REFERENCE F907_6762 (EIF_REFERENCE Current)
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("runtime_name", 906, Current, 0, 0, 11685);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
+	RTEAA("runtime_name", 784, Current, 0, 0, 9603);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
 	if (!Result) {RTEC(EN_FAIL);}
 	RTLE;
 	RTEE;
