@@ -1,5 +1,5 @@
 /*
- * Code for class DS_LINKABLE [CHARACTER_8]
+ * Code for class DS_LINKABLE [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -22,36 +22,29 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {DS_LINKABLE}.right */
-EIF_REFERENCE F936_12741 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {DS_LINKABLE}.put_right */
-void F936_12742 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F1016_15469 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("put_right", 935, Current, 0, 1, 12550);
-	RTHOOK(2);
+	RTEAA("put_right", 1015, Current, 0, 1, 13941);
+	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
-	RTHOOK(4);
+	RTHOOK(3);
 	RTEE;
 }
 
 /* {DS_LINKABLE}.forget_right */
-void F936_12743 (EIF_REFERENCE Current)
+void F1016_15470 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("forget_right", 935, Current, 0, 0, 12551);
+	RTEAA("forget_right", 1015, Current, 0, 0, 13942);
 	RTHOOK(1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) NULL;
 	RTHOOK(3);
