@@ -6,9 +6,7 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F5859_79638(EIF_REFERENCE, EIF_REFERENCE);
-extern EIF_REFERENCE F5859_79641(EIF_REFERENCE);
-extern void F5859_79642(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F6272_84378(EIF_REFERENCE);
 extern void EIF_Minit7178(void);
 
 #ifdef __cplusplus
