@@ -6,7 +6,7 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F2021_22530(EIF_REFERENCE, EIF_CHARACTER_32, EIF_CHARACTER_32);
+extern EIF_BOOLEAN F1998_27373(EIF_REFERENCE, EIF_INTEGER_32, EIF_INTEGER_32);
 extern void EIF_Minit7237(void);
 
 #ifdef __cplusplus
