@@ -6,8 +6,8 @@
 extern "C" {
 #endif
 
-extern void F1887_21196(EIF_REFERENCE, EIF_REFERENCE, EIF_BOOLEAN, EIF_BOOLEAN);
-extern EIF_REFERENCE F1887_21197(EIF_REFERENCE);
+extern void F1713_24143(EIF_REFERENCE, EIF_REFERENCE);
+extern void F1713_24144(EIF_REFERENCE);
 extern void EIF_Minit7218(void);
 
 #ifdef __cplusplus
