@@ -6,11 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F5716_72746(EIF_REFERENCE);
-extern EIF_REFERENCE F5716_72747(EIF_REFERENCE);
+extern EIF_BOOLEAN F6437_87229(EIF_REFERENCE);
 extern void EIF_Minit7299(void);
-extern long O54826[];
-extern long O54792[];
 
 #ifdef __cplusplus
 }
