@@ -6,7 +6,8 @@
 extern "C" {
 #endif
 
-extern void F5987_81202(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_INTEGER_32 F6519_87660(EIF_REFERENCE);
+extern EIF_INTEGER_32 F6519_87663(EIF_REFERENCE, EIF_INTEGER_32);
 extern void EIF_Minit7308(void);
 
 #ifdef __cplusplus
