@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAYED_LIST [POINTER]
+ * Code for class ARRAYED_LIST [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {ARRAYED_LIST}.make */
-void F567_4711 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F845_4771 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -38,7 +38,7 @@ void F567_4711 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	
 	RTGC;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-	tr1 = RTLNSP2(eif_final_id(Y3653,Y3653_gen_type,Dftype(Current),226).id,0,arg1,sizeof(EIF_POINTER), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y2615,Y2615_gen_type,Dftype(Current),290).id,0,arg1,sizeof(EIF_INTEGER_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -46,7 +46,7 @@ void F567_4711 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {ARRAYED_LIST}.area */
-EIF_REFERENCE F567_4715 (EIF_REFERENCE Current)
+EIF_REFERENCE F845_4775 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -55,15 +55,14 @@ EIF_REFERENCE F567_4715 (EIF_REFERENCE Current)
 }
 
 /* {ARRAYED_LIST}.item */
-EIF_POINTER F567_4716 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F845_4776 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
+	EIF_INTEGER_32 ti4_3;
+	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
 	
@@ -74,24 +73,23 @@ EIF_POINTER F567_4716 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))));
+	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - ((EIF_INTEGER_32) 1L))));
 	/* END INLINED CODE */
-	Result = tp2;
+	Result = ti4_3;
 	RTLE;
 	return Result;
 }
 
 /* {ARRAYED_LIST}.i_th */
-EIF_POINTER F567_4717 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_INTEGER_32 F845_4777 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
+	EIF_INTEGER_32 ti4_2;
+	EIF_INTEGER_32 ti4_3;
+	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
 	
@@ -103,77 +101,21 @@ EIF_POINTER F567_4717 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - ((EIF_INTEGER_32) 1L))));
+	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - ((EIF_INTEGER_32) 1L))));
 	/* END INLINED CODE */
-	Result = tp2;
-	RTLE;
-	return Result;
-}
-
-/* {ARRAYED_LIST}.at */
-EIF_POINTER F567_4718 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current);
-	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - ((EIF_INTEGER_32) 1L))));
-	/* END INLINED CODE */
-	Result = tp2;
+	Result = ti4_3;
 	RTLE;
 	return Result;
 }
 
 /* {ARRAYED_LIST}.first */
-EIF_POINTER F567_4719 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F845_4779 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current);
-	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + (((EIF_INTEGER_32) 0L)));
-	/* END INLINED CODE */
-	Result = tp2;
-	RTLE;
-	return Result;
-}
-
-/* {ARRAYED_LIST}.last */
-EIF_POINTER F567_4720 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
+	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
 	
@@ -184,24 +126,23 @@ EIF_POINTER F567_4720 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = F567_4732(Current);
 	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L))));
+	ti4_2 = *((EIF_INTEGER_32 *)RTCW(tr1) + (((EIF_INTEGER_32) 0L)));
 	/* END INLINED CODE */
-	Result = tp2;
+	Result = ti4_2;
 	RTLE;
 	return Result;
 }
 
 /* {ARRAYED_LIST}.index */
-EIF_INTEGER_32 F567_4721 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F845_4781 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 }
 
 
 /* {ARRAYED_LIST}.cursor */
-EIF_REFERENCE F567_4722 (EIF_REFERENCE Current)
+EIF_REFERENCE F845_4782 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -213,21 +154,21 @@ EIF_REFERENCE F567_4722 (EIF_REFERENCE Current)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNS(eif_new_type(211, 0x00).id, 211, _OBJSIZ_0_0_0_1_0_0_0_0_);
-	F212_3410(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
+	tr1 = RTLNS(eif_new_type(228, 0x01).id, 228, _OBJSIZ_0_0_0_1_0_0_0_0_);
+	F229_2422(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
 	RTLE;
 	return (EIF_REFERENCE) tr1;
 }
 
 /* {ARRAYED_LIST}.has */
-EIF_BOOLEAN F567_4723 (EIF_REFERENCE Current, EIF_POINTER arg1)
+EIF_BOOLEAN F845_4783 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	RTLD;
@@ -239,25 +180,25 @@ EIF_BOOLEAN F567_4723 (EIF_REFERENCE Current, EIF_POINTER arg1)
 	
 	RTGC;
 	loc1 = *(EIF_REFERENCE *)(Current);
-	loc3 = F567_4732(Current);
+	loc3 = F845_4792(Current);
 	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) && EIF_TRUE)) {
 		for (;;) {
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc2 >= loc3) || Result)) break;
 			/* INLINED CODE (SPECIAL.item) */
-			tp2 = *((EIF_POINTER *)RTCW(loc1) + (loc2));
+			ti4_2 = *((EIF_INTEGER_32 *)RTCW(loc1) + (loc2));
 			/* END INLINED CODE */
-			tp1 = tp2;
-			Result = (EIF_BOOLEAN) (arg1 == tp1);
+			ti4_1 = ti4_2;
+			Result = (EIF_BOOLEAN) (arg1 == ti4_1);
 			loc2++;
 		}
 	} else {
 		for (;;) {
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc2 >= loc3) || Result)) break;
 			/* INLINED CODE (SPECIAL.item) */
-			tp2 = *((EIF_POINTER *)RTCW(loc1) + (loc2));
+			ti4_2 = *((EIF_INTEGER_32 *)RTCW(loc1) + (loc2));
 			/* END INLINED CODE */
-			tp1 = tp2;
-			Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(arg1 == tp1);
+			ti4_1 = ti4_2;
+			Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(arg1 == ti4_1);
 			loc2++;
 		}
 	}
@@ -266,7 +207,7 @@ EIF_BOOLEAN F567_4723 (EIF_REFERENCE Current, EIF_POINTER arg1)
 }
 
 /* {ARRAYED_LIST}.new_cursor */
-EIF_REFERENCE F567_4725 (EIF_REFERENCE Current)
+EIF_REFERENCE F845_4785 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -279,49 +220,25 @@ EIF_REFERENCE F567_4725 (EIF_REFERENCE Current)
 	
 	RTGC;
 	{
-		EIF_TYPE_INDEX typarr0[] = {767,0,0,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,490,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y3659,Y3659_gen_type,Dftype(Current),226);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
+			l_type = eif_final_id(Y2621,Y2621_gen_type,Dftype(Current),290);
+			typarr0[2] = l_type.annotations | 0xFF00;
+			typarr0[3] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 767, _OBJSIZ_2_0_0_2_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 490, _OBJSIZ_2_0_0_2_0_0_0_0_);
 	}
-	F768_5493(RTCW(tr1), Current);
+	F491_3984(RTCW(tr1), Current);
 	RTLE;
 	return (EIF_REFERENCE) tr1;
 }
 
-/* {ARRAYED_LIST}.do_all */
-void F567_4726 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE tr2 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(4);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLR(2,arg1);
-	RTLR(3,tr2);
-	RTLIU(4);
-	
-	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current);
-	tr2 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr2);
-	F628_5258(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L)));
-	RTLE;
-}
-
 /* {ARRAYED_LIST}.count */
-EIF_INTEGER_32 F567_4732 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F845_4792 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -336,13 +253,13 @@ EIF_INTEGER_32 F567_4732 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 	RTLE;
 	return Result;
 }
 
 /* {ARRAYED_LIST}.capacity */
-EIF_INTEGER_32 F567_4733 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F845_4793 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -357,13 +274,13 @@ EIF_INTEGER_32 F567_4733 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	RTLE;
 	return Result;
 }
 
 /* {ARRAYED_LIST}.upper */
-EIF_INTEGER_32 F567_4734 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F845_4794 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -378,21 +295,20 @@ EIF_INTEGER_32 F567_4734 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+	Result = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 	RTLE;
 	return Result;
 }
 
 /* {ARRAYED_LIST}.is_equal */
-EIF_BOOLEAN F567_4735 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F845_4795 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -412,8 +328,8 @@ EIF_BOOLEAN F567_4735 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 		return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
 	} else {
 		tb1 = '\0';
-		ti4_1 = F567_4732(RTCW(arg1));
-		if ((EIF_BOOLEAN)(F567_4732(Current) == ti4_1)) {
+		ti4_1 = F845_4792(RTCW(arg1));
+		if ((EIF_BOOLEAN)(F845_4792(Current) == ti4_1)) {
 			tb2 = *(EIF_BOOLEAN *)(RTCW(arg1)+ _CHROFF_1_0_);
 			tb1 = (EIF_BOOLEAN)(*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) == tb2);
 		}
@@ -424,19 +340,19 @@ EIF_BOOLEAN F567_4735 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 				for (;;) {
 					tb1 = '\01';
 					if (!(EIF_BOOLEAN) !Result) {
-						tb1 = (EIF_BOOLEAN) (loc1 > F567_4734(Current));
+						tb1 = (EIF_BOOLEAN) (loc1 > F845_4794(Current));
 					}
 					if (tb1) break;
-					tp1 = F567_4717(Current, loc1);
-					tp2 = F567_4717(RTCW(arg1), loc1);
-					Result = (EIF_BOOLEAN) (tp1 == tp2);
+					ti4_1 = F845_4777(Current, loc1);
+					ti4_2 = F845_4777(RTCW(arg1), loc1);
+					Result = (EIF_BOOLEAN) (ti4_1 == ti4_2);
 					loc1++;
 				}
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-				ti4_1 = F567_4732(Current);
-				Result = F628_5234(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
+				ti4_1 = F845_4792(Current);
+				Result = F749_4508(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
 			}
 		}
 	}
@@ -444,17 +360,8 @@ EIF_BOOLEAN F567_4735 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	return Result;
 }
 
-/* {ARRAYED_LIST}.prunable */
-EIF_BOOLEAN F567_4736 (EIF_REFERENCE Current)
-{
-	GTCX
-	
-	
-	return (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
-}
-
 /* {ARRAYED_LIST}.valid_index */
-EIF_BOOLEAN F567_4738 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F845_4798 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -468,38 +375,14 @@ EIF_BOOLEAN F567_4738 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	Result = '\0';
 	if ((EIF_BOOLEAN) (((EIF_INTEGER_32) 1L) <= arg1)) {
-		Result = (EIF_BOOLEAN) (arg1 <= F567_4732(Current));
+		Result = (EIF_BOOLEAN) (arg1 <= F845_4792(Current));
 	}
 	RTLE;
 	return Result;
 }
 
-/* {ARRAYED_LIST}.move */
-void F567_4741 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)) += arg1;
-	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) > (EIF_INTEGER_32) (F567_4732(Current) + ((EIF_INTEGER_32) 1L)))) {
-		ti4_1 = F567_4732(Current);
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L));
-	} else {
-		if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) < ((EIF_INTEGER_32) 0L))) {
-			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-		}
-	}
-	RTLE;
-}
-
 /* {ARRAYED_LIST}.start */
-void F567_4742 (EIF_REFERENCE Current)
+void F845_4802 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -507,25 +390,8 @@ void F567_4742 (EIF_REFERENCE Current)
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 }
 
-/* {ARRAYED_LIST}.finish */
-void F567_4743 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	ti4_1 = F567_4732(Current);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
-	RTLE;
-}
-
 /* {ARRAYED_LIST}.forth */
-void F567_4744 (EIF_REFERENCE Current)
+void F845_4804 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -533,17 +399,8 @@ void F567_4744 (EIF_REFERENCE Current)
 	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))++;
 }
 
-/* {ARRAYED_LIST}.back */
-void F567_4745 (EIF_REFERENCE Current)
-{
-	GTCX
-	
-	
-	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))--;
-}
-
 /* {ARRAYED_LIST}.go_i_th */
-void F567_4746 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F845_4806 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
@@ -552,7 +409,7 @@ void F567_4746 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {ARRAYED_LIST}.go_to */
-void F567_4747 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F845_4807 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
@@ -567,7 +424,7 @@ void F567_4747 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	loc1 = arg1;
-	loc1 = RTRV(eif_new_type(211, 0x00),loc1);
+	loc1 = RTRV(eif_new_type(228, 0x01),loc1);
 	if (EIF_TEST(loc1)) {
 		ti4_1 = *(EIF_INTEGER_32 *)(loc1+ _LNGOFF_0_0_0_0_);
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
@@ -576,150 +433,72 @@ void F567_4747 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLE;
 }
 
-/* {ARRAYED_LIST}.search */
-void F567_4748 (EIF_REFERENCE Current, EIF_POINTER arg1)
-{
-	GTCX
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,loc1);
-	RTLR(1,Current);
-	RTLIU(2);
-	
-	RTGC;
-	loc1 = *(EIF_REFERENCE *)(Current);
-	loc3 = F567_4732(Current);
-	loc3 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc3 - ((EIF_INTEGER_32) 1L));
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	loc2 = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L)),((EIF_INTEGER_32) 0L));
-	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) && EIF_TRUE)) {
-		for (;;) {
-			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc2 > loc3) || loc4)) break;
-			/* INLINED CODE (SPECIAL.item) */
-			tp2 = *((EIF_POINTER *)RTCW(loc1) + (loc2));
-			/* END INLINED CODE */
-			tp1 = tp2;
-			loc4 = (EIF_BOOLEAN) (arg1 == tp1);
-			loc2++;
-		}
-	} else {
-		for (;;) {
-			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc2 > loc3) || loc4)) break;
-			/* INLINED CODE (SPECIAL.item) */
-			tp2 = *((EIF_POINTER *)RTCW(loc1) + (loc2));
-			/* END INLINED CODE */
-			tp1 = tp2;
-			loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN)(arg1 == tp1);
-			loc2++;
-		}
-	}
-	if (loc4) {
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc2;
-	} else {
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 + ((EIF_INTEGER_32) 1L));
-	}
-	RTLE;
-}
-
-/* {ARRAYED_LIST}.put_i_th */
-void F567_4750 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current);
-	/* INLINED CODE (SPECIAL.put) */
-	*((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)))) = arg1;
-	/* END INLINED CODE */
-	;
-	RTLE;
-}
-
-/* {ARRAYED_LIST}.extend */
-void F567_4752 (EIF_REFERENCE Current, EIF_POINTER arg1)
+/* {ARRAYED_LIST}.force */
+void F845_4811 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
+	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	RTLD;
 	
-	RTLI(2);
+	RTLI(3);
 	RTLR(0,Current);
 	RTLR(1,loc2);
-	RTLIU(2);
+	RTLR(2,tr1);
+	RTLIU(3);
 	
 	RTGC;
-	loc1 = F567_4732(Current);
+	loc1 = F845_4792(Current);
 	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L));
 	loc2 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (loc2);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (loc2);
 	if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
-		ti4_1 = F418_4217(Current);
-		loc2 = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (loc2, (EIF_INTEGER_32) (loc1 + ti4_1));
+		ti4_1 = F698_4128(Current);
+		tr1 = F749_4527(loc2, (EIF_INTEGER_32) (loc1 + ti4_1));
+		loc2 = (EIF_REFERENCE) tr1;
 		RTAR(Current, loc2);
 		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
 	}
-	F628_5238(RTCW(loc2), arg1);
+	F749_4512(RTCW(loc2), arg1);
 	RTLE;
 }
 
-/* {ARRAYED_LIST}.put_left */
-void F567_4753 (EIF_REFERENCE Current, EIF_POINTER arg1)
+/* {ARRAYED_LIST}.extend */
+void F845_4812 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
+	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
+	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
+	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN tb1;
 	RTLD;
 	
-	RTLI(1);
+	RTLI(3);
 	RTLR(0,Current);
-	RTLIU(1);
+	RTLR(1,loc2);
+	RTLR(2,tr1);
+	RTLIU(3);
 	
 	RTGC;
-	tb1 = '\01';
-	if (!F526_4454(Current)) {
-		tb1 = F394_4211(Current);
+	loc1 = F845_4792(Current);
+	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L));
+	loc2 = *(EIF_REFERENCE *)(Current);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (loc2);
+	if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
+		ti4_1 = F698_4128(Current);
+		tr1 = F749_4527(loc2, (EIF_INTEGER_32) (loc1 + ti4_1));
+		loc2 = (EIF_REFERENCE) tr1;
+		RTAR(Current, loc2);
+		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) loc2;
 	}
-	if (tb1) {
-		F567_4752(Current, arg1);
-	} else {
-		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-		F567_4774(Current, arg1, ti4_1);
-	}
-	(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))++;
+	F749_4512(RTCW(loc2), arg1);
 	RTLE;
 }
 
-/* {ARRAYED_LIST}.replace */
-void F567_4755 (EIF_REFERENCE Current, EIF_POINTER arg1)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	
-	
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	F567_4750(Current, arg1, ti4_1);
-}
-
 /* {ARRAYED_LIST}.grow */
-void F567_4759 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F845_4819 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -733,10 +512,10 @@ void F567_4759 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	if ((EIF_BOOLEAN) (arg1 > ti4_1)) {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (tr1, arg1);
+		tr1 = F749_4527(tr1, arg1);
 		RTAR(Current, tr1);
 		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	}
@@ -744,7 +523,7 @@ void F567_4759 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {ARRAYED_LIST}.copy */
-void F567_4762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F845_4822 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -758,57 +537,16 @@ void F567_4762 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
-		eif_builtin_ANY_standard_copy (Current, arg1);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
-		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
-		F228_3793(Current, tr1);
-	}
-	RTLE;
-}
-
-/* {ARRAYED_LIST}.prune */
-void F567_4764 (EIF_REFERENCE Current, EIF_POINTER arg1)
-{
-	GTCX
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	if (F526_4455(Current)) {
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	}
-	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
-		for (;;) {
-			tb1 = '\01';
-			if (!F526_4454(Current)) {
-				tb1 = (F567_4716(Current) == arg1);
-			}
-			if (tb1) break;
-			F567_4744(Current);
-		}
-	} else {
-		for (;;) {
-			tb2 = '\01';
-			if (!F526_4454(Current)) {
-				tb2 = (EIF_BOOLEAN)(F567_4716(Current) == arg1);
-			}
-			if (tb2) break;
-			F567_4744(Current);
-		}
-	}
-	if ((EIF_BOOLEAN) !F526_4454(Current)) {
-		F567_4765(Current);
+		tr1 = F1_14(tr1);
+		F292_2878(Current, tr1);
 	}
 	RTLE;
 }
 
 /* {ARRAYED_LIST}.remove */
-void F567_4765 (EIF_REFERENCE Current)
+void F845_4825 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -816,8 +554,6 @@ void F567_4765 (EIF_REFERENCE Current)
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
 	EIF_INTEGER_32 ti4_4;
-	EIF_INTEGER_32 ti4_5;
-	EIF_INTEGER_32 ti4_6;
 	RTLD;
 	
 	RTLI(2);
@@ -826,110 +562,25 @@ void F567_4765 (EIF_REFERENCE Current)
 	RTLIU(2);
 	
 	RTGC;
-	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) < F567_4732(Current))) {
+	if ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) < F845_4792(Current))) {
 		tr1 = *(EIF_REFERENCE *)(Current);
 		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-		ti4_3 = F567_4732(Current);
+		ti4_3 = F845_4792(Current);
 		ti4_4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 		/* INLINED CODE (SPECIAL.overlapping_move) */
-		memmove((EIF_POINTER *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L))),(EIF_POINTER *)RTCW(tr1) + ti4_1, (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)(EIF_INTEGER_32) (ti4_3 - ti4_4));
+		memmove((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L))),(EIF_INTEGER_32 *)RTCW(tr1) + ti4_1, (rt_uint_ptr)sizeof(EIF_INTEGER_32) * (rt_uint_ptr)(EIF_INTEGER_32) (ti4_3 - ti4_4));
 		RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L)) + (EIF_INTEGER_32) (ti4_3 - ti4_4));
 		/* END INLINED CODE */
 		;
 	}
 	tr1 = *(EIF_REFERENCE *)(Current);
-	F628_5250(RTCW(tr1), ((EIF_INTEGER_32) 1L));
-	RTLE;
-}
-
-/* {ARRAYED_LIST}.prune_all */
-void F567_4766 (EIF_REFERENCE Current, EIF_POINTER arg1)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
-	EIF_BOOLEAN loc5 = (EIF_BOOLEAN) 0;
-	EIF_REFERENCE loc6 = (EIF_REFERENCE) 0;
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,loc6);
-	RTLIU(2);
-	
-	RTGC;
-	loc5 = *(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_);
-	loc6 = *(EIF_REFERENCE *)(Current);
-	loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-	loc2 = F567_4732(Current);
-	for (;;) {
-		if ((EIF_BOOLEAN)(loc1 == F567_4732(Current))) break;
-		if ((EIF_BOOLEAN) (loc1 < (EIF_INTEGER_32) (loc2 - loc3))) {
-			if ((EIF_BOOLEAN) (loc3 > ((EIF_INTEGER_32) 0L))) {
-				/* INLINED CODE (SPECIAL.item) */
-				tp2 = *((EIF_POINTER *)RTCW(loc6) + ((EIF_INTEGER_32) (loc1 + loc3)));
-				/* END INLINED CODE */
-				tp1 = tp2;
-				/* INLINED CODE (SPECIAL.put) */
-				*((EIF_POINTER *)RTCW(loc6) + (loc1)) = tp1;
-				/* END INLINED CODE */
-				;
-			}
-			if (loc5) {
-				/* INLINED CODE (SPECIAL.item) */
-				tp2 = *((EIF_POINTER *)RTCW(loc6) + (loc1));
-				/* END INLINED CODE */
-				tp1 = tp2;
-				loc4 = (EIF_BOOLEAN) (arg1 == tp1);
-			} else {
-				/* INLINED CODE (SPECIAL.item) */
-				tp2 = *((EIF_POINTER *)RTCW(loc6) + (loc1));
-				/* END INLINED CODE */
-				tp1 = tp2;
-				loc4 = (EIF_BOOLEAN) (EIF_BOOLEAN)(arg1 == tp1);
-			}
-			if (loc4) {
-				loc3++;
-			} else {
-				loc1++;
-			}
-		} else {
-			loc1++;
-		}
-	}
-	F628_5250(RTCW(loc6), loc3);
-	ti4_1 = F567_4732(Current);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L));
-	RTLE;
-}
-
-/* {ARRAYED_LIST}.wipe_out */
-void F567_4769 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	tr1 = *(EIF_REFERENCE *)(Current);
-	F628_5256(RTCW(tr1));
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
+	F749_4524(RTCW(tr1), ((EIF_INTEGER_32) 1L));
 	RTLE;
 }
 
 /* {ARRAYED_LIST}.correct_mismatch */
-void F567_4771 (EIF_REFERENCE Current)
+void F845_4832 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -937,11 +588,11 @@ void F567_4771 (EIF_REFERENCE Current)
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
 	EIF_BOOLEAN loc4 = (EIF_BOOLEAN) 0;
 	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_REFERENCE tr3 = NULL;
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
 	EIF_BOOLEAN tb3;
@@ -963,22 +614,22 @@ void F567_4771 (EIF_REFERENCE Current)
 	tb2 = '\0';
 	tb3 = '\0';
 	tb4 = '\0';
-	tr1 = RTOUCR(3,F556_4547,(Current));
+	tr1 = RTOSCF(4738,F842_4738, (Current));
 	tr2 = RTMS_EX_H("area_v2",7,1288217906);
-	tb5 = F558_4587(RTCW(tr1), tr2);
+	tb5 = F856_4845(RTCW(tr1), tr2);
 	if ((EIF_BOOLEAN) !tb5) {
-		tr1 = RTOUCR(3,F556_4547,(Current));
+		tr1 = RTOSCF(4738,F842_4738, (Current));
 		tr2 = RTMS_EX_H("area",4,1634887009);
-		tr1 = F558_4585(RTCW(tr1), tr2);
+		tr1 = F856_4843(RTCW(tr1), tr2);
 		loc2 = RTCCL(tr1);
 		{
-			EIF_TYPE_INDEX typarr0[] = {627,0,0,0xFFFF};
+			static EIF_TYPE_INDEX typarr0[] = {0xFF01,748,0,0,0xFFFF};
 			EIF_TYPE typres0;
 			{
 				EIF_TYPE l_type;
-				l_type = eif_final_id(Y3659,Y3659_gen_type,dftype,226);
-				typarr0[1] = l_type.annotations | 0xFF00;
-				typarr0[2] = l_type.id;
+				l_type = eif_final_id(Y2621,Y2621_gen_type,dftype,290);
+				typarr0[2] = l_type.annotations | 0xFF00;
+				typarr0[3] = l_type.id;
 			}
 			
 			typres0 = eif_compound_id(dftype, typarr0);
@@ -987,31 +638,31 @@ void F567_4771 (EIF_REFERENCE Current)
 		tb4 = EIF_TEST(loc2);
 	}
 	if (tb4) {
-		tr2 = RTOUCR(3,F556_4547,(Current));
+		tr2 = RTOSCF(4738,F842_4738, (Current));
 		tr3 = RTMS_EX_H("count",5,1870727284);
-		tr2 = F558_4585(RTCW(tr2), tr3);
+		tr2 = F856_4843(RTCW(tr2), tr3);
 		tr1 = RTCCL(tr2);
-		RTOB(*(EIF_INTEGER_32 *), eif_new_type(877, 0x00), tr1, loc3, tb4);
+		RTOB(*(EIF_INTEGER_32 *), eif_new_type(908, 0x00), tr1, loc3, tb4);
 		tb3 = tb4;
 	}
 	if (tb3) {
-		tr2 = RTOUCR(3,F556_4547,(Current));
+		tr2 = RTOSCF(4738,F842_4738, (Current));
 		tr3 = RTMS_EX_H("object_comparison",17,2049833582);
-		tr2 = F558_4585(RTCW(tr2), tr3);
+		tr2 = F856_4843(RTCW(tr2), tr3);
 		tr1 = RTCCL(tr2);
-		RTOB(*(EIF_BOOLEAN *), eif_new_type(910, 0x00), tr1, loc4, tb3);
+		RTOB(*(EIF_BOOLEAN *), eif_new_type(941, 0x00), tr1, loc4, tb3);
 		tb2 = tb3;
 	}
 	if (tb2) {
-		tr2 = RTOUCR(3,F556_4547,(Current));
+		tr2 = RTOSCF(4738,F842_4738, (Current));
 		tr3 = RTMS_EX_H("index",5,1852879736);
-		tr2 = F558_4585(RTCW(tr2), tr3);
+		tr2 = F856_4843(RTCW(tr2), tr3);
 		tr1 = RTCCL(tr2);
-		RTOB(*(EIF_INTEGER_32 *), eif_new_type(877, 0x00), tr1, loc5, tb2);
+		RTOB(*(EIF_INTEGER_32 *), eif_new_type(908, 0x00), tr1, loc5, tb2);
 		tb1 = tb2;
 	}
 	if (tb1) {
-		tr1 = RTLNSP2(eif_final_id(Y3653,Y3653_gen_type,dftype,226).id,0,loc3,sizeof(EIF_POINTER), EIF_TRUE);
+		tr1 = RTLNSP2(eif_final_id(Y2615,Y2615_gen_type,dftype,290).id,0,loc3,sizeof(EIF_INTEGER_32), EIF_TRUE);
 		RT_SPECIAL_COUNT(tr1) = 0;
 		RTAR(Current, tr1);
 		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -1020,52 +671,20 @@ void F567_4771 (EIF_REFERENCE Current)
 			if ((EIF_BOOLEAN)(loc1 == loc3)) break;
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.item) */
-			tp2 = *((EIF_POINTER *)loc2 + (loc1));
+			ti4_2 = *((EIF_INTEGER_32 *)loc2 + (loc1));
 			/* END INLINED CODE */
-			tp1 = tp2;
-			F628_5238(RTCW(tr1), tp1);
+			ti4_1 = ti4_2;
+			F749_4512(RTCW(tr1), ti4_1);
 			loc1++;
 		}
 		*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) = (EIF_BOOLEAN) loc4;
 		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc5;
 	} else {
-		F556_4546(Current);
+		F842_4737(Current);
 	}
 	RTLE;
 }
 
-/* {ARRAYED_LIST}.insert */
-void F567_4774 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if ((EIF_BOOLEAN) ((EIF_INTEGER_32) (F567_4732(Current) + ((EIF_INTEGER_32) 1L)) > F567_4733(Current))) {
-		ti4_1 = F567_4732(Current);
-		ti4_2 = F418_4217(Current);
-		F567_4759(Current, (EIF_INTEGER_32) (ti4_1 + ti4_2));
-	}
-	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = F567_4732(Current);
-	/* INLINED CODE (SPECIAL.overlapping_move) */
-	memmove((EIF_POINTER *)RTCW(tr1) + (arg2),(EIF_POINTER *)RTCW(tr1) + (EIF_INTEGER_32) (arg2 - ((EIF_INTEGER_32) 1L)), (rt_uint_ptr)sizeof(EIF_POINTER) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_1 - arg2) + ((EIF_INTEGER_32) 1L)));
-	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), arg2 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_1 - arg2) + ((EIF_INTEGER_32) 1L)));
-	/* END INLINED CODE */
-	;
-	F567_4750(Current, arg1, arg2);
-	RTLE;
-}
-
 void EIF_Minit715 (void)
 {
 	GTCX
