@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAY [BOOLEAN]
+ * Code for class ARRAY [NATURAL_8]
  */
 
 #include "eif_eiffel.h"
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {ARRAY}.make_empty */
-void F793_5917 (EIF_REFERENCE Current)
+void F728_5631 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTLD;
@@ -37,12 +37,12 @@ void F793_5917 (EIF_REFERENCE Current)
 	RTGC;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-	F370_4546(Current, ((EIF_INTEGER_32) 0L));
+	F305_4320(Current, ((EIF_INTEGER_32) 0L));
 	RTLE;
 }
 
 /* {ARRAY}.make_filled */
-void F793_5918 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F728_5632 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -58,16 +58,16 @@ void F793_5918 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2, EI
 	if ((EIF_BOOLEAN) (arg2 <= arg3)) {
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L));
 	}
-	F370_4547(Current, arg1, loc1);
+	F305_4321(Current, arg1, loc1);
 	RTLE;
 }
 
 /* {ARRAY}.make */
-void F793_5919 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F728_5633 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_BOOLEAN tb1;
+	EIF_NATURAL_8 tu1_1;
 	RTLD;
 	
 	RTLI(2);
@@ -79,17 +79,17 @@ void F793_5919 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg1;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg2;
 	if ((EIF_BOOLEAN) (arg1 <= arg2)) {
-		tr1 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,Dftype(Current),425), 0x00);
-		tb1 = F1052_8429(tr1);
-		F370_4547(Current, tb1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
+		tr1 = RTLNTY2(eif_final_id(Y4392,Y4392_gen_type,Dftype(Current),372), 0x00);
+		tu1_1 = F948_7426(tr1);
+		F305_4321(Current, tu1_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
 	} else {
-		F370_4546(Current, ((EIF_INTEGER_32) 0L));
+		F305_4320(Current, ((EIF_INTEGER_32) 0L));
 	}
 	RTLE;
 }
 
 /* {ARRAY}.make_from_special */
-void F793_5921 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F728_5635 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -101,22 +101,22 @@ void F793_5921 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F370_4553(Current, arg1);
+	F305_4327(Current, arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
 	RTLE;
 }
 
 /* {ARRAY}.item */
-EIF_BOOLEAN F793_5923 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_NATURAL_8 F728_5637 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
+	EIF_NATURAL_8 tu1_1;
+	EIF_NATURAL_8 tu1_2;
+	EIF_NATURAL_8 Result = ((EIF_NATURAL_8) 0);
 	
 	RTLD;
 	
@@ -128,64 +128,15 @@ EIF_BOOLEAN F793_5923 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.item) */
-	tb2 = *((EIF_BOOLEAN *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
+	tu1_2 = *((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
 	/* END INLINED CODE */
-	Result = tb2;
-	RTLE;
-	return Result;
-}
-
-/* {ARRAY}.has */
-EIF_BOOLEAN F793_5926 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
-	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN tb1;
-	EIF_BOOLEAN tb2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,loc3);
-	RTLR(1,Current);
-	RTLIU(2);
-	
-	RTGC;
-	loc3 = *(EIF_REFERENCE *)(Current);
-	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ti4_1);
-	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) && EIF_TRUE)) {
-		for (;;) {
-			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || Result)) break;
-			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)RTCW(loc3) + (loc1));
-			/* END INLINED CODE */
-			Result = tb2;
-			Result = (EIF_BOOLEAN) (Result == arg1);
-			loc1++;
-		}
-	} else {
-		for (;;) {
-			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || Result)) break;
-			/* INLINED CODE (SPECIAL.item) */
-			tb2 = *((EIF_BOOLEAN *)RTCW(loc3) + (loc1));
-			/* END INLINED CODE */
-			Result = tb2;
-			Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(Result == arg1);
-			loc1++;
-		}
-	}
+	Result = tu1_2;
 	RTLE;
 	return Result;
 }
 
 /* {ARRAY}.new_cursor */
-EIF_REFERENCE F793_5927 (EIF_REFERENCE Current)
+EIF_REFERENCE F728_5641 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -198,39 +149,39 @@ EIF_REFERENCE F793_5927 (EIF_REFERENCE Current)
 	
 	RTGC;
 	{
-		static EIF_TYPE_INDEX typarr0[] = {514,0,0,0xFFFF};
+		static EIF_TYPE_INDEX typarr0[] = {0xFF01,465,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y4602,Y4602_gen_type,Dftype(Current),425);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
+			l_type = eif_final_id(Y4392,Y4392_gen_type,Dftype(Current),372);
+			typarr0[2] = l_type.annotations | 0xFF00;
+			typarr0[3] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 514, _OBJSIZ_2_0_0_3_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 465, _OBJSIZ_2_0_0_3_0_0_0_0_);
 	}
-	F515_5161(RTCW(tr1), Current);
+	F466_5419(RTCW(tr1), Current);
 	RTLE;
 	return (EIF_REFERENCE) tr1;
 }
 
 /* {ARRAY}.lower */
-EIF_INTEGER_32 F793_5928 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F728_5642 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 }
 
 
 /* {ARRAY}.upper */
-EIF_INTEGER_32 F793_5929 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F728_5643 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 }
 
 
 /* {ARRAY}.count */
-EIF_INTEGER_32 F793_5930 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F728_5644 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -239,7 +190,7 @@ EIF_INTEGER_32 F793_5930 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.capacity */
-EIF_INTEGER_32 F793_5931 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F728_5645 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -248,13 +199,15 @@ EIF_INTEGER_32 F793_5931 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.is_equal */
-EIF_BOOLEAN F793_5933 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F728_5647 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
+	EIF_NATURAL_8 tu1_1;
+	EIF_NATURAL_8 tu1_2;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -290,16 +243,16 @@ EIF_BOOLEAN F793_5933 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 				loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 				for (;;) {
 					if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !Result || (EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)))) break;
-					Result = F793_5923(Current, loc1);
-					tb1 = F793_5923(RTCW(arg1), loc1);
-					Result = (EIF_BOOLEAN) (Result == tb1);
+					tu1_1 = F728_5637(Current, loc1);
+					tu1_2 = F728_5637(RTCW(arg1), loc1);
+					Result = (EIF_BOOLEAN) (tu1_1 == tu1_2);
 					loc1++;
 				}
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-				ti4_1 = F793_5930(Current);
-				Result = F1094_8462(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
+				ti4_1 = F728_5644(Current);
+				Result = F881_7208(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
 			}
 		}
 	}
@@ -308,32 +261,16 @@ EIF_BOOLEAN F793_5933 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {ARRAY}.valid_index */
-EIF_BOOLEAN F793_5938 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	
-	
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 <= arg1) && (EIF_BOOLEAN) (arg1 <= ti4_2));
-	return Result;
-}
-
-/* {ARRAY}.extendible */
-EIF_BOOLEAN F793_5939 (EIF_REFERENCE Current)
+EIF_BOOLEAN F728_5652 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) <= arg1) && (EIF_BOOLEAN) (arg1 <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)));
 }
 
 /* {ARRAY}.put */
-void F793_5942 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F728_5656 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -348,14 +285,14 @@ void F793_5942 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.put) */
-	*((EIF_BOOLEAN *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
+	*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
 /* {ARRAY}.force */
-void F793_5944 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F728_5658 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -369,7 +306,7 @@ void F793_5944 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN tb1;
+	EIF_NATURAL_8 tu1_1;
 	RTCFDT;
 	RTLD;
 	
@@ -388,84 +325,84 @@ void F793_5944 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 	loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))) || (EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L))));
-	if (F793_5975(Current)) {
-		ti4_1 = F626_5233(Current);
+	if (F728_5689(Current)) {
+		ti4_1 = F660_5562(Current);
 		ti4_1 = eif_max_int32 (loc2,ti4_1);
-		F370_4546(Current, ti4_1);
+		F305_4320(Current, ti4_1);
 		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
 			tr1 = *(EIF_REFERENCE *)(Current);
-			F1094_8466(RTCW(tr1), arg1);
+			F881_7212(RTCW(tr1), arg1);
 			if ((EIF_BOOLEAN) !loc7) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,dftype,425), 0x00);
-				tb1 = F1052_8429(tr2);
-				F1094_8468(RTCW(tr1), tb1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
+				tr2 = RTLNTY2(eif_final_id(Y4392,Y4392_gen_type,dftype,372), 0x00);
+				tu1_1 = F948_7426(tr2);
+				F881_7214(RTCW(tr1), tu1_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
 			}
 		} else {
 			if ((EIF_BOOLEAN) !loc7) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,dftype,425), 0x00);
-				tb1 = F1052_8429(tr2);
-				F1094_8468(RTCW(tr1), tb1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+				tr2 = RTLNTY2(eif_final_id(Y4392,Y4392_gen_type,dftype,372), 0x00);
+				tu1_1 = F948_7426(tr2);
+				F881_7214(RTCW(tr1), tu1_1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
 			}
 			tr1 = *(EIF_REFERENCE *)(Current);
-			F1094_8466(RTCW(tr1), arg1);
+			F881_7212(RTCW(tr1), arg1);
 		}
 	} else {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+		loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 		if ((EIF_BOOLEAN) (loc2 > loc1)) {
 			tr1 = *(EIF_REFERENCE *)(Current);
-			ti4_1 = F626_5233(Current);
+			ti4_1 = F660_5562(Current);
 			ti4_1 = eif_max_int32 (loc2,(EIF_INTEGER_32) (loc1 + ti4_1));
-			tr1 = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (tr1, ti4_1);
-			F370_4553(Current, tr1);
+			tr1 = F881_7227(tr1, ti4_1);
+			F305_4327(Current, tr1);
 		}
 		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
 			loc6 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 			loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc6 - loc3);
-			loc5 = F793_5931(Current);
+			loc5 = F728_5645(Current);
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !loc7 && (EIF_BOOLEAN) (loc6 > loc5))) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,dftype,425), 0x00);
-				tb1 = F1052_8429(tr2);
-				F1094_8468(RTCW(tr1), tb1, loc5, (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+				tr2 = RTLNTY2(eif_final_id(Y4392,Y4392_gen_type,dftype,372), 0x00);
+				tu1_1 = F948_7426(tr2);
+				F881_7214(RTCW(tr1), tu1_1, loc5, (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
 			}
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.overlapping_move) */
-			memmove((EIF_BOOLEAN *)RTCW(tr1) + (loc6),(EIF_BOOLEAN *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)loc5);
+			memmove((EIF_NATURAL_8 *)RTCW(tr1) + (loc6),(EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)loc5);
 			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc6 + loc5);
 			/* END INLINED CODE */
 			;
 			if ((EIF_BOOLEAN) !loc7) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,dftype,425), 0x00);
-				tb1 = F1052_8429(tr2);
-				F1094_8468(RTCW(tr1), tb1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+				tr2 = RTLNTY2(eif_final_id(Y4392,Y4392_gen_type,dftype,372), 0x00);
+				tu1_1 = F948_7426(tr2);
+				F881_7214(RTCW(tr1), tu1_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
 			}
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.put) */
-			*((EIF_BOOLEAN *)RTCW(tr1) + (((EIF_INTEGER_32) 0L))) = arg1;
+			*((EIF_NATURAL_8 *)RTCW(tr1) + (((EIF_INTEGER_32) 0L))) = arg1;
 			/* END INLINED CODE */
 			;
 		} else {
 			tr1 = *(EIF_REFERENCE *)(Current);
-			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 			if ((EIF_BOOLEAN) (loc2 > ti4_1)) {
 				if ((EIF_BOOLEAN) !loc7) {
 					tr1 = *(EIF_REFERENCE *)(Current);
-					tr2 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,dftype,425), 0x00);
-					tb1 = F1052_8429(tr2);
+					tr2 = RTLNTY2(eif_final_id(Y4392,Y4392_gen_type,dftype,372), 0x00);
+					tu1_1 = F948_7426(tr2);
 					tr2 = *(EIF_REFERENCE *)(Current);
-					ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr2);
-					F1094_8468(RTCW(tr1), tb1, ti4_1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+					ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr2);
+					F881_7214(RTCW(tr1), tu1_1, ti4_1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
 				}
 				tr1 = *(EIF_REFERENCE *)(Current);
-				F1094_8466(RTCW(tr1), arg1);
+				F881_7212(RTCW(tr1), arg1);
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				/* INLINED CODE (SPECIAL.put) */
-				*((EIF_BOOLEAN *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
+				*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 				/* END INLINED CODE */
 				;
 			}
@@ -477,7 +414,7 @@ void F793_5944 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 }
 
 /* {ARRAY}.subcopy */
-void F793_5947 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+void F728_5661 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -488,7 +425,7 @@ void F793_5947 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	EIF_INTEGER_32 ti4_4;
 	EIF_INTEGER_32 ti4_5;
 	EIF_INTEGER_32 ti4_6;
-	EIF_BOOLEAN tb1;
+	EIF_NATURAL_8 tu1_1;
 	RTLD;
 	
 	RTLI(4);
@@ -503,139 +440,15 @@ void F793_5947 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
 	/* INLINED CODE (SPECIAL.copy_data) */
-	memmove((EIF_BOOLEAN *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_BOOLEAN *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	memmove((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_NATURAL_8 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
-/* {ARRAY}.grow */
-void F793_5961 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_BOOLEAN tb1;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if ((EIF_BOOLEAN) (arg1 > F793_5931(Current))) {
-		tr1 = RTLNTY2(eif_final_id(Y4602,Y4602_gen_type,Dftype(Current),425), 0x00);
-		tb1 = F1052_8429(tr1);
-		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-		ti4_3 = F793_5931(Current);
-		F793_5963(Current, tb1, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_2 + arg1) - ti4_3));
-	}
-	RTLE;
-}
-
-/* {ARRAY}.conservative_resize_with_default */
-void F793_5963 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if (F793_5975(Current)) {
-		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = F1094_8482(RTCW(tr1), arg1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
-		F370_4553(Current, tr1);
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg3;
-	} else {
-		loc2 = eif_min_int32 (arg2,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_));
-		loc3 = eif_max_int32 (arg3,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
-		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 - loc2) + ((EIF_INTEGER_32) 1L));
-		tr1 = *(EIF_REFERENCE *)(Current);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
-		if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
-			tr1 = *(EIF_REFERENCE *)(Current);
-			tr1 = F1094_8482(RTCW(tr1), arg1, loc1);
-			F370_4553(Current, tr1);
-		}
-		if ((EIF_BOOLEAN) (loc2 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
-			loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-			loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - loc2);
-			tr1 = *(EIF_REFERENCE *)(Current);
-			/* INLINED CODE (SPECIAL.overlapping_move) */
-			memmove((EIF_BOOLEAN *)RTCW(tr1) + (loc4),(EIF_BOOLEAN *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_BOOLEAN) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
-			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc4 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
-			/* END INLINED CODE */
-			;
-			tr1 = *(EIF_REFERENCE *)(Current);
-			F1094_8468(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc4 - ((EIF_INTEGER_32) 1L)));
-		}
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc3;
-	}
-	RTLE;
-}
-
-/* {ARRAY}.linear_representation */
-EIF_REFERENCE F793_5970 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN tb1;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,loc1);
-	RTLR(1,Current);
-	RTLIU(2);
-	
-	RTGC;
-	{
-		static EIF_TYPE_INDEX typarr0[] = {861,0,0,0xFFFF};
-		EIF_TYPE typres0;
-		{
-			EIF_TYPE l_type;
-			l_type = eif_final_id(Y4602,Y4602_gen_type,Dftype(Current),425);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
-		}
-		
-		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		loc1 = RTLNS(typres0.id, 861, _OBJSIZ_1_1_0_1_0_0_0_0_);
-	}
-	ti4_1 = F793_5931(Current);
-	F862_6107(RTCW(loc1), ti4_1);
-	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	for (;;) {
-		if ((EIF_BOOLEAN) (loc2 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))) break;
-		tb1 = F793_5923(Current, loc2);
-		F862_6148(RTCW(loc1), tb1);
-		loc2++;
-	}
-	RTLE;
-	return (EIF_REFERENCE) loc1;
-}
-
 /* {ARRAY}.copy */
-void F793_5971 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F728_5685 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -649,25 +462,16 @@ void F793_5971 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
-		eif_builtin_ANY_standard_copy (Current, arg1);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
-		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
-		F370_4553(Current, tr1);
+		tr1 = F1_14(tr1);
+		F305_4327(Current, tr1);
 	}
 	RTLE;
 }
 
-/* {ARRAY}.extend */
-void F793_5974 (EIF_REFERENCE Current, EIF_BOOLEAN arg1)
-{
-	GTCX
-	
-	
-	RTGC;
-}
-
 /* {ARRAY}.empty_area */
-EIF_BOOLEAN F793_5975 (EIF_REFERENCE Current)
+EIF_BOOLEAN F728_5689 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -683,7 +487,7 @@ EIF_BOOLEAN F793_5975 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
 	RTLE;
 	return Result;
