@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAY [NATURAL_8]
+ * Code for class ARRAY [NATURAL_32]
  */
 
 #include "eif_eiffel.h"
@@ -24,25 +24,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ARRAY}.make_empty */
-void F641_3184 (EIF_REFERENCE Current)
-{
-	GTCX
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-	F209_1997(Current, ((EIF_INTEGER_32) 0L));
-	RTLE;
-}
-
 /* {ARRAY}.make_filled */
-void F641_3185 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F640_3128 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -58,16 +41,16 @@ void F641_3185 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2,
 	if ((EIF_BOOLEAN) (arg2 <= arg3)) {
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L));
 	}
-	F209_1998(Current, arg1, loc1);
+	F187_1858(Current, arg1, loc1);
 	RTLE;
 }
 
 /* {ARRAY}.make */
-void F641_3186 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F640_3129 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_NATURAL_8 tu1_1;
+	EIF_NATURAL_32 tu4_1;
 	RTLD;
 	
 	RTLI(2);
@@ -79,41 +62,17 @@ void F641_3186 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg1;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg2;
 	if ((EIF_BOOLEAN) (arg1 <= arg2)) {
-		tr1 = RTLNTY2(eif_final_id(Y2272,Y2272_gen_type,Dftype(Current),294), 0x00);
-		tu1_1 = F735_3674(tr1);
-		F209_1998(Current, tu1_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
+		tr1 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,Dftype(Current),273), 0x00);
+		tu4_1 = F763_3884(tr1);
+		F187_1858(Current, tu4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
 	} else {
-		F209_1997(Current, ((EIF_INTEGER_32) 0L));
+		F187_1857(Current, ((EIF_INTEGER_32) 0L));
 	}
 	RTLE;
 }
 
-/* {ARRAY}.make_from_array */
-void F641_3187 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(3);
-	RTLR(0,arg1);
-	RTLR(1,tr1);
-	RTLR(2,Current);
-	RTLIU(3);
-	
-	RTGC;
-	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
-	F209_2004(Current, tr1);
-	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ti4_1;
-	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
-	RTLE;
-}
-
 /* {ARRAY}.make_from_special */
-void F641_3188 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F640_3131 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -125,22 +84,22 @@ void F641_3188 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F209_2004(Current, arg1);
+	F187_1864(Current, arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
 	RTLE;
 }
 
 /* {ARRAY}.item */
-EIF_NATURAL_8 F641_3190 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_NATURAL_32 F640_3133 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_NATURAL_8 tu1_1;
-	EIF_NATURAL_8 tu1_2;
-	EIF_NATURAL_8 Result = ((EIF_NATURAL_8) 0);
+	EIF_NATURAL_32 tu4_1;
+	EIF_NATURAL_32 tu4_2;
+	EIF_NATURAL_32 Result = ((EIF_NATURAL_32) 0);
 	
 	RTLD;
 	
@@ -152,29 +111,29 @@ EIF_NATURAL_8 F641_3190 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.item) */
-	tu1_2 = *((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
+	tu4_2 = *((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
 	/* END INLINED CODE */
-	Result = tu1_2;
+	Result = tu4_2;
 	RTLE;
 	return Result;
 }
 
 /* {ARRAY}.lower */
-EIF_INTEGER_32 F641_3195 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F640_3138 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 }
 
 
 /* {ARRAY}.upper */
-EIF_INTEGER_32 F641_3196 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F640_3139 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 }
 
 
 /* {ARRAY}.count */
-EIF_INTEGER_32 F641_3197 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F640_3140 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -183,7 +142,7 @@ EIF_INTEGER_32 F641_3197 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.capacity */
-EIF_INTEGER_32 F641_3198 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F640_3141 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -192,15 +151,15 @@ EIF_INTEGER_32 F641_3198 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.is_equal */
-EIF_BOOLEAN F641_3200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F640_3143 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_NATURAL_8 tu1_1;
-	EIF_NATURAL_8 tu1_2;
+	EIF_NATURAL_32 tu4_1;
+	EIF_NATURAL_32 tu4_2;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
@@ -236,16 +195,16 @@ EIF_BOOLEAN F641_3200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 				loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 				for (;;) {
 					if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !Result || (EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)))) break;
-					tu1_1 = F641_3190(Current, loc1);
-					tu1_2 = F641_3190(RTCW(arg1), loc1);
-					Result = (EIF_BOOLEAN) (tu1_1 == tu1_2);
+					tu4_1 = F640_3133(Current, loc1);
+					tu4_2 = F640_3133(RTCW(arg1), loc1);
+					Result = (EIF_BOOLEAN) (tu4_1 == tu4_2);
 					loc1++;
 				}
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-				ti4_1 = F641_3197(Current);
-				Result = F616_3112(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
+				ti4_1 = F640_3140(Current);
+				Result = F615_3055(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
 			}
 		}
 	}
@@ -254,23 +213,16 @@ EIF_BOOLEAN F641_3200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {ARRAY}.valid_index */
-EIF_BOOLEAN F641_3205 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F640_3148 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
-	
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 <= arg1) && (EIF_BOOLEAN) (arg1 <= ti4_2));
-	return Result;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) <= arg1) && (EIF_BOOLEAN) (arg1 <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)));
 }
 
 /* {ARRAY}.put */
-void F641_3209 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
+void F640_3152 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -285,14 +237,136 @@ void F641_3209 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.put) */
-	*((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
+	*((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
+/* {ARRAY}.force */
+void F640_3154 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
+{
+	GTCX
+	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
+	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
+	EIF_REFERENCE tr1 = NULL;
+	EIF_REFERENCE tr2 = NULL;
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
+	EIF_NATURAL_32 tu4_1;
+	RTCFDT;
+	RTLD;
+	
+	RTLI(3);
+	RTLR(0,Current);
+	RTLR(1,tr1);
+	RTLR(2,tr2);
+	RTLIU(3);
+	
+	RTGC;
+	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
+	loc3 = eif_min_int32 (ti4_1,arg2);
+	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
+	loc4 = eif_max_int32 (ti4_1,arg2);
+	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc4 - loc3) + ((EIF_INTEGER_32) 1L));
+	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
+	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
+	loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))) || (EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L))));
+	if (F640_3185(Current)) {
+		ti4_1 = F564_2675(Current);
+		ti4_1 = eif_max_int32 (loc2,ti4_1);
+		F187_1857(Current, ti4_1);
+		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
+			tr1 = *(EIF_REFERENCE *)(Current);
+			F615_3059(RTCW(tr1), arg1);
+			if ((EIF_BOOLEAN) !loc7) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tu4_1 = F763_3884(tr2);
+				F615_3061(RTCW(tr1), tu4_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
+			}
+		} else {
+			if ((EIF_BOOLEAN) !loc7) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tu4_1 = F763_3884(tr2);
+				F615_3061(RTCW(tr1), tu4_1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+			}
+			tr1 = *(EIF_REFERENCE *)(Current);
+			F615_3059(RTCW(tr1), arg1);
+		}
+	} else {
+		tr1 = *(EIF_REFERENCE *)(Current);
+		loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
+		if ((EIF_BOOLEAN) (loc2 > loc1)) {
+			tr1 = *(EIF_REFERENCE *)(Current);
+			ti4_1 = F564_2675(Current);
+			ti4_1 = eif_max_int32 (loc2,(EIF_INTEGER_32) (loc1 + ti4_1));
+			tr1 = F615_3074(tr1, ti4_1);
+			F187_1864(Current, tr1);
+		}
+		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
+			loc6 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
+			loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc6 - loc3);
+			loc5 = F640_3141(Current);
+			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !loc7 && (EIF_BOOLEAN) (loc6 > loc5))) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tu4_1 = F763_3884(tr2);
+				F615_3061(RTCW(tr1), tu4_1, loc5, (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+			}
+			tr1 = *(EIF_REFERENCE *)(Current);
+			/* INLINED CODE (SPECIAL.overlapping_move) */
+			memmove((EIF_NATURAL_32 *)RTCW(tr1) + (loc6),(EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)loc5);
+			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc6 + loc5);
+			/* END INLINED CODE */
+			;
+			if ((EIF_BOOLEAN) !loc7) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tu4_1 = F763_3884(tr2);
+				F615_3061(RTCW(tr1), tu4_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+			}
+			tr1 = *(EIF_REFERENCE *)(Current);
+			/* INLINED CODE (SPECIAL.put) */
+			*((EIF_NATURAL_32 *)RTCW(tr1) + (((EIF_INTEGER_32) 0L))) = arg1;
+			/* END INLINED CODE */
+			;
+		} else {
+			tr1 = *(EIF_REFERENCE *)(Current);
+			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
+			if ((EIF_BOOLEAN) (loc2 > ti4_1)) {
+				if ((EIF_BOOLEAN) !loc7) {
+					tr1 = *(EIF_REFERENCE *)(Current);
+					tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+					tu4_1 = F763_3884(tr2);
+					tr2 = *(EIF_REFERENCE *)(Current);
+					ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr2);
+					F615_3061(RTCW(tr1), tu4_1, ti4_1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+				}
+				tr1 = *(EIF_REFERENCE *)(Current);
+				F615_3059(RTCW(tr1), arg1);
+			} else {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				/* INLINED CODE (SPECIAL.put) */
+				*((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
+				/* END INLINED CODE */
+				;
+			}
+		}
+	}
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc3;
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc4;
+	RTLE;
+}
+
 /* {ARRAY}.subcopy */
-void F641_3214 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+void F640_3157 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -303,7 +377,7 @@ void F641_3214 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	EIF_INTEGER_32 ti4_4;
 	EIF_INTEGER_32 ti4_5;
 	EIF_INTEGER_32 ti4_6;
-	EIF_NATURAL_8 tu1_1;
+	EIF_NATURAL_32 tu4_1;
 	RTLD;
 	
 	RTLI(4);
@@ -318,69 +392,15 @@ void F641_3214 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
 	/* INLINED CODE (SPECIAL.copy_data) */
-	memmove((EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_NATURAL_8 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	memmove((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_NATURAL_32 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
-/* {ARRAY}.conservative_resize_with_default */
-void F641_3230 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if (F641_3242(Current)) {
-		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = F616_3132(RTCW(tr1), arg1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
-		F209_2004(Current, tr1);
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg3;
-	} else {
-		loc2 = eif_min_int32 (arg2,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_));
-		loc3 = eif_max_int32 (arg3,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
-		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 - loc2) + ((EIF_INTEGER_32) 1L));
-		tr1 = *(EIF_REFERENCE *)(Current);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
-		if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
-			tr1 = *(EIF_REFERENCE *)(Current);
-			tr1 = F616_3132(RTCW(tr1), arg1, loc1);
-			F209_2004(Current, tr1);
-		}
-		if ((EIF_BOOLEAN) (loc2 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
-			loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-			loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - loc2);
-			tr1 = *(EIF_REFERENCE *)(Current);
-			/* INLINED CODE (SPECIAL.overlapping_move) */
-			memmove((EIF_NATURAL_8 *)RTCW(tr1) + (loc4),(EIF_NATURAL_8 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_8) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
-			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc4 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
-			/* END INLINED CODE */
-			;
-			tr1 = *(EIF_REFERENCE *)(Current);
-			F616_3118(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc4 - ((EIF_INTEGER_32) 1L)));
-		}
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc3;
-	}
-	RTLE;
-}
-
 /* {ARRAY}.copy */
-void F641_3238 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F640_3181 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -394,16 +414,16 @@ void F641_3238 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
-		eif_builtin_ANY_standard_copy (Current, arg1);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
 		tr1 = F1_14(tr1);
-		F209_2004(Current, tr1);
+		F187_1864(Current, tr1);
 	}
 	RTLE;
 }
 
 /* {ARRAY}.empty_area */
-EIF_BOOLEAN F641_3242 (EIF_REFERENCE Current)
+EIF_BOOLEAN F640_3185 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -419,7 +439,7 @@ EIF_BOOLEAN F641_3242 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
 	RTLE;
 	return Result;
