@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_NATURAL_64 F141_2789(EIF_REFERENCE);
-extern void F141_2790(EIF_REFERENCE, EIF_NATURAL_64);
-extern void F141_2791(EIF_REFERENCE, EIF_NATURAL_64);
+extern EIF_INTEGER_32 F104_1249(EIF_REFERENCE);
+extern void F104_1250(EIF_REFERENCE, EIF_INTEGER_32);
 extern void EIF_Minit700(void);
 
 #ifdef __cplusplus
