@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_NATURAL_64 F56_721(EIF_REFERENCE);
-extern void F56_722(EIF_REFERENCE, EIF_NATURAL_64);
+extern EIF_REFERENCE F103_1249(EIF_REFERENCE);
+extern void F103_1250(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit701(void);
+extern long O1236[];
 
 #ifdef __cplusplus
 }
