@@ -1,5 +1,5 @@
 /*
- * Code for class DS_SPARSE_TABLE_CURSOR [G#1, G#2]
+ * Code for class DS_SPARSE_TABLE_CURSOR [NATURAL_64, NATURAL_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,34 +23,26 @@ extern "C" {
 #endif
 
 /* {DS_SPARSE_TABLE_CURSOR}.key */
-EIF_REFERENCE F1041_6976 (EIF_REFERENCE Current)
+EIF_NATURAL_32 F1015_6842 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
+	EIF_NATURAL_32 Result = ((EIF_NATURAL_32) 0);
 	
 	RTLD;
 	
-	RTLI(3);
+	RTLI(2);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLR(2,Result);
-	RTLIU(3);
+	RTLIU(2);
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_REFERENCE)) R5611[Dtype(RTCW(tr1))-1165])(tr1, Current);
+	Result = F1100_7547(RTCW(tr1), Current);
 	RTLE;
 	return Result;
 }
 
-/* {DS_SPARSE_TABLE_CURSOR}.container */
-EIF_REFERENCE F1041_6977 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
-}
-
-
 void EIF_Minit700 (void)
 {
 	GTCX
