@@ -6,10 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1041_6976(EIF_REFERENCE);
-extern EIF_REFERENCE F1041_6977(EIF_REFERENCE);
+extern EIF_NATURAL_32 F1015_6842(EIF_REFERENCE);
 extern void EIF_Minit700(void);
-extern char *(*R5611[])();
+extern EIF_NATURAL_32 F1100_7547(EIF_REFERENCE, EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
