@@ -6,9 +6,11 @@
 extern "C" {
 #endif
 
-extern void F1076_7152(EIF_REFERENCE, EIF_REFERENCE);
+extern void F135_1567(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F135_1568(EIF_REFERENCE);
 extern void EIF_Minit701(void);
-extern char *(*R944[])();
+extern long O1519[];
+extern long O1513[];
 
 #ifdef __cplusplus
 }
