@@ -1,5 +1,5 @@
 /*
- * Code for class DS_SET_CURSOR [G#1]
+ * Code for class DS_ARRAYED_SPARSE_TABLE_CURSOR [G#1, G#2]
  */
 
 #include "eif_eiffel.h"
@@ -22,10 +22,10 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {DS_SET_CURSOR}.next_cursor */
-EIF_REFERENCE F927_6108 (EIF_REFERENCE Current)
+/* {DS_ARRAYED_SPARSE_TABLE_CURSOR}.container */
+EIF_REFERENCE F1156_8356 (EIF_REFERENCE Current)
 {
-	return *(EIF_REFERENCE *)(Current + O4587[Dtype(Current) - 918]);
+	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
 }
 
 
