@@ -6,10 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1072_7135(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_REFERENCE F1156_8356(EIF_REFERENCE);
 extern void EIF_Minit734(void);
-extern char *(*R5478[])();
-extern char *(*R5481[])();
 
 #ifdef __cplusplus
 }
