@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern void F1627_16664(EIF_REFERENCE);
-extern EIF_BOOLEAN F1627_16665(EIF_REFERENCE);
-extern EIF_REFERENCE F1627_16667(EIF_REFERENCE);
+extern EIF_INTEGER_32 F1675_16619(EIF_REFERENCE);
+extern void F1675_16621(EIF_REFERENCE, EIF_INTEGER_32);
 extern void EIF_Minit736(void);
 
 #ifdef __cplusplus
