@@ -1,5 +1,5 @@
 /*
- * Code for class ET_AST_LEAF
+ * Code for class ET_CHOICE
  */
 
 #include "eif_eiffel.h"
@@ -22,26 +22,18 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ET_AST_LEAF}.position */
-EIF_REFERENCE F1564_14363 (EIF_REFERENCE Current)
+/* {ET_CHOICE}.is_range */
+EIF_BOOLEAN F1694_17329 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	return (EIF_REFERENCE) Current;
+	RTGC;
+	return (EIF_BOOLEAN) 0;
 }
 
-/* {ET_AST_LEAF}.first_leaf */
-EIF_REFERENCE F1564_14365 (EIF_REFERENCE Current)
-{
-	GTCX
-	
-	
-	return (EIF_REFERENCE) Current;
-}
-
-/* {ET_AST_LEAF}.last_leaf */
-EIF_REFERENCE F1564_14366 (EIF_REFERENCE Current)
+/* {ET_CHOICE}.choice */
+EIF_REFERENCE F1694_17332 (EIF_REFERENCE Current)
 {
 	GTCX
 	
