@@ -6,10 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F1299_12263(EIF_REFERENCE);
-extern EIF_REFERENCE F1299_12265(EIF_REFERENCE);
+extern EIF_REFERENCE F776_11945(EIF_REFERENCE);
 extern void EIF_Minit704(void);
-extern EIF_REFERENCE F1564_15521(EIF_REFERENCE);
+extern void F3002_33755(EIF_REFERENCE);
+extern long O11616[];
 
 #ifdef __cplusplus
 }
