@@ -1,5 +1,5 @@
 /*
- * Code for class EV_HORIZONTAL_BOX_IMP
+ * Code for class EV_PASSWORD_FIELD_IMP
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,11 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {EV_HORIZONTAL_BOX_IMP}.make */
-void F1355_13749 (EIF_REFERENCE Current)
+/* {EV_PASSWORD_FIELD_IMP}.make */
+void F1367_13559 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_POINTER tp1;
 	RTLD;
 	
@@ -34,11 +35,16 @@ void F1355_13749 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
+	RTEAA("make", 1366, Current, 0, 0, 19280);
 	RTGC;
-	tp1 = (EIF_POINTER) gtk_hbox_new((gboolean) EIF_FALSE, (gint) ((EIF_INTEGER_32) 0L));
-	F1283_12697(Current, tp1);
-	F1351_13697(Current);
+	RTHOOK(1);
+	F1365_13495(Current);
+	RTHOOK(2);
+	tp1 = *(EIF_POINTER *)(Current+ _PTROFF_46_14_10_7_0_1_);
+	gtk_entry_set_visibility((GtkEntry*) tp1, (gboolean) (EIF_BOOLEAN) 0);
+	RTHOOK(3);
 	RTLE;
+	RTEE;
 }
 
 void EIF_Minit719 (void)
