@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_INTEGER_32 F1385_14519(EIF_REFERENCE);
+extern EIF_REFERENCE F1402_13561(EIF_REFERENCE);
+extern void F1402_13562(EIF_REFERENCE);
 extern void EIF_Minit749(void);
-extern char *(*R10580[])();
+extern void F1675_17597(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
