@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F259_1665(EIF_REFERENCE);
+extern EIF_BOOLEAN F561_2770(EIF_REFERENCE);
 extern void EIF_Minit716(void);
-extern char *(*R1515[])();
+extern EIF_INTEGER_32 F661_3248(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
