@@ -1,5 +1,5 @@
 /*
- * Code for class FINITE [G#1]
+ * Code for class FINITE [NATURAL_64]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {FINITE}.is_empty */
-EIF_BOOLEAN F369_3776 (EIF_REFERENCE Current)
+EIF_BOOLEAN F606_3221 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -36,7 +36,7 @@ EIF_BOOLEAN F369_3776 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R3564[Dtype(Current)-420])(Current);
+	ti4_1 = F707_3699(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
 	RTLE;
 	return Result;
