@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern EIF_BOOLEAN F369_3776(EIF_REFERENCE);
+extern EIF_BOOLEAN F606_3221(EIF_REFERENCE);
 extern void EIF_Minit719(void);
-extern char *(*R3564[])();
+extern EIF_INTEGER_32 F707_3699(EIF_REFERENCE);
 
 #ifdef __cplusplus
 }
