@@ -1,5 +1,5 @@
 /*
- * Code for class FINITE [NATURAL_32]
+ * Code for class FINITE [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {FINITE}.is_empty */
-EIF_BOOLEAN F216_1594 (EIF_REFERENCE Current)
+EIF_BOOLEAN F731_6212 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
@@ -36,14 +35,10 @@ EIF_BOOLEAN F216_1594 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("is_empty", 215, Current, 0, 0, 1934);
 	RTGC;
-	RTHOOK(1);
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1422[Dtype(Current)-417])(Current);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5523[Dtype(Current)-768])(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
