@@ -1,5 +1,5 @@
 /*
- * Code for class GENERAL_SPECIAL_ITERATION_CURSOR [POINTER, G#2]
+ * Code for class GENERAL_SPECIAL_ITERATION_CURSOR [INTEGER_32, G#2]
  */
 
 #include "eif_eiffel.h"
@@ -23,14 +23,14 @@ extern "C" {
 #endif
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.item */
-EIF_POINTER F503_5617 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F526_5992 (EIF_REFERENCE Current)
 {
 	GTCX
-	EIF_POINTER tp1;
-	EIF_POINTER tp2;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_POINTER Result = ((EIF_POINTER) 0);
+	EIF_INTEGER_32 ti4_2;
+	EIF_INTEGER_32 ti4_3;
+	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
 	RTLD;
 	
@@ -42,15 +42,15 @@ EIF_POINTER F503_5617 (EIF_REFERENCE Current)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.item) */
-	tp2 = *((EIF_POINTER *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(Current + O5060[Dtype(Current)-501])));
+	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(Current + O5387[Dtype(Current)-524])));
 	/* END INLINED CODE */
-	Result = tp2;
+	Result = ti4_3;
 	RTLE;
 	return Result;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.target_index */
-EIF_INTEGER_32 F503_5619 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F526_5994 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -65,26 +65,26 @@ EIF_INTEGER_32 F503_5619 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	Result = *(EIF_INTEGER_32 *)(Current + O5060[dtype-501]);
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5034[dtype-479])(Current);
-	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5061[dtype-513])(Current);
+	Result = *(EIF_INTEGER_32 *)(Current + O5387[dtype-524]);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5361[dtype-502])(Current);
+	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5388[dtype-536])(Current);
 	Result = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (Result + ti4_1) - ti4_2);
 	RTLE;
 	return Result;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.after */
-EIF_BOOLEAN F503_5626 (EIF_REFERENCE Current)
+EIF_BOOLEAN F526_6001 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTCDT;
 	
 	
-	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current + O5060[dtype-501]) > *(EIF_INTEGER_32 *)(Current + O5062[dtype-501]));
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current + O5387[dtype-524]) > *(EIF_INTEGER_32 *)(Current + O5389[dtype-524]));
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.is_first */
-EIF_BOOLEAN F503_5629 (EIF_REFERENCE Current)
+EIF_BOOLEAN F526_6004 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -99,15 +99,25 @@ EIF_BOOLEAN F503_5629 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	ti4_1 = *(EIF_INTEGER_32 *)(Current + O5060[dtype-501]);
-	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5061[dtype-513])(Current);
+	ti4_1 = *(EIF_INTEGER_32 *)(Current + O5387[dtype-524]);
+	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5388[dtype-536])(Current);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
 	RTLE;
 	return Result;
 }
 
+/* {GENERAL_SPECIAL_ITERATION_CURSOR}.is_last */
+EIF_BOOLEAN F526_6005 (EIF_REFERENCE Current)
+{
+	GTCX
+	RTCDT;
+	
+	
+	return (EIF_BOOLEAN) (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current + O5387[dtype-524]) == *(EIF_INTEGER_32 *)(Current + O5389[dtype-524]));
+}
+
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.start */
-void F503_5631 (EIF_REFERENCE Current)
+void F526_6006 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -119,23 +129,23 @@ void F503_5631 (EIF_REFERENCE Current)
 	RTLIU(1);
 	
 	RTGC;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5061[dtype-513])(Current);
-	*(EIF_INTEGER_32 *)(Current + O5060[dtype-501]) = (EIF_INTEGER_32) ti4_1;
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5388[dtype-536])(Current);
+	*(EIF_INTEGER_32 *)(Current + O5387[dtype-524]) = (EIF_INTEGER_32) ti4_1;
 	RTLE;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.forth */
-void F503_5632 (EIF_REFERENCE Current)
+void F526_6007 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTCDT;
 	
 	
-	(*(EIF_INTEGER_32 *)(Current + O5060[dtype-501]))++;
+	(*(EIF_INTEGER_32 *)(Current + O5387[dtype-524]))++;
 }
 
 /* {GENERAL_SPECIAL_ITERATION_CURSOR}.area */
-EIF_REFERENCE F503_5633 (EIF_REFERENCE Current)
+EIF_REFERENCE F526_6008 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current);
 }
