@@ -1,5 +1,5 @@
 /*
- * Code for class HASH_TABLE_ITERATION_CURSOR [INTEGER_32, INTEGER_32]
+ * Code for class HASH_TABLE_ITERATION_CURSOR [G#1, G#2]
  */
 
 #include "eif_eiffel.h"
@@ -7,7 +7,6 @@
 #include "../E1/eoffsets.h"
 
 #include "ha712.h"
-#include "eif_built_in.h"
 
 #ifdef __cplusplus
 extern "C" {
@@ -24,76 +23,55 @@ extern "C" {
 #endif
 
 /* {HASH_TABLE_ITERATION_CURSOR}.item */
-EIF_INTEGER_32 F263_1957 (EIF_REFERENCE Current)
+EIF_REFERENCE F729_5560 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
+	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
 	
-	RTLI(2);
+	RTLI(3);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLIU(2);
+	RTLR(2,Result);
+	RTLIU(3);
 	
-	RTEAA("item", 262, Current, 0, 0, 2995);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
-	/* INLINED CODE (SPECIAL.item) */
-	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_)));
-	/* END INLINED CODE */
-	Result = ti4_3;
-	RTHOOK(2);
+	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O4684[Dtype(tr1)-613]);
+	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R4506[Dtype(RTCW(tr1))-543])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_));
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.key */
-EIF_INTEGER_32 F263_1958 (EIF_REFERENCE Current)
+EIF_REFERENCE F729_5561 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
+	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
 	
-	RTLI(2);
+	RTLI(3);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLIU(2);
+	RTLR(2,Result);
+	RTLIU(3);
 	
-	RTEAA("key", 262, Current, 0, 0, 2996);
 	RTGC;
-	RTHOOK(1);
 	tr1 = *(EIF_REFERENCE *)(Current);
-	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-	/* INLINED CODE (SPECIAL.item) */
-	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_)));
-	/* END INLINED CODE */
-	Result = ti4_3;
-	RTHOOK(2);
+	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O4685[Dtype(tr1)-613]);
+	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R4506[Dtype(RTCW(tr1))-543])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_));
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.after */
-EIF_BOOLEAN F263_1960 (EIF_REFERENCE Current)
+EIF_BOOLEAN F729_5563 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
@@ -107,33 +85,27 @@ EIF_BOOLEAN F263_1960 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("after", 262, Current, 1, 0, 2998);
 	RTGC;
-	RTHOOK(1);
 	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_);
-	RTHOOK(2);
 	Result = '\01';
 	tb1 = '\01';
-	if (!(EIF_BOOLEAN) !F253_1943(Current)) {
+	if (!(EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4889[Dtype(Current)-713])(Current)) {
 		tb1 = (EIF_BOOLEAN) (loc1 < ((EIF_INTEGER_32) 0L));
 	}
 	if (!tb1) {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O4685[Dtype(tr1)-613]);
+		ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5039[Dtype(RTCW(tr1))-790])(tr1);
 		Result = (EIF_BOOLEAN) (loc1 >= ti4_1);
 	}
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.forth */
-void F263_1961 (EIF_REFERENCE Current)
+void F729_5564 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
 	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
@@ -147,54 +119,41 @@ void F263_1961 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("forth", 262, Current, 3, 0, 2999);
 	RTGC;
-	RTHOOK(1);
 	loc3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_);
-	RTHOOK(2);
 	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	RTHOOK(3);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_)) {
-		RTHOOK(4);
 		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		for (;;) {
-			RTHOOK(5);
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || (EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L)))) break;
-			RTHOOK(6);
 			tr1 = *(EIF_REFERENCE *)(Current);
-			loc3 = F623_2860(RTCW(tr1), loc3);
-			RTHOOK(7);
+			ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4676[Dtype(RTCW(tr1))-613])(tr1, loc3);
+			loc3 = (EIF_INTEGER_32) ti4_1;
 			loc1++;
 		}
 	} else {
-		RTHOOK(8);
 		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		for (;;) {
-			RTHOOK(9);
 			tb1 = '\01';
 			if (!(EIF_BOOLEAN) (loc1 > loc2)) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+				tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O4685[Dtype(tr1)-613]);
+				ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5039[Dtype(RTCW(tr1))-790])(tr1);
 				tb1 = (EIF_BOOLEAN) (loc3 >= ti4_1);
 			}
 			if (tb1) break;
-			RTHOOK(10);
 			tr1 = *(EIF_REFERENCE *)(Current);
-			loc3 = F623_2859(RTCW(tr1), loc3);
-			RTHOOK(11);
+			ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R4675[Dtype(RTCW(tr1))-613])(tr1, loc3);
+			loc3 = (EIF_INTEGER_32) ti4_1;
 			loc1++;
 		}
 	}
-	RTHOOK(12);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_) = (EIF_INTEGER_32) loc3;
-	RTHOOK(13);
 	RTLE;
-	RTEE;
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.target */
-EIF_REFERENCE F263_1962 (EIF_REFERENCE Current)
+EIF_REFERENCE F729_5565 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current);
 }
