@@ -1,5 +1,5 @@
 /*
- * Code for class HASH_TABLE_ITERATION_CURSOR [INTEGER_32, INTEGER_32]
+ * Code for class HASH_TABLE_ITERATION_CURSOR [G#1, INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -24,41 +24,33 @@ extern "C" {
 #endif
 
 /* {HASH_TABLE_ITERATION_CURSOR}.item */
-EIF_INTEGER_32 F544_2969 (EIF_REFERENCE Current)
+EIF_REFERENCE F442_3443 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE tr2 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
+	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
 	
 	RTLD;
 	
 	RTLI(3);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLR(2,tr2);
+	RTLR(2,Result);
 	RTLIU(3);
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
-	/* INLINED CODE (SPECIAL.item) */
-	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_)));
-	/* END INLINED CODE */
-	Result = ti4_3;
+	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O3581[Dtype(tr1)-824]);
+	Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE, EIF_INTEGER_32)) R3361[Dtype(RTCW(tr1))-715])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_));
 	RTLE;
 	return Result;
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.key */
-EIF_INTEGER_32 F544_2970 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F442_3444 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
 	EIF_INTEGER_32 ti4_3;
@@ -66,15 +58,14 @@ EIF_INTEGER_32 F544_2970 (EIF_REFERENCE Current)
 	
 	RTLD;
 	
-	RTLI(3);
+	RTLI(2);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLR(2,tr2);
-	RTLIU(3);
+	RTLIU(2);
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
+	tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O3582[Dtype(tr1)-824]);
 	/* INLINED CODE (SPECIAL.item) */
 	ti4_3 = *((EIF_INTEGER_32 *)RTCW(tr1) + (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_)));
 	/* END INLINED CODE */
@@ -84,7 +75,7 @@ EIF_INTEGER_32 F544_2970 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.after */
-EIF_BOOLEAN F544_2972 (EIF_REFERENCE Current)
+EIF_BOOLEAN F442_3446 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -104,13 +95,13 @@ EIF_BOOLEAN F544_2972 (EIF_REFERENCE Current)
 	loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_4_);
 	Result = '\01';
 	tb1 = '\01';
-	if (!(EIF_BOOLEAN) !F528_2955(Current)) {
+	if (!(EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R3053[Dtype(Current)-440])(Current)) {
 		tb1 = (EIF_BOOLEAN) (loc1 < ((EIF_INTEGER_32) 0L));
 	}
 	if (!tb1) {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+		tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O3582[Dtype(tr1)-824]);
+		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 		Result = (EIF_BOOLEAN) (loc1 >= ti4_1);
 	}
 	RTLE;
@@ -118,7 +109,7 @@ EIF_BOOLEAN F544_2972 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.forth */
-void F544_2973 (EIF_REFERENCE Current)
+void F442_3447 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -142,7 +133,8 @@ void F544_2973 (EIF_REFERENCE Current)
 		for (;;) {
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || (EIF_BOOLEAN) (loc3 < ((EIF_INTEGER_32) 0L)))) break;
 			tr1 = *(EIF_REFERENCE *)(Current);
-			loc3 = F717_3445(RTCW(tr1), loc3);
+			ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R3573[Dtype(RTCW(tr1))-824])(tr1, loc3);
+			loc3 = (EIF_INTEGER_32) ti4_1;
 			loc1++;
 		}
 	} else {
@@ -151,13 +143,14 @@ void F544_2973 (EIF_REFERENCE Current)
 			tb1 = '\01';
 			if (!(EIF_BOOLEAN) (loc1 > loc2)) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + _REFACS_1_);
-				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+				tr1 = *(EIF_REFERENCE *)(RTCW(tr1) + O3582[Dtype(tr1)-824]);
+				ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 				tb1 = (EIF_BOOLEAN) (loc3 >= ti4_1);
 			}
 			if (tb1) break;
 			tr1 = *(EIF_REFERENCE *)(Current);
-			loc3 = F717_3444(RTCW(tr1), loc3);
+			ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R3572[Dtype(RTCW(tr1))-824])(tr1, loc3);
+			loc3 = (EIF_INTEGER_32) ti4_1;
 			loc1++;
 		}
 	}
@@ -166,7 +159,7 @@ void F544_2973 (EIF_REFERENCE Current)
 }
 
 /* {HASH_TABLE_ITERATION_CURSOR}.target */
-EIF_REFERENCE F544_2974 (EIF_REFERENCE Current)
+EIF_REFERENCE F442_3448 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current);
 }
