@@ -1,5 +1,5 @@
 /*
- * Code for class KL_CELL [CHARACTER_8]
+ * Code for class KL_LINKABLE [CHARACTER_8]
  */
 
 #include "eif_eiffel.h"
@@ -22,13 +22,16 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {KL_CELL}.item */
-EIF_CHARACTER_8 F65_815 (EIF_REFERENCE Current)
+/* {KL_LINKABLE}.put_right */
+void F71_968 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
-	return *(EIF_CHARACTER_8 *)(Current + O822[Dtype(Current) - 63]);
+	GTCX
+	
+	
+	RTAR(Current, arg1);
+	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
 }
 
-
 void EIF_Minit748 (void)
 {
 	GTCX
