@@ -6,9 +6,8 @@
 extern "C" {
 #endif
 
-extern EIF_CHARACTER_8 F65_815(EIF_REFERENCE);
+extern void F71_968(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit748(void);
-extern long O822[];
 
 #ifdef __cplusplus
 }
