@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern EIF_REFERENCE F66_818(EIF_REFERENCE);
+extern EIF_CHARACTER_8 F69_964(EIF_REFERENCE);
+extern void F69_966(EIF_REFERENCE, EIF_CHARACTER_8);
 extern void EIF_Minit749(void);
-extern long O826[];
+extern long O966[];
 
 #ifdef __cplusplus
 }
