@@ -6,8 +6,9 @@
 extern "C" {
 #endif
 
-extern void F318_3761(EIF_REFERENCE, EIF_REFERENCE, EIF_BOOLEAN, EIF_BOOLEAN);
+extern void F146_2141(EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit726(void);
+extern long O2109[];
 
 #ifdef __cplusplus
 }
