@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {LINKED_LIST_ITERATION_CURSOR}.item */
-EIF_REFERENCE F546_5855 (EIF_REFERENCE Current)
+EIF_REFERENCE F435_5369 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
@@ -41,17 +40,11 @@ EIF_REFERENCE F546_5855 (EIF_REFERENCE Current)
 	RTLR(3,Result);
 	RTLIU(4);
 	
-	RTEAA("item", 545, Current, 1, 0, 6244);
 	RTGC;
-	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
-		RTHOOK(2);
-		RTHOOK(3);
 		RTLE;
-		RTEE;
-		return (EIF_REFERENCE) F514_5821(Current);
+		return (EIF_REFERENCE) F405_5335(Current);
 	} else {
-		RTHOOK(4);
 		RTCT0("active_attached", EX_CHECK);
 		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
 		loc1 = tr1;
@@ -60,20 +53,16 @@ EIF_REFERENCE F546_5855 (EIF_REFERENCE Current)
 		} else {
 			RTCF0;
 		}
-		RTHOOK(5);
-		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2416[Dtype(loc1)-184])(loc1);
+		Result = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R2105[Dtype(loc1)-140])(loc1);
 	}
-	RTHOOK(6);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {LINKED_LIST_ITERATION_CURSOR}.after */
-EIF_BOOLEAN F546_5856 (EIF_REFERENCE Current)
+EIF_BOOLEAN F435_5370 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	RTLD;
@@ -82,33 +71,24 @@ EIF_BOOLEAN F546_5856 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("after", 545, Current, 0, 0, 6245);
 	RTGC;
-	RTHOOK(1);
 	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
-		RTHOOK(2);
-		RTHOOK(3);
 		RTLE;
-		RTEE;
-		return (EIF_BOOLEAN) F526_5839(Current);
+		return (EIF_BOOLEAN) F417_5353(Current);
 	} else {
-		RTHOOK(4);
 		Result = '\01';
-		if (!(EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R5251[Dtype(Current)-525])(Current)) {
+		if (!(EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4431[Dtype(Current)-416])(Current)) {
 			Result = (EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) == NULL);
 		}
 	}
-	RTHOOK(5);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
 /* {LINKED_LIST_ITERATION_CURSOR}.start */
-void F546_5857 (EIF_REFERENCE Current)
+void F435_5371 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -117,28 +97,21 @@ void F546_5857 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("start", 545, Current, 0, 0, 6246);
 	RTGC;
-	RTHOOK(1);
-	F526_5846(Current);
-	RTHOOK(2);
+	F417_5360(Current);
 	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
-		RTHOOK(3);
 		tr1 = *(EIF_REFERENCE *)(Current);
 		tr1 = *(EIF_REFERENCE *)(RTCW(tr1));
 		RTAR(Current, tr1);
 		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
 	}
-	RTHOOK(4);
 	RTLE;
-	RTEE;
 }
 
 /* {LINKED_LIST_ITERATION_CURSOR}.forth */
-void F546_5858 (EIF_REFERENCE Current)
+void F435_5372 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
 	EIF_REFERENCE tr1 = NULL;
@@ -151,34 +124,25 @@ void F546_5858 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("forth", 545, Current, 2, 0, 6247);
 	RTGC;
-	RTHOOK(1);
-	F526_5847(Current);
-	RTHOOK(2);
+	F417_5361(Current);
 	if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_2_0_)) {
-		RTHOOK(3);
 		loc1 = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 		for (;;) {
-			RTHOOK(4);
 			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
 			loc2 = tr1;
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_1_0_1_)) || (EIF_BOOLEAN) !EIF_TEST(loc2))) break;
-			RTHOOK(5);
-			tr1 = *(EIF_REFERENCE *)(loc2 + O2420[Dtype(loc2)-189]);
+			tr1 = *(EIF_REFERENCE *)(loc2 + O2109[Dtype(loc2)-145]);
 			RTAR(Current, tr1);
 			*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
-			RTHOOK(6);
 			loc1++;
 		}
 	}
-	RTHOOK(7);
 	RTLE;
-	RTEE;
 }
 
 /* {LINKED_LIST_ITERATION_CURSOR}.target */
-EIF_REFERENCE F546_5859 (EIF_REFERENCE Current)
+EIF_REFERENCE F435_5373 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current);
 }
