@@ -6,9 +6,9 @@
 extern "C" {
 #endif
 
-extern void F1376_15858(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_INTEGER_32 F505_2182(EIF_REFERENCE);
 extern void EIF_Minit701(void);
-extern char *(*R3871[])();
+extern char *(*R1921[])();
 
 #ifdef __cplusplus
 }
