@@ -1,5 +1,5 @@
 /*
- * Code for class RESIZABLE [NATURAL_32]
+ * Code for class RESIZABLE [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -24,10 +24,9 @@ extern "C" {
 #endif
 
 /* {RESIZABLE}.additional_space */
-EIF_INTEGER_32 F410_2060 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F754_6218 (EIF_REFERENCE Current)
 {
 	GTCX
-	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
 	
@@ -37,17 +36,33 @@ EIF_INTEGER_32 F410_2060 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("additional_space", 409, Current, 0, 0, 3879);
 	RTGC;
-	RTHOOK(1);
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R1833[Dtype(Current)-543])(Current);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5524[Dtype(Current)-768])(Current);
 	Result = eif_max_int32 ((EIF_INTEGER_32) (ti4_1 / ((EIF_INTEGER_32) 2L)),((EIF_INTEGER_32) 5L));
-	RTHOOK(3);
 	RTLE;
-	RTEE;
 	return Result;
 }
 
+/* {RESIZABLE}.automatic_grow */
+void F754_6220 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
+	RTCDT;
+	RTLD;
+	
+	RTLI(1);
+	RTLR(0,Current);
+	RTLIU(1);
+	
+	RTGC;
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5524[dtype-768])(Current);
+	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R5528[dtype-768])(Current);
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R5530[dtype-768])(Current, (EIF_INTEGER_32) (ti4_1 + ti4_2));
+	RTLE;
+}
+
 void EIF_Minit704 (void)
 {
 	GTCX
