@@ -6,9 +6,11 @@
 extern "C" {
 #endif
 
-extern void F1404_16392(EIF_REFERENCE, EIF_REFERENCE);
+extern EIF_INTEGER_32 F698_4128(EIF_REFERENCE);
+extern void F698_4130(EIF_REFERENCE);
 extern void EIF_Minit713(void);
-extern char *(*R4173[])();
+extern char *(*R3567[])();
+extern char *(*R3573[])();
 
 #ifdef __cplusplus
 }
