@@ -1,5 +1,5 @@
 /*
- * Code for class SHARED_I18N_PLURAL_TOOLS
+ * Code for class SHARED_TIME
  */
 
 #include "eif_eiffel.h"
@@ -22,8 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {SHARED_I18N_PLURAL_TOOLS}.plural_tools */
-static EIF_REFERENCE F824_13022_body (EIF_REFERENCE Current)
+/* {SHARED_TIME}.time_checker */
+static EIF_REFERENCE F816_13498_body (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -31,31 +31,31 @@ static EIF_REFERENCE F824_13022_body (EIF_REFERENCE Current)
 	RTLD;
 	
 #define Result RTOTRR
-	RTOUDR(5506)
+	RTOUDR(1850)
 
 	RTLI(2);
 	RTLR(0,tr1);
 	RTLR(1,Current);
 	RTLIU(2);
 	
-	RTEAA("plural_tools", 823, Current, 0, 0, 11334);
+	RTEAA("time_checker", 815, Current, 0, 0, 12247);
 	RTGC;
 	RTOTP;
 	RTHOOK(1);
-	tr1 = RTLNS(eif_new_type(56, 0x00).id, 56, _OBJSIZ_0_0_0_0_0_0_0_0_);
+	tr1 = RTLNS(eif_new_type(4619, 0x00).id, 4619, _OBJSIZ_0_0_0_0_0_0_0_0_);
 	Result = (EIF_REFERENCE) tr1;
 	RTOTE;
-	RTHOOK(3);
+	RTHOOK(2);
 	RTLE;
 	RTEE;
 	return Result;
 #undef Result
 }
 
-EIF_REFERENCE F824_13022 (EIF_REFERENCE Current)
+EIF_REFERENCE F816_13498 (EIF_REFERENCE Current)
 {
 	GTCX
-	return RTOUCR(5506,F824_13022_body,(Current));
+	return RTOUCR(1850,F816_13498_body,(Current));
 }
 
 void EIF_Minit739 (void)
