@@ -23,9 +23,10 @@ extern "C" {
 #endif
 
 /* {SPECIAL_ITERATION_CURSOR}.make */
-void F742_5409 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F603_6335 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
+	RTEX;
 	EIF_INTEGER_32 ti4_1;
 	RTLD;
 	
@@ -34,24 +35,30 @@ void F742_5409 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,arg1);
 	RTLIU(2);
 	
+	RTEAA("make", 602, Current, 0, 1, 7061);
 	RTGC;
+	RTHOOK(1);
 	RTAR(Current, arg1);
-	*(EIF_REFERENCE *)(Current + O4673[Dtype(Current)-703]) = (EIF_REFERENCE) arg1;
-	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R4114[Dtype(arg1)-502])(RTCW(arg1));
+	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
+	RTHOOK(2);
+	ti4_1 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R6002[Dtype(RTCW(arg1))-859])(arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ti4_1;
+	RTHOOK(9);
 	RTLE;
+	RTEE;
 }
 
 /* {SPECIAL_ITERATION_CURSOR}.first_index */
-EIF_INTEGER_32 F742_5410 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F603_6336 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 }
 
 /* {SPECIAL_ITERATION_CURSOR}.new_cursor */
-EIF_REFERENCE F742_5411 (EIF_REFERENCE Current)
+EIF_REFERENCE F603_6337 (EIF_REFERENCE Current)
 {
 	GTCX
+	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -60,27 +67,31 @@ EIF_REFERENCE F742_5411 (EIF_REFERENCE Current)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
+	RTEAA("new_cursor", 602, Current, 0, 0, 7063);
 	RTGC;
+	RTHOOK(1);
 	{
-		static EIF_TYPE_INDEX typarr0[] = {741,0,0,0xFFFF};
+		EIF_TYPE_INDEX typarr0[] = {0xFF01,602,0,0,0xFFFF};
 		EIF_TYPE typres0;
 		{
 			EIF_TYPE l_type;
-			l_type = eif_final_id(Y4587,Y4587_gen_type,Dftype(Current),633);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
+			l_type = eif_final_id(Y5256,Y5256_gen_type,Dftype(Current),461);
+			typarr0[2] = l_type.annotations | 0xFF00;
+			typarr0[3] = l_type.id;
 		}
 		
 		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 741, _OBJSIZ_1_0_0_2_0_0_0_0_);
+		tr1 = RTLNS(typres0.id, 602, _OBJSIZ_1_0_0_2_0_0_0_0_);
 	}
-	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4688[Dtype(tr1)-741])(RTCW(tr1), *(EIF_REFERENCE *)(Current + O4673[Dtype(Current)-703]));
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R5644[Dtype(RTCW(tr1))-602])(tr1, *(EIF_REFERENCE *)(Current));
+	RTHOOK(2);
 	RTLE;
+	RTEE;
 	return (EIF_REFERENCE) tr1;
 }
 
 /* {SPECIAL_ITERATION_CURSOR}.area_first_index */
-EIF_INTEGER_32 F742_5412 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F603_6338 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 }
