@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [POINTER]
+ * Code for class TO_SPECIAL [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -23,7 +23,7 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F202_3517 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F250_4217 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -35,7 +35,7 @@ void F202_3517 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y3401,Y3401_gen_type,Dftype(Current),200).id,0,arg1,sizeof(EIF_POINTER), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y4075,Y4075_gen_type,Dftype(Current),249).id,EO_REF,arg1,sizeof(EIF_REFERENCE), EIF_FALSE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -43,27 +43,31 @@ void F202_3517 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F202_3518 (EIF_REFERENCE Current, EIF_POINTER arg1, EIF_INTEGER_32 arg2)
+void F250_4218 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
+	EIF_REFERENCE tr2 = NULL;
 	RTLD;
 	
-	RTLI(2);
+	RTLI(4);
 	RTLR(0,Current);
 	RTLR(1,tr1);
-	RTLIU(2);
+	RTLR(2,arg1);
+	RTLR(3,tr2);
+	RTLIU(4);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y3401,Y3401_gen_type,Dftype(Current),200).id,0,arg2,sizeof(EIF_POINTER), EIF_TRUE);
-	F596_4793(RTCW(tr1), arg1, arg2);
+	tr2 = RTCCL(arg1);
+	tr1 = RTLNSP2(eif_final_id(Y4075,Y4075_gen_type,Dftype(Current),249).id,EO_REF,arg2,sizeof(EIF_REFERENCE), EIF_FALSE);
+	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE, EIF_INTEGER_32)) R5043[Dtype(RTCW(tr1))-790])(tr1, tr2, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
 /* {TO_SPECIAL}.set_area */
-void F202_3524 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F250_4224 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	
