@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [NATURAL_32]
+ * Code for class TO_SPECIAL [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F126_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F292_2871 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -35,23 +34,18 @@ void F126_1495 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_empty_area", 125, Current, 0, 1, 1595);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1387,Y1387_gen_type,Dftype(Current),115).id,0,arg1,sizeof(EIF_NATURAL_32), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y2615,Y2615_gen_type,Dftype(Current),290).id,0,arg1,sizeof(EIF_INTEGER_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(5);
 	RTLE;
-	RTEE;
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F126_1496 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
+void F292_2872 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -60,31 +54,22 @@ void F126_1496 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_filled_area", 125, Current, 0, 2, 1596);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y1387,Y1387_gen_type,Dftype(Current),115).id,0,arg2,sizeof(EIF_NATURAL_32), EIF_TRUE);
-	F529_2471(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y2615,Y2615_gen_type,Dftype(Current),290).id,0,arg2,sizeof(EIF_INTEGER_32), EIF_TRUE);
+	F749_4493(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(6);
 	RTLE;
-	RTEE;
 }
 
 /* {TO_SPECIAL}.set_area */
-void F126_1502 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F292_2878 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("set_area", 125, Current, 0, 1, 1602);
-	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
-	RTHOOK(3);
-	RTEE;
 }
 
 void EIF_Minit711 (void)
