@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [NATURAL_32]
+ * Code for class TO_SPECIAL [BOOLEAN]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {TO_SPECIAL}.make_empty_area */
-void F398_2464 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F186_1857 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -35,23 +34,18 @@ void F398_2464 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_empty_area", 397, Current, 0, 1, 3006);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y2180,Y2180_gen_type,Dftype(Current),389).id,0,arg1,sizeof(EIF_NATURAL_32), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),179).id,0,arg1,sizeof(EIF_BOOLEAN), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F398_2465 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
+void F186_1858 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	RTLD;
 	
@@ -60,38 +54,22 @@ void F398_2465 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 	RTLR(1,tr1);
 	RTLIU(2);
 	
-	RTEAA("make_filled_area", 397, Current, 0, 2, 3007);
 	RTGC;
-	RTHOOK(1);
-	tr1 = RTLNSP2(eif_final_id(Y2180,Y2180_gen_type,Dftype(Current),389).id,0,arg2,sizeof(EIF_NATURAL_32), EIF_TRUE);
-	F664_3885(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1715,Y1715_gen_type,Dftype(Current),179).id,0,arg2,sizeof(EIF_BOOLEAN), EIF_TRUE);
+	F614_3040(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(2);
 	RTLE;
-	RTEE;
 }
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F398_2466 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.set_area */
-void F398_2471 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F186_1864 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	
 	
-	RTEAA("set_area", 397, Current, 0, 1, 3013);
-	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
-	RTHOOK(2);
-	RTEE;
 }
 
 void EIF_Minit715 (void)
