@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [REAL_64]
+ * Code for class TO_SPECIAL [NATURAL_8]
  */
 
 #include "eif_eiffel.h"
@@ -22,15 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F361_1638 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.make_empty_area */
-void F361_1639 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F206_1937 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -42,7 +35,7 @@ void F361_1639 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1460,Y1460_gen_type,Dftype(Current),349).id,0,arg1,sizeof(EIF_REAL_64), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y1793,Y1793_gen_type,Dftype(Current),199).id,0,arg1,sizeof(EIF_NATURAL_8), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -50,7 +43,7 @@ void F361_1639 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F361_1640 (EIF_REFERENCE Current, EIF_REAL_64 arg1, EIF_INTEGER_32 arg2)
+void F206_1938 (EIF_REFERENCE Current, EIF_NATURAL_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -62,15 +55,15 @@ void F361_1640 (EIF_REFERENCE Current, EIF_REAL_64 arg1, EIF_INTEGER_32 arg2)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1460,Y1460_gen_type,Dftype(Current),349).id,0,arg2,sizeof(EIF_REAL_64), EIF_TRUE);
-	F512_2322(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y1793,Y1793_gen_type,Dftype(Current),199).id,0,arg2,sizeof(EIF_NATURAL_8), EIF_TRUE);
+	F636_3148(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
 /* {TO_SPECIAL}.set_area */
-void F361_1645 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F206_1944 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	
