@@ -1,5 +1,5 @@
 /*
- * Code for class TO_SPECIAL [BOOLEAN]
+ * Code for class TO_SPECIAL [INTEGER_32]
  */
 
 #include "eif_eiffel.h"
@@ -22,15 +22,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TO_SPECIAL}.area */
-EIF_REFERENCE F416_2105 (EIF_REFERENCE Current)
-{
-	return *(EIF_REFERENCE *)(Current);
-}
-
-
 /* {TO_SPECIAL}.make_empty_area */
-void F416_2106 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+void F282_2753 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -42,7 +35,7 @@ void F416_2106 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1895,Y1895_gen_type,Dftype(Current),409).id,0,arg1,sizeof(EIF_BOOLEAN), EIF_TRUE);
+	tr1 = RTLNSP2(eif_final_id(Y2480,Y2480_gen_type,Dftype(Current),280).id,0,arg1,sizeof(EIF_INTEGER_32), EIF_TRUE);
 	RT_SPECIAL_COUNT(tr1) = 0;
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
@@ -50,7 +43,7 @@ void F416_2106 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TO_SPECIAL}.make_filled_area */
-void F416_2107 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
+void F282_2754 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -62,15 +55,15 @@ void F416_2107 (EIF_REFERENCE Current, EIF_BOOLEAN arg1, EIF_INTEGER_32 arg2)
 	RTLIU(2);
 	
 	RTGC;
-	tr1 = RTLNSP2(eif_final_id(Y1895,Y1895_gen_type,Dftype(Current),409).id,0,arg2,sizeof(EIF_BOOLEAN), EIF_TRUE);
-	F564_2792(RTCW(tr1), arg1, arg2);
+	tr1 = RTLNSP2(eif_final_id(Y2480,Y2480_gen_type,Dftype(Current),280).id,0,arg2,sizeof(EIF_INTEGER_32), EIF_TRUE);
+	F717_3978(RTCW(tr1), arg1, arg2);
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
 	RTLE;
 }
 
 /* {TO_SPECIAL}.set_area */
-void F416_2112 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F282_2760 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	
