@@ -1,5 +1,5 @@
 /*
- * Code for class TYPE [TYPED_POINTER [NATURAL_16]]
+ * Code for class TYPE [TYPED_POINTER [REAL_32]]
  */
 
 #include "eif_eiffel.h"
@@ -23,8 +23,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {TYPE}.name */
-EIF_REFERENCE F796_4269 (EIF_REFERENCE Current)
+/* {TYPE}.name_32 */
+EIF_REFERENCE F684_3086 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -39,19 +39,19 @@ EIF_REFERENCE F796_4269 (EIF_REFERENCE Current)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("name", 795, Current, 0, 0, 10127);
+	RTEAA("name_32", 683, Current, 0, 0, 8732);
 	RTGC;
 	RTHOOK(1);
-	Result = *(EIF_REFERENCE *)(Current + _REFACS_1_);
+	Result = *(EIF_REFERENCE *)(Current);
 	RTHOOK(2);
 	if ((EIF_BOOLEAN) !(EIF_BOOLEAN)(Result != NULL)) {
 		RTHOOK(3);
-		Result = RTLNS(eif_new_type(883, 0x00).id, 883, _OBJSIZ_1_0_0_4_0_0_0_0_);
-		tr1 = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
-		F883_5787(RTCW(Result), tr1);
+		Result = RTLNS(eif_new_type(769, 0x00).id, 769, _OBJSIZ_1_0_0_4_0_0_0_0_);
+		tr1 = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
+		F770_4532(RTCW(Result), tr1);
 		RTHOOK(4);
 		RTAR(Current, Result);
-		*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) Result;
+		*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) Result;
 	}
 	RTHOOK(6);
 	RTLE;
@@ -60,7 +60,7 @@ EIF_REFERENCE F796_4269 (EIF_REFERENCE Current)
 }
 
 /* {TYPE}.generic_parameter_type */
-EIF_REFERENCE F796_4270 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_REFERENCE F684_3088 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	RTEX;
@@ -73,8 +73,8 @@ EIF_REFERENCE F796_4270 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("generic_parameter_type", 795, Current, 0, 1, 10128);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type (Current, arg1);
+	RTEAA("generic_parameter_type", 683, Current, 0, 1, 8734);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_generic_parameter_type__i4_t (Current, arg1);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -82,7 +82,7 @@ EIF_REFERENCE F796_4270 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 }
 
 /* {TYPE}.type_id */
-EIF_INTEGER_32 F796_4271 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F684_3089 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -94,8 +94,8 @@ EIF_INTEGER_32 F796_4271 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("type_id", 795, Current, 0, 0, 10129);
-	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	RTEAA("type_id", 683, Current, 0, 0, 8735);
+	Result = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
@@ -103,21 +103,21 @@ EIF_INTEGER_32 F796_4271 (EIF_REFERENCE Current)
 }
 
 /* {TYPE}.hash_code */
-EIF_INTEGER_32 F796_4272 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F684_3090 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
 	
 	
-	RTEAA("hash_code", 795, Current, 0, 0, 10130);
+	RTEAA("hash_code", 683, Current, 0, 0, 8736);
 	RTHOOK(1);
 	RTHOOK(2);
 	RTEE;
-	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
+	return (EIF_INTEGER_32) (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
 }
 
 /* {TYPE}.is_attached */
-EIF_BOOLEAN F796_4277 (EIF_REFERENCE Current)
+EIF_BOOLEAN F684_3095 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -129,8 +129,8 @@ EIF_BOOLEAN F796_4277 (EIF_REFERENCE Current)
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("is_attached", 795, Current, 0, 0, 10135);
-	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached (Current);
+	RTEAA("is_attached", 683, Current, 0, 0, 8741);
+	Result = (EIF_BOOLEAN) eif_builtin_TYPE_is_attached__b (Current);
 	RTHOOK(1);
 	RTLE;
 	RTEE;
@@ -138,7 +138,7 @@ EIF_BOOLEAN F796_4277 (EIF_REFERENCE Current)
 }
 
 /* {TYPE}.is_equal */
-EIF_BOOLEAN F796_4278 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F684_3096 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	RTEX;
@@ -153,11 +153,11 @@ EIF_BOOLEAN F796_4278 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(1,arg1);
 	RTLIU(2);
 	
-	RTEAA("is_equal", 795, Current, 0, 1, 10136);
+	RTEAA("is_equal", 683, Current, 0, 1, 8742);
 	RTGC;
 	RTHOOK(1);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (Current);
+	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id__i4 (arg1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
 	RTHOOK(2);
 	RTLE;
@@ -165,85 +165,28 @@ EIF_BOOLEAN F796_4278 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	return Result;
 }
 
-/* {TYPE}.is_strictly_conforming_to */
-EIF_BOOLEAN F796_4279 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
-{
-	GTCX
-	RTEX;
-	EIF_INTEGER_32 ti4_1;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,arg1);
-	RTLIU(2);
-	
-	RTEAA("is_strictly_conforming_to", 795, Current, 0, 1, 10137);
-	RTGC;
-	RTHOOK(1);
-	Result = '\0';
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
-	if ((EIF_BOOLEAN)((EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current) != ti4_1)) {
-		Result = F796_4280(Current, arg1);
-	}
-	RTHOOK(2);
-	RTLE;
-	RTEE;
-	return Result;
-}
-
-/* {TYPE}.is_conforming_to */
-EIF_BOOLEAN F796_4280 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
-{
-	GTCX
-	RTEX;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,arg1);
-	RTLIU(2);
-	
-	RTEAA("is_conforming_to", 795, Current, 0, 1, 10138);
-	RTGC;
-	RTHOOK(1);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (Current);
-	ti4_2 = (EIF_INTEGER_32) eif_builtin_TYPE_type_id (arg1);
-	Result = (EIF_BOOLEAN) eif_builtin_ISE_RUNTIME_type_conforms_to (ti4_1, ti4_2);
-	RTHOOK(2);
-	RTLE;
-	RTEE;
-	return Result;
-}
-
 /* {TYPE}.default */
-EIF_NATURAL_16* F796_4285 (EIF_REFERENCE Current)
+EIF_REAL_32* F684_3103 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
-	EIF_NATURAL_16* loc1 = (EIF_NATURAL_16*) 0;
+	EIF_REAL_32* loc1 = (EIF_REAL_32*) 0;
 	RTLD;
 	
 	RTLI(1);
 	RTLR(0,Current);
 	RTLIU(1);
 	
-	RTEAA("default", 795, Current, 1, 0, 10143);
+	RTEAA("default", 683, Current, 1, 0, 8749);
 	RTGC;
 	RTHOOK(1);
 	RTLE;
 	RTEE;
-	return (EIF_NATURAL_16*) 0;
+	return (EIF_REAL_32*) 0;
 }
 
 /* {TYPE}.runtime_name */
-EIF_REFERENCE F796_4297 (EIF_REFERENCE Current)
+EIF_REFERENCE F684_3115 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTEX;
@@ -256,8 +199,8 @@ EIF_REFERENCE F796_4297 (EIF_REFERENCE Current)
 	RTLR(1,Result);
 	RTLIU(2);
 	
-	RTEAA("runtime_name", 795, Current, 0, 0, 10155);
-	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name (Current);
+	RTEAA("runtime_name", 683, Current, 0, 0, 8761);
+	Result = (EIF_REFERENCE) eif_builtin_TYPE_runtime_name__s1 (Current);
 	RTHOOK(2);
 	RTLE;
 	RTEE;
