@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAYED_LIST_ITERATION_CURSOR [BOOLEAN]
+ * Code for class ARRAYED_LIST_ITERATION_CURSOR [CHARACTER_8]
  */
 
 #include "eif_eiffel.h"
@@ -23,10 +23,9 @@ extern "C" {
 #endif
 
 /* {ARRAYED_LIST_ITERATION_CURSOR}.make */
-void F314_2811 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F748_5586 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
-	RTEX;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	RTLD;
@@ -37,39 +36,64 @@ void F314_2811 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLR(2,tr1);
 	RTLIU(3);
 	
-	RTEAA("make", 313, Current, 0, 1, 3400);
 	RTGC;
-	RTHOOK(1);
 	RTAR(Current, arg1);
 	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
-	RTHOOK(2);
 	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
-	tr1 = F642_3620(RTCW(tr1));
+	tr1 = F624_5234(RTCW(tr1));
 	RTAR(Current, tr1);
 	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
-	RTHOOK(3);
-	ti4_1 = F642_3639(RTCW(arg1));
+	ti4_1 = F624_5253(RTCW(arg1));
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_2_0_0_1_) = (EIF_INTEGER_32) (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 1L));
-	RTHOOK(10);
 	RTLE;
-	RTEE;
 }
 
 /* {ARRAYED_LIST_ITERATION_CURSOR}.first_index */
-EIF_INTEGER_32 F314_2812 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F748_5587 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 }
 
+/* {ARRAYED_LIST_ITERATION_CURSOR}.new_cursor */
+EIF_REFERENCE F748_5588 (EIF_REFERENCE Current)
+{
+	GTCX
+	EIF_REFERENCE tr1 = NULL;
+	RTLD;
+	
+	RTLI(2);
+	RTLR(0,Current);
+	RTLR(1,tr1);
+	RTLIU(2);
+	
+	RTGC;
+	{
+		EIF_TYPE_INDEX typarr0[] = {747,0,0,0xFFFF};
+		EIF_TYPE typres0;
+		{
+			EIF_TYPE l_type;
+			l_type = eif_final_id(Y4839,Y4839_gen_type,Dftype(Current),665);
+			typarr0[1] = l_type.annotations | 0xFF00;
+			typarr0[2] = l_type.id;
+		}
+		
+		typres0 = eif_compound_id(Dftype(Current), typarr0);
+		tr1 = RTLNS(typres0.id, 747, _OBJSIZ_2_0_0_2_0_0_0_0_);
+	}
+	F748_5586(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_1_));
+	RTLE;
+	return (EIF_REFERENCE) tr1;
+}
+
 /* {ARRAYED_LIST_ITERATION_CURSOR}.target */
-EIF_REFERENCE F314_2815 (EIF_REFERENCE Current)
+EIF_REFERENCE F748_5590 (EIF_REFERENCE Current)
 {
 	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
 }
 
 
 /* {ARRAYED_LIST_ITERATION_CURSOR}.area_first_index */
-EIF_INTEGER_32 F314_2816 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F748_5591 (EIF_REFERENCE Current)
 {
 	return (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
 }
