@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAY [INTEGER_32]
+ * Code for class ARRAY [CHARACTER_8]
  */
 
 #include "eif_eiffel.h"
@@ -24,25 +24,8 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {ARRAY}.make_empty */
-void F792_5904 (EIF_REFERENCE Current)
-{
-	GTCX
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-	F369_4540(Current, ((EIF_INTEGER_32) 0L));
-	RTLE;
-}
-
 /* {ARRAY}.make_filled */
-void F792_5905 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F641_3128 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -58,16 +41,16 @@ void F792_5905 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2,
 	if ((EIF_BOOLEAN) (arg2 <= arg3)) {
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L));
 	}
-	F369_4541(Current, arg1, loc1);
+	F188_1858(Current, arg1, loc1);
 	RTLE;
 }
 
 /* {ARRAY}.make */
-void F792_5906 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F641_3129 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
+	EIF_CHARACTER_8 tc1;
 	RTLD;
 	
 	RTLI(2);
@@ -79,17 +62,17 @@ void F792_5906 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg1;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg2;
 	if ((EIF_BOOLEAN) (arg1 <= arg2)) {
-		tr1 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,Dftype(Current),424), 0x00);
-		ti4_1 = F1066_8379(tr1);
-		F369_4541(Current, ti4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
+		tr1 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,Dftype(Current),273), 0x00);
+		tc1 = F769_3884(tr1);
+		F188_1858(Current, tc1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
 	} else {
-		F369_4540(Current, ((EIF_INTEGER_32) 0L));
+		F188_1857(Current, ((EIF_INTEGER_32) 0L));
 	}
 	RTLE;
 }
 
 /* {ARRAY}.make_from_special */
-void F792_5908 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F641_3131 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -101,23 +84,22 @@ void F792_5908 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F369_4547(Current, arg1);
+	F188_1864(Current, arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
 	RTLE;
 }
 
 /* {ARRAY}.item */
-EIF_INTEGER_32 F792_5910 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_CHARACTER_8 F641_3133 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 ti4_4;
-	EIF_INTEGER_32 Result = ((EIF_INTEGER_32) 0);
+	EIF_CHARACTER_8 tc1;
+	EIF_CHARACTER_8 tc2;
+	EIF_CHARACTER_8 Result = ((EIF_CHARACTER_8) 0);
 	
 	RTLD;
 	
@@ -128,110 +110,30 @@ EIF_INTEGER_32 F792_5910 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 	/* INLINED CODE (SPECIAL.item) */
-	ti4_4 = *((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - ti4_1)));
+	tc2 = *((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
 	/* END INLINED CODE */
-	Result = ti4_4;
+	Result = tc2;
 	RTLE;
 	return Result;
 }
 
-/* {ARRAY}.has */
-EIF_BOOLEAN F792_5913 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE loc3 = (EIF_REFERENCE) 0;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,loc3);
-	RTLR(1,Current);
-	RTLIU(2);
-	
-	RTGC;
-	loc3 = *(EIF_REFERENCE *)(Current);
-	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc2 - ti4_1);
-	if ((EIF_BOOLEAN) (*(EIF_BOOLEAN *)(Current+ _CHROFF_1_0_) && EIF_TRUE)) {
-		for (;;) {
-			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || Result)) break;
-			/* INLINED CODE (SPECIAL.item) */
-			ti4_2 = *((EIF_INTEGER_32 *)RTCW(loc3) + (loc1));
-			/* END INLINED CODE */
-			ti4_1 = ti4_2;
-			Result = (EIF_BOOLEAN) (ti4_1 == arg1);
-			loc1++;
-		}
-	} else {
-		for (;;) {
-			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) (loc1 > loc2) || Result)) break;
-			/* INLINED CODE (SPECIAL.item) */
-			ti4_2 = *((EIF_INTEGER_32 *)RTCW(loc3) + (loc1));
-			/* END INLINED CODE */
-			ti4_1 = ti4_2;
-			Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == arg1);
-			loc1++;
-		}
-	}
-	RTLE;
-	return Result;
-}
-
-/* {ARRAY}.new_cursor */
-EIF_REFERENCE F792_5914 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	{
-		static EIF_TYPE_INDEX typarr0[] = {513,0,0,0xFFFF};
-		EIF_TYPE typres0;
-		{
-			EIF_TYPE l_type;
-			l_type = eif_final_id(Y4596,Y4596_gen_type,Dftype(Current),424);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
-		}
-		
-		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 513, _OBJSIZ_2_0_0_3_0_0_0_0_);
-	}
-	F514_5153(RTCW(tr1), Current);
-	RTLE;
-	return (EIF_REFERENCE) tr1;
-}
-
 /* {ARRAY}.lower */
-EIF_INTEGER_32 F792_5915 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F641_3138 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 }
 
 
 /* {ARRAY}.upper */
-EIF_INTEGER_32 F792_5916 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F641_3139 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 }
 
 
 /* {ARRAY}.count */
-EIF_INTEGER_32 F792_5917 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F641_3140 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -240,7 +142,7 @@ EIF_INTEGER_32 F792_5917 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.capacity */
-EIF_INTEGER_32 F792_5918 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F641_3141 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -249,16 +151,17 @@ EIF_INTEGER_32 F792_5918 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.is_equal */
-EIF_BOOLEAN F792_5920 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F641_3143 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
+	EIF_CHARACTER_8 tc1;
+	EIF_CHARACTER_8 tc2;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	RTLD;
@@ -292,16 +195,16 @@ EIF_BOOLEAN F792_5920 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 				loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 				for (;;) {
 					if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !Result || (EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)))) break;
-					ti4_1 = F792_5910(Current, loc1);
-					ti4_2 = F792_5910(RTCW(arg1), loc1);
-					Result = (EIF_BOOLEAN) (ti4_1 == ti4_2);
+					tc1 = F641_3133(Current, loc1);
+					tc2 = F641_3133(RTCW(arg1), loc1);
+					Result = (EIF_BOOLEAN) (tc1 == tc2);
 					loc1++;
 				}
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-				ti4_1 = F792_5917(Current);
-				Result = F1093_8412(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
+				ti4_1 = F641_3140(Current);
+				Result = F616_3055(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
 			}
 		}
 	}
@@ -310,37 +213,20 @@ EIF_BOOLEAN F792_5920 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {ARRAY}.valid_index */
-EIF_BOOLEAN F792_5925 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	
-	
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 <= arg1) && (EIF_BOOLEAN) (arg1 <= ti4_2));
-	return Result;
-}
-
-/* {ARRAY}.extendible */
-EIF_BOOLEAN F792_5926 (EIF_REFERENCE Current)
+EIF_BOOLEAN F641_3148 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	
 	
-	return (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) <= arg1) && (EIF_BOOLEAN) (arg1 <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)));
 }
 
 /* {ARRAY}.put */
-void F792_5929 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F641_3152 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
 	RTLD;
 	
 	RTLI(2);
@@ -350,16 +236,15 @@ void F792_5929 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 	/* INLINED CODE (SPECIAL.put) */
-	*((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - ti4_1))) = arg1;
+	*((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
 /* {ARRAY}.force */
-void F792_5931 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F641_3154 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -373,6 +258,7 @@ void F792_5931 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
 	EIF_INTEGER_32 ti4_2;
+	EIF_CHARACTER_8 tc1;
 	RTCFDT;
 	RTLD;
 	
@@ -391,85 +277,84 @@ void F792_5931 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 	loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))) || (EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L))));
-	if (F792_5962(Current)) {
-		ti4_1 = F625_5225(Current);
+	if (F641_3185(Current)) {
+		ti4_1 = F565_2675(Current);
 		ti4_1 = eif_max_int32 (loc2,ti4_1);
-		F369_4540(Current, ti4_1);
+		F188_1857(Current, ti4_1);
 		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
 			tr1 = *(EIF_REFERENCE *)(Current);
-			F1093_8416(RTCW(tr1), arg1);
+			F616_3059(RTCW(tr1), arg1);
 			if ((EIF_BOOLEAN) !loc7) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,dftype,424), 0x00);
-				ti4_1 = F1066_8379(tr2);
-				F1093_8418(RTCW(tr1), ti4_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tc1 = F769_3884(tr2);
+				F616_3061(RTCW(tr1), tc1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
 			}
 		} else {
 			if ((EIF_BOOLEAN) !loc7) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,dftype,424), 0x00);
-				ti4_1 = F1066_8379(tr2);
-				F1093_8418(RTCW(tr1), ti4_1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tc1 = F769_3884(tr2);
+				F616_3061(RTCW(tr1), tc1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
 			}
 			tr1 = *(EIF_REFERENCE *)(Current);
-			F1093_8416(RTCW(tr1), arg1);
+			F616_3059(RTCW(tr1), arg1);
 		}
 	} else {
 		tr1 = *(EIF_REFERENCE *)(Current);
-		loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+		loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 		if ((EIF_BOOLEAN) (loc2 > loc1)) {
 			tr1 = *(EIF_REFERENCE *)(Current);
-			ti4_1 = F625_5225(Current);
+			ti4_1 = F565_2675(Current);
 			ti4_1 = eif_max_int32 (loc2,(EIF_INTEGER_32) (loc1 + ti4_1));
-			tr1 = (EIF_REFERENCE) eif_builtin_SPECIAL_aliased_resized_area (tr1, ti4_1);
-			F369_4547(Current, tr1);
+			tr1 = F616_3074(tr1, ti4_1);
+			F188_1864(Current, tr1);
 		}
 		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
 			loc6 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 			loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc6 - loc3);
-			loc5 = F792_5918(Current);
+			loc5 = F641_3141(Current);
 			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !loc7 && (EIF_BOOLEAN) (loc6 > loc5))) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,dftype,424), 0x00);
-				ti4_1 = F1066_8379(tr2);
-				F1093_8418(RTCW(tr1), ti4_1, loc5, (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tc1 = F769_3884(tr2);
+				F616_3061(RTCW(tr1), tc1, loc5, (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
 			}
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.overlapping_move) */
-			memmove((EIF_INTEGER_32 *)RTCW(tr1) + (loc6),(EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_INTEGER_32) * (rt_uint_ptr)loc5);
+			memmove((EIF_CHARACTER_8 *)RTCW(tr1) + (loc6),(EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_CHARACTER_8) * (rt_uint_ptr)loc5);
 			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc6 + loc5);
 			/* END INLINED CODE */
 			;
 			if ((EIF_BOOLEAN) !loc7) {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				tr2 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,dftype,424), 0x00);
-				ti4_1 = F1066_8379(tr2);
-				F1093_8418(RTCW(tr1), ti4_1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+				tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+				tc1 = F769_3884(tr2);
+				F616_3061(RTCW(tr1), tc1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
 			}
 			tr1 = *(EIF_REFERENCE *)(Current);
 			/* INLINED CODE (SPECIAL.put) */
-			*((EIF_INTEGER_32 *)RTCW(tr1) + (((EIF_INTEGER_32) 0L))) = arg1;
+			*((EIF_CHARACTER_8 *)RTCW(tr1) + (((EIF_INTEGER_32) 0L))) = arg1;
 			/* END INLINED CODE */
 			;
 		} else {
 			tr1 = *(EIF_REFERENCE *)(Current);
-			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
+			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
 			if ((EIF_BOOLEAN) (loc2 > ti4_1)) {
 				if ((EIF_BOOLEAN) !loc7) {
 					tr1 = *(EIF_REFERENCE *)(Current);
-					tr2 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,dftype,424), 0x00);
-					ti4_1 = F1066_8379(tr2);
+					tr2 = RTLNTY2(eif_final_id(Y2179,Y2179_gen_type,dftype,273), 0x00);
+					tc1 = F769_3884(tr2);
 					tr2 = *(EIF_REFERENCE *)(Current);
-					ti4_2 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr2);
-					F1093_8418(RTCW(tr1), ti4_1, ti4_2, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+					ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr2);
+					F616_3061(RTCW(tr1), tc1, ti4_1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
 				}
 				tr1 = *(EIF_REFERENCE *)(Current);
-				F1093_8416(RTCW(tr1), arg1);
+				F616_3059(RTCW(tr1), arg1);
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
-				ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 				/* INLINED CODE (SPECIAL.put) */
-				*((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - ti4_1))) = arg1;
+				*((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 				/* END INLINED CODE */
 				;
 			}
@@ -481,7 +366,7 @@ void F792_5931 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 }
 
 /* {ARRAY}.subcopy */
-void F792_5934 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+void F641_3157 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -492,9 +377,7 @@ void F792_5934 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	EIF_INTEGER_32 ti4_4;
 	EIF_INTEGER_32 ti4_5;
 	EIF_INTEGER_32 ti4_6;
-	EIF_INTEGER_32 ti4_7;
-	EIF_INTEGER_32 ti4_8;
-	EIF_INTEGER_32 ti4_9;
+	EIF_CHARACTER_8 tc1;
 	RTLD;
 	
 	RTLI(4);
@@ -508,147 +391,16 @@ void F792_5934 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	tr1 = *(EIF_REFERENCE *)(Current);
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 	/* INLINED CODE (SPECIAL.copy_data) */
-	memmove((EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - ti4_2)),(EIF_INTEGER_32 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_INTEGER_32) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
-	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (arg4 - ti4_2) + (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	memmove((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_CHARACTER_8 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_CHARACTER_8) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
-/* {ARRAY}.grow */
-void F792_5948 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 ti4_4;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if ((EIF_BOOLEAN) (arg1 > F792_5918(Current))) {
-		tr1 = RTLNTY2(eif_final_id(Y4596,Y4596_gen_type,Dftype(Current),424), 0x00);
-		ti4_1 = F1066_8379(tr1);
-		ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-		ti4_3 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-		ti4_4 = F792_5918(Current);
-		F792_5950(Current, ti4_1, ti4_2, (EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_3 + arg1) - ti4_4));
-	}
-	RTLE;
-}
-
-/* {ARRAY}.conservative_resize_with_default */
-void F792_5950 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_INTEGER_32 ti4_3;
-	EIF_INTEGER_32 ti4_4;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if (F792_5962(Current)) {
-		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = F1093_8432(RTCW(tr1), arg1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
-		F369_4547(Current, tr1);
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg3;
-	} else {
-		loc2 = eif_min_int32 (arg2,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_));
-		loc3 = eif_max_int32 (arg3,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
-		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 - loc2) + ((EIF_INTEGER_32) 1L));
-		tr1 = *(EIF_REFERENCE *)(Current);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
-		if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
-			tr1 = *(EIF_REFERENCE *)(Current);
-			tr1 = F1093_8432(RTCW(tr1), arg1, loc1);
-			F369_4547(Current, tr1);
-		}
-		if ((EIF_BOOLEAN) (loc2 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
-			loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-			loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - loc2);
-			tr1 = *(EIF_REFERENCE *)(Current);
-			ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-			ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-			/* INLINED CODE (SPECIAL.overlapping_move) */
-			memmove((EIF_INTEGER_32 *)RTCW(tr1) + (loc4),(EIF_INTEGER_32 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_INTEGER_32) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_1 - ti4_2) + ((EIF_INTEGER_32) 1L)));
-			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc4 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_1 - ti4_2) + ((EIF_INTEGER_32) 1L)));
-			/* END INLINED CODE */
-			;
-			tr1 = *(EIF_REFERENCE *)(Current);
-			F1093_8418(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc4 - ((EIF_INTEGER_32) 1L)));
-		}
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc3;
-	}
-	RTLE;
-}
-
-/* {ARRAY}.linear_representation */
-EIF_REFERENCE F792_5957 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	RTLD;
-	
-	RTLI(3);
-	RTLR(0,loc1);
-	RTLR(1,Current);
-	RTLR(2,tr1);
-	RTLIU(3);
-	
-	RTGC;
-	{
-		static EIF_TYPE_INDEX typarr0[] = {860,0,0,0xFFFF};
-		EIF_TYPE typres0;
-		{
-			EIF_TYPE l_type;
-			l_type = eif_final_id(Y4596,Y4596_gen_type,Dftype(Current),424);
-			typarr0[1] = l_type.annotations | 0xFF00;
-			typarr0[2] = l_type.id;
-		}
-		
-		typres0 = eif_compound_id(Dftype(Current), typarr0);
-		tr1 = RTLNS(typres0.id, 860, _OBJSIZ_1_1_0_1_0_0_0_0_);
-	}
-	ti4_1 = F792_5918(Current);
-	F861_6094(RTCW(tr1), ti4_1);
-	loc1 = (EIF_REFERENCE) tr1;
-	loc2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	for (;;) {
-		if ((EIF_BOOLEAN) (loc2 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_))) break;
-		ti4_1 = F792_5910(Current, loc2);
-		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R4746[Dtype(loc1)-715])(RTCW(loc1), (EIF_REFERENCE) &ti4_1);
-		loc2++;
-	}
-	RTLE;
-	return (EIF_REFERENCE) loc1;
-}
-
 /* {ARRAY}.copy */
-void F792_5958 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F641_3181 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -662,25 +414,16 @@ void F792_5958 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
-		eif_builtin_ANY_standard_copy (Current, arg1);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
-		tr1 = (EIF_REFERENCE) eif_builtin_ANY_twin (tr1);
-		F369_4547(Current, tr1);
+		tr1 = F1_14(tr1);
+		F188_1864(Current, tr1);
 	}
 	RTLE;
 }
 
-/* {ARRAY}.extend */
-void F792_5961 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
-{
-	GTCX
-	
-	
-	RTGC;
-}
-
 /* {ARRAY}.empty_area */
-EIF_BOOLEAN F792_5962 (EIF_REFERENCE Current)
+EIF_BOOLEAN F641_3185 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -696,7 +439,7 @@ EIF_BOOLEAN F792_5962 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
 	RTLE;
 	return Result;
