@@ -1,5 +1,5 @@
 /*
- * Code for class ARRAY [NATURAL_32]
+ * Code for class ARRAY [CHARACTER_8]
  */
 
 #include "eif_eiffel.h"
@@ -25,7 +25,7 @@ extern "C" {
 #endif
 
 /* {ARRAY}.make_empty */
-void F642_3184 (EIF_REFERENCE Current)
+void F743_4065 (EIF_REFERENCE Current)
 {
 	GTCX
 	RTLD;
@@ -37,12 +37,12 @@ void F642_3184 (EIF_REFERENCE Current)
 	RTGC;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 0L);
-	F210_1997(Current, ((EIF_INTEGER_32) 0L));
+	F283_2753(Current, ((EIF_INTEGER_32) 0L));
 	RTLE;
 }
 
 /* {ARRAY}.make_filled */
-void F642_3185 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
+void F743_4066 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
@@ -58,16 +58,16 @@ void F642_3185 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2,
 	if ((EIF_BOOLEAN) (arg2 <= arg3)) {
 		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L));
 	}
-	F210_1998(Current, arg1, loc1);
+	F283_2754(Current, arg1, loc1);
 	RTLE;
 }
 
 /* {ARRAY}.make */
-void F642_3186 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
+void F743_4067 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
-	EIF_NATURAL_32 tu4_1;
+	EIF_CHARACTER_8 tc1;
 	RTLD;
 	
 	RTLI(2);
@@ -79,17 +79,17 @@ void F642_3186 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2)
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg1;
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg2;
 	if ((EIF_BOOLEAN) (arg1 <= arg2)) {
-		tr1 = RTLNTY2(eif_final_id(Y2272,Y2272_gen_type,Dftype(Current),294), 0x00);
-		tu4_1 = F739_3674(tr1);
-		F210_1998(Current, tu4_1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
+		tr1 = RTLNTY2(eif_final_id(Y2987,Y2987_gen_type,Dftype(Current),381), 0x00);
+		tc1 = F851_4642(tr1);
+		F283_2754(Current, tc1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg2 - arg1) + ((EIF_INTEGER_32) 1L)));
 	} else {
-		F210_1997(Current, ((EIF_INTEGER_32) 0L));
+		F283_2753(Current, ((EIF_INTEGER_32) 0L));
 	}
 	RTLE;
 }
 
 /* {ARRAY}.make_from_array */
-void F642_3187 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F743_4068 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -104,7 +104,7 @@ void F642_3187 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
-	F210_2004(Current, tr1);
+	F283_2760(Current, tr1);
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ti4_1;
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_0_);
@@ -113,7 +113,7 @@ void F642_3187 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {ARRAY}.make_from_special */
-void F642_3188 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F743_4069 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 ti4_1;
@@ -125,22 +125,22 @@ void F642_3188 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	RTLIU(2);
 	
 	RTGC;
-	F210_2004(Current, arg1);
+	F283_2760(Current, arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (arg1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (arg1);
 	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) ti4_1;
 	RTLE;
 }
 
 /* {ARRAY}.item */
-EIF_NATURAL_32 F642_3190 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_CHARACTER_8 F743_4071 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_NATURAL_32 tu4_1;
-	EIF_NATURAL_32 tu4_2;
-	EIF_NATURAL_32 Result = ((EIF_NATURAL_32) 0);
+	EIF_CHARACTER_8 tc1;
+	EIF_CHARACTER_8 tc2;
+	EIF_CHARACTER_8 Result = ((EIF_CHARACTER_8) 0);
 	
 	RTLD;
 	
@@ -152,29 +152,29 @@ EIF_NATURAL_32 F642_3190 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.item) */
-	tu4_2 = *((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
+	tc2 = *((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg1 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))));
 	/* END INLINED CODE */
-	Result = tu4_2;
+	Result = tc2;
 	RTLE;
 	return Result;
 }
 
 /* {ARRAY}.lower */
-EIF_INTEGER_32 F642_3195 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F743_4076 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 }
 
 
 /* {ARRAY}.upper */
-EIF_INTEGER_32 F642_3196 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F743_4077 (EIF_REFERENCE Current)
 {
 	return *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
 }
 
 
 /* {ARRAY}.count */
-EIF_INTEGER_32 F642_3197 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F743_4078 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -183,7 +183,7 @@ EIF_INTEGER_32 F642_3197 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.capacity */
-EIF_INTEGER_32 F642_3198 (EIF_REFERENCE Current)
+EIF_INTEGER_32 F743_4079 (EIF_REFERENCE Current)
 {
 	GTCX
 	
@@ -192,17 +192,17 @@ EIF_INTEGER_32 F642_3198 (EIF_REFERENCE Current)
 }
 
 /* {ARRAY}.is_equal */
-EIF_BOOLEAN F642_3200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+EIF_BOOLEAN F743_4081 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
 	EIF_REFERENCE tr1 = NULL;
 	EIF_REFERENCE tr2 = NULL;
 	EIF_INTEGER_32 ti4_1;
-	EIF_NATURAL_32 tu4_1;
-	EIF_NATURAL_32 tu4_2;
 	EIF_BOOLEAN tb1;
 	EIF_BOOLEAN tb2;
+	EIF_CHARACTER_8 tc1;
+	EIF_CHARACTER_8 tc2;
 	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	RTLD;
@@ -236,16 +236,16 @@ EIF_BOOLEAN F642_3200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 				loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
 				for (;;) {
 					if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !Result || (EIF_BOOLEAN) (loc1 > *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)))) break;
-					tu4_1 = F642_3190(Current, loc1);
-					tu4_2 = F642_3190(RTCW(arg1), loc1);
-					Result = (EIF_BOOLEAN) (tu4_1 == tu4_2);
+					tc1 = F743_4071(Current, loc1);
+					tc2 = F743_4071(RTCW(arg1), loc1);
+					Result = (EIF_BOOLEAN) (tc1 == tc2);
 					loc1++;
 				}
 			} else {
 				tr1 = *(EIF_REFERENCE *)(Current);
 				tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
-				ti4_1 = F642_3197(Current);
-				Result = F617_3112(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
+				ti4_1 = F743_4078(Current);
+				Result = F718_3993(RTCW(tr1), tr2, ((EIF_INTEGER_32) 0L), ((EIF_INTEGER_32) 0L), ti4_1);
 			}
 		}
 	}
@@ -254,23 +254,16 @@ EIF_BOOLEAN F642_3200 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 }
 
 /* {ARRAY}.valid_index */
-EIF_BOOLEAN F642_3205 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
+EIF_BOOLEAN F743_4086 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
 {
 	GTCX
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
 	
 	
-	
-	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
-	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (ti4_1 <= arg1) && (EIF_BOOLEAN) (arg1 <= ti4_2));
-	return Result;
+	return (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) <= arg1) && (EIF_BOOLEAN) (arg1 <= *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_)));
 }
 
 /* {ARRAY}.put */
-void F642_3209 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
+void F743_4090 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1, EIF_INTEGER_32 arg2)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -285,14 +278,136 @@ void F642_3209 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2)
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
 	/* INLINED CODE (SPECIAL.put) */
-	*((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
+	*((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
+/* {ARRAY}.force */
+void F743_4092 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1, EIF_INTEGER_32 arg2)
+{
+	GTCX
+	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc5 = (EIF_INTEGER_32) 0;
+	EIF_INTEGER_32 loc6 = (EIF_INTEGER_32) 0;
+	EIF_BOOLEAN loc7 = (EIF_BOOLEAN) 0;
+	EIF_REFERENCE tr1 = NULL;
+	EIF_REFERENCE tr2 = NULL;
+	EIF_INTEGER_32 ti4_1;
+	EIF_INTEGER_32 ti4_2;
+	EIF_CHARACTER_8 tc1;
+	RTCFDT;
+	RTLD;
+	
+	RTLI(3);
+	RTLR(0,Current);
+	RTLR(1,tr1);
+	RTLR(2,tr2);
+	RTLIU(3);
+	
+	RTGC;
+	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
+	loc3 = eif_min_int32 (ti4_1,arg2);
+	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
+	loc4 = eif_max_int32 (ti4_1,arg2);
+	loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc4 - loc3) + ((EIF_INTEGER_32) 1L));
+	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_);
+	ti4_2 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
+	loc7 = (EIF_BOOLEAN) (EIF_BOOLEAN) ((EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_1 + ((EIF_INTEGER_32) 1L))) || (EIF_BOOLEAN)(arg2 == (EIF_INTEGER_32) (ti4_2 - ((EIF_INTEGER_32) 1L))));
+	if (F743_4123(Current)) {
+		ti4_1 = F668_3613(Current);
+		ti4_1 = eif_max_int32 (loc2,ti4_1);
+		F283_2753(Current, ti4_1);
+		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
+			tr1 = *(EIF_REFERENCE *)(Current);
+			F718_3997(RTCW(tr1), arg1);
+			if ((EIF_BOOLEAN) !loc7) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2987,Y2987_gen_type,dftype,381), 0x00);
+				tc1 = F851_4642(tr2);
+				F718_3999(RTCW(tr1), tc1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 1L)));
+			}
+		} else {
+			if ((EIF_BOOLEAN) !loc7) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2987,Y2987_gen_type,dftype,381), 0x00);
+				tc1 = F851_4642(tr2);
+				F718_3999(RTCW(tr1), tc1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+			}
+			tr1 = *(EIF_REFERENCE *)(Current);
+			F718_3997(RTCW(tr1), arg1);
+		}
+	} else {
+		tr1 = *(EIF_REFERENCE *)(Current);
+		loc1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
+		if ((EIF_BOOLEAN) (loc2 > loc1)) {
+			tr1 = *(EIF_REFERENCE *)(Current);
+			ti4_1 = F668_3613(Current);
+			ti4_1 = eif_max_int32 (loc2,(EIF_INTEGER_32) (loc1 + ti4_1));
+			tr1 = F718_4012(tr1, ti4_1);
+			F283_2760(Current, tr1);
+		}
+		if ((EIF_BOOLEAN) (loc3 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
+			loc6 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
+			loc6 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc6 - loc3);
+			loc5 = F743_4079(Current);
+			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) !loc7 && (EIF_BOOLEAN) (loc6 > loc5))) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2987,Y2987_gen_type,dftype,381), 0x00);
+				tc1 = F851_4642(tr2);
+				F718_3999(RTCW(tr1), tc1, loc5, (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+			}
+			tr1 = *(EIF_REFERENCE *)(Current);
+			/* INLINED CODE (SPECIAL.overlapping_move) */
+			memmove((EIF_CHARACTER_8 *)RTCW(tr1) + (loc6),(EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_CHARACTER_8) * (rt_uint_ptr)loc5);
+			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc6 + loc5);
+			/* END INLINED CODE */
+			;
+			if ((EIF_BOOLEAN) !loc7) {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				tr2 = RTLNTY2(eif_final_id(Y2987,Y2987_gen_type,dftype,381), 0x00);
+				tc1 = F851_4642(tr2);
+				F718_3999(RTCW(tr1), tc1, ((EIF_INTEGER_32) 1L), (EIF_INTEGER_32) (loc6 - ((EIF_INTEGER_32) 1L)));
+			}
+			tr1 = *(EIF_REFERENCE *)(Current);
+			/* INLINED CODE (SPECIAL.put) */
+			*((EIF_CHARACTER_8 *)RTCW(tr1) + (((EIF_INTEGER_32) 0L))) = arg1;
+			/* END INLINED CODE */
+			;
+		} else {
+			tr1 = *(EIF_REFERENCE *)(Current);
+			ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr1);
+			if ((EIF_BOOLEAN) (loc2 > ti4_1)) {
+				if ((EIF_BOOLEAN) !loc7) {
+					tr1 = *(EIF_REFERENCE *)(Current);
+					tr2 = RTLNTY2(eif_final_id(Y2987,Y2987_gen_type,dftype,381), 0x00);
+					tc1 = F851_4642(tr2);
+					tr2 = *(EIF_REFERENCE *)(Current);
+					ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count__i4 (tr2);
+					F718_3999(RTCW(tr1), tc1, ti4_1, (EIF_INTEGER_32) (loc2 - ((EIF_INTEGER_32) 2L)));
+				}
+				tr1 = *(EIF_REFERENCE *)(Current);
+				F718_3997(RTCW(tr1), arg1);
+			} else {
+				tr1 = *(EIF_REFERENCE *)(Current);
+				/* INLINED CODE (SPECIAL.put) */
+				*((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg2 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)))) = arg1;
+				/* END INLINED CODE */
+				;
+			}
+		}
+	}
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc3;
+	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc4;
+	RTLE;
+}
+
 /* {ARRAY}.subcopy */
-void F642_3214 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
+void F743_4095 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3, EIF_INTEGER_32 arg4)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -303,7 +418,7 @@ void F642_3214 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	EIF_INTEGER_32 ti4_4;
 	EIF_INTEGER_32 ti4_5;
 	EIF_INTEGER_32 ti4_6;
-	EIF_NATURAL_32 tu4_1;
+	EIF_CHARACTER_8 tc1;
 	RTLD;
 	
 	RTLI(4);
@@ -318,69 +433,15 @@ void F642_3214 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_INTEGER_32 arg2,
 	tr2 = *(EIF_REFERENCE *)(RTCW(arg1));
 	ti4_1 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_1_1_0_1_);
 	/* INLINED CODE (SPECIAL.copy_data) */
-	memmove((EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_NATURAL_32 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
+	memmove((EIF_CHARACTER_8 *)RTCW(tr1) + ((EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))),(EIF_CHARACTER_8 *)tr2 + (EIF_INTEGER_32) (arg2 - ti4_1), (rt_uint_ptr)sizeof(EIF_CHARACTER_8) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), (EIF_INTEGER_32) (arg4 - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
 	/* END INLINED CODE */
 	;
 	RTLE;
 }
 
-/* {ARRAY}.conservative_resize_with_default */
-void F642_3230 (EIF_REFERENCE Current, EIF_NATURAL_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
-{
-	GTCX
-	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc3 = (EIF_INTEGER_32) 0;
-	EIF_INTEGER_32 loc4 = (EIF_INTEGER_32) 0;
-	EIF_REFERENCE tr1 = NULL;
-	EIF_INTEGER_32 ti4_1;
-	EIF_INTEGER_32 ti4_2;
-	RTLD;
-	
-	RTLI(2);
-	RTLR(0,Current);
-	RTLR(1,tr1);
-	RTLIU(2);
-	
-	RTGC;
-	if (F642_3242(Current)) {
-		tr1 = *(EIF_REFERENCE *)(Current);
-		tr1 = F617_3132(RTCW(tr1), arg1, (EIF_INTEGER_32) ((EIF_INTEGER_32) (arg3 - arg2) + ((EIF_INTEGER_32) 1L)));
-		F210_2004(Current, tr1);
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) arg2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) arg3;
-	} else {
-		loc2 = eif_min_int32 (arg2,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_));
-		loc3 = eif_max_int32 (arg3,*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_));
-		loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc3 - loc2) + ((EIF_INTEGER_32) 1L));
-		tr1 = *(EIF_REFERENCE *)(Current);
-		ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_count (tr1);
-		if ((EIF_BOOLEAN) (loc1 > ti4_1)) {
-			tr1 = *(EIF_REFERENCE *)(Current);
-			tr1 = F617_3132(RTCW(tr1), arg1, loc1);
-			F210_2004(Current, tr1);
-		}
-		if ((EIF_BOOLEAN) (loc2 < *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_))) {
-			loc4 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_);
-			loc4 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc4 - loc2);
-			tr1 = *(EIF_REFERENCE *)(Current);
-			/* INLINED CODE (SPECIAL.overlapping_move) */
-			memmove((EIF_NATURAL_32 *)RTCW(tr1) + (loc4),(EIF_NATURAL_32 *)RTCW(tr1) + ((EIF_INTEGER_32) 0L), (rt_uint_ptr)sizeof(EIF_NATURAL_32) * (rt_uint_ptr)(EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
-			RT_SPECIAL_COUNT(tr1) = eif_max_int32(RT_SPECIAL_COUNT(tr1), loc4 + (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) - *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_)) + ((EIF_INTEGER_32) 1L)));
-			/* END INLINED CODE */
-			;
-			tr1 = *(EIF_REFERENCE *)(Current);
-			F617_3118(RTCW(tr1), arg1, ((EIF_INTEGER_32) 0L), (EIF_INTEGER_32) (loc4 - ((EIF_INTEGER_32) 1L)));
-		}
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_1_) = (EIF_INTEGER_32) loc2;
-		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_1_0_0_) = (EIF_INTEGER_32) loc3;
-	}
-	RTLE;
-}
-
 /* {ARRAY}.copy */
-void F642_3238 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
+void F743_4119 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -394,16 +455,16 @@ void F642_3238 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
 	
 	RTGC;
 	if ((EIF_BOOLEAN)(arg1 != Current)) {
-		eif_builtin_ANY_standard_copy (Current, arg1);
+		eif_builtin_ANY_standard_copy__o_ (Current, arg1);
 		tr1 = *(EIF_REFERENCE *)(RTCW(arg1));
 		tr1 = F1_14(tr1);
-		F210_2004(Current, tr1);
+		F283_2760(Current, tr1);
 	}
 	RTLE;
 }
 
 /* {ARRAY}.empty_area */
-EIF_BOOLEAN F642_3242 (EIF_REFERENCE Current)
+EIF_BOOLEAN F743_4123 (EIF_REFERENCE Current)
 {
 	GTCX
 	EIF_REFERENCE tr1 = NULL;
@@ -419,7 +480,7 @@ EIF_BOOLEAN F642_3242 (EIF_REFERENCE Current)
 	
 	RTGC;
 	tr1 = *(EIF_REFERENCE *)(Current);
-	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity (tr1);
+	ti4_1 = (EIF_INTEGER_32) eif_builtin_SPECIAL_capacity__i4 (tr1);
 	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ((EIF_INTEGER_32) 0L));
 	RTLE;
 	return Result;
