@@ -1,5 +1,5 @@
 /*
- * Code for class BILINEAR [NATURAL_64]
+ * Code for class BILINEAR [CHARACTER_8]
  */
 
 #include "eif_eiffel.h"
@@ -22,32 +22,12 @@ extern "C" {
 extern "C" {
 #endif
 
-/* {BILINEAR}.off */
-EIF_BOOLEAN F504_4967 (EIF_REFERENCE Current)
-{
-	GTCX
-	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
-	
-	RTLD;
-	
-	RTLI(1);
-	RTLR(0,Current);
-	RTLIU(1);
-	
-	RTGC;
-	Result = '\01';
-	if (!F729_5219(Current)) {
-		Result = F729_5218(Current);
-	}
-	RTLE;
-	return Result;
-}
-
 /* {BILINEAR}.search */
-void F504_4970 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
+void F342_4683 (EIF_REFERENCE Current, EIF_CHARACTER_8 arg1)
 {
 	GTCX
 	EIF_BOOLEAN tb1;
+	RTCDT;
 	RTLD;
 	
 	RTLI(1);
@@ -56,13 +36,13 @@ void F504_4970 (EIF_REFERENCE Current, EIF_NATURAL_64 arg1)
 	
 	RTGC;
 	tb1 = '\0';
-	if (F729_5219(Current)) {
-		tb1 = (EIF_BOOLEAN) !F597_5036(Current);
+	if ((FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4451[dtype-604])(Current)) {
+		tb1 = (EIF_BOOLEAN) !(FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4326[dtype-315])(Current);
 	}
 	if (tb1) {
-		F774_5578(Current);
+		(FUNCTION_CAST(void, (EIF_REFERENCE)) R4450[dtype-604])(Current);
 	}
-	F492_4953(Current, arg1);
+	F330_4666(Current, arg1);
 	RTLE;
 }
 
