@@ -6,9 +6,10 @@
 extern "C" {
 #endif
 
-extern void F413_2646(EIF_REFERENCE);
+extern void F313_4202(EIF_REFERENCE, EIF_CHARACTER_8);
 extern void EIF_Minit754(void);
-extern long O2373[];
+extern char *(*R4032[])();
+extern char *(*R3898[])();
 
 #ifdef __cplusplus
 }
