@@ -6,10 +6,9 @@
 extern "C" {
 #endif
 
-extern void F238_3609(EIF_REFERENCE);
-extern void F238_3610(EIF_REFERENCE);
+extern EIF_BOOLEAN F233_2861(EIF_REFERENCE, EIF_REFERENCE, EIF_REFERENCE);
 extern void EIF_Minit763(void);
-extern long O3490[];
+extern char *(*R3851[])();
 
 #ifdef __cplusplus
 }
