@@ -1,5 +1,5 @@
 /*
- * Code for class CONTAINER [CHARACTER_32]
+ * Code for class CONTAINER [G#1]
  */
 
 #include "eif_eiffel.h"
@@ -23,12 +23,21 @@ extern "C" {
 #endif
 
 /* {CONTAINER}.compare_objects */
-void F161_2531 (EIF_REFERENCE Current)
+void F340_5041 (EIF_REFERENCE Current)
 {
 	GTCX
 	
 	
-	*(EIF_BOOLEAN *)(Current + O1937[Dtype(Current)-155]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+	*(EIF_BOOLEAN *)(Current + O4839[Dtype(Current)-339]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
+}
+
+/* {CONTAINER}.compare_references */
+void F340_5042 (EIF_REFERENCE Current)
+{
+	GTCX
+	
+	
+	*(EIF_BOOLEAN *)(Current + O4839[Dtype(Current)-339]) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
 }
 
 void EIF_Minit764 (void)
