@@ -1,7 +1,7 @@
 /*
 	description: "Thread management routines."
-	date:		"$Date: 2018-02-13 04:57:34 -0800 (Tue, 13 Feb 2018) $"
-	revision:	"$Revision: 101414 $"
+	date:		"$Date: 2022-11-23 16:59:42 +0000 (Wed, 23 Nov 2022) $"
+	revision:	"$Revision: 106406 $"
 	copyright:	"Copyright (c) 1985-2018, Eiffel Software."
 	license:	"GPL version 2 see http://www.eiffel.com/licensing/gpl.txt)"
 	licensing_options:	"Commercial license is available at http://www.eiffel.com/licensing"
@@ -35,7 +35,7 @@
 */
 
 /*
-doc:<file name="eif_thread.c" header="eif_thread.h" version="$Id: eif_threads.c 101414 2018-02-13 12:57:34Z alexk $" summary="Thread management routines">
+doc:<file name="eif_thread.c" header="eif_thread.h" version="$Id: eif_threads.c 106406 2022-11-23 16:59:42Z jfiat $" summary="Thread management routines">
 */
 
 #include "eif_portable.h"
@@ -1068,7 +1068,7 @@ rt_public void eif_thr_exit(void)
 				if (eif_thr_context->set_terminated_func) {
 						/* Set the `terminated' field of the thread object to True so that
 						 * it knows the thread is terminated */
-					eif_thr_context->set_terminated_func(eif_access(eif_thr_context->current), EIF_TRUE);
+					(FUNCTION_CAST(void,(EIF_REFERENCE, EIF_BOOLEAN)) eif_thr_context->set_terminated_func) (eif_access(eif_thr_context->current), EIF_TRUE);
 				}
 			}
 				
